@@ -23,12 +23,7 @@
 
 @TOP@
 
-#undef PACKAGE
-#undef VERSION
-
-/* Always defined */
 #undef D_INO_IN_DIRENT
-#undef IS_AIX
 #undef MOUNTED_FREAD
 #undef MOUNTED_FREAD_FSTYP
 #undef MOUNTED_GETFSSTAT
@@ -51,15 +46,6 @@
 /* Define nlink_t if your system does not provide it */
 #undef nlink_t
 
-/* Does the file command accepts the -L option */
-#undef FILE_L
-
-/* Does the file command work well with - option for stdin? */
-#undef FILE_STDIN
-
-/* Does the grep command work well with - option for stdin? */
-#undef GREP_STDIN
-
 /* Is the program using the GPM library? */
 #undef HAVE_LIBGPM
 
@@ -72,17 +58,9 @@
 /* Is the program using a system-installed slang library? */
 #undef HAVE_SYSTEM_SLANG
 
-/* Define if the slang.h header file is inside a directory slang
-** in the standard directories
-*/
-#undef SLANG_H_INSIDE_SLANG_DIR
-
 /* Does the program have subshell support? */
 #undef HAVE_SUBSHELL_SUPPORT
 
-/* If you don't have gcc, define this */
-#undef OLD_TOOLS 
-
 /* Found some version of curses that we're going to use */
 #undef HAS_CURSES
 
@@ -122,9 +100,6 @@
 /* If you have socket and the rest of the net functions use this */
 #undef USE_NETCODE
 
-/* If defined, use .netrc for FTP connections */
-#undef USE_NETRC 
-
 /* If your operating system does not have enough space for a file name
  * in a struct dirent, then define this
  */
@@ -142,12 +117,6 @@
 /* Defined if you have the crypt prototype in neither unistd.h nor crypt.h */
 #undef NEED_CRYPT_PROTOTYPE
 
-/* Defined if your CPP understands ## macro token pasting method */
-#undef HAVE_PORTABLE_TOKEN_PASTING
-
-/* Define if you want to turn on SCO-specific code */
-#undef SCO_FLAVOR
-
 /* Define if your system has struct linger */
 #undef HAVE_STRUCT_LINGER
 
@@ -163,18 +132,12 @@
 /* Define if you have isascii */
 #undef HAVE_ISASCII
 
-/* Define if you want to use the HSC firewall */
-#undef HSC_PROXY
-
 /* Define if your system uses PAM for auth stuff */
 #undef HAVE_PAM
 
 /* Define if you have the pmap_getmaps function */
 #undef HAVE_PMAP_GETMAPS
 
-/* Define if you have the <sys/select.h> header file.  */
-#undef HAVE_SYS_SELECT_H
-
 /* Define if you have the get_process_stats function and have to use that instead of gettimeofday  */
 #undef HAVE_GET_PROCESS_STATS
 
@@ -202,50 +165,8 @@
 
 #undef WITH_SMBFS
 
-@BOTTOM@
-
-#ifdef HAVE_LIBPT
-#    define HAVE_GRANTPT
-#endif
-
-#if defined(HAVE_LIBCRYPT) || defined(HAVE_LIBCRYPT_I)
-#    define HAVE_CRYPT
-#endif
-
-#if defined(HAVE_SIGADDSET) && defined(HAVE_SIGEMPTYSET)
-# if defined(HAVE_SIGACTION) && defined(HAVE_SIGPROCMASK)
-#  define SLANG_POSIX_SIGNALS
-# endif
-#endif
-
-#ifdef __os2__
-#    define OS2_NT 1
-#    define S_ISFIFO(x) 0
-
-#    define NEEDS_IO_H
-#    define NEEDS_DRIVE_H
-#    define NEEDS_FCNTL_H
-#    define HAS_NO_GRP_PWD_H
-#    define HAS_NO_TERMIOS_H
-#    define HAS_NO_SYS_PARAM_H
-#    define HAS_NO_SYS_IOCTL_H
-
-#    define USE_O_TEXT
-#    define HAS_ACS_AS_PCCHARS
-#    define HAS_DIRECT_COLOR_ACCESS
-#    define NEEDS_CR_LF_TRANSLATION
-#endif
-
-#ifdef _OS_NT
-#    define OS2_NT 1
-#endif
-
-#ifndef OS2_NT
-/* some Unices do not define this, and slang requires it: */
-#ifndef unix
-#    define unix
-#endif
-#endif
-
 #undef HAVE_GNOME_WINDOW_ICON
 
+@BOTTOM@
+
+#include <extraconf.h>
