@@ -47,7 +47,7 @@
      KEY_PPAGE, CK_Page_Up, KEY_NPAGE, CK_Page_Down, KEY_LEFT, CK_Left,
      KEY_RIGHT, CK_Right, KEY_UP, CK_Up, KEY_DOWN, CK_Down, ALT ('\t'), CK_Return, ALT ('\n'), CK_Return,
      KEY_HOME, CK_Home, KEY_END, CK_End, '\t', CK_Tab, XCTRL ('u'), CK_Undo, KEY_IC, CK_Toggle_Insert,
-     XCTRL ('o'), CK_Load, KEY_F (3), CK_Mark, KEY_F (13), CK_Column_Mark, KEY_F (5), CK_Copy,
+     XCTRL ('o'), CK_Shell, KEY_F (3), CK_Mark, KEY_F (13), CK_Column_Mark, KEY_F (5), CK_Copy,
      KEY_F (6), CK_Move, KEY_F (8), CK_Remove, KEY_F (12), CK_Save_As,
      KEY_F (2), CK_Save, XCTRL ('n'), CK_New,
      XCTRL ('l'), CK_Refresh, ESC_CHAR, CK_Exit, KEY_F (10), CK_Exit,
@@ -61,6 +61,7 @@
      KEY_F (4), CK_Replace, KEY_F (7), CK_Find, KEY_F (14), CK_Replace_Again,
      XCTRL ('h'), CK_BackSpace, ALT ('l'), CK_Goto, ALT ('L'), CK_Goto, XCTRL ('y'), CK_Delete_Line,
      KEY_F (17), CK_Find_Again, ALT ('p'), CK_Paragraph_Format,
+     ALT ('b'), CK_Match_Bracket,
      0177, CK_BackSpace,
      0, 0};
 
@@ -69,7 +70,7 @@
      KEY_PPAGE, CK_Page_Up, KEY_NPAGE, CK_Page_Down, KEY_LEFT, CK_Left,
      KEY_RIGHT, CK_Right, KEY_UP, CK_Up, KEY_DOWN, CK_Down, ALT ('\t'), CK_Return, ALT ('\n'), CK_Return,
      KEY_HOME, CK_Home, KEY_END, CK_End, '\t', CK_Tab, XCTRL ('u'), CK_Undo, KEY_IC, CK_Toggle_Insert,
-     XCTRL ('o'), CK_Load, KEY_F (3), CK_Mark, KEY_F (13), CK_Column_Mark, KEY_F (5), CK_Copy,
+     XCTRL ('o'), CK_Shell, KEY_F (3), CK_Mark, KEY_F (13), CK_Column_Mark, KEY_F (5), CK_Copy,
      KEY_F (6), CK_Move, KEY_F (8), CK_Remove, KEY_F (12), CK_Save_As,
      KEY_F (2), CK_Save, ALT ('p'), CK_Paragraph_Format,
 
@@ -145,6 +146,16 @@
 	break;
     }
 
+#ifdef HAVE_CHARSET
+    if (x_key == XCTRL('t')) {
+	do_select_codepage();
+
+	edit->force = REDRAW_COMPLETELY;
+	command = CK_Refresh;
+	goto fin;
+    }
+#endif
+
     if (x_key == XCTRL ('q')) {
 	char_for_insertion = edit_raw_key_query (_(" Insert Literal "), _(" Press any key: "), 0);
 	goto fin;
@@ -190,6 +201,12 @@
 	case KEY_RIGHT:
 	    command = CK_Word_Right_Highlight;
 	    goto fin;
+	case KEY_UP:
+	    command = CK_Scroll_Up_Highlight;
+	    goto fin;
+	case KEY_DOWN:
+	    command = CK_Scroll_Down_Highlight;
+	    goto fin;
 	}
     }
     if ((x_state & SHIFT_PRESSED) && !(x_state & CONTROL_PRESSED)) {
@@ -268,10 +285,17 @@
 	}
     }
 /* an ordinary insertable character */
+
+#ifndef HAVE_CHARSET
     if (x_key < 256 && is_printable (x_key)) {
 	char_for_insertion = x_key;
+#else
+    if (x_key < 256 && is_printable (conv_input [x_key])) {
+	char_for_insertion = conv_input [x_key];
+#endif
 	goto fin;
     }
+
 /* other commands */
     i = 0;
     while (key_map[i] != x_key && (key_map[i] || key_map[i + 1]))
