@@ -29,30 +29,6 @@
 
 static char *panelize_section = "Panelize";
 
-void
-gnome_listing_cmd (GtkWidget *widget, WPanel *panel)
-{
-	int   view_type, use_msformat;
-	char  *user, *status;
-
-	view_type = display_box (panel, &user, &status, &use_msformat, get_current_index ());
-
-	if (view_type == -1)
-		return;
-
-	configure_panel_listing (panel, view_type, use_msformat, user, status);
-}
-
-void
-gnome_compare_panels (void)
-{
-	if (get_other_panel () == NULL){
-		message (1, MSG_ERROR, _(" There is no other panel to compare contents to "));
-		return;
-	}
-	compare_dirs_cmd ();
-}
-
 void
 gnome_open_terminal_with_cmd (const char *command)
 {
@@ -73,7 +49,7 @@ gnome_open_terminal_with_cmd (const char *command)
 			char *q;
 
 			if (quote_all)
-				q = g_strconcat (p, " -e '", command, "'", NULL);
+				q = g_strconcat (p, " --start-factory-server --use-factory -e '", command, "'", NULL);
 			else
 				q = g_strconcat (p, " -e ", command, NULL);
 			my_system (EXECUTE_AS_SHELL, shell, q);
@@ -113,7 +89,7 @@ gnome_about_cmd (void)
 	}
 
         about = gnome_about_new (_("GNU Midnight Commander"), VERSION,
-				 "Copyright 1994-1999 the Free Software Foundation",
+				 "Copyright 1994-2001 the Free Software Foundation",
 				 authors,
 				 _("The GNOME edition of the Midnight Commander file manager."),
 				 NULL);
@@ -416,6 +392,7 @@ get_nickname (gchar *text)
 		break;
 	case 1:
 	default:
+		break;
 	}
 	if (destroy)
 		gtk_widget_destroy (dlg);
@@ -615,6 +592,7 @@ gnome_external_panelize (GtkWidget *widget, WPanel *panel)
 		destroy = FALSE;
 		break;
 	default:
+		break;
 	}
 	for (i = 0; i < GTK_CLIST (data->clist)->rows; i++) {
 		row_data = gtk_clist_get_row_data (GTK_CLIST (data->clist), i);
@@ -724,8 +702,8 @@ gnome_filter_cmd (GtkWidget *widget, WPanel *panel)
 		else
 			text2 = NULL;
 	} else {
-		text1 = ("mc_filter_regexps");
-		text3 = _(".");
+		text1 = "mc_filter_regexps";
+		text3 = "^.*$";
 		if (!panel->filter)
 			text2 = NULL;
 		else
@@ -984,14 +962,10 @@ set_cursor_busy (WPanel *panel)
 void
 set_cursor_normal (WPanel *panel)
 {
-	GdkCursor *cursor;
-
 	if (is_a_desktop_panel (panel))
 		return;
 
-	cursor = gdk_cursor_new (GDK_TOP_LEFT_ARROW);
-	gdk_window_set_cursor (GTK_WIDGET (panel->xwindow)->window, cursor);
-	gdk_cursor_destroy (cursor);
+	gdk_window_set_cursor (GTK_WIDGET (panel->xwindow)->window, NULL);
 	gdk_flush ();
 }
 
@@ -999,6 +973,7 @@ void
 gnome_new_link (GtkWidget *widget, WPanel *panel)
 {
 	char *template;
+	char *icon;
 	char *url;
 
 	url = input_expand_dialog (_("Creating a desktop link"),
@@ -1006,15 +981,12 @@ gnome_new_link (GtkWidget *widget, WPanel *panel)
 	if (!url)
 		return;
 
-	template = g_concat_dir_and_file (desktop_directory, "urlXXXXXX");
+	template = g_concat_dir_and_file (desktop_directory, "url");
 
-	if (mktemp (template)) {
-		char *icon;
+	icon = g_concat_dir_and_file (ICONDIR, "gnome-http-url.png");
+	desktop_create_url (template, url, url, icon, TRUE);
 
-		icon = g_concat_dir_and_file (ICONDIR, "gnome-http-url.png");
-		desktop_create_url (template, url, url, icon);
-		g_free (icon);
-	}
+	g_free (icon);
 	g_free (template);
 	g_free (url);
 }
