@@ -15,10 +15,11 @@
 
 /* The ORB and the POA */
 extern CORBA_ORB orb;
-PortableServer_POA poa;
+extern PortableServer_POA poa;
 
 
 int corba_init_server (void);
+void corba_activate_server (void);
 void corba_create_window (char *dir);
 
 
