@@ -7,9 +7,9 @@
 
 #include <config.h>
 #include <unistd.h>
+#include "x.h"
 #include "main.h"
 #include "util.h"
-#include <libgnome/libgnome.h>
 #include "gdesktop.h"
 #include "gdesktop-init.h"
 #include "gprint.h"
@@ -58,7 +58,7 @@ desktop_load_init_from (const char *file)
 			if (url && *url){
 				char *filename = g_concat_dir_and_file (desktop_directory, key);
 
-				desktop_create_url (filename, title, url, icon2);
+				desktop_create_url (filename, title, url, icon2, FALSE);
 				g_free (filename);
 			}
 
