@@ -32,6 +32,7 @@
 #include "../vfs/vfs.h"
 #include "main.h"
 #include "gmount.h"
+#include "gprefs.h"
 
 
 struct layout_slot {
@@ -2505,12 +2506,15 @@ migrate_init (void)
 static void
 create_desktop_dir (void)
 {
+	char *desktop_symlink;
+	
 	if (getenv ("GNOME_DESKTOP_DIR") != NULL)
 		desktop_directory = g_strdup (getenv ("GNOME_DESKTOP_DIR"));
 	else
 		desktop_directory = g_concat_dir_and_file (gnome_user_home_dir, DESKTOP_DIR_NAME);
 
 	if (!g_file_exists (desktop_directory)) {
+
 		/* Create the directory */
 		mkdir (desktop_directory, 0777);
 
@@ -2520,6 +2524,15 @@ create_desktop_dir (void)
 		gmount_setup_devices ();
 		gprint_setup_devices ();
 	}
+
+	/* Create a user-visible symlink at ~/Desktop */
+	desktop_symlink = g_concat_dir_and_file (gnome_user_home_dir, "Desktop");
+
+	if (! g_file_exists (desktop_symlink))
+		symlink (desktop_directory, desktop_symlink);
+
+	g_free (desktop_symlink);
+
 	migrate_init ();
 }
 
@@ -2939,7 +2952,7 @@ new_terminal (GtkWidget *widget, gpointer data)
 	if (is_a_desktop_panel (cpanel))
 		mc_chdir (home_dir);
 
-	gnome_open_terminal_with_cmd ("--use-factory --start-factory-server");
+	gnome_open_terminal ();
 }
 
 static GnomeUIInfo gnome_panel_new_menu [] = {
@@ -3580,21 +3593,36 @@ desktop_destroy (void)
 }
 
 void
-desktop_create_url (const char *filename, const char *title, const char *url, const char *icon)
+desktop_create_url (const char *filename, const char *title,
+		    const char *url, const char *icon, gboolean is_template)
 {
 	FILE *f;
+	char *tmpname = NULL;
 
-	f = fopen (filename, "w");
-	if (f) {
+	if (is_template) {
+		int fd;
 
-		fprintf (f, "URL: %s\n", url);
-		fclose (f);
-
-		gnome_metadata_set (filename, "desktop-url",
-				    strlen (url) + 1, url);
-		gnome_metadata_set (filename, "icon-caption",
-				    strlen (title) + 1, title);
-
-		gnome_metadata_set (filename, "icon-filename", strlen (icon) + 1, icon);
+		fd = mc_mkstemps (&tmpname, filename, NULL);
+		if (fd == -1)
+			return;
+		f = fdopen (fd, "w");
+		filename = tmpname;
+	} else {
+		f = fopen (filename, "w");
 	}
+
+	if (!f) {
+		g_free (tmpname);
+		return;
+	}
+
+	fprintf (f, "URL: %s\n", url);
+	fclose (f);
+
+	gnome_metadata_set (filename, "desktop-url",
+			    strlen (url) + 1, url);
+	gnome_metadata_set (filename, "icon-caption",
+			    strlen (title) + 1, title);
+
+	gnome_metadata_set (filename, "icon-filename", strlen (icon) + 1, icon);
 }
