@@ -2,7 +2,7 @@
 /* New dialogs... */
 #include <config.h>
 #include "panel.h"
-#include <gnome.h>
+#include "x.h"
 #include "dialog.h"
 #include "global.h"
 #include "file.h"
@@ -244,7 +244,7 @@ file_progress_show (FileOpContext *ctx, long done, long total)
 
         if (total > 0) {
                 perc = (double) done / (double) total;
-                snprintf (count, 9, "%3d%% ", (gint) (100.0 * perc));
+                g_snprintf (count, 9, "%3d%% ", (gint) (100.0 * perc));
                 gtk_label_set_text (GTK_LABEL (ui->file_label), count);
         }
         while (gtk_events_pending ())
@@ -269,7 +269,7 @@ file_progress_show_count (FileOpContext *ctx, long done, long total)
         if (ui->aborting)
                 return FILE_ABORT;
 
-        snprintf (count, 100, "%ld/%ld ", done, total);
+        g_snprintf (count, 100, "%ld/%ld ", done, total);
         gtk_label_set_text (GTK_LABEL (ui->count_label), count);
         while (gtk_events_pending ())
                 gtk_main_iteration ();
@@ -484,7 +484,7 @@ file_progress_real_query_replace (FileOpContext *ctx, enum OperationMode mode, c
                                            GNOME_STOCK_BUTTON_CANCEL, NULL);
 
                 gtk_window_set_position (GTK_WINDOW (qr_dlg), GTK_WIN_POS_MOUSE);
-                snprintf (msg, sizeof (msg)-1, _("The target file already exists: %s"), destname);
+                g_snprintf (msg, sizeof (msg)-1, _("The target file already exists: %s"), destname);
                 label = gtk_label_new (msg);
                 gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
                 gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
@@ -564,12 +564,19 @@ file_mask_dialog (FileOpContext *ctx, FileOperation operation, char *text, char
         ctx->stable_symlinks = 0;
 
         /* Basic window */
-        if (operation == OP_COPY)
+	switch (operation) {
+	case OP_COPY:
                 fmd_win = gnome_dialog_new (_("Copy"), GNOME_STOCK_BUTTON_OK,
                                             GNOME_STOCK_BUTTON_CANCEL, NULL);
-        else if (operation == OP_MOVE)
+		break;
+	case OP_MOVE:
                 fmd_win = gnome_dialog_new (_("Move"), GNOME_STOCK_BUTTON_OK,
                                             GNOME_STOCK_BUTTON_CANCEL, NULL);
+		break;
+	default:
+		g_assert_not_reached ();
+		return NULL; /* keep -Wall happy */
+	}
 
         gtk_window_set_position (GTK_WINDOW (fmd_win), GTK_WIN_POS_MOUSE);
 
@@ -814,6 +821,7 @@ file_delete_query_recursive (FileOpContext *ctx, enum OperationMode mode, gchar
                         ctx->recursive_result = RECURSIVE_ABORT;
                         break;
                 default:
+                        break;
                 }
 
                 if (ctx->recursive_result != RECURSIVE_ABORT)
@@ -1092,3 +1100,101 @@ symlink_dialog (char *existing, char *new, char **ret_existing, char **ret_new)
         if (ret != -1)
                 gtk_widget_destroy (dialog);
 }
+
+#ifdef WITH_SMBFS
+struct smb_authinfo *
+vfs_smb_get_authinfo (const char *host, const char *share, const char *domain,
+		      const char *user)
+{
+	struct smb_authinfo *return_value;
+	GtkWidget *smbauth_dialog;
+	GtkWidget *domain_entry, *user_entry, *passwd_entry;
+	GtkWidget *domain_label, *user_label, *passwd_label;
+
+	char *title;
+	static char* labs[] = {N_("Domain:"), N_("Username:"), N_("Password: ")};
+
+	if (!domain)
+	    domain = "";
+	if (!user)
+	    user = "";
+
+	title = g_strdup_printf (_("Password for \\\\%s\\%s"), host, share);
+
+	/* Create dialog */
+	smbauth_dialog =
+	    gnome_dialog_new(title, GNOME_STOCK_BUTTON_OK,
+			     GNOME_STOCK_BUTTON_CANCEL, NULL);
+	g_free (title);
+	gmc_window_setup_from_panel(GNOME_DIALOG(smbauth_dialog), cpanel);
+
+	domain_label = gtk_label_new(_(labs[0]));
+	gtk_misc_set_alignment(GTK_MISC(domain_label), 0.0, 0.5);
+	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(smbauth_dialog)->vbox), domain_label, FALSE,
+			   FALSE, 0);
+
+	domain_entry = gnome_entry_new("domain");
+	gnome_entry_load_history(GNOME_ENTRY(domain_entry));
+	gtk_entry_set_text(GTK_ENTRY(gnome_entry_gtk_entry(GNOME_ENTRY(domain_entry))),
+			   domain);
+	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(smbauth_dialog)->vbox), domain_entry, FALSE,
+			   FALSE, 0);
+
+	user_label = gtk_label_new(_(labs[1]));
+	gtk_misc_set_alignment(GTK_MISC(user_label), 0.0, 0.5);
+	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(smbauth_dialog)->vbox), user_label, FALSE,
+			   FALSE, 0);
+
+	user_entry = gnome_entry_new("user");
+	gnome_entry_load_history(GNOME_ENTRY(user_entry));
+	gtk_entry_set_text(GTK_ENTRY(gnome_entry_gtk_entry(GNOME_ENTRY(user_entry))),
+			   user);
+	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(smbauth_dialog)->vbox), user_entry, FALSE,
+			   FALSE, 0);
+
+	passwd_label = gtk_label_new(_(labs[2]));
+	gtk_misc_set_alignment(GTK_MISC(passwd_label), 0.0, 0.5);
+	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(smbauth_dialog)->vbox), passwd_label, FALSE,
+			   FALSE, 0);
+
+	passwd_entry = gtk_entry_new();
+	gtk_entry_set_text(GTK_ENTRY(passwd_entry), "");
+	gtk_entry_set_visibility(GTK_ENTRY(passwd_entry), FALSE);
+	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(smbauth_dialog)->vbox), passwd_entry, FALSE,
+			   FALSE, 0);
+
+	gtk_widget_grab_focus(passwd_entry);
+	gnome_dialog_set_default(GNOME_DIALOG(smbauth_dialog), 0);
+
+	gtk_widget_show_all(GNOME_DIALOG(smbauth_dialog)->vbox);
+
+	switch (gnome_dialog_run(GNOME_DIALOG(smbauth_dialog))) {
+	case 0:
+		return_value = g_new (struct smb_authinfo, 1);
+		if (!return_value)
+			break;
+
+		return_value->host = g_strdup (host);
+		return_value->share = g_strdup (share);
+		return_value->domain =
+			g_strdup(gtk_entry_get_text
+				 (GTK_ENTRY(gnome_entry_gtk_entry(GNOME_ENTRY(domain_entry)))));
+		return_value->user =
+			g_strdup(gtk_entry_get_text
+				 (GTK_ENTRY(gnome_entry_gtk_entry(GNOME_ENTRY(user_entry)))));
+		return_value->password = g_strdup(gtk_entry_get_text(GTK_ENTRY(passwd_entry)));
+		break;
+
+	case 1:
+		return_value = 0;
+		break;
+
+	default:
+		return 0;
+	}
+
+	gtk_widget_destroy(smbauth_dialog);
+
+	return return_value;
+}
+#endif /* WITH_SMBFS */
