@@ -10,6 +10,7 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 #include "global.h"
+#include "x.h"
 #include "file.h"
 #include "fileopctx.h"
 #include "main.h"
@@ -17,7 +18,6 @@
 #include "ext.h"
 #include "gscreen.h"
 #include "../vfs/vfs.h"
-#include <gdk/gdkprivate.h>
 #include "gdesktop.h"
 #include "gdnd.h"
 #include "gmain.h"
@@ -262,20 +262,27 @@ static void
 drop_url_on_directory (GdkDragContext *context, GtkSelectionData *selection_data, char *destdir)
 {
 	char *template;
+	char *icon;
+	char *url;
+	char *title;
 
-	template = g_concat_dir_and_file (destdir, "urlXXXXXX");
+	template = g_concat_dir_and_file (destdir, "url");
+	icon = g_concat_dir_and_file (ICONDIR, "gnome-http-url.png");
 
-	if (mktemp (template)) {
-		char *icon;
-
-		icon = g_concat_dir_and_file (ICONDIR, "gnome-http-url.png");
-		desktop_create_url (
-			template,
-			selection_data->data,
-			selection_data->data,
-			icon);
-		g_free (icon);
+	/* Mozilla uses newline to separate URL from title.  */
+	url = g_strdup(selection_data->data);
+	title = strchr (url, '\n');
+	if (title) {
+		title[0] = 0;
+		title++;
+	} else {
+		title = url;
 	}
+
+	desktop_create_url (template, title, url, icon, TRUE);
+
+	g_free (url);
+	g_free (icon);
 	g_free (template);
 }
 
@@ -533,8 +540,8 @@ gdnd_validate_action (GdkDragContext *context,
 		      int on_desktop, int same_process, int same_source,
 		      char *dest_full_name, file_entry *dest_fe, int dest_selected)
 {
-	int on_directory;
-	int on_exe;
+	int on_directory = 0;
+	int on_exe = 0;
 
 	g_return_val_if_fail (context != NULL, 0);
 	g_return_val_if_fail (dest_full_name != NULL, 0);
