@@ -21,7 +21,6 @@
 #include "boxes.h"
 #include "panelize.h"
 #include "gcmd.h"
-#include "gcliplabel.h"
 #include "gdesktop.h"
 #include "setup.h"
 #include "../vfs/vfs.h"
@@ -71,12 +70,6 @@ GnomeUIInfo panel_view_toolbar_uiinfo[] = {
 
 GList *containers = 0;
 
-int output_lines = 0;
-int command_prompt = 1;
-int keybar_visible = 1;
-int message_visible = 1;
-int xterm_hintbar = 0;
-
 PanelContainer *current_panel_ptr, *other_panel_ptr;
 
 WPanel *
@@ -294,14 +287,18 @@ save_panel_types (void)
 			panel_save_setup (pc->panel, pc->panel->panel_name);
 	}
 }
+
 static void
 run_cmd (void)
 {
-	char *cmd;
+	char *cmd = _("Enter command to run");
 
-	cmd = input_dialog (_("Enter command to run"), _("Enter command to run"), "");
-	if (cmd && *cmd){
-		my_system (EXECUTE_AS_SHELL, shell, cmd);
+	cmd = input_dialog (cmd, cmd, "");
+	if (cmd){
+		if (*cmd){
+			my_system (EXECUTE_AS_SHELL, shell, cmd);
+		}
+		g_free (cmd);
 	}
 }
 
@@ -319,6 +316,7 @@ gnome_exit (void)
 		GNOME_STOCK_BUTTON_YES,
 		GNOME_STOCK_BUTTON_NO,
 		NULL);
+	gmc_window_setup_from_panel (GNOME_DIALOG (w), cpanel);
 	v = gnome_dialog_run (GNOME_DIALOG (w));
 	if (v != 0)
 		return;
@@ -332,6 +330,7 @@ gnome_exit (void)
 		GNOME_STOCK_BUTTON_OK,
 		GNOME_STOCK_BUTTON_CANCEL,
 		NULL);
+	gmc_window_setup_from_panel (GNOME_DIALOG (w), cpanel);
 	v = gnome_dialog_run (GNOME_DIALOG (w));
 	if (v == 0) {
 		/*
@@ -418,8 +417,8 @@ GnomeUIInfo gnome_panel_settings_menu [] = {
 };
 
 GnomeUIInfo gnome_panel_layout_menu [] = {
-	GNOMEUIINFO_ITEM_NONE(N_("_Sort By..."),     N_("Confirmation settings"), gnome_sort_cmd),
-	GNOMEUIINFO_ITEM_NONE(N_("_Filter View..."),    N_("Global option settings"), gnome_filter_cmd),
+	GNOMEUIINFO_ITEM_NONE(N_("_Sort By..."),     N_("Filename sort order"), gnome_sort_cmd),
+	GNOMEUIINFO_ITEM_NONE(N_("_Filter View..."),    N_("Filename filtering settings"), gnome_filter_cmd),
 	GNOMEUIINFO_SEPARATOR,
         GNOMEUIINFO_RADIOLIST(panel_view_menu_uiinfo),
 	GNOMEUIINFO_END
@@ -539,15 +538,14 @@ create_new_menu_from (char *file, GtkWidget *shell, gint pos)
 
 	g_return_val_if_fail (shell != NULL, pos);
 
+	if (shell == NULL){
+		return pos;
+	}
+
 	dir = opendir (file);
 	if (dir == NULL)
 		return pos;
 
-	if (shell == NULL){
-		closedir (dir);
-		return pos;
-	}
-
 	while ((dirstruc = readdir (dir)) != NULL){
 		if (dirstruc->d_name[0] == '.')
 			continue;
@@ -623,20 +621,24 @@ create_new_menu (GnomeApp *app, WPanel *panel)
 	gchar *file, *file2;
 	gint pos;
 	GtkWidget *shell;
+	GList *child_list;
 
-	shell = gnome_app_find_menu_pos (app->menubar, _("File/New/Directory..."), &pos);
+	shell = gnome_panel_new_menu[0].widget->parent;
 
 	file = gnome_unconditional_datadir_file ("mc/templates");
+
+	child_list = gtk_container_children (GTK_CONTAINER (shell));
+	pos = g_list_length (child_list);
 	pos = create_new_menu_from (file, shell, pos);
 
 	file2 = gnome_datadir_file ("mc/templates");
 	if (file2 != NULL){
 		if (strcmp (file, file2) != 0)
 			create_new_menu_from (file2, shell, pos);
+		g_free (file2);
 	}
 
 	g_free (file);
-	g_free (file2);
 }
 
 /*
