@@ -29,6 +29,10 @@
 #include "cmd.h"
 #include <gdk/gdkx.h>
 
+#ifdef HAVE_GNOME_WINDOW_ICON
+#include <libgnomeui/gnome-window-icon.h>
+#endif
+
 GdkColorContext *mc_cc;
 
 #define MAX_COLOR_PAIRS 40
@@ -65,12 +69,6 @@ extern int finish_program;
 /* Whether the gmc server was present or not */
 int corba_have_server = FALSE;
 
-/* This is only used by the editor, so we provide a dummy implementation */
-void
-try_alloc_color_pair (char *str, char *str2)
-{
-}
-
 void
 init_pair (int index, GdkColor *fore, GdkColor *back)
 {
@@ -126,12 +124,6 @@ interactive_display (char *filename, char *node)
 	/* FIXME: Implement gnome version */
 }
 
-void
-beep (void)
-{
-	gdk_beep ();
-}
-
 void
 xtoolkit_end (void)
 {
@@ -216,7 +208,7 @@ bind_gtk_keys (GtkWidget *w, Dlg_head *h)
 widget_data
 xtoolkit_create_dialog (Dlg_head *h, int flags)
 {
-	GtkWidget *win, *ted;
+	GtkWidget *win;
 
 	if (!(flags & DLG_NO_TOPLEVEL)){
 		if (flags & DLG_GNOME_APP)
@@ -224,6 +216,9 @@ xtoolkit_create_dialog (Dlg_head *h, int flags)
 		else {
 			win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 			gtk_window_set_position (GTK_WINDOW (win), GTK_WIN_POS_MOUSE);
+#ifdef HAVE_GNOME_WINDOW_ICON
+			gnome_window_icon_set_from_default (GTK_WINDOW (win));
+#endif
 		}
 	} else
 		win = 0;
@@ -232,11 +227,7 @@ xtoolkit_create_dialog (Dlg_head *h, int flags)
 	h->idle_fn_tag = -1;
 	if (!(flags & DLG_NO_TED)){
 		g_warning ("Should never use GtkTed!!!  Write a real dialog!!!");
-		ted = gtk_ted_new_layout (h->name, LIBDIR "/layout");
-		gtk_container_add (GTK_CONTAINER (win), ted);
-		gtk_widget_show (ted);
-
-		bind_gtk_keys (GTK_WIDGET (ted), h);
+		g_assert_not_reached ();
 	}
 	if (win){
 		bind_gtk_keys (GTK_WIDGET (win), h);
@@ -257,7 +248,7 @@ x_dlg_set_window (Dlg_head *h, GtkWidget *win)
 }
 
 void
-x_set_dialog_title (Dlg_head *h, char *title)
+x_set_dialog_title (Dlg_head *h, const char *title)
 {
 	gtk_window_set_title (GTK_WINDOW (h->wdata), title);
 }
@@ -268,6 +259,9 @@ xtoolkit_get_main_dialog (Dlg_head *h)
 	GtkWidget *win;
 
 	win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+#ifdef HAVE_GNOME_WINDOW_ICON
+	gnome_window_icon_set_from_default (GTK_WINDOW (win));
+#endif
 	return (widget_data) win;
 }
 
@@ -278,6 +272,9 @@ x_create_panel_container (int which)
 	GtkWidget *win;
 
 	win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+#ifdef HAVE_GNOME_WINDOW_ICON
+	gnome_window_icon_set_from_default (GTK_WINDOW (win));
+#endif
 	return (widget_data) 0;
 }
 
@@ -333,8 +330,10 @@ x_init_dlg (Dlg_head *h)
 		gtk_widget_show (GTK_WIDGET (h->wdata));
 	}
 
-	gtk_signal_connect (GTK_OBJECT (h->wdata), "delete_event",
-			    GTK_SIGNAL_FUNC (gnome_dlg_send_destroy), h);
+	if (!(h->grided & DLG_GNOME_APP)) {
+		gtk_signal_connect (GTK_OBJECT ((void *)h->wdata), "delete_event",
+				    GTK_SIGNAL_FUNC (gnome_dlg_send_destroy), h);
+	}
 
 	if (h->current)
 		x_focus_widget (h->current);
@@ -467,17 +466,6 @@ dialog_panel_callback (struct Dlg_head *h, int id, int msg)
 	return 0;
 }
 
-/* Ugly function to support the hack described in non_corba_create_panels() */
-static gint
-idle_destroy_panel (gpointer data)
-{
-	WPanel *panel;
-
-	panel = data;
-	gnome_close_panel (GTK_WIDGET (panel->widget.wdata), panel);
-	return FALSE;
-}
-
 /* Initializes the desktop and creates the initial panels.  This is to be used
  * when we do not have a CORBA server.
  */
@@ -487,7 +475,6 @@ non_corba_create_panels (char *startup_dir)
 	desktop_init ();
 	gnome_init_panels ();
 
-	cmdline = command_new (0, 0, 0);
 	the_hint = label_new (0, 0, 0, NULL);
 	desktop_dlg = create_dlg (0, 0, 24, 80, 0,
 				  dialog_panel_callback, "[panel]", "midnight", DLG_NO_TED);
@@ -532,7 +519,9 @@ void
 gmc_window_setup_from_panel (GnomeDialog *dialog, WPanel *panel)
 {
 	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
-	gnome_dialog_set_parent (dialog, GTK_WINDOW (panel->xwindow));
+	if (panel && panel->xwindow) {
+		gnome_dialog_set_parent (dialog, GTK_WINDOW (panel->xwindow));
+	}
 }
 
 /**
@@ -546,16 +535,38 @@ void
 gnome_check_super_user (void)
 {
 	GtkWidget *warning_dlg;
+	GtkWidget *cbox;
+
+	gboolean show_dialog;
 
 	if (geteuid () != 0)
 		return;
 
+	gnome_config_push_prefix( "/gmc/Root/");
+	show_dialog = gnome_config_get_bool ("show_dialog=true");
+	gnome_config_pop_prefix ();
+	if (!show_dialog)
+		return;
+
+	cbox = gtk_check_button_new_with_label (_("Don't show this window again"));
 	warning_dlg = gnome_message_box_new (
 		_("You are running the GNOME File Manager as root.\n\n"
-		  "As root, you can damage your system if you are not careful, and the "
-		  "GNOME File Manager will not stop you from doing it."),
+		  "As root, you can damage your system, and the "
+		  "File Manager will not stop you.\n"
+		  "Your manual explains how to add a non-privileged user "
+		  "account to the system.\n"),
 		GNOME_MESSAGE_BOX_WARNING,
 		GNOME_STOCK_BUTTON_OK, NULL);
-
+	gtk_widget_show (cbox);
+	gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (warning_dlg)->vbox), cbox, FALSE, FALSE, 0);
+	gnome_dialog_close_hides (GNOME_DIALOG (warning_dlg), TRUE);
 	gnome_dialog_run_and_close (GNOME_DIALOG (warning_dlg));
+	if (GTK_TOGGLE_BUTTON (cbox)->active) {
+		gnome_config_push_prefix( "/gmc/Root/");
+		gnome_config_set_bool ("show_dialog", FALSE);
+		gnome_config_pop_prefix ();
+	}
+	gnome_config_sync ();
+	gtk_widget_destroy (warning_dlg);
 }
+
