@@ -295,10 +295,12 @@ gnome_open_dialog_generate_tree_helper (GtkCTree *ctree, GtkCTreeNode *parent, G
 }
 
 /* Stolen from gnome-core/panel/menu.c */
+#define MAX_ORDER_ENTRY 1024
+
 static GSList *
 get_presorted_from(char *dir)
 {
-	char buf[PATH_MAX+1];
+	char buf[MAX_ORDER_ENTRY];
 	GSList *list = NULL;
 	char *fname = g_concat_dir_and_file(dir,".order");
 	FILE *fp = fopen(fname,"r");
@@ -307,7 +309,7 @@ get_presorted_from(char *dir)
 		g_free(fname);
 		return NULL;
 	}
-	while(fgets(buf,PATH_MAX+1,fp)!=NULL) {
+	while(fgets(buf, sizeof (buf), fp) != NULL) {
 		char *p = strchr(buf,'\n');
 		if(p) *p = '\0';
 		list = g_slist_prepend(list,g_strdup(buf));
@@ -347,8 +349,6 @@ gnome_open_dialog_get_tree (GnomeOpenDialog *dialog)
 	/* widget stuff */
 	retval = gtk_ctree_new (1, 0);
         gtk_clist_set_row_height(GTK_CLIST (retval),20);
-        gtk_ctree_set_line_style (GTK_CTREE (retval), GTK_CTREE_LINES_DOTTED);
-        gtk_ctree_set_expander_style (GTK_CTREE (retval), GTK_CTREE_EXPANDER_SQUARE);
         gtk_clist_set_column_width(GTK_CLIST (retval), 0, 150);
         gtk_signal_connect( GTK_OBJECT (retval),
 			    "tree_select_row",
