@@ -132,6 +132,7 @@ static Property confirmation_props [] =
         PROPERTIES_DONE
 };
 
+#ifdef USE_VFS
 static Property vfs_props [] =
 {
         {
@@ -148,6 +149,7 @@ static Property vfs_props [] =
         },
         PROPERTIES_DONE
 };
+#endif /* !USE_VFS */
 
 static Property caching_and_optimization_props [] =
 {
@@ -159,10 +161,12 @@ static Property caching_and_optimization_props [] =
                 N_("Compute totals before copying files"), PROPERTY_BOOL,
                 &file_op_compute_totals, NULL, NULL, NULL
         },
+#ifdef USE_VFS
         {
                 N_("FTP directory cache timeout :"), PROPERTY_INT,
                 &ftpfs_directory_timeout, N_("Seconds"), NULL, NULL
         },
+#endif /* !USE_VFS */
         {
                 N_("Allow customization of icons in icon view"), PROPERTY_BOOL,
                 &we_can_afford_the_speed, NULL, NULL, NULL
@@ -180,10 +184,12 @@ static PrefsPage prefs_pages [] =
                 N_("Confirmation"),
                 confirmation_props
         },
+#ifdef USE_VFS
         {
                 N_("VFS"),
                 vfs_props
         },
+#endif /* !USE_VFS */
         {
                 N_("Caching"),
                 caching_and_optimization_props
@@ -372,7 +378,7 @@ create_prop_int (PrefsDlg *dlg, Property *prop)
 
         entry = gnome_entry_new (_(prop->label));
 
-        snprintf (buffer, 9, "%d", *( (int*) prop->property_variable));
+        g_snprintf (buffer, 9, "%d", *( (int*) prop->property_variable));
 
         gtk_entry_set_text (GTK_ENTRY (gnome_entry_gtk_entry (GNOME_ENTRY (entry))),
                             buffer);
@@ -473,7 +479,9 @@ create_prop_box (PrefsDlg *dlg)
         PrefsPage *cur_page;
 
 	dlg->prop_box = gnome_property_box_new ();
-	gnome_dialog_set_parent (GNOME_DIALOG (dlg->prop_box), GTK_WINDOW (dlg->panel->xwindow));
+	if (dlg->panel)
+		gnome_dialog_set_parent (GNOME_DIALOG (dlg->prop_box), 
+					 GTK_WINDOW (dlg->panel->xwindow));
 	gtk_window_set_modal (GTK_WINDOW (dlg->prop_box), TRUE);
 	gtk_window_set_title (GTK_WINDOW (dlg->prop_box), _("Preferences"));
 
@@ -488,8 +496,10 @@ create_prop_box (PrefsDlg *dlg)
 	dlg->desktop_prefs = desktop_prefs_new (GNOME_PROPERTY_BOX (dlg->prop_box));
 	dlg->desktop_prefs_page = i++;
 
-	dlg->custom_layout = custom_layout_create_page (GNOME_PROPERTY_BOX (dlg->prop_box),
-							dlg->panel);
+	if (dlg->panel)
+		dlg->custom_layout = custom_layout_create_page (
+			GNOME_PROPERTY_BOX (dlg->prop_box), dlg->panel);
+
 	dlg->custom_layout_page = i;
 
         gtk_signal_connect (GTK_OBJECT (dlg->prop_box), "apply",
@@ -499,7 +509,8 @@ create_prop_box (PrefsDlg *dlg)
 }
 
 void
-gnome_configure_box (GtkWidget *widget, WPanel *panel)
+gnome_configure_box_with_desktop (GtkWidget *widget, WPanel *panel, 
+				  gboolean desktop)
 {
 	static PrefsDlg dlg;
 
@@ -507,5 +518,17 @@ gnome_configure_box (GtkWidget *widget, WPanel *panel)
         dlg.prefs_pages = prefs_pages;
 
         create_prop_box (&dlg);
+
+	if (desktop)
+		gtk_notebook_set_page (
+			GTK_NOTEBOOK (GNOME_PROPERTY_BOX (
+				dlg.prop_box)->notebook),
+			dlg.desktop_prefs_page);
         gtk_widget_show (dlg.prop_box);
 }
+
+void
+gnome_configure_box (GtkWidget *widget, WPanel *panel)
+{
+	gnome_configure_box_with_desktop (widget, panel, FALSE);
+}
