@@ -6,9 +6,9 @@
  */
 
 #include <config.h>
+#include "x.h"
 #include "main.h"
 #include "util.h"
-#include <libgnome/libgnome.h>
 #include "gdesktop.h"
 #include "gprint.h"
 
