@@ -32,10 +32,8 @@
 #include "gdesktop.h"
 #include "gdnd.h"
 #include "gtkdtree.h"
-#include "gpageprop.h"
 #include "gpopup.h"
 #include "gcmd.h"
-#include "gcliplabel.h"
 #include "gicon.h"
 #include "gtkflist.h"
 #include "../vfs/vfs.h"
@@ -331,10 +329,9 @@ x_fill_panel (WPanel *panel)
 	gtk_signal_handler_block_by_data (GTK_OBJECT (panel->tree), panel);
 
 	if (vfs_current_is_local ()){
-		char buffer [MC_MAXPATHLEN];
-
-		get_current_wd (buffer, sizeof (buffer)-1);
-		gtk_dtree_select_dir (GTK_DTREE (panel->tree), buffer);
+		char *cur_dir = g_get_current_dir ();
+		gtk_dtree_select_dir (GTK_DTREE (panel->tree), cur_dir);
+		g_free (cur_dir);
 	} else
 		gtk_dtree_select_dir (GTK_DTREE (panel->tree), panel->cwd);
 
@@ -698,10 +695,10 @@ panel_drag_data_delete (GtkWidget *widget, GdkDragContext *context, WPanel *pane
 static void
 drop_on_panel (WPanel *panel, int idx, GdkDragContext *context, GtkSelectionData *selection_data)
 {
-	char *file;
-	file_entry *fe;
 	int drop_on_dir;
 	int reload;
+	char *file = NULL;
+	file_entry *fe = NULL;
 
 	g_assert (panel != NULL);
 	g_assert (idx == -1 || idx < panel->count);
@@ -1323,19 +1320,6 @@ panel_icon_list_select_icon (GtkWidget *widget, int index, GdkEvent *event, WPan
 
 		break;
 
-	case GDK_BUTTON_RELEASE:
-		if (event->button.button == 2){
-			char *fullname;
-
-			if (S_ISDIR (panel->dir.list [index].buf.st_mode) ||
-			    panel->dir.list [index].f.link_to_dir){
-				fullname = concat_dir_and_file (panel->cwd, panel->dir.list [index].fname);
-				new_panel_at (fullname);
-				g_free (fullname);
-			}
-		}
-		break;
-
 	case GDK_2BUTTON_PRESS:
 		if (event->button.button == 1) {
 			do_enter (panel);
@@ -1455,7 +1439,7 @@ file_list_popup (GdkEventButton *event, WPanel *panel)
 
 	trash_dir = g_strconcat (gnome_user_home_dir, "/",
 				 DESKTOP_DIR_NAME, "/",
-				 "Trash",
+				 "Trash.gmc",
 				 NULL);
 
 	if ((strncmp (panel->cwd, trash_dir, strlen (trash_dir)) == 0) && (panel->count != 1))
@@ -1523,6 +1507,23 @@ static int
 panel_icon_list_button_release (GtkWidget *widget, GdkEventButton *event, WPanel *panel)
 {
 	panel->maybe_start_drag = 0;
+	if (event->button == 2){
+		char *fullname;
+		int icon;
+		file_entry *fe;
+
+		GnomeIconList *gil = GNOME_ICON_LIST (widget);
+		icon = gnome_icon_list_get_icon_at (gil, event->x, event->y);
+		fe = &panel->dir.list [icon];
+
+		if (S_ISDIR (fe->buf.st_mode) || fe->f.link_to_dir){
+			fullname = concat_dir_and_file (panel->cwd, fe->fname);
+			new_panel_at (fullname);
+			g_free (fullname);
+		}
+		return TRUE;
+	}
+
 	return FALSE;
 }
 
@@ -1729,27 +1730,22 @@ panel_chdir (GtkDTree *dtree, char *path, WPanel *panel)
 	show_dir (panel);
 }
 
-static void
-set_cursor (WPanel *panel, GdkCursorType type)
-{
-	GdkCursor *cursor;
-
-	cursor = gdk_cursor_new (type);
-	gdk_window_set_cursor (GTK_WIDGET (panel->xwindow)->window, cursor);
-	gdk_cursor_destroy (cursor);
-	gdk_flush ();
-}
-
 static void
 panel_tree_scan_begin (GtkWidget *widget, gpointer data)
 {
-	set_cursor (data, GDK_WATCH);
+	WPanel *panel;
+
+	panel = data;
+	set_cursor_busy (panel);
 }
 
 static void
 panel_tree_scan_end (GtkWidget *widget, gpointer data)
 {
-	set_cursor (data, GDK_TOP_LEFT_ARROW);
+	WPanel *panel;
+
+	panel = data;
+	set_cursor_normal (panel);
 }
 
 /* Handler for the possibly_ungrab signal of the dtree widget */
@@ -1860,7 +1856,6 @@ panel_tree_check_auto_expand (WPanel *panel, GtkCTreeNode *current)
 	GtkCList *clist;
 	GList *free_list;
 	GList *tmp_list;
-	gint row, old_y, new_y;
 
 	dtree = GTK_DTREE (panel->tree);
 	ctree = GTK_CTREE (panel->tree);
@@ -1876,6 +1871,8 @@ panel_tree_check_auto_expand (WPanel *panel, GtkCTreeNode *current)
 	 * "current" stays the same place on the screen.
 	 */
 	if (tmp_list) {
+		gint row, new_y;
+		gint old_y = 0;
 		if (current) {
 			row = g_list_position (clist->row_list, (GList *) current);
 			old_y = row * clist->row_height - clist->vadjustment->value;
@@ -2139,6 +2136,38 @@ panel_tree_button_press (GtkWidget *widget, GdkEventButton *event, WPanel *panel
 }
 #endif
 
+/*
+ * Middle click on the directory tree opens a new window.
+ */
+static void
+panel_tree_button_release (GtkWidget *widget, GdkEventButton *event, WPanel *panel)
+{
+	GtkDTree *dtree;
+	GtkCTreeNode *node;
+	int row;
+	char *path;
+
+	if (event->type != GDK_BUTTON_RELEASE)
+		return;
+
+	if (event->button != 2)
+		return;
+
+	dtree = GTK_DTREE (widget);
+	if (!gtk_clist_get_selection_info (GTK_CLIST (dtree), event->x, event->y, &row, NULL))
+		return;
+
+	node = gtk_ctree_node_nth (GTK_CTREE (dtree), row);
+	if (!node)
+		return;
+
+	path = gtk_dtree_get_row_path (dtree, node);
+	if (!path)
+		return;
+
+	new_panel_at (path);
+}
+
 /**
  * panel_create_tree_view:
  *
@@ -2200,6 +2229,9 @@ panel_create_tree_view (WPanel *panel)
 				  GTK_SIGNAL_FUNC (panel_tree_button_press), panel);
 	gtk_clist_set_button_actions (GTK_CLIST (tree), 2, GTK_BUTTON_SELECTS);
 #endif
+
+	gtk_signal_connect_after (GTK_OBJECT (tree), "button_release_event",
+				  GTK_SIGNAL_FUNC (panel_tree_button_release), panel);
 	return tree;
 }
 
@@ -2310,7 +2342,10 @@ tree_size_allocate (GtkWidget *widget, GtkAllocation *allocation, WPanel *panel)
 	} else {
 		tree_panel_visible = allocation->width;
 	}
-	save_setup ();
+
+	if (auto_save_setup) {
+		save_setup ();
+	}
 }
 
 void
