@@ -7,6 +7,9 @@
  *
  */
 #include <config.h>
+#ifdef HAVE_ALLOCA_H
+#include <alloca.h>
+#endif
 #include "global.h"
 #include <gnome.h>
 #include <sys/types.h>
@@ -776,7 +779,7 @@ gtk_dtree_construct (GtkDTree *dtree)
 	gtk_clist_set_column_auto_resize (clist, 0, TRUE);
 	gtk_clist_columns_autosize (clist);
 
-	gtk_ctree_set_line_style (ctree, GTK_CTREE_LINES_DOTTED);
+	/*gtk_ctree_set_line_style (ctree, GTK_CTREE_LINES_DOTTED);*/
 	gtk_clist_set_reorderable (GTK_CLIST (ctree), FALSE);
 
 	gdk_dtree_load_pixmaps (dtree);
