@@ -4,6 +4,8 @@
    
    Authors: 1996, 1997 Paul Sheer
 
+   $Id: edit.c,v 1.24 2001/08/12 18:02:56 proskin Exp $
+
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -38,7 +40,12 @@
 #include "mad.h"
 #endif
 
-#include <../src/dialog.h> /* MSG_ERROR */
+#include "../src/dialog.h" /* MSG_ERROR */
+
+#ifdef HAVE_CHARSET
+#include "../src/charsets.h"
+#include "../src/selcodepage.h"
+#endif
 
 extern char *edit_one_file;
 
@@ -113,7 +120,7 @@ char *edit_get_buffer_as_text (WEdit * e)
 /* Note on CRLF->LF translation: */
 
 #if MY_O_TEXT
-#error MY_O_TEXT is depreciated. CR_LF_TRANSLATION must be defined which does CR-LF translation internally. See note in source.
+ #error "MY_O_TEXT is depreciated. CR_LF_TRANSLATION must be defined which does CR-LF translation internally. See note in source."
 #endif
 
 /* 
@@ -182,7 +189,7 @@ int init_dynamic_edit_buffers (WEdit * edit, const char *filename, const char *t
 /* detecting an error on read, is not so easy 'cos there is not way to tell
    whether you read everything or not. */
 /* FIXME: add proper `triple_pipe_open' to read, write and check errors. */
-static struct edit_filters {
+static const struct edit_filters {
     char *read, *write, *extension;
 } all_filters[] = {
 
@@ -226,7 +233,7 @@ char *edit_get_filter (const char *filename)
     return p;
 }
 
-char *edit_get_write_filter (char *writename, char *filename)
+char *edit_get_write_filter (char *writename, const char *filename)
 {
     int i, l;
     char *p;
@@ -280,7 +287,7 @@ long edit_write_stream (WEdit * edit, FILE * f)
     }
     return i;
 }
-#else
+#else /* CR_LF_TRANSLATION */
 long edit_insert_stream (WEdit * edit, FILE * f)
 {
     int c;
@@ -299,7 +306,7 @@ long edit_write_stream (WEdit * edit, FILE * f)
 	    break;
     return i;
 }
-#endif
+#endif /* CR_LF_TRANSLATION */
 
 #define TEMP_BUF_LEN 1024
 
@@ -370,7 +377,7 @@ static int check_file_access (WEdit *edit, const char *filename, struct stat *st
     if ((file = open ((char *) filename, O_RDONLY)) < 0) {
 	close (creat ((char *) filename, 0666));
 	if ((file = open ((char *) filename, O_RDONLY)) < 0) {
-	    edit_error_dialog (_ (" Error "), get_sys_error (catstrs (" Fail trying to open the file, ", filename, ", for reading ", 0)));
+	    edit_error_dialog (_ (" Error "), get_sys_error (catstrs (_ (" Failed trying to open file for reading: "), filename, " ", 0)));
 	    return 2;
 	}
     }
@@ -420,7 +427,7 @@ int edit_open_file (WEdit * edit, const char *filename, const char *text, unsign
 #endif
 	if (r)
 	    return 1;
-	edit->stat = st;
+	edit->stat1 = st;
 #ifndef CR_LF_TRANSLATION
 	edit->last_byte = st.st_size;
 #else
@@ -444,10 +451,10 @@ void edit_set_space_width (int s)
     space_width = s;
 }
 
-#endif
-
 int (*edit_file_is_open) (char *) = 0;
 
+#endif
+
 /* fills in the edit struct. returns 0 on fail. Pass edit as NULL for this */
 WEdit *edit_init (WEdit * edit, int lines, int columns, const char *filename, const char *text, const char *dir, unsigned long text_size)
 {
@@ -461,6 +468,30 @@ WEdit *edit_init (WEdit * edit, int lines, int columns, const char *filename, co
 	edit_set_space_width (FONT_PER_CHAR[' ']);
 #endif
     if (!edit) {
+#ifdef ENABLE_NLS
+	/* 
+	 * Expand option_whole_chars_search by national letters using
+	 * current locale
+	 */
+
+	static char option_whole_chars_search_buf [256];
+
+	if (option_whole_chars_search_buf != option_whole_chars_search) {
+	    int i;
+	    int len = strlen (option_whole_chars_search);
+
+	    strcpy (option_whole_chars_search_buf, option_whole_chars_search);
+
+	    for (i = 1; i <= sizeof (option_whole_chars_search_buf); i++) {
+		if (islower (i) && !strchr (option_whole_chars_search, i)) {
+		    option_whole_chars_search_buf [len++] = i;
+		}
+	    }
+
+	    option_whole_chars_search_buf [len] = 0;
+	    option_whole_chars_search = option_whole_chars_search_buf;
+	}
+#endif	/* ENABLE_NLS */
 	edit = malloc (sizeof (WEdit));
 	memset (edit, 0, sizeof (WEdit));
 	to_free = 1;
@@ -471,21 +502,23 @@ WEdit *edit_init (WEdit * edit, int lines, int columns, const char *filename, co
 #endif
     edit->num_widget_lines = lines;
     edit->num_widget_columns = columns;
-    edit->stat.st_mode = S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH;
-    edit->stat.st_uid = getuid ();
-    edit->stat.st_gid = getgid ();
+    edit->stat1.st_mode = S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH;
+    edit->stat1.st_uid = getuid ();
+    edit->stat1.st_gid = getgid ();
     edit->bracket = -1;
     if (!dir)
 	dir = "";
     f = (char *) filename;
     if (filename) {
 	f = catstrs (dir, filename, 0);
+#ifndef MIDNIGHT
 	if (edit_file_is_open)
 	    if ((*edit_file_is_open) (f)) {
 		if (to_free)
 		    free (edit);
 		return 0;
 	    }
+#endif
     }
     if (edit_find_filter (f) < 0) {
 #ifdef CR_LF_TRANSLATION
@@ -526,7 +559,7 @@ WEdit *edit_init (WEdit * edit, int lines, int columns, const char *filename, co
 		free (edit);
 	    return 0;
 	}
-	edit->stat = st;
+	edit->stat1 = st;
 	if (!edit_insert_file (edit, f)) {
 	    edit_clean (edit);
 	    if (to_free)
@@ -1213,7 +1246,7 @@ long edit_move_forward3 (WEdit * edit, long current, int cols, long upto)
 		return p;
 	}
     }
-    return (float) col;
+    return col;
 }
 #endif
 
@@ -1811,9 +1844,7 @@ void edit_do_undo (WEdit * edit)
 
 static void edit_delete_to_line_end (WEdit * edit)
 {
-    for (;;) {
-	if (edit_get_byte (edit, edit->curs1) == '\n')
-	    break;
+    while (edit_get_byte (edit, edit->curs1) != '\n') {
 	if (!edit->curs2)
 	    break;
 	edit_delete (edit);
@@ -1822,9 +1853,7 @@ static void edit_delete_to_line_end (WEdit * edit)
 
 static void edit_delete_to_line_begin (WEdit * edit)
 {
-    for (;;) {
-	if (edit_get_byte (edit, edit->curs1 - 1) == '\n')
-	    break;
+    while (edit_get_byte (edit, edit->curs1 - 1) != '\n') {
 	if (!edit->curs1)
 	    break;
 	edit_backspace (edit);
@@ -2138,17 +2167,16 @@ int edit_execute_key_command (WEdit * edit, int command, int char_for_insertion)
 
 #ifdef MIDNIGHT
 static const char *shell_cmd[] = SHELL_COMMANDS_i
+void edit_mail_dialog (WEdit * edit);
+
 #else
 static void (*user_commamd) (WEdit *, int) = 0;
 void edit_set_user_command (void (*func) (WEdit *, int))
 {
     user_commamd = func;
 }
-
 #endif
 
-void edit_mail_dialog (WEdit * edit);
-
 /* 
    This executes a command at a lower level than macro recording.
    It also does not push a key_press onto the undo stack. This means
@@ -2279,11 +2307,11 @@ int edit_execute_cmd (WEdit * edit, int command, int char_for_insertion)
 	    if (option_return_does_auto_indent)
 		edit_auto_indent (edit, 0, 1);
 	    format_paragraph (edit, 0);
-	} else if (option_return_does_auto_indent) {
-	    edit_insert (edit, '\n');
-	    edit_auto_indent (edit, 0, 1);
 	} else {
 	    edit_insert (edit, '\n');
+	    if (option_return_does_auto_indent) {
+		edit_auto_indent (edit, 0, 1);
+	    }
 	}
 	break;
     case CK_Return:
@@ -2542,10 +2570,11 @@ int edit_execute_cmd (WEdit * edit, int command, int char_for_insertion)
 	    time_t t;
 #ifdef HAVE_STRFTIME
 	    char s[1024];
+	    static const char time_format[] = "%c";
 #endif
 	    time (&t);
 #ifdef HAVE_STRFTIME
-	    strftime (s, 1024, "%c", localtime (&t));
+	    strftime (s, sizeof (s), time_format, localtime (&t));
 	    edit_printf (edit, s);
 #else
 	    edit_printf (edit, ctime (&t));
@@ -2566,14 +2595,16 @@ int edit_execute_cmd (WEdit * edit, int command, int char_for_insertion)
     case CK_Match_Bracket:
 	edit_goto_matching_bracket (edit);
 	break;
+#ifndef GTK
     case CK_User_Menu:
 	if (edit_one_file) {
-	    message (1, MSG_ERROR, _("User menu avalaible only in mcedit invoked from mc"));
+	    message (1, MSG_ERROR, _("User menu available only in mcedit invoked from mc"));
 	    break;
 	}    
 	else
 	    user_menu (edit);
 	break;
+#endif /* !GTK */
 #ifdef MIDNIGHT
     case CK_Sort:
 	edit_sort_cmd (edit);
@@ -2581,7 +2612,10 @@ int edit_execute_cmd (WEdit * edit, int command, int char_for_insertion)
     case CK_Mail:
 	edit_mail_dialog (edit);
 	break;
-#endif
+    case CK_Shell:
+	view_other_cmd ();
+	break;
+#endif /* MIDNIGHT */
 
 /* These commands are not handled and must be handled by the user application */
 #ifndef MIDNIGHT
@@ -2726,6 +2760,7 @@ void edit_execute_macro (WEdit * edit, struct macro macro[], int n)
     edit_update_screen (edit);
 }
 
+#ifndef GTK
 /* User edit menu, like user menu (F2) but only in editor. */
 void user_menu (WEdit *edit)
 {
@@ -2756,16 +2791,16 @@ void user_menu (WEdit *edit)
                 edit_cursor_to_bol (edit);
                 edit_insert_file (edit, block_file);
                 edit_cursor_to_eol (edit);
-                if (fd = fopen (block_file, "w")) fclose(fd);
+                if ((fd = fopen (block_file, "w"))) fclose(fd);
             }
         } else { /* it is error */
                 edit_cursor_to_bol (edit);
 		edit_insert_file (edit, error_file);
-		if (fd = fopen (error_file, "w")) fclose(fd);
-		if (fd = fopen (block_file, "w")) fclose(fd);
+		if ((fd = fopen (error_file, "w"))) fclose(fd);
+		if ((fd = fopen (block_file, "w"))) fclose(fd);
         }
     } else {
-        edit_error_dialog (_(""),
+	edit_error_dialog ("",
         get_sys_error (catstrs (_ ("Error trying to stat file:"),
 	    						    error_file, 0)));
         return;
@@ -2774,13 +2809,4 @@ void user_menu (WEdit *edit)
     edit->force |= REDRAW_COMPLETELY;
     return;
 }
-
-void edit_init_file()
-{
-    FILE *f;
-
-    if (f = fopen (catstrs (home_dir, ERROR_FILE, 0), "w")) fclose(f);
-    if (f = fopen (catstrs (home_dir, BLOCK_FILE, 0), "w")) fclose(f);
-    if (f = fopen (catstrs (home_dir, TEMP_FILE, 0) , "w")) fclose(f);
-    return;
-}
+#endif /* !GTK */
