@@ -23,6 +23,10 @@
 #ifndef __EDIT_H
 #define __EDIT_H
 
+#ifdef HAVE_SYS_PARAM_H
+#    include <sys/param.h>
+#endif
+
 #ifdef MIDNIGHT
 
 #ifdef HAVE_SLANG
@@ -104,9 +108,9 @@
 #    include "coollocal.h"
 #    include "stringtools.h"
 #else
-#    include "gtk/gtk.h"
-#    include "gdk/gdkprivate.h"
-#    include "gdk/gdk.h"
+#    include <gtk/gtk.h>
+#    include <gdk/gdkprivate.h>
+#    include <gdk/gdk.h>
 #    include "gtkedit.h"
 #    include "editcmddef.h"
 #    ifndef _
@@ -128,6 +132,7 @@
 #    include "src/help.h"
 #    include "src/key.h"
 #    include "src/wtools.h"		/* for QuickWidgets */
+#    include "src/cmd.h"		/* for menu_edit_cmd */
 #    include "src/win.h"
 #    include "vfs/vfs.h"
 #    include "src/menu.h"
@@ -165,6 +170,8 @@
 #      define N_(x) x
 #   endif
 #include "vfs/vfs.h"
+#include "src/dialog.h"		/* for input_dialog() */
+#include "src/util.h"		/* for is_printable() */
 #    define CDisplay gdk_display
 #    define CRoot gdk_root_parent
 #    define Window GtkEdit *
@@ -461,6 +468,8 @@ void user_menu (WEdit *edit);
 
 #ifdef MIDNIGHT
 
+#include "src/user.h" /* for user_menu_cmd, must be after edit-widget.h */
+
 #define CPushFont(x,y)
 #define CPopFont()
 #define FIXED_FONT 1
@@ -622,14 +631,10 @@ extern Display             *gdk_display;
 extern Window               gdk_root_window;
 */
 
-enum {
- match_file, match_normal
-};
-
 #        define edit_get_load_file(d,f,h) gtk_edit_dialog_get_load_file(d,f,h)
 #        define edit_get_save_file(d,f,h) gtk_edit_dialog_get_save_file(d,f,h)
 #        define edit_error_dialog(h,t) gtk_edit_dialog_error(h,"%s",t)
-#        define edit_message_dialog(h,t) gtk_edit_dialog_message(0,h,"%s",t)
+#        define edit_message_dialog(h,t) gtk_edit_dialog_message(h,"%s",t)
 #        define edit_query_dialog2(h,t,a,b) gtk_edit_dialog_query(h,t,a,b,0)
 #        define edit_query_dialog3(h,t,a,b,c) gtk_edit_dialog_query(h,t,a,b,c,0)
 #        define edit_query_dialog4(h,t,a,b,c,d) gtk_edit_dialog_query(h,t,a,b,c,d,0)
@@ -741,6 +746,7 @@ extern int current_selection;
    or EDIT_KEY_EMULATION_EMACS
  */
 extern int edit_key_emulation;
+extern WEdit *wedit;
 #endif	/* ! MIDNIGHT */
 
 extern int option_word_wrap_line_length;
