@@ -4,7 +4,7 @@
 
    Authors: 1996, 1997 Paul Sheer
 
-   $Id: editcmd.c,v 1.32 2001/04/06 21:48:11 proskin Exp $
+   $Id: editcmd.c,v 1.47 2001/08/23 17:21:13 proskin Exp $
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -41,6 +41,10 @@
 #endif
 #endif
 
+#ifdef HAVE_CHARSET
+#include "../src/charsets.h"
+#endif
+
 /* globals: */
 
 /* search and replace: */
@@ -165,9 +169,7 @@ char *catstrs (const char *first,...)
 
 void edit_help_cmd (WEdit * edit)
 {
-    char *hlpdir = concat_dir_and_file (mc_home, _("mc.hlp"));
-    interactive_display (hlpdir, "[Internal File Editor]");
-    free (hlpdir);
+    interactive_display (NULL, "[Internal File Editor]");
     edit->force |= REDRAW_COMPLETELY;
 }
 
@@ -259,15 +261,27 @@ int edit_save_file (WEdit * edit, const char *filename)
 
     savename = (char *) strdup ((char *) filename);
 
-    if ((fd = open (savename, O_WRONLY)) == -1) {
-	this_save_mode = 0;	/* the file does not exists yet, so no safe save or backup necessary */
+    if (vfs_file_is_local (filename)) {
+	if ((fd = open (savename, O_WRONLY)) == -1) {
+	    /*
+	     * The file does not exists yet, so no safe save or
+	     * backup are necessary.
+	     */
+	    this_save_mode = 0;
+	} else {
+	    close (fd);
+	    this_save_mode = option_save_mode;
+	}
     } else {
-	close (fd);
-	this_save_mode = option_save_mode;
+	/*
+	 * FIXME - rename is not impemented in VFS, so only
+	 * quick save is possible.
+	 */
+	this_save_mode = 0;
     }
 
     if (this_save_mode > 0) {
-	char *savedir, *slashpos;
+	char *savedir, *slashpos, *saveprefix;
 	savedir = (char *) strdup (".");
 	slashpos = strrchr (filename, '/');
 	if (slashpos) {
@@ -277,17 +291,25 @@ int edit_save_file (WEdit * edit, const char *filename)
 	}
 	if (savename)
 	    free (savename);
-	savename = (char *) tempnam (savedir, "cooledit");
+	saveprefix = concat_dir_and_file (savedir, "cooledit");
+	fd = mc_mkstemps(&savename, saveprefix, NULL);
+	g_free (saveprefix);
 	free (savedir);
 	if (!savename)
 	    return 0;
+	/*
+	 * Close for now because it needs to be reopened by
+	 * VFS-aware mc_open() and MY_O_TEXT should be used.
+	 */
+	close (fd);
     }
 
-    if ((fd = open (savename, O_CREAT | O_WRONLY | O_TRUNC | MY_O_TEXT, edit->stat.st_mode)) == -1)
+    if ((fd = open (savename, O_CREAT | O_WRONLY | O_TRUNC | MY_O_TEXT,
+		    edit->stat1.st_mode)) == -1)
 	goto error_save;
 
-    chmod (savename, edit->stat.st_mode);
-    chown (savename, edit->stat.st_uid, edit->stat.st_gid);
+    chmod (savename, edit->stat1.st_mode);
+    chown (savename, edit->stat1.st_uid, edit->stat1.st_gid);
 
 /* pipe save */
     if ((p = (char *) edit_get_write_filter (savename, filename))) {
@@ -393,7 +415,7 @@ void menu_save_mode_cmd (void)
 	{quick_button, 6, DLG_X, 7, DLG_Y, N_("&Ok"), 0,
 	 B_ENTER, 0, 0, "o"},
 	{quick_input, 23, DLG_X, 5, DLG_Y, 0, 9,
-	 0, 0, &str_result, "i"},
+	 0, 0, &str_result, "edit-backup-ext"},
 	{quick_label, 22, DLG_X, 4, DLG_Y, N_("Extension:"), 0,
 	 0, 0, 0, "savemext"},
 	{quick_radio, 4, DLG_X, 3, DLG_Y, "", 3,
@@ -406,10 +428,33 @@ void menu_save_mode_cmd (void)
 
     if (!i18n_flag) {
         int i;
+	int maxlen = 0;
+	int dlg_x;
+	int l1;
+
+	/* Ok/Cancel buttons */
+	l1 = strlen (_(widgets[0].text)) + strlen (_(widgets[1].text)) + 5;
+	maxlen = max (maxlen, l1);
         
-        for (i = 0; i < 3; i++ )
+        for (i = 0; i < 3; i++ ) {
             str[i] = _(str[i]);
+	    maxlen = max (maxlen, strlen (str[i]) + 7);
+	}
         i18n_flag = 1;
+
+        dlg_x = maxlen + strlen (_(widgets[3].text)) + 5 + 1;
+        widgets[2].hotkey_pos = strlen (_(widgets[3].text)); /* input field length */
+        dlg_x = min (COLS, dlg_x);
+	dialog.xlen = dlg_x;
+
+        i = (dlg_x - l1)/3;
+	widgets[1].relative_x = i;
+	widgets[0].relative_x = i + strlen (_(widgets[1].text)) + i + 4;
+
+	widgets[2].relative_x = widgets[3].relative_x = maxlen + 2;
+
+	for (i = 0; i < sizeof (widgets)/sizeof (widgets[0]); i++)
+		widgets[i].x_divisions = dlg_x;
     }
 
     widgets[2].text = option_backup_ext;
@@ -437,27 +482,23 @@ void edit_split_filename (WEdit * edit, const char *f)
 
 #ifdef GTK
 
-static char cwd[1040];
 
-static char *canonicalize_pathname (const char *p)
+static char *edit_canonicalize_pathname (const char *p)
 {
     char *q, *r;
     char *t = NULL;
+    char *cwd;
 
     if (*p != '/') {
-	if (strlen (cwd) == 0) {
-#ifdef HAVE_GETCWD
-	    getcwd (cwd, MAX_PATH_LEN);
-#else
-	    getwd (cwd);
-#endif
-	}
-	t = malloc (strlen (cwd) + strlen (p) + 2);
+	cwd = g_get_current_dir ();
+	t = g_malloc (strlen (cwd) + strlen (p) + 2);
 	strcpy (t, cwd);
 	strcat (t, "/");
 	strcat (t, p);
+	g_free (cwd);
 	p = t;
     }
+
     r = q = malloc (strlen (p) + 2);
     while (*p) {
 	if (*p != '/') {
@@ -481,8 +522,7 @@ static char *canonicalize_pathname (const char *p)
 	    q++;
 	}
     }
-    if (t)
-	free (t);
+    g_free (t);
     *q = '\0';
 /* get rid of trailing / */
     if (r[0] && r[1])
@@ -498,7 +538,7 @@ void edit_split_filename (WEdit * edit, const char *longname)
 {
     char *exp, *p;
 #ifdef	GTK
-    exp = canonicalize_pathname (longname);
+    exp = edit_canonicalize_pathname (longname);
 #else
     exp = pathdup (longname);	/* this ensures a full path */
 #endif
@@ -1202,7 +1242,16 @@ int edit_replace_prompt (WEdit * edit, char *replace_text, int xpos, int ypos)
 	 0, 0, 0, 0, 0},
 	{0}};
 
+#ifndef HAVE_CHARSET
     quick_widgets[5].text = catstrs (_ (" Replace with: "), replace_text, 0);
+#else
+    char *msg; 
+
+    quick_widgets[5].text = catstrs (msg = _(" Replace with: "), replace_text, 0);
+
+    if (*replace_text)
+	convert_to_display (quick_widgets[5].text + strlen (msg));
+#endif
 
     {
 	QuickDialog Quick_input =
@@ -1215,7 +1264,7 @@ int edit_replace_prompt (WEdit * edit, char *replace_text, int xpos, int ypos)
 
 	/* Sometimes menu can hide replaced text. I don't like it */
 
-	if ((edit->curs_row >= ypos) && (edit->curs_row <= ypos + CONFIRM_DLG_HEIGTH))
+	if ((edit->curs_row >= ypos - 1) && (edit->curs_row <= ypos + CONFIRM_DLG_HEIGTH - 1))
 	    ypos -= CONFIRM_DLG_HEIGTH;
 
 	Quick_input.ypos = ypos;
@@ -1375,6 +1424,9 @@ void edit_search_dialog (WEdit * edit, char **search_text)
 
 #else
 
+#undef B_ENTER
+#undef B_CANCEL
+
 #define B_ENTER 0
 #define B_SKIP_REPLACE 1
 #define B_REPLACE_ALL 2
@@ -1665,6 +1717,8 @@ int edit_replace_prompt (WEdit * edit, char *replace_text, int xpos, int ypos)
 	return B_SKIP_REPLACE;
     if (!strcmp (s, "Replace"))
 	return B_ENTER;
+    /* Shouldn't ever reach this point */
+    return B_CANCEL;
 }
 
 #else
@@ -2088,7 +2142,23 @@ void edit_replace_cmd (WEdit * edit, int again)
 	exp3 = (char *) strdup (old3);
     } else {
 	edit_push_action (edit, KEY_PRESS + edit->start_display);
+
+#ifdef HAVE_CHARSET
+	if (exp1 && *exp1)
+	    convert_to_display (exp1);
+	if (exp2 && *exp2)
+	    convert_to_display (exp2);
+#endif
+
 	edit_replace_dialog (edit, &exp1, &exp2, &exp3);
+
+#ifdef HAVE_CHARSET
+	if (exp1 && *exp1)
+	    convert_from_input (exp1);
+	if (exp2 && *exp2)
+	    convert_from_input (exp2);
+#endif
+
 	treplace_prompt = replace_prompt;
     }
 
@@ -2285,7 +2355,19 @@ void edit_search_cmd (WEdit * edit, int again)
 	    return;
 	exp = (char *) strdup (old);
     } else {
+
+#ifdef HAVE_CHARSET
+	if (exp && *exp)
+	    convert_to_display (exp);
+#endif
+
 	edit_search_dialog (edit, &exp);
+
+#ifdef HAVE_CHARSET
+	if (exp && *exp)
+	    convert_from_input (exp);
+#endif
+
 	edit_push_action (edit, KEY_PRESS + edit->start_display);
     }
 
@@ -2375,12 +2457,12 @@ void edit_quit_cmd (WEdit * edit)
 	char *r;
 	r = gtk_dialog_cauldron (_ (" Quit "), GTK_CAULDRON_TOPLEVEL | GTK_CAULDRON_GRAB, " [ ( %Lxf )xf ]xf / ( %Bgxfq || %Bgxfq || %Bgxfq ) ",
 				     _ (" Current text was modified without a file save. \n Save with exit? "), GNOME_STOCK_BUTTON_CANCEL, GNOME_STOCK_BUTTON_YES, GNOME_STOCK_BUTTON_NO);
-	if (!strcmp (r, GNOME_STOCK_BUTTON_YES)) {
+	if (r == GNOME_STOCK_BUTTON_YES) {
 	    edit_push_markers (edit);
 	    edit_set_markers (edit, 0, 0, 0, 0);
 	    if (!edit_save_cmd (edit))
 		return;
-	} else if (!strcmp (r, GNOME_STOCK_BUTTON_NO)) {
+	} else if (r == GNOME_STOCK_BUTTON_NO) {
 	    if (edit->delete_file)
 		unlink (catstrs (edit->dir, edit->filename, 0));
 	} else {
@@ -2725,7 +2807,7 @@ void edit_paste_from_X_buf_cmd (WEdit * edit)
     edit_insert_file (edit, catstrs (home_dir, CLIP_FILE, 0));
 }
 
-#endif				/* MIDMIGHT */
+#endif /* MIDNIGHT */
 
 void edit_goto_cmd (WEdit *edit)
 {
@@ -2914,13 +2996,12 @@ void edit_block_process_cmd (WEdit * edit, const char *shell_cmd, int block)
         edit_save_block (edit, b, start_mark, end_mark);
         
 	/* run your script */
-        my_system (EXECUTE_AS_SHELL, shell,
-	    catstrs (home_dir, EDIT_DIR, shell_cmd, " ", 
+        execute (catstrs (home_dir, EDIT_DIR, shell_cmd, " ", 
 	    edit->filename, " ", home_dir, BLOCK_FILE, " ", 
 	    home_dir, ERROR_FILE, 0));
 
     } else { /* for missing marked block run ... */
-	my_system (0, shell, catstrs (EDIT_DIR, shell_cmd));
+	execute (catstrs (EDIT_DIR, shell_cmd));
     }
 
     edit_refresh_cmd (edit);
