@@ -4,6 +4,8 @@
 
    Authors: 1996, 1997 Paul Sheer
 
+   $Id: editdraw.c,v 1.17 2001/07/11 15:01:03 proskin Exp $
+
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -31,54 +33,53 @@
 #include "mad.h"
 #endif
 
+#ifdef HAVE_CHARSET
+#include "../src/charsets.h"
+#endif
+
 extern int column_highlighting;
 
 #if defined (MIDNIGHT) || defined (GTK)
 
-void status_string (WEdit * edit, char *s, int w, int fill, int font_width)
+static void status_string (WEdit * edit, char *s, int w, int fill, int font_width)
 {
-#ifdef MIDNIGHT
-    int i;
-#endif
-    char t[160];		/* 160 just to be sure */
-/* The field lengths just prevents the status line from shortening to much */
-sprintf (t,"[%c%c%c%c] %2ld L:[%3ld+%2ld %3ld/%3ld] *(%-4ld/%4ldb)= %c %d %xH",
-	edit->mark1 != edit->mark2 ? ( column_highlighting ? 'C' : 'B') : '-',
-	edit->modified ? 'M' : '-',
-        edit->macro_i < 0 ? '-' : 'R',
-	edit->overwrite == 0 ? '-' : 'O',
-	edit->curs_col / font_width,
-        
-        edit->start_line + 1,
-        edit->curs_row,
-        edit->curs_line + 1,
-        edit->total_lines + 1,
-        
-        edit->curs1,
-	edit->last_byte, 
-        
-        edit->curs1 < edit->last_byte ? edit_get_byte (edit, edit->curs1) : '?',
-        edit->curs1 < edit->last_byte ? edit_get_byte (edit, edit->curs1) : -1,
-        edit->curs1 < edit->last_byte ? edit_get_byte (edit, edit->curs1) : -1
-        );
-#ifdef MIDNIGHT
-    sprintf (s, "%.*s", w + 1, t);
-    i = strlen (s);
-    s[i] = ' ';
-    i = w;
-    do {
-	if (strchr ("+-*=/:b", s[i]))	/* chop off the last word/number */
-	    break;
-	s[i] = fill;
-    } while (i--);
-    s[i] = fill;
-    s[w] = 0;
-#else
-    strcpy (s, t);
-#endif
+    char byte_str[16];
+
+    /*
+     * If we are at the end of file, print <EOF>,
+     * otherwise print the current character as is (if printable),
+     * as decimal and as hex.
+     */
+    if (edit->curs1 < edit->last_byte) {
+	unsigned char cur_byte = edit_get_byte (edit, edit->curs1);
+	g_snprintf (byte_str, sizeof(byte_str), "%c %3d 0x%02X",
+		    is_printable(cur_byte) ? cur_byte : '.',
+		    cur_byte,
+		    cur_byte);
+    } else {
+	strcpy(byte_str, "<EOF>");
+    }
+
+    /* The field lengths just prevent the status line from shortening too much */
+    g_snprintf (s, w,
+		"[%c%c%c%c] %2ld L:[%3ld+%2ld %3ld/%3ld] *(%-4ld/%4ldb)= %s",
+		edit->mark1 != edit->mark2 ? ( column_highlighting ? 'C' : 'B') : '-',
+		edit->modified ? 'M' : '-',
+		edit->macro_i < 0 ? '-' : 'R',
+		edit->overwrite == 0 ? '-' : 'O',
+		edit->curs_col / font_width,
+
+		edit->start_line + 1,
+		edit->curs_row,
+		edit->curs_line + 1,
+		edit->total_lines + 1,
+
+		edit->curs1,
+		edit->last_byte, 
+		byte_str);
 }
 
-#endif
+#endif /* MIDNIGHT || GTK */
 
 #ifdef MIDNIGHT
 
@@ -97,17 +98,17 @@ void edit_status (WEdit * edit)
 	widget_move (edit, edit->have_frame, edit->have_frame);
 	i = w > 24 ? 18 : w - 6;
 	i = i < 13 ? 13 : i;
-	sprintf (s, "%s", (char *) name_trunc (edit->filename ? edit->filename : "", i));
-	i += strlen (s);
-	s[strlen (s)] = ' ';
+	strcpy (s, (char *) name_trunc (edit->filename ? edit->filename : "", i));
+	i = strlen (s);
+	s[i] = ' ';
 	t = w - 20;
 	if (t < 0)
 	    t = 0;
 	status_string (edit, s + 20, t, ' ', 1);
-    } else {
-	s[w] = 0;
     }
-    printw ("%.*s", w, s);
+    s[w] = 0;
+
+    printw ("%-*s", w, s);
     attrset (NORMAL_COLOR);
     free (s);
 }
@@ -133,7 +134,7 @@ void edit_status (WEdit *edit)
     if (w > 1) {
 	i = w > 24 ? 18 : w - 6;
 	i = i < 13 ? 13 : i;
-	sprintf (s, "%s", (char *) name_trunc (edit->filename ? edit->filename : "", i));
+	strcpy (s, (char *) name_trunc (edit->filename ? edit->filename : "", i));
 	i = strlen (s);
 	s[i] = ' ';
 	s[i + 1] = ' ';
@@ -195,12 +196,12 @@ void edit_status (WEdit * edit)
     CPopFont ();
 }
 
-#endif
+#endif	/* GTK */
 
-#endif
+#endif	/* !MIDNIGHT */
 
 
-/* boolean */
+/* result is boolean */
 int cursor_in_screen (WEdit * edit, long row)
 {
     if (row < 0 || row >= edit->num_widget_lines)
@@ -294,7 +295,10 @@ void edit_scroll_screen_over_cursor (WEdit * edit)
 int EditExposeRedraw = 0;
 int EditClear = 0;
 
-/* background colors: marked is refers to mouse highlighting, highlighted refers to a found string. */
+/*
+ * background colors: marked is refers to mouse highlighting,
+ * highlighted refers to a found string.
+ */
 unsigned long edit_abnormal_color, edit_marked_abnormal_color;
 unsigned long edit_highlighted_color, edit_marked_color;
 unsigned long edit_normal_background_color;
@@ -329,10 +333,7 @@ void edit_set_cursor_color (unsigned long c)
 
 #else
 
-static void set_color (int font)
-{
-    attrset (font);
-}
+#define set_color(font)    attrset (font)
 
 #define edit_move(x,y) widget_move(edit, y, x);
 
@@ -378,7 +379,7 @@ static void print_to_widget (WEdit * edit, long row, int start_col, float start_
     }
 }
 
-/* b pointer to begining of line */
+/* b is a pointer to the beginning of the line */
 static void edit_draw_this_line (WEdit * edit, long b, long row, long start_col, long end_col)
 {
     static unsigned int line[MAX_LINE_LEN];
@@ -446,6 +447,10 @@ static void edit_draw_this_line (WEdit * edit, long b, long row, long start_col,
 		case '\r':
 		    break;
 		default:
+#ifdef HAVE_CHARSET
+		    if (c >= 0 && c <= 255)
+			c = conv_displ[ c ];
+#endif
 		    if (is_printable (c)) {
 			*(p++) |= c;
 		    } else {
@@ -479,10 +484,10 @@ int option_smooth_scrolling = 0;
 
 static int key_pending (WEdit * edit)
 {
-    static int flush = 0, line = 0;
 #ifdef GTK
     /* ******* */
 #else
+    static int flush = 0, line = 0;
     if (!edit) {
 	flush = line = 0;
     } else if (!(edit->force & REDRAW_COMPLETELY) && !EditExposeRedraw && !option_smooth_scrolling) {
@@ -500,7 +505,6 @@ static int key_pending (WEdit * edit)
 #endif
 
 
-/* b for pointer to begining of line */
 static void edit_draw_this_char (WEdit * edit, long curs, long row)
 {
     int b = edit_bol (edit, curs);
@@ -535,8 +539,8 @@ void render_edit_text (WEdit * edit, long start_row, long start_column, long end
 #endif
 
 /*
-   if the position of the page has not moved then we can draw the cursor character only.
-   This will prevent line flicker when using arrow keys.
+ * If the position of the page has not moved then we can draw the cursor
+ * character only.  This will prevent line flicker when using arrow keys.
  */
     if ((!(force & REDRAW_CHAR_ONLY)) || (force & REDRAW_PAGE)
 #ifndef MIDNIGHT
@@ -547,12 +551,12 @@ void render_edit_text (WEdit * edit, long start_row, long start_column, long end
 #endif
 #endif
 	) {
+#if !defined(MIDNIGHT) && !defined(GTK)
 	int time_division = 5;
 #if 0
 	if (CPending ())
 	    time_division--;
 #endif
-#if !defined(MIDNIGHT) && !defined(GTK)
 	if (prev_start < 0)
 	    prev_start = edit->start_line;
 	if (option_smooth_scrolling && prev_win == CWindowOf (edit->widget) && !edit->screen_modified) {
@@ -800,9 +804,12 @@ void edit_render (WEdit * edit, int page, int row_start, int col_start, int row_
 #endif
 #endif
     render_edit_text (edit, row_start, col_start, row_end, col_end);
-    if (edit->force)		/* edit->force != 0 means a key was pending and the redraw 
-				   was halted, so next time we must redraw everything in case stuff
-				   was left undrawn from a previous key press */
+    /*
+     * edit->force != 0 means a key was pending and the redraw 
+     * was halted, so next time we must redraw everything in case stuff
+     * was left undrawn from a previous key press.
+     */
+    if (edit->force)
 	edit->force |= REDRAW_PAGE;
 #ifndef MIDNIGHT
     if (f) {
