@@ -4,6 +4,8 @@
 
    Authors: 1996, 1997 Paul Sheer
 
+   $Id: editmenu.c,v 1.12 2001/08/12 18:02:56 proskin Exp $
+
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -35,7 +37,6 @@
 #include "../src/mad.h"
 
 extern int edit_key_emulation;
-extern WEdit *wedit;
 extern WButtonBar *edit_bar;
 extern Dlg_head *edit_dlg;
 extern WMenu *edit_menubar;
@@ -54,23 +55,22 @@ static void menu_key (int i)
     send_message (wedit->widget.parent, (Widget *) wedit, WIDGET_KEY, i);
 }
 
-void edit_wrap_cmd ()
+void edit_wrap_cmd (void)
 {
     char *f;
     char s[12];
     sprintf (s, "%d", option_word_wrap_line_length);
     f = input_dialog (_(" Word wrap "), 
-/* Not essential to translate */
-    _(" Enter line length, 0 for off: "), s);
+	_(" Enter line length, 0 for off: "), s);
     if (f) {
 	if (*f) {
 	    option_word_wrap_line_length = atoi (f);
-	    free (f);
 	}
+	free (f);
     }
 }
 
-void edit_about_cmd ()
+void edit_about_cmd (void)
 {
     edit_message_dialog (wedit->mainid, 20, 20, _(" About "),
 		      _("\n"
@@ -125,7 +125,7 @@ void edit_user_menu_cmd (void)          { menu_edit_cmd (1); }
 
 static menu_entry FileMenu[] =
 {
-    {' ', N_("&Open/load...     C-o"), 'O', menu_load_cmd},
+    {' ', N_("&Open file..."),         'O', menu_load_cmd},
     {' ', N_("&New              C-n"), 'N', menu_new_cmd},
     {' ', "", ' ', 0},
     {' ', N_("&Save              F2"), 'S', menu_save_cmd},
@@ -144,7 +144,7 @@ static menu_entry FileMenu[] =
 
 static menu_entry FileMenuEmacs[] =
 {
-    {' ', N_("&Open/load...     C-o"), 'O', menu_load_cmd},
+    {' ', N_("&Open file..."),         'O', menu_load_cmd},
     {' ', N_("&New            C-x k"), 'N', menu_new_cmd},
     {' ', "", ' ', 0},
     {' ', N_("&Save              F2"), 'S', menu_save_cmd},
