@@ -64,57 +64,57 @@ void edit_options_dialog (void)
     {
 /*0 */
 	{quick_button, 6, 10, OPT_DLG_H - 3, OPT_DLG_H, N_("&Cancel"), 0, B_CANCEL, 0,
-	 0, XV_WLAY_DONTCARE, NULL},
+	 0, NULL},
 /*1 */
 	{quick_button, 2, 10, OPT_DLG_H - 3, OPT_DLG_H, N_("&Ok"), 0, B_ENTER, 0,
-	 0, XV_WLAY_DONTCARE, NULL},
+	 0, NULL},
 /*2 */
 	{quick_label, OPT_DLG_W / 2, OPT_DLG_W, OPT_DLG_H - 4, OPT_DLG_H, N_("Word wrap line length : "), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 /*3 */
 	{quick_input, OPT_DLG_W / 2 + 24, OPT_DLG_W, OPT_DLG_H - 4, OPT_DLG_H, "", OPT_DLG_W / 2 - 4 - 24, 0,
-	 0, 0, XV_WLAY_DONTCARE, "i"},
+	 0, 0, "edit-word-wrap"},
 /*4 */
 	{quick_label, OPT_DLG_W / 2, OPT_DLG_W, OPT_DLG_H - 5, OPT_DLG_H, N_("Tab spacing : "), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 /*5 */
 	{quick_input, OPT_DLG_W / 2 + 24, OPT_DLG_W, OPT_DLG_H - 5, OPT_DLG_H, "", OPT_DLG_W / 2 - 4 - 24, 0,
-	 0, 0, XV_WLAY_DONTCARE, "i"},
+	 0, 0, "edit-tab-spacing"},
 /*6 */
 #if !defined(MIDNIGHT) || defined(HAVE_SYNTAXH)
 #define OA 1
 	{quick_checkbox, OPT_DLG_W / 2 + 1, OPT_DLG_W, OPT_DLG_H - 7, OPT_DLG_H, N_("synta&X highlighting"), 8, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 #else
 #define OA 0
 #endif
 /*7 */
 	{quick_checkbox, OPT_DLG_W / 2 + 1, OPT_DLG_W, OPT_DLG_H - 8, OPT_DLG_H, N_("confir&M before saving"), 6, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 /*8 */
 	{quick_checkbox, OPT_DLG_W / 2 + 1, OPT_DLG_W, OPT_DLG_H - 9, OPT_DLG_H, N_("fill tabs with &Spaces"), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 /*9 */
 	{quick_checkbox, OPT_DLG_W / 2 + 1, OPT_DLG_W, OPT_DLG_H - 10, OPT_DLG_H, N_("&Return does autoindent"), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 /*10 */
 	{quick_checkbox, OPT_DLG_W / 2 + 1, OPT_DLG_W, OPT_DLG_H - 11, OPT_DLG_H, N_("&Backspace through tabs"), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 /*11 */
 	{quick_checkbox, OPT_DLG_W / 2 + 1, OPT_DLG_W, OPT_DLG_H - 12, OPT_DLG_H, N_("&Fake half tabs"), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 /*12 */
 	{quick_radio, 5, OPT_DLG_W, OPT_DLG_H - 6, OPT_DLG_H, "", 3, 0,
-	 0, wrap_str, XV_WLAY_DONTCARE, "wrapm"},
+	 0, wrap_str, "wrapm"},
 /*13 */
 	{quick_label, 4, OPT_DLG_W, OPT_DLG_H - 7, OPT_DLG_H, N_("Wrap mode"), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 /*14 */
 	{quick_radio, 5, OPT_DLG_W, OPT_DLG_H - 11, OPT_DLG_H, "", 2, 0,
-       0, key_emu_str, XV_WLAY_DONTCARE, "keyemu"},
+       0, key_emu_str, "keyemu"},
 /*15 */
 	{quick_label, 4, OPT_DLG_W, OPT_DLG_H - 12, OPT_DLG_H, N_("Key emulation"), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 	{0}};
 
     static int i18n_flag = 0;
@@ -160,6 +160,8 @@ void edit_options_dialog (void)
 	Quick_options.widgets = quick_widgets;
 
 	if (quick_dialog (&Quick_options) != B_CANCEL) {
+	    int old_syntax_hl = option_syntax_highlighting;
+
 	    if (p) {
 		option_word_wrap_line_length = atoi (p);
 		free (p);
@@ -168,7 +170,10 @@ void edit_options_dialog (void)
 		option_tab_spacing = atoi (q);
 		if (option_tab_spacing < 0)
 		    option_tab_spacing = 2;
+#if 0
+		/* Only allow even numbers */
 		option_tab_spacing += option_tab_spacing & 1;
+#endif
 		free (q);
 	    }
 	    option_syntax_highlighting = *quick_widgets[5 + OA].result;
@@ -191,6 +196,10 @@ void edit_options_dialog (void)
 
 	    edit_key_emulation = *quick_widgets[13 + OA].result;
 
+	    /* Load or unload syntax rules if the option has changed */
+	    if (option_syntax_highlighting != old_syntax_hl)
+		edit_load_syntax (wedit, 0, 0);
+
 	    return;
 	} else {
 	    return;
