@@ -22,14 +22,19 @@
 #define _GTK_EDIT_C
 
 #include <config.h>
-#include <gnome.h>
 #include <ctype.h>
 #include <string.h>
 #include <pwd.h>
-#include "gdk/gdkkeysyms.h"
-#include "gtk/gtkmain.h"
-#include "gtk/gtkselection.h"
-#include "gtk/gtksignal.h"
+
+#ifdef HAVE_SYS_PARAM_H
+#include <sys/param.h>
+#endif
+
+#include <gnome.h>
+#include <gdk/gdkkeysyms.h>
+#include <gtk/gtkmain.h>
+#include <gtk/gtkselection.h>
+#include <gtk/gtksignal.h>
 #include "edit.h"
 #if ! defined (MIDNIGHT) && ! defined (GTK)
 #include "mousemark.h"
@@ -47,7 +52,6 @@ int column_highlighting = 0;
 static GtkWidgetClass *parent_class = NULL;
 
 WEdit *edit_init (WEdit * edit, int lines, int columns, const char *filename, const char *text, const char *dir, unsigned long text_size);
-void edit_destroy_callback (CWidget * w);
 int edit_translate_key (unsigned int x_keycode, long x_key, int x_state, int *cmd, int *ch);
 void gtk_edit_alloc_colors (GtkEdit *edit, GdkColormap *colormap);
 static void gtk_edit_set_position (GtkEditable *editable, gint position);
@@ -245,7 +249,7 @@ static void gtk_edit_realize (GtkWidget * widget)
 
     gtk_edit_alloc_colors (edit, colormap);
 
-    /* Can't call gtk_style_set_background here because it's handled specially */
+    /* Cannot call gtk_style_set_background here because it's handled specially */
     gdk_window_set_background (widget->window, &edit->color[1]);
     gdk_window_set_background (edit->text_area, &edit->color[1]);
 
@@ -783,8 +787,6 @@ static gint gtk_edit_key_press (GtkWidget * widget, GdkEventKey * event)
 /*                              Widget Crap                           */
 /**********************************************************************/
 
-char *home_dir = 0;
-
 static void get_home_dir (void)
 {
     if (home_dir)		/* already been set */
@@ -1000,7 +1002,7 @@ void gtk_edit_dialog_message (guchar * heading, char *fmt,...)
 			    heading, GTK_CAULDRON_TOPLEVEL | GTK_CAULDRON_GRAB,
 			    " [ ( %Ld )xf ]xf / ( %Bxfgq )f ",
 			    s,
-			    GNOME_STOCK_BUTTON_CANCEL
+			    GNOME_STOCK_BUTTON_OK
 	);
     return;
 }
@@ -1204,6 +1206,11 @@ void gtk_edit_move (GtkEdit * widget, void *data) { GtkEdit *edit = (GtkEdit *)
 void gtk_edit_delete (GtkEdit * widget, void *data) { GtkEdit *edit = (GtkEdit *) data ; gtk_edit_command (edit, CK_Remove); }
 void gtk_edit_undo (GtkEdit * widget, void *data) { GtkEdit *edit = (GtkEdit *) data ; gtk_edit_command (edit, CK_Undo); }
 
+gint gtk_edit_delete_cb (GtkWidget *widget, GdkEvent *event, GtkWidget *edit) {
+    gtk_edit_quit (NULL, edit);
+    return TRUE;	
+}
+
 #if 0
 struct _GnomeUIInfo {
     GnomeUIInfoType type;
@@ -1248,13 +1255,15 @@ static TbItems tb_items[] =
     {"F1", N_("Help"), N_("Interactive help browser"), GNOME_STOCK_MENU_BLANK, 0, NULL},
     {"F2", N_("Save"), N_("Save to current file name"), GNOME_STOCK_MENU_SAVE, gtk_edit_save_file, NULL},
     {"F3", N_("Mark"), N_("Toggle In/Off invisible marker to highlight text"), GNOME_STOCK_MENU_BLANK, gtk_edit_toggle_mark, NULL},
-    {"F4", N_("Replc"), N_("Find and replace strings/regular expressions"), GNOME_STOCK_MENU_SRCHRPL, gtk_edit_replace, NULL},
+    {"F4", N_("Replace"), N_("Find and replace strings/regular expressions"), GNOME_STOCK_MENU_SRCHRPL, gtk_edit_replace, NULL},
     {"F5", N_("Copy"), N_("Copy highlighted block to cursor position"), GNOME_STOCK_MENU_COPY, gtk_edit_copy, NULL},
 
     {"F6", N_("Move"), N_("Move highlighted block to cursor position"), GNOME_STOCK_MENU_BLANK, gtk_edit_move, NULL},
     {"F7", N_("Find"), N_("Find strings/regular expressions"), GNOME_STOCK_MENU_SEARCH, gtk_edit_search, NULL},
-    {"F8", N_("Dlete"), N_("Delete highlighted text"), GNOME_STOCK_MENU_BLANK, gtk_edit_delete, NULL},
+    {"F8", N_("Delete"), N_("Delete highlighted text"), GNOME_STOCK_MENU_BLANK, gtk_edit_delete, NULL},
+#if 0
     {"F9", N_("Menu"), N_("Pull down menu"), GNOME_STOCK_MENU_BLANK, /* gtk_edit_menu*/ 0, NULL},
+#endif
     {"F10", N_("Quit"), N_("Exit editor"), GNOME_STOCK_MENU_QUIT, gtk_edit_quit, NULL},
     {0, 0, 0, 0, 0, 0}
 };
@@ -1354,6 +1363,9 @@ int edit (const char *file, int line)
 	GTK_EDIT(edit)->destroy_me = gtk_widget_destroy;
 	GTK_EDIT(edit)->destroy_me_user_data = app;
 
+	gtk_signal_connect (GTK_OBJECT (app), "delete_event",
+			    (GtkSignalFunc) gtk_edit_delete_cb, edit);
+
 	gtk_widget_show (edit);
 	gtk_widget_realize (edit);
 	if (file)
