@@ -16,7 +16,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include <config.h>
 #include "edit.h"
@@ -161,7 +161,7 @@ int edit_translate_key (unsigned int x_keycode, long x_key, int x_state, int *cm
 	    goto fin;
 	}
 
-    if ((x_state & MyAltMask)) {
+    if ((x_state & MyAltMask) && !(x_state & ShiftMask)) {
 	switch ((int) x_key) {
 	case GDK_Left:
 	case GDK_KP_Left:
@@ -175,6 +175,10 @@ int edit_translate_key (unsigned int x_keycode, long x_key, int x_state, int *cm
 	case GDK_L:
 	    command = CK_Goto;
 	    goto fin;
+	case GDK_b:
+	case GDK_B:
+	    command = CK_Match_Bracket;
+	    goto fin;
 	case GDK_Insert:
 	case GDK_KP_Insert:
 	    command = CK_Selection_History;
