@@ -4,7 +4,7 @@
 
    Authors: 1998 Paul Sheer
 
-   $Id: syntax.c,v 1.16 2000/09/07 17:45:28 andrew Exp $
+   $Id: syntax.c,v 1.25 2001/08/24 04:58:42 proskin Exp $
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -592,11 +592,13 @@ int this_allocate_color (WEdit *edit, char *fg)
 	return allocate_color (fg);
     return allocate_color (p + 1);
 }
-#endif
-#endif
+#endif	/* GTK */
+#endif	/* MIDNIGHT */
 
 static char *error_file_name = 0;
 
+extern char *mc_home;
+
 static FILE *open_include_file (char *filename)
 {
     FILE *f;
@@ -613,7 +615,12 @@ static FILE *open_include_file (char *filename)
     f = fopen (p, "r");
     if (f)
 	return f;
+#if !defined (MIDNIGHT) && !defined(GTK)
     strcpy (p, LIBDIR "/syntax/");
+#else
+    strcpy (p, mc_home);
+    strcat (p, "/syntax/");
+#endif /* MIDNIGHT || GTK */
     strcat (p, filename);
     syntax_free (error_file_name);
     error_file_name = (char *) strdup (p);
@@ -1204,10 +1211,10 @@ static const char * const syntax_text[] = {
 "file ..\\*\\\\.lsm$ LSM\\sFile",
 "include lsm.syntax",
 "",
-"file ..\\*\\\\.sh$ Shell\\sScript ^#!\\s\\*/.\\*/(ksh|bash|sh|pdkzsh)",
+"file ..\\*\\\\.sh$ Shell\\sScript ^#!\\s\\*/.\\*/(k|ba||pdk|z)sh",
 "include sh.syntax",
 "",
-"file ..\\*\\\\.(pl|PL])$ Perl\\sProgram ^#!\\s\\*/.\\*/perl",
+"file ..\\*\\\\.(pl|PL|pm|PM])$ Perl\\sProgram ^#!\\s\\*/.\\*/perl",
 "include perl.syntax",
 "",
 "file ..\\*\\\\.(py|PY])$ Python\\sProgram ^#!\\s\\*/.\\*/python",
@@ -1225,6 +1232,9 @@ static const char * const syntax_text[] = {
 "file ..\\*\\\\.(ada|adb|ads|ADA|ADB|ADS)$ Ada\\sProgram",
 "include ada95.syntax",
 "",
+"file ..\\*\\\\.(sl|SL)$ S-Lang\\sProgram",
+"include slang.syntax",
+"",
 "file ..\\*\\\\.tex$ LaTeX\\s2.09\\sDocument",
 "include latex.syntax",
 "",
@@ -1249,12 +1259,18 @@ static const char * const syntax_text[] = {
 "file ..\\*\\\\.(ml|mli|mly|mll|mlp)$ ML\\sProgram",
 "include ml.syntax",
 "",
+"file ..\\*\\\\.m$ Matlab\\sor\\sOctave\\sFile",
+"include octave.syntax",
+"",
 "file .\\*ChangeLog$ GNU\\sDistribution\\sChangeLog\\sFile",
 "include changelog.syntax",
 "",
 "file .\\*[Mm]akefile[\\\\\\.a-z]\\*$ Makefile",
 "include makefile.syntax",
 "",
+"file ..\\*\\\\.(po|pot|pox)$ PO\\sFile",
+"include po.syntax",
+"",
 "file Don_t_match_me Mail\\sfolder ^From\\s",
 "include mail.syntax",
 "",
@@ -1505,6 +1521,9 @@ void edit_load_syntax (WEdit * edit, char **names, char *type)
 
     edit_free_syntax_rules (edit);
 
+    if (!option_syntax_highlighting)
+	return;
+
     if (edit) {
 	if (!edit->filename)
 	    return;
@@ -1554,5 +1573,3 @@ int edit_check_spelling (WEdit * edit)
 
 #endif		/* !defined(MIDNIGHT) || defined(HAVE_SYNTAXH) */
 
-
-
