@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  
 
  ----------------------------------------------------------------------------
  Changes:
@@ -44,7 +44,6 @@
 
 #define USE_O_TEXT
 #define HAS_ACS_AS_PCCHARS
-#define HAS_DIRECT_COLOR_ACCESS
 #define NEEDS_CR_LF_TRANSLATION
 
 #ifdef MC_NT
