@@ -17,7 +17,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include <config.h>
 #include <sys/types.h>
@@ -194,7 +194,7 @@ char *tilde_expand (char *directory)
 }
 
 /* sleep: Call Windows API.
-	  Can't do simple define. That would need <windows.h> in every source
+	  Cannot do simple define. That would need <windows.h> in every source
 */
 #ifndef __EMX__
 void sleep(unsigned long dwMiliSecs)
@@ -241,10 +241,6 @@ char *canonicalize_pathname (char *path)
 	    i = start + 1;
 	}
 
-        /* Handle backquoted `/'. */
-        if (start > 0 && path[start - 1] == '\\')
-	    continue;
-
         /* Check for trailing `/'. */
         if (start && !path[i]) {
 	zero_last:
