@@ -9,7 +9,7 @@
 # include <stdlib.h>
 #endif
 
-#ifdef HAVE_MALLOC_H
+#if !defined(STDC_HEADERS) && defined(HAVE_MALLOC_H)
 # include <malloc.h>
 #endif
 
