@@ -11,13 +11,15 @@
 
 /* The current versions only work in the forward direction only!! */
       
+#include "config.h"
+
 #include <stdio.h>
 #include "slang.h"
 #include "_slang.h"
 
-char *jed_memcpy(char *s1, char *s2, int n)
+char *SLmemcpy(char *s1, char *s2, int n)
 {
-#if defined(msdos) && !defined(__WIN32__)
+#if defined(msdos) && !defined(__WIN32__) && !defined(__GO32__)
    asm mov ax, ds
    asm mov bx, si
    asm mov dx, di
