@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  
  */
 
 #include <config.h>
@@ -64,7 +64,9 @@
 #define B_OUSER         B_USER + 6
 #define B_OGROUP        B_USER + 7
 
-struct {
+static struct Dlg_head *ch_dlg;
+
+static struct {
     int ret_cmd, flags, y, x;
     char *text;
 } chown_advanced_but [BUTTONS] = {
@@ -79,23 +81,23 @@ struct {
     { B_ENTER,  NARROW_BUTTON, 0, 3, "   "},
 };
 
-WButton *b_att[3];	/* permission */
-WButton *b_user, *b_group;	/* owner */
+static WButton *b_att[3];	/* permission */
+static WButton *b_user, *b_group;	/* owner */
 
 static int files_on_begin;	/* Number of files at startup */
 static int flag_pos;
 static int x_toggle;
 static char ch_flags[11];
-static char *ch_perm = "rwx";
+static const char ch_perm[] = "rwx";
 static umode_t ch_cmode;
-struct stat *sf_stat;
+static struct stat *sf_stat;
 static int need_update;
 static int end_chown;
 static int current_file;
 static int single_set;
 static char *fname;
 
-static void get_ownership ()
+static void get_ownership (void)
 {				/* set buttons  - ownership */
     char *name_t;
 
@@ -136,20 +138,14 @@ static void set_perm_by_flags (char *s, int f_p)
 {
     int i;
 
-    for (i = 0; i < 3; i++)
+    for (i = 0; i < 3; i++) {
 	if (ch_flags[f_p + i] == '+')
 	    s[i] = ch_perm[i];
 	else if (ch_flags[f_p + i] == '-')
 	    s[i] = '-';
 	else
 	    s[i] = (ch_cmode & (1 << (8 - f_p - i))) ? ch_perm[i] : '-';
-}
-
-static void set_perm (char *s, int p)
-{
-    s[0] = (p & 4) ? 'r' : '-';
-    s[1] = (p & 2) ? 'w' : '-';
-    s[2] = (p & 1) ? 'x' : '-';
+    }
 }
 
 static umode_t get_perm (char *s, int base)
@@ -169,7 +165,7 @@ static umode_t get_perm (char *s, int base)
     return m;
 }
 
-static umode_t get_mode ()
+static umode_t get_mode (void)
 {
     umode_t m;
 
@@ -181,15 +177,6 @@ static umode_t get_mode ()
     return m;
 }
 
-#ifdef HAVE_X
-static void update_mode (Dlg_head *h)
-{
-}
-static void print_flags (void)
-{
-}
-
-#else
 static void print_flags (void)
 {
     int i;
@@ -233,7 +220,6 @@ static void update_mode (Dlg_head * h)
     printw ("%12o", get_mode ());
     send_message (h, h->current->widget, WIDGET_FOCUS, 0);
 }
-#endif /* HAVE_X */
 
 static int l_call (void *data)
 {
@@ -244,11 +230,9 @@ static int chl_callback (Dlg_head * h, int Par, int Msg)
 {
     switch (Msg) {
     case DLG_DRAW:
-#ifndef HAVE_X
 	attrset (COLOR_NORMAL);
 	dlg_erase (h);
 	draw_box (h, 0, 0, 13, 17);
-#endif
 	break;
 	
     case DLG_KEY:
@@ -277,7 +261,7 @@ static void do_enter_key (Dlg_head *h, int f_pos)
 	chl_end = 0;
 	
 	chl_dlg = create_dlg (lyy, lxx, 13, 17, dialog_colors, chl_callback,
-			      "[Chown-advanced]", "achown_enter", DLG_NONE);
+			      "[Advanced Chown]", "achown_enter", DLG_NONE);
 	
 	/* get new listboxes */
 	chl_list = listbox_new (1, 1, 15, 11, 0, l_call, NULL);
@@ -350,7 +334,6 @@ static void do_enter_key (Dlg_head *h, int f_pos)
     } while (chl_end);
 }
 
-#ifndef HAVE_X
 static void chown_refresh (void)
 {
     attrset (COLOR_NORMAL);
@@ -391,7 +374,7 @@ static void chown_refresh (void)
     addstr (_(" Chown advanced command "));
 }
 
-static void chown_info_update ()
+static void chown_info_update (void)
 {
     /* display file info */
     attrset (COLOR_NORMAL);
@@ -403,11 +386,10 @@ static void chown_info_update ()
     printw ("%12o", get_mode ());
     
     /* permissions */
-    set_perm (b_att[0]->text, sf_stat->st_mode >> 6);
-    set_perm (b_att[1]->text, sf_stat->st_mode >> 3);
-    set_perm (b_att[2]->text, sf_stat->st_mode);
+    set_perm_by_flags (b_att[0]->text, 0);
+    set_perm_by_flags (b_att[1]->text, 3);
+    set_perm_by_flags (b_att[2]->text, 6);
 }
-#endif
 
 static void b_setpos (int f_pos) {
 	b_att[0]->hotpos=-1;
@@ -422,10 +404,8 @@ static int advanced_chown_callback (Dlg_head * h, int Par, int Msg)
 
     switch (Msg) {
     case DLG_DRAW:
-#ifndef HAVE_X
 	chown_refresh ();
 	chown_info_update ();
-#endif
 	return 1;
 	
     case DLG_POST_KEY:
@@ -569,7 +549,7 @@ static void init_chown_advanced (void)
     x_toggle = 070;
 
     ch_dlg = create_dlg (0, 0, 13, 74, dialog_colors, advanced_chown_callback,
-			 "[Chown-advanced]", "achown", DLG_CENTER);
+			 "[Advanced Chown]", "achown", DLG_CENTER);
 
 #define XTRACT(i) BY+chown_advanced_but[i].y, BX+chown_advanced_but[i].x, \
 	chown_advanced_but[i].ret_cmd, chown_advanced_but[i].flags, _(chown_advanced_but[i].text), \
@@ -659,21 +639,6 @@ chown_advanced_cmd (void)
 
     files_on_begin = cpanel->marked;
 
-#if 0
-    /* I think that this code is trying to be much too clever  -- pavel@ucw.cz */
-    if (!vfs_current_is_local ()) {
-	if (vfs_current_is_extfs ()) {
-	    message (1, _(" Oops... "),
-		     _(" I can't run the Advanced Chown command on an extfs "));
-	    return;
-	} else if (vfs_current_is_tarfs ()) {
-	    message (1, _(" Oops... "),
-		     _(" I can't run the Advanced Chown command on a tarfs "));
-	    return;
-	}
-    }
-#endif
-
     do {			/* do while any files remaining */
 	init_chown_advanced ();
 
@@ -688,9 +653,7 @@ chown_advanced_cmd (void)
 	}
 	ch_cmode = sf_stat->st_mode;
 
-#ifndef HAVE_X
 	chown_refresh ();
-#endif
 	
 	get_ownership ();
 
