@@ -17,7 +17,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 /* }}} */
 
@@ -32,11 +32,14 @@
 #    include <unistd.h>
 #endif
 #include <sys/stat.h>
-#include <sys/param.h>
+#ifdef HAVE_SYS_PARAM_H
+#    include <sys/param.h>
+#endif
 #include <string.h>
 #include <fcntl.h>
 #include <stdio.h>
 #include "tty.h"
+#include "x.h"
 #include "global.h"
 #include "dlg.h"
 #include "widget.h"
@@ -46,7 +49,7 @@
  * We currenlty only support one way of comunicating the background
  * and foreground process by using the socketpair system call
  */
-#ifdef USE_NETCODE
+#ifdef WITH_BACKGROUND
 #    include <sys/socket.h>
 #endif
 #include "dialog.h"
@@ -178,58 +181,46 @@ do_background (FileOpContext *ctx, char *info)
 static char *
 background_title (char *str)
 {
-    char *result = g_strconcat (_("Background process:"), str, NULL);
-
-    return result;
+    return g_strconcat (_("Background process:"), str, NULL);
 }
 
 /* {{{ Routines that do the real job */
 static void
-real_message_1s (enum OperationMode mode, int *flags, char *title, char *str1)
+real_message_1s (enum OperationMode mode, int *flags, char *title, const char *str1)
 {
-    char *full_title;
-    
     if (mode == Background)
-	full_title = background_title (title);
-    else
-        full_title = title;
-    
-    message (*flags, title, str1);
+	title = background_title (title);
 
-    if (title != full_title)
-	g_free (full_title);
+    message (*flags, title, "%s", str1);
+
+    if (mode == Background)
+	g_free (title);
 }
 
 static void
-real_message_2s (enum OperationMode mode, int *flags, char *title, char *str1, char *str2)
+real_message_2s (enum OperationMode mode, int *flags, char *title,
+		 const char *str1, const char *str2)
 {
-    char *full_title;
-    
     if (mode == Background)
-	full_title = background_title (title);
-    else
-        full_title = title;
+	title = background_title (title);
     
     message (*flags, title, str1, str2);
     
-    if (title != full_title)
-	g_free (full_title);
+    if (mode == Background)
+	g_free (title);
 }
 
 static void
-real_message_3s (enum OperationMode mode, int *flags, char *title, char *str1, char *str2, const char *str3)
+real_message_3s (enum OperationMode mode, int *flags, char *title,
+		 const char *str1, const char *str2, const char *str3)
 {
-    char *full_title;
-    
     if (mode == Background)
-	full_title = background_title (title);
-    else
-        full_title = title;
+	title = background_title (title);
     
     message (*flags, title, str1, str2, str3);
     
-    if (title != full_title)
-	g_free (full_title);
+    if (mode == Background)
+	g_free (title);
 }
 /* }}} */
 
@@ -281,15 +272,15 @@ background_attention (int fd, void *closure)
     void *routine;
     int  argc, i, result, status;
     char *data [MAXCALLARGS];
-    char *resstr;
     int bytes;
     enum ReturnType type;
-    char *background_process_error = _(" Background process error ");
 
     ctx = closure;
 
     bytes = read (fd, &routine, sizeof (routine));
     if (bytes < (sizeof (routine))){
+	char *background_process_error = _(" Background process error ");
+
 	if (errno == ECHILD)
 	    message (1, background_process_error, _(" Child died unexpectedly "));
 	else
@@ -373,6 +364,7 @@ background_attention (int fd, void *closure)
 	    write (fd, ctx, sizeof (FileOpContext));
     } else if (type == Return_String) {
 	int len;
+	char *resstr = NULL;
 
 	/* FIXME: string routines should also use the Foreground/Background
 	 * parameter.  Currently, this is not used here
@@ -414,7 +406,7 @@ background_attention (int fd, void *closure)
     mc_refresh ();
 #ifndef HAVE_X
     doupdate ();
-#endif
+#endif /* !HAVE_X */
     return 0;
 }
 
@@ -501,7 +493,7 @@ tell_parent (int msg)
 }
 
 void
-message_1s (int flags, char *title, char *str1)
+message_1s (int flags, char *title, const char *str1)
 {
     if (we_are_background)
 	parent_call ((void *)real_message_1s, NULL, 3, sizeof (flags), &flags,
@@ -511,7 +503,7 @@ message_1s (int flags, char *title, char *str1)
 }
 
 void
-message_2s (int flags, char *title, char *str1, char *str2)
+message_2s (int flags, char *title, const char *str1, const char *str2)
 {
     if (we_are_background)
 	parent_call ((void *)real_message_2s, NULL, 4, sizeof (flags), &flags,
@@ -522,7 +514,8 @@ message_2s (int flags, char *title, char *str1, char *str2)
 }
 
 void
-message_3s (int flags, char *title, char *str1, char *str2, const char *str3)
+message_3s (int flags, char *title, const char *str1,
+	    const char *str2, const char *str3)
 {
     if (we_are_background)
 	parent_call ((void *)real_message_3s, NULL, 3, sizeof (flags), &flags,
@@ -535,7 +528,6 @@ message_3s (int flags, char *title, char *str1, char *str2, const char *str3)
 char *
 input_dialog_help (char *header, char *text, char *help, char *def_text)
 {
-    extern char *real_input_dialog_help (char *header, char *text, char *help, char *def_text);
     if (we_are_background)
 	return parent_call_string ((void *)real_input_dialog_help, 4,
 				   strlen (header),   header,
@@ -550,19 +542,20 @@ input_dialog_help (char *header, char *text, char *help, char *def_text)
 
 /* {{{ Stubs if background code is not supported */
 void
-message_1s (int flags, char *title, char *str1)
+message_1s (int flags, char *title, const char *str1)
 {
-    message (flags, title, str1);
+    message (flags, title, "%s", str1);
 }
 
 void
-message_2s (int flags, char *title, char *str1, char *str2)
+message_2s (int flags, char *title, const char *str1, const char *str2)
 {
     message (flags, title, str1, str2);
 }
 
 void
-message_3s (int flags, char *title, char *str1, char *str2, const char *str3)
+message_3s (int flags, char *title, const char *str1,
+	    const char *str2, const char *str3)
 {
     message (flags, title, str1, str2, str3);
 }
@@ -574,12 +567,12 @@ input_dialog_help (char *header, char *text, char *help, char *def_text)
 }
 /* }}} */
 
-#endif
+#endif /* !WITH_BACKGROUND */
 
 /* {{{ Functions shared between background and foreground */
 
 void
-message_1s1d (int flags, char *title, char *str, int d)
+message_1s1d (int flags, char *title, const char *str, int d)
 {
     char *p = g_strdup_printf (str, d);
     message_1s (flags, title, p);
