@@ -49,6 +49,15 @@
 #include "background.h"
 #include "x.h"
 
+#ifdef HAVE_CHARSET
+#include "charsets.h"
+#include "selcodepage.h"
+#endif
+
+#ifdef WITH_SMBFS
+#include "../vfs/vfs.h"		/* smb_authinfo */
+#endif /* WITH_SMBFS */
+
 static int DISPLAY_X = 45, DISPLAY_Y = 14;
 
 static Dlg_head *dd;
@@ -77,7 +86,6 @@ static int user_hotkey = 'u';
 static int
 display_callback (struct Dlg_head *h, int id, int Msg)
 {
-#ifndef HAVE_X
     switch (Msg){
     case DLG_DRAW:
 	attrset (COLOR_NORMAL);
@@ -126,7 +134,6 @@ display_callback (struct Dlg_head *h, int id, int Msg)
 	    return MSG_HANDLED;
 	}
     }
-#endif    
     return MSG_NOT_HANDLED;
 }
 
@@ -180,7 +187,7 @@ display_init (int radio_sel, char *init_text,
         i18n_displays_flag = 1;
     }
     dd = create_dlg (0, 0, DISPLAY_Y, DISPLAY_X, dialog_colors,
-		     display_callback, "[Left and Right Menus]", "display",
+		     display_callback, "[Listing Mode...]", "display",
 		     DLG_CENTER | DLG_GRID);
 
     x_set_dialog_title (dd, _("Listing mode"));
@@ -203,11 +210,7 @@ display_init (int radio_sel, char *init_text,
     add_widget (dd, user);
     input_set_point (user, 0);
 
-#ifdef PORT_HAS_ICON_VIEW
-    my_radio = radio_new (3, 5, LIST_TYPES, displays, 1, "radio");
-#else
     my_radio = radio_new (3, 5, LIST_TYPES-1, displays, 1, "radio");
-#endif
     my_radio->sel = my_radio->pos = current_mode;
     add_widget (dd, my_radio);
 }
@@ -327,7 +330,7 @@ sort_box (sortfn *sort_fn, int *reverse, int *case_sensitive)
 	}
     
     dd = create_dlg (0, 0, SORT_Y, SORT_X, dialog_colors, common_dialog_callback,
-		     "[Left and Right Menus]", "sort", DLG_CENTER | DLG_GRID);
+		     "[Sort Order...]", "sort", DLG_CENTER | DLG_GRID);
 		     
     x_set_dialog_title (dd, sort_title);
 
@@ -452,6 +455,9 @@ confirm_box ()
 #define DISPY 11
 #define DISPX 46
 
+
+#ifndef HAVE_CHARSET
+
 static int new_mode;
 static int new_meta;
 
@@ -530,16 +536,127 @@ display_bits_box ()
 
     eight_bit_clean = new_mode < 2;
     full_eight_bits = new_mode == 0;
-#ifndef HAVE_X
 #ifndef HAVE_SLANG
     meta (stdscr, eight_bit_clean);
 #else
     SLsmg_Display_Eight_Bit = full_eight_bits ? 128 : 160;
-#endif
 #endif
     use_8th_bit_as_meta = !new_meta;
 }
 
+
+#else /* HAVE_CHARSET */
+
+
+Dlg_head *dbits_dlg;
+
+static void dbits_refresh()
+{
+    attrset( COLOR_NORMAL );
+    dlg_erase( dbits_dlg );
+    
+    draw_box( dbits_dlg, 1, 2, dbits_dlg->lines - 2, dbits_dlg->cols - 4 );
+    
+    attrset( COLOR_HOT_NORMAL );
+    dlg_move( dbits_dlg, 1, (dbits_dlg->cols - strlen(dbits_dlg->title)) / 2 );
+    addstr( dbits_dlg->title );
+}
+
+static int dbits_callback( Dlg_head * h, int Par, int Msg )
+{
+    switch (Msg) {
+	case DLG_DRAW:
+	    dbits_refresh();
+	    break;
+    }
+    return 0;
+}
+
+static int new_display_codepage;
+
+WLabel *cplabel;
+WCheck *inpcheck;
+
+static int sel_charset_button( int action, void *param )
+{
+    char *cpname, buf[64];
+    new_display_codepage = select_charset( new_display_codepage, 1 );
+    cpname = (new_display_codepage < 0)
+	     ? _("Other 8 bit")
+	     : codepages[ new_display_codepage ].name;
+    sprintf( buf, "%-27s", cpname ); /* avoid strange bug with label repainting */
+    label_set_text( cplabel, buf );
+    return 0;
+}
+
+void init_disp_bits_box()
+{
+    char *cpname;
+
+    do_refresh();
+
+    dbits_dlg = create_dlg( 0, 0, DISPY, DISPX, dialog_colors,
+		dbits_callback, "[Display bits]", "Display bits",
+		DLG_CENTER );
+    x_set_dialog_title( dbits_dlg, _(" Display bits "));
+
+    add_widget( dbits_dlg,
+		label_new( 3, 4, _("Input / display codepage:"), NULL));
+
+    cpname = (new_display_codepage < 0)
+	     ? "Other 8 bit"
+	     : codepages[ new_display_codepage ].name;
+    cplabel = label_new( 4, 4, cpname, NULL);
+    add_widget( dbits_dlg, cplabel );
+	
+    add_widget( dbits_dlg,
+		button_new( DISPY - 3, DISPX / 2 + 3, B_CANCEL,
+			    NORMAL_BUTTON, _("&Cancel"), 0, 0, NULL ) );
+    add_widget( dbits_dlg,
+		button_new( DISPY - 3, 7, B_ENTER,
+			    NORMAL_BUTTON, _("&Ok"), 0, 0, NULL ) );
+
+    inpcheck = check_new( 6, 4, !use_8th_bit_as_meta,
+			  _("F&ull 8 bits input"), NULL );
+    add_widget( dbits_dlg, inpcheck );
+
+    cpname = _("&Select");
+    add_widget( dbits_dlg,
+		button_new( 4, DISPX - 8 - strlen(cpname) , B_USER,
+			    NORMAL_BUTTON, cpname,
+			    sel_charset_button, 0, NULL ) );
+}
+
+void display_bits_box()
+{
+    new_display_codepage = display_codepage;
+
+    application_keypad_mode ();
+    init_disp_bits_box();
+
+    run_dlg( dbits_dlg );
+
+    if (dbits_dlg->ret_value == B_ENTER) {
+	char *errmsg;
+	display_codepage = new_display_codepage;
+	errmsg = init_translation_table( source_codepage, display_codepage );
+	if (errmsg)
+	    message( 1, MSG_ERROR, "%s", errmsg );
+#ifndef HAVE_SLANG
+	meta( stdscr, display_codepage != 0 );
+#else
+	SLsmg_Display_Eight_Bit
+	    = (display_codepage != 0 && display_codepage != 1) ? 128 : 160;
+#endif
+	use_8th_bit_as_meta = ! (inpcheck->state & C_BOOL);
+    }    
+    destroy_dlg( dbits_dlg );
+    repaint_screen();
+}
+
+#endif /* HAVE_CHARSET */
+
+
 #define TREE_Y 20
 #define TREE_X 60
 
@@ -565,7 +682,6 @@ tree_callback (struct Dlg_head *h, int id, int msg)
     return MSG_NOT_HANDLED;
 }
 
-#ifndef HAVE_GNOME
 char *
 tree (char *current_dir)
 {
@@ -596,13 +712,6 @@ tree (char *current_dir)
     destroy_dlg (dlg);
     return val;
 }
-#endif
-
-#ifndef USE_VFS
-#ifdef USE_NETCODE
-#undef USE_NETCODE
-#endif
-#endif
 
 #ifdef USE_VFS
 
@@ -720,13 +829,6 @@ cd_dialog (void)
 {
     QuickDialog Quick_input;
     QuickWidget quick_widgets [] = {
-#ifdef HAVE_TK
-#define INPUT_INDEX 2
-    { quick_button, 0, 1, 0, 1, N_("&Cancel"), 0, B_CANCEL, 0, 0, "cancel" },
-    { quick_button, 0, 1, 0, 1, N_("&Ok"),     0, B_ENTER,  0, 0, "ok" },
-#else
-#define INPUT_INDEX 0
-#endif
     { quick_input,  6, 57, 5, 0, "", 50, 0, 0, 0, "input" },
     { quick_label,  3, 57, 2, 0, "",  0, 0, 0, 0, "label" },
     { 0 } };
@@ -738,51 +840,40 @@ cd_dialog (void)
     Quick_input.title = _("Quick cd");
     Quick_input.help  = "[Quick cd]";
     Quick_input.class = "quick_input";
-    quick_widgets [INPUT_INDEX].text = "";
-    quick_widgets [INPUT_INDEX].value = 2; /* want cd like completion */
-    quick_widgets [INPUT_INDEX+1].text = _("cd");
-    quick_widgets [INPUT_INDEX+1].y_divisions =
-	quick_widgets [INPUT_INDEX].y_divisions = Quick_input.ylen = 5;
+    quick_widgets [0].text = "";
+    quick_widgets [0].value = 2; /* want cd like completion */
+    quick_widgets [1].text = _("cd");
+    quick_widgets [1].y_divisions =
+	quick_widgets [0].y_divisions = Quick_input.ylen = 5;
 
-	len = strlen (quick_widgets [INPUT_INDEX+1].text);
+	len = strlen (quick_widgets [1].text);
 
-	quick_widgets [INPUT_INDEX+1].relative_x = 3;
-	quick_widgets [INPUT_INDEX].relative_x = 
-		quick_widgets [INPUT_INDEX+1].relative_x + len + 1;
+	quick_widgets [1].relative_x = 3;
+	quick_widgets [0].relative_x = 
+		quick_widgets [1].relative_x + len + 1;
 
-    Quick_input.xlen = len + quick_widgets [INPUT_INDEX].hotkey_pos + 7;
-	quick_widgets [INPUT_INDEX].x_divisions =
-		quick_widgets [INPUT_INDEX+1].x_divisions = Quick_input.xlen;
+    Quick_input.xlen = len + quick_widgets [0].hotkey_pos + 7;
+	quick_widgets [0].x_divisions =
+		quick_widgets [1].x_divisions = Quick_input.xlen;
 
     Quick_input.i18n = 1;
     Quick_input.xpos = 2;
     Quick_input.ypos = LINES - 2 - Quick_input.ylen;
-    quick_widgets [INPUT_INDEX].relative_y = 2;
-    quick_widgets [INPUT_INDEX].str_result = &my_str;
+    quick_widgets [0].relative_y = 2;
+    quick_widgets [0].str_result = &my_str;
     
     Quick_input.widgets = quick_widgets;
     if (quick_dialog (&Quick_input) != B_CANCEL){
-	return *(quick_widgets [INPUT_INDEX].str_result);
+	return *(quick_widgets [0].str_result);
     } else
 	return 0;
 }
 
-#ifndef HAVE_GNOME
 void
 symlink_dialog (char *existing, char *new, char **ret_existing, char **ret_new)
 {
     QuickDialog Quick_input;
     QuickWidget quick_widgets [] = {
-#undef INPUT_INDEX
-#if defined(HAVE_TK)
-#define INPUT_INDEX 2
-    { quick_button, 0, 1, 0, 1, _("&Cancel"), 0, B_CANCEL, 0, 0,
-	  "cancel" },
-    { quick_button, 0, 1, 0, 1, _("&Ok"), 0, B_ENTER, 0, 0,
-	  "ok" },
-#else
-#define INPUT_INDEX 0
-#endif
     { quick_input,  4, 80, 5, 8, "", 58, 0, 0, 0, "input-1" },
     { quick_label,  4, 80, 4, 8, "", 0, 0, 0, 0, "label-1" },
     { quick_input,  4, 80, 3, 8, "", 58, 0, 0, 0, "input-2" },
@@ -795,13 +886,13 @@ symlink_dialog (char *existing, char *new, char **ret_existing, char **ret_new)
     Quick_input.help  = "[File Menu]";
     Quick_input.class = "quick_symlink";
     Quick_input.i18n  = 0;
-    quick_widgets [INPUT_INDEX].text = new;
-    quick_widgets [INPUT_INDEX+1].text = _("Symbolic link filename:");
-    quick_widgets [INPUT_INDEX+2].text = existing;
-    quick_widgets [INPUT_INDEX+3].text = _("Existing filename (filename symlink will point to):");
+    quick_widgets [0].text = new;
+    quick_widgets [1].text = _("Symbolic link filename:");
+    quick_widgets [2].text = existing;
+    quick_widgets [3].text = _("Existing filename (filename symlink will point to):");
     Quick_input.xpos = -1;
-    quick_widgets [INPUT_INDEX].str_result = ret_new;
-    quick_widgets [INPUT_INDEX+2].str_result = ret_existing;
+    quick_widgets [0].str_result = ret_new;
+    quick_widgets [2].str_result = ret_existing;
     
     Quick_input.widgets = quick_widgets;
     if (quick_dialog (&Quick_input) == B_CANCEL){
@@ -809,7 +900,6 @@ symlink_dialog (char *existing, char *new, char **ret_existing, char **ret_new)
         *ret_existing = NULL;
     }
 }
-#endif
 
 #ifdef WITH_BACKGROUND
 #define B_STOP   B_USER+1
@@ -885,7 +975,7 @@ static struct
 	char* name;
 	int xpos;
 	int value;
-	int (*callback)();
+	int (*callback)(int, void *);
 	char* tkname;
 } 
 job_buttons [] =
@@ -952,4 +1042,113 @@ jobs_cmd (void)
     
     destroy_dlg (jobs_dlg);
 }
-#endif
+#endif /* WITH_BACKGROUND */
+
+#ifdef WITH_SMBFS
+struct smb_authinfo *
+vfs_smb_get_authinfo (const char *host, const char *share, const char *domain,
+		      const char *user)
+{
+    static int dialog_x = 44;
+    int dialog_y = 12;
+    struct smb_authinfo *return_value;
+    static char* labs[] = {N_("Domain:"), N_("Username:"), N_("Password: ")};
+    static char* buts[] = {N_("&Ok"), N_("&Cancel")};
+    static int ilen = 30, istart = 14;
+    static int b0 = 3, b2 = 30;
+    char *title;
+    WInput *in_password;
+    WInput *in_user;
+    WInput *in_domain;
+    Dlg_head *auth_dlg;
+
+#ifdef ENABLE_NLS
+    static int i18n_flag = 0;
+    
+    if (!i18n_flag)
+    {
+        register int i = sizeof(labs)/sizeof(labs[0]);
+        int l1, maxlen = 0;
+        
+        while (i--)
+        {
+            l1 = strlen (labs [i] = _(labs [i]));
+            if (l1 > maxlen)
+                maxlen = l1;
+        }
+        i = maxlen + ilen + 7;
+        if (i > dialog_x)
+            dialog_x = i;
+        
+        for (i = sizeof(buts)/sizeof(buts[0]), l1 = 0; i--; )
+        {
+            l1 += strlen (buts [i] = _(buts [i]));
+        }
+        l1 += 15;
+        if (l1 > dialog_x)
+            dialog_x = l1;
+
+        ilen = dialog_x - 7 - maxlen; /* for the case of very long buttons :) */
+        istart = dialog_x - 3 - ilen;
+        
+        b2 = dialog_x - (strlen(buts[1]) + 6);
+        
+        i18n_flag = 1;
+    }
+    
+#endif /* ENABLE_NLS */
+
+    if (!domain)
+    domain = "";
+    if (!user)
+    user = "";
+
+    auth_dlg = create_dlg (0, 0, dialog_y, dialog_x, dialog_colors,
+                       common_dialog_callback, "[Smb Authinfo]", "smbauthinfo",
+                       DLG_CENTER | DLG_GRID);
+
+    title = g_strdup_printf (_("Password for \\\\%s\\%s"), host, share);
+    x_set_dialog_title (auth_dlg, title);
+    g_free (title);
+
+    in_user  = input_new (5, istart, INPUT_COLOR, ilen, user, "auth_name");
+    add_widget (auth_dlg, in_user);
+
+    in_domain = input_new (3, istart, INPUT_COLOR, ilen, domain, "auth_domain");
+    add_widget (auth_dlg, in_domain);
+    add_widget (auth_dlg, button_new (9, b2, B_CANCEL, NORMAL_BUTTON,
+                 buts[1], 0 ,0, "cancel"));
+    add_widget (auth_dlg, button_new (9, b0, B_ENTER, DEFPUSH_BUTTON,
+                 buts[0], 0, 0, "ok"));
+
+    in_password  = input_new (7, istart, INPUT_COLOR, ilen, "", "auth_password");
+    in_password->completion_flags = 0;
+    in_password->is_password = 1;
+    add_widget (auth_dlg, in_password);
+
+    add_widget (auth_dlg, label_new (7, 3, labs[2], "label-passwd"));
+    add_widget (auth_dlg, label_new (5, 3, labs[1], "label-user"));
+    add_widget (auth_dlg, label_new (3, 3, labs[0], "label-domain"));
+
+    run_dlg (auth_dlg);
+
+    switch (auth_dlg->ret_value) {
+    case B_CANCEL:
+        return_value = 0;
+        break;
+    default:
+        return_value = g_new (struct smb_authinfo, 1);
+        if (return_value) {
+            return_value->host = g_strdup (host);
+            return_value->share = g_strdup (share);
+            return_value->domain = g_strdup (in_domain->buffer);
+            return_value->user = g_strdup (in_user->buffer);
+            return_value->password = g_strdup (in_password->buffer);
+        }
+    }
+
+    destroy_dlg (auth_dlg);
+             
+    return return_value;
+}
+#endif /* WITH_SMBFS */
