@@ -46,12 +46,8 @@
 #include "chown.h"
 #include "../vfs/vfs.h"
 
-#ifdef HAVE_TK
-#   include "tkmain.h"
-#endif
-
 static int single_set;
-struct Dlg_head *ch_dlg;
+static struct Dlg_head *ch_dlg;
 
 #define PX		5
 #define PY		2
@@ -73,19 +69,18 @@ struct Dlg_head *ch_dlg;
 #define B_SETMRK        B_USER+2
 #define B_CLRMRK        B_USER+3
 
-int mode_change, need_update;
-int c_file, end_chmod;
+static int mode_change, need_update;
+static int c_file, end_chmod;
 
-umode_t and_mask, or_mask, c_stat;
-char *c_fname, *c_fown, *c_fgrp, *c_fperm;
-int c_fsize;
+static umode_t and_mask, or_mask, c_stat;
+static char *c_fname, *c_fown, *c_fgrp;
 
 static WLabel *statl;
 static int normal_color;
 static int title_color;
 static int selection_color;
 
-struct {
+static struct {
     mode_t mode;
     char *text;
     int selected;
@@ -106,7 +101,7 @@ struct {
     { S_ISUID, N_("set user ID on execution"), 0, 0, },
 };
 
-struct {
+static struct {
     int ret_cmd, flags, y, x;
     char *text;
 } chmod_but[BUTTONS] = 
@@ -119,12 +114,6 @@ struct {
     { B_ALL,    NORMAL_BUTTON,  0, 0,  N_("Set &all") },
 };
 
-#ifdef HAVE_X
-static void chmod_toggle_select (void)
-{
-}
-
-#else
 static void chmod_toggle_select (void)
 {
     int Id = ch_dlg->current->dlg_id - BUTTONS + single_set * 2;
@@ -174,7 +163,6 @@ static void chmod_refresh (void)
     dlg_move (ch_dlg, TY + 3, TX);
     addstr (_("and T or INS to mark"));
 }
-#endif
 
 static int chmod_callback (Dlg_head *h, int Par, int Msg)
 {
@@ -200,11 +188,10 @@ static int chmod_callback (Dlg_head *h, int Par, int Msg)
 	    return 1;
 	}
 	break;
-#ifndef HAVE_X
+
     case DLG_DRAW:
 	chmod_refresh ();
 	break;
-#endif
     }
     return 0;
 }
@@ -309,22 +296,6 @@ void chmod_cmd (void)
     int i;
     struct stat sf_stat;
 
-#if 0
-    /* Don't do things like this: you do not want to enumerate all
-       filesystems that can not support chmod, here. */
-    if (!vfs_current_is_local ()) {
-	if (vfs_current_is_extfs ()) {
-	    message (1, _(" Oops... "),
-		     _(" I can't run the Chmod command on an extfs "));
-	    return;
-	} else if (vfs_current_is_tarfs ()) {
-	    message (1, _(" Oops... "),
-		     _(" I can't run the Chmod command on a tarfs "));
-	    return;
-	}
-    }
-#endif
-
     do {			/* do while any files remaining */
 	init_chmod ();
 	if (cpanel->marked)
