@@ -20,17 +20,22 @@
 
 #include <config.h>
 #ifdef __os2__
-#  define INCL_DOSFILEMGR
-#  define INCL_DOSMISC
-#  define INCL_DOSERROR
+#   define INCL_DOSFILEMGR
+#   define INCL_DOSMISC
+#   define INCL_DOSERROR
 #endif
+
 #ifdef HAVE_UNISTD_H
-#    include <unistd.h>
+#   include <unistd.h>
 #endif
-#include "tty.h"
+
 #include <stdio.h>
 #include <sys/types.h>
-#include <sys/param.h>
+
+#ifdef HAVE_SYS_PARAM_H
+#   include <sys/param.h>
+#endif
+
 #include <sys/stat.h>
 #include <sys/time.h>
 #include <string.h>
@@ -48,6 +53,8 @@
 #ifdef HAVE_MMAP
 #   include <sys/mman.h>
 #endif
+
+#include "tty.h"
 #include "global.h"
 #include "dir.h"
 #include "panel.h"
@@ -77,9 +84,6 @@
 #include "setup.h"
 #include "x.h"
 #include "profile.h"
-#ifndef HAVE_X
-#include "textconf.h"
-#endif
 
 #define MIDNIGHT
 #include "../vfs/vfs.h"
@@ -89,10 +93,6 @@
 #   define MAP_FILE 0
 #endif
 
-#ifdef HAVE_TK
-#    include "tkscreen.h"
-#endif
-
 /* If set and you don't have subshell support,then C-o will give you a shell */
 int output_starts_shell = 0;
 
@@ -107,10 +107,6 @@ int is_right;
 #define MENU_PANEL_IDX  (is_right ? 1 : 0)
 
 
-#ifndef PORT_HAS_FILTER_CHANGED
-#    define x_filter_changed(p)
-#endif
-
 /* This is used since the parameter panel on some of the commands */
 /* defined in this file may receive a 0 parameter if they are invoked */
 /* The drop down menu */
@@ -168,7 +164,7 @@ int view_file_at_line (char *filename, int plain_view, int internal, int start_l
         return move_dir;
     }
     if (internal){
-#ifdef HAVE_GNOME
+#ifdef HAVE_X
 	gmc_view (filename, start_line);
 #else
 	char view_entry [BUF_TINY];
@@ -182,7 +178,7 @@ int view_file_at_line (char *filename, int plain_view, int internal, int start_l
 	    view (0, filename, &move_dir, start_line);
 	    repaint_screen ();
 	}
-#endif
+#endif /* !HAVE_X */
     } else {
 	char *localcopy;
 	
@@ -323,7 +319,7 @@ void do_edit_at_line (const char *what, int start_line)
 	repaint_screen ();
 	return;
     }
-#endif
+#endif /* USE_INTERNAL_EDIT */
     if (!editor){
 	editor = getenv ("EDITOR");
 	if (!editor)
@@ -342,13 +338,13 @@ do_edit (const char *what)
 
 void edit_cmd (WPanel *panel)
 {
-#ifndef HAVE_GNOME
+#ifndef HAVE_X
     panel = get_a_panel(panel);
     if (!regex_command (selection (panel)->fname, "Edit", NULL, 0))
         do_edit (selection (panel)->fname);
 #else
     gmc_edit (selection (panel)->fname);
-#endif
+#endif /* !HAVE_X */
 }
 
 void edit_cmd_new (WPanel *panel)
@@ -439,9 +435,12 @@ set_panel_filter_to (WPanel *p, char *allocated_filter_string)
     else
 	g_free (allocated_filter_string);
     reread_cmd ();
+#ifdef HAVE_X
     x_filter_changed (p);
+#endif /* HAVE_X */
 }
 
+#ifndef HAVE_X
 /* Set a given panel filter expression */
 void set_panel_filter (WPanel *p)
 {
@@ -450,7 +449,9 @@ void set_panel_filter (WPanel *p)
     
     x = p->filter ? p->filter : easy_patterns ? "*" : ".";
 	
-    reg_exp = input_dialog (_(" Filter "), _(" Set expression for filtering filenames"), x);
+    reg_exp = input_dialog_help (_(" Filter "),
+				 _(" Set expression for filtering filenames"),
+				 "[Filter...]", x);
     if (!reg_exp)
 	return;
     set_panel_filter_to (p, reg_exp);
@@ -467,6 +468,7 @@ void filter_cmd (void)
     p = MENU_PANEL;
     set_panel_filter (p);
 }
+#endif /* HAVE_X */
 
 void reread_cmd (void)
 {
@@ -504,10 +506,12 @@ void reverse_selection_cmd_panel (WPanel *panel)
     paint_panel (panel);
 }
 
+#ifndef HAVE_X
 void reverse_selection_cmd (void)
 {
     reverse_selection_cmd_panel (cpanel);
 }
+#endif /* HAVE_X */
 
 void select_cmd_panel (WPanel *panel)
 {
@@ -556,10 +560,12 @@ void select_cmd_panel (WPanel *panel)
     g_free (reg_exp);
 }
 
+#ifndef HAVE_X
 void select_cmd (void)
 {
 	select_cmd_panel (cpanel);
 }
+#endif /* !HAVE_X */
 
 void unselect_cmd_panel (WPanel *panel)
 {
@@ -607,6 +613,7 @@ void unselect_cmd_panel (WPanel *panel)
     g_free (reg_exp);
 }
 
+#ifndef HAVE_X
 void unselect_cmd (void)
 {
 	unselect_cmd_panel (cpanel);
@@ -633,7 +640,6 @@ static int check_for_default(char *default_file, char *file)
     return 0;
 }
 
-#ifndef HAVE_GNOME
 void ext_cmd (void)
 {
     char *buffer;
@@ -659,7 +665,6 @@ void ext_cmd (void)
    g_free (extdir);
    flush_extension_file ();
 }
-#endif /* !HAVE_GNOME */
 
 /* where  = 0 - do edit a file menu for mc */
 /* where  = 1 - do edit a file menu for cool edit */
@@ -712,11 +717,9 @@ void quick_chdir_cmd (void)
     if (!target)
 	return;
 
-#ifndef HAVE_GNOME
     if (get_current_type () == view_tree)
 	tree_chdir (the_tree, target);
     else
-#endif
         if (!do_cd (target, cd_exact))
 	    message (1, MSG_ERROR, _("Could not change directory") );
     g_free (target);
@@ -740,7 +743,7 @@ void reselect_vfs (void)
         message (1, MSG_ERROR, _("Could not change directory") );
     g_free (target);
 }
-#endif
+#endif /* USE_VFS */
 
 static int compare_files (char *name1, char *name2, long size)
 {
@@ -775,7 +778,7 @@ static int compare_files (char *name1, char *name2, long size)
 		while((n2 = read(file2,buf2,BUFSIZ)) == -1 && errno == EINTR);
 	    } while (n1 == n2 && n1 == BUFSIZ && !memcmp(buf1,buf2,BUFSIZ));
 	    result = (n1 != n2) || memcmp(buf1,buf2,n1);
-#endif
+#endif /* !HAVE_MMAP */
 	    close (file2);
 	}
 	close (file1);
@@ -916,14 +919,12 @@ void history_cmd (void)
     update_input (input_w (cmdline), 1);
 }
 
-#if !defined(HAVE_XVIEW) && !defined(HAVE_GNOME)
 void swap_cmd (void)
 {
     swap_panels ();
     touchwin (stdscr);
     repaint_screen ();
 }
-#endif
 
 void
 view_other_cmd (void)
@@ -932,7 +933,7 @@ view_other_cmd (void)
 #ifdef HAVE_SUBSHELL_SUPPORT
     char *new_dir = NULL;
     char **new_dir_p;
-#endif
+#endif /* HAVE_SUBSHELL_SUPPORT */
 
     if (!xterm_flag && !console_flag && !use_subshell){
 	if (message_flag)
@@ -940,27 +941,23 @@ view_other_cmd (void)
 				     " the panels cannot be toggled. "));
 	message_flag = FALSE;
     } else {
-#ifndef HAVE_X
 	if (use_mouse_p)
 	    shut_mouse ();
 	if (clear_before_exec)
 	    clr_scr ();
         if (alternate_plus_minus)
             numeric_keypad_mode ();
-#endif
 #ifndef HAVE_SLANG
 	/* With slang we don't want any of this, since there
 	 * is no mc_raw_mode supported
 	 */
 	reset_shell_mode ();
 	noecho ();
-#endif
-#ifndef HAVE_X
+#endif /* HAVE_SLANG */
 	keypad(stdscr, FALSE);
 	endwin ();
 	if (!status_using_ncurses)
 	    do_exit_ca_mode ();
-#endif
 	mc_raw_mode ();
 	if (console_flag)
 	    restore_console ();
@@ -971,7 +968,7 @@ view_other_cmd (void)
 	    if (invoke_subshell (NULL, VISIBLY, new_dir_p))
 		quiet_quit_cmd();  /* User did `exit' or `logout': quit MC quietly */
 	} else
-#endif
+#endif /* HAVE_SUBSHELL_SUPPORT */
 	{
 	    if (output_starts_shell){
 		fprintf (stderr,
@@ -985,7 +982,6 @@ view_other_cmd (void)
 	if (console_flag)
 	    handle_console (CONSOLE_SAVE);
 
-#ifndef HAVE_X	
 	if (!status_using_ncurses)
 	    do_enter_ca_mode ();
 
@@ -995,7 +991,6 @@ view_other_cmd (void)
 	    init_mouse ();
         if (alternate_plus_minus)
             application_keypad_mode ();
-#endif	    
 
 #ifdef HAVE_SUBSHELL_SUPPORT
 	if (use_subshell){
@@ -1007,10 +1002,8 @@ view_other_cmd (void)
 				       LINES-keybar_visible-output_lines-1,
 				       LINES-keybar_visible-1);
 	}
-#endif
-#ifndef HAVE_X
+#endif /* HAVE_SUBSHELL_SUPPORT */
         touchwin (stdscr);
-#endif
 	
 	/* prevent screen flash when user did 'exit' or 'logout' within
 	   subshell */
@@ -1018,26 +1011,14 @@ view_other_cmd (void)
 	    repaint_screen ();
     }
 }
+#endif /* !HAVE_X */
 
 #ifndef OS2_NT
 static void
 do_link (int symbolic_link, char *fname)
 {
-    struct stat s;
     char *dest, *src;
-    int  stat_r;
 
-    if (!symbolic_link){
-	stat_r = mc_stat (fname, &s);
-	if (stat_r != 0){
-	    message (1, MSG_ERROR, _(" Couldn't stat %s \n %s "),
-		     fname, unix_error_string (errno));
-	    return;
-	}
-	if (!S_ISREG (s.st_mode))
-	    return;
-    }
-    
     if (!symbolic_link){
         src = g_strconcat (_(" Link "), name_trunc (fname, 46), 
             _(" to:"), NULL);
@@ -1053,42 +1034,34 @@ do_link (int symbolic_link, char *fname)
 	if (-1 == mc_link (fname, dest))
 	    message (1, MSG_ERROR, _(" link: %s "), unix_error_string (errno));
     } else {
-#ifdef OLD_SYMLINK_VERSION
-        symlink_dialog (fname, "", &dest, &src);
-#else
+	char *s;
+	char *d;
+
 	/* suggest the full path for symlink */
-        char s[MC_MAXPATHLEN];
-        char d[MC_MAXPATHLEN];
-	
-        strcpy(s, cpanel->cwd);
-        if ( ! ((s[0] == '/') && (s[1] == 0)))
-            strcat(s, "/");
-        strcat(s, fname);
-	if (get_other_type () == view_listing)
-	    strcpy(d, opanel->cwd);
-	else
-	    strcpy (d,"");
-	
-        if ( ! ((d[0] == '/') && (d[1] == 0)))
-            strcat(d, "/");
+	s = concat_dir_and_file (cpanel->cwd, fname);
+
+	if (get_other_type () == view_listing) {
+	    d = concat_dir_and_file (opanel->cwd, fname);
+	} else {
+	    d = g_strdup (fname);
+	}
+
         symlink_dialog (s, d, &dest, &src);
-#endif
-	if (!dest || !*dest) {
+	g_free (d);
+	g_free (s);
+
+	if (!dest || !*dest || !src || !*src) {
 	    if (src)
 	        g_free (src);
 	    if (dest)
 	        g_free (dest);
 	    return;
 	}
-	if (src){
-	    if (*src) {
-	        save_cwds_stat ();
-	        if (-1 == mc_symlink (dest, src))
-		    message (1, MSG_ERROR, _(" symlink: %s "),
-			     unix_error_string (errno));
-	    }
-	    g_free (src);
-	}
+	save_cwds_stat ();
+	if (-1 == mc_symlink (dest, src))
+	    message (1, MSG_ERROR, _(" symlink: %s "),
+		     unix_error_string (errno));
+	g_free (src);
     }
     g_free (dest);
     update_panels (UP_OPTIMIZE, UP_KEEPSEL);
@@ -1102,7 +1075,7 @@ void link_cmd (void)
 
 void symlink_cmd (void)
 {
-    char *filename;
+    char *filename = NULL;
     if (is_a_desktop_panel (cpanel)) {
         gint i;
 	for (i = 0; i < cpanel->count; i++) 
@@ -1113,15 +1086,18 @@ void symlink_cmd (void)
     } else {
 	    filename = selection (cpanel)->fname;
     }
-    do_link (1, filename);
+
+    if (filename) {
+	do_link (1, filename);
+    }
 }
 
 void edit_symlink_cmd (void)
 {
-#ifndef HAVE_GNOME
+#ifndef HAVE_X
 /* GNOME already checks this, and selection(cpanel) does bbad things */
     if (S_ISLNK (selection (cpanel)->buf.st_mode)) {
-#endif
+#endif /* !HAVE_X */
 	char buffer [MC_MAXPATHLEN];
 	char *p = NULL;
 	int i;
@@ -1162,9 +1138,12 @@ void edit_symlink_cmd (void)
 	    }
 	}
 	g_free (q);
-#ifndef HAVE_GNOME
+#ifndef HAVE_X
+    } else {
+	message (1, MSG_ERROR, _("`%s' is not a symbolic link"),
+		 selection (cpanel)->fname);
     }
-#endif
+#endif /* !HAVE_X */
 }
 
 void other_symlink_cmd (void)
@@ -1205,13 +1184,11 @@ void other_symlink_cmd (void)
     g_free (p);
     g_free (r);
 }
-#endif
+#endif /* !OS2_NT */
 
 void help_cmd (void)
 {
-   char *hlpfile = concat_dir_and_file (mc_home, _("mc.hlp"));
-   interactive_display (hlpfile, "[main]");
-   g_free (hlpfile);
+   interactive_display (NULL, "[main]");
 }
 
 void view_panel_cmd (void)
@@ -1229,8 +1206,8 @@ void mkdir_panel_cmd (void)
     mkdir_cmd (cpanel);
 }
 
-/* partly taken from dcgettect.c, returns "" for C locale */
-/* value should be gfreed by calling function */
+/* partly taken from dcigettext.c, returns "" for default locale */
+/* value should be freed by calling function g_free() */
 char *guess_message_value (unsigned want_info)
 {
     const char *var[] = {
@@ -1240,7 +1217,7 @@ char *guess_message_value (unsigned want_info)
 	/* Setting of LC_ALL overwrites all other.  */
 	"LC_ALL",
 	/* Next comes the name of the desired category.  */
-	"LC_MESSAGE",
+	"LC_MESSAGES",
         /* Last possibility is the LANG environment variable.  */
 	"LANG",
 	/* NULL exit loops */
@@ -1277,8 +1254,6 @@ char *guess_message_value (unsigned want_info)
 char *get_random_hint (void)
 {
     char *data, *result, *eol;
-    char *hintfile_base, *hintfile;
-    char *lang;
     int  len;
     int start;
     
@@ -1300,26 +1275,9 @@ char *get_random_hint (void)
     if (!(tv.tv_sec> last_sec+60))
 	return g_strdup (""); 
     last_sec = tv.tv_sec;
-#endif
+#endif /* !SCO_FLAVOR */
 
-    hintfile_base = concat_dir_and_file (mc_home, MC_HINT);
-    lang = guess_message_value (0);
-
-    hintfile = g_strdup_printf ("%s.%s", hintfile_base, lang);
-    data = load_file (hintfile);
-    g_free (hintfile);
-
-    if (!data) {
-	hintfile = g_strdup_printf ("%s.%.2s", hintfile_base, lang);
-	data = load_file (hintfile);
-	g_free (hintfile);
-
-	if (!data)
-	    data = load_file (hintfile_base);
-    }
-
-    g_free (lang);
-    g_free (hintfile_base);
+    data = load_mc_home_file (MC_HINT, NULL);
     if (!data)
 	return 0;
 
@@ -1327,7 +1285,7 @@ char *get_random_hint (void)
     srand ((short) now);
 #else
     srand (tv.tv_sec);
-#endif
+#endif /* !SCO_FLAVOR */
     /* get a random entry */
     len = strlen (data);
     start = rand () % len;
@@ -1346,12 +1304,7 @@ char *get_random_hint (void)
     return result;
 }
 
-#ifndef USE_VFS
-#ifdef USE_NETCODE
-#undef USE_NETCODE
-#endif
-#endif
-
+#ifndef HAVE_X
 #ifdef USE_NETCODE
 
 static char *machine_str = N_(" Enter machine name (F1 for details): ");
@@ -1435,7 +1388,7 @@ void undelete_cmd (void)
 	       "  files on: (F1 for details)"),
 	     "[Undelete File System]", "/#undel:", 0);
 }
-#endif
+#endif /* USE_EXT2FSLIB */
 
 void quick_cd_cmd (void)
 {
@@ -1450,6 +1403,7 @@ void quick_cd_cmd (void)
     if (p)
        g_free (p);
 }
+#endif /* !HAVE_X */
 
 void 
 dirsizes_cmd (void)
@@ -1474,6 +1428,7 @@ dirsizes_cmd (void)
     paint_panel (panel);
 }
 
+#ifndef HAVE_X
 void
 save_setup_cmd (void)
 {
@@ -1483,12 +1438,8 @@ save_setup_cmd (void)
     sync_profiles ();
     str = g_strconcat ( _(" Setup saved to ~/"), PROFILE_NAME, NULL);
     
-#ifdef HAVE_GNOME
-    set_hintbar (str);
-#else
     message (0, _(" Setup "), str);
-#endif
-   g_free (str);
+    g_free (str);
 }
 
 void
@@ -1517,7 +1468,6 @@ configure_panel_listing (WPanel *p, int view_type, int use_msformat, char *user,
     do_refresh ();
 }
 
-#ifndef HAVE_GNOME
 void
 info_cmd_no_menu (void)
 {
@@ -1582,7 +1532,6 @@ quick_view_cmd (void)
 	change_panel ();
     set_display_type (MENU_PANEL_IDX, view_quick);
 }
-#endif
 
 /* Handle the tree internal listing modes switching */
 static int
@@ -1590,9 +1539,9 @@ set_basic_panel_listing_to (int panel_index, int listing_mode)
 {
     WPanel *p = (WPanel *) get_panel_widget (panel_index);
 
-#ifndef HAVE_GNOME
+#ifndef HAVE_X
     switch_to_listing (panel_index);
-#endif
+#endif /* !HAVE_X */
     p->list_type = listing_mode;
     if (set_panel_formats (p))
 	return 0;
@@ -1625,4 +1574,5 @@ toggle_listing_cmd (void)
 	return;
     set_basic_panel_listing_to (current, list_full);
 }
+#endif /* !HAVE_X */
 
