@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include <config.h>
 #include "tty.h"
@@ -24,7 +24,7 @@
 #include "color.h"
 #include "x.h"
 
-/* "$Id: color.c,v 1.14 1999/02/13 21:39:21 unammx Exp $" */
+/* "$Id: color.c,v 1.20 2001/07/31 10:32:50 andrew Exp $" */
 
 /* To avoid excessive calls to ncurses' has_colors () */
 int   hascolors = 0;
@@ -120,7 +120,8 @@ struct color_table_s {
 };
 
 
-struct color_table_s color_table [] = {
+#ifndef HAVE_X
+static struct color_table_s const color_table [] = {
     { "black",         COLOR_BLACK   },
     { "gray",          COLOR_BLACK   | A_BOLD },
     { "red",           COLOR_RED     },
@@ -139,6 +140,7 @@ struct color_table_s color_table [] = {
     { "white",         COLOR_WHITE   | A_BOLD },
     { "default",       0 } /* hack for transparent background */
 };
+#endif /* !HAVE_X */
 
 #ifdef HAVE_GNOME
 void get_color (char *cpp, CTYPE *colp);
@@ -293,18 +295,21 @@ void init_colors (void)
 	}
 #endif
 
-#if defined HAVE_SLANG && !defined(HAS_DIRECT_COLOR_ACCESS)
-	if (use_colors) { /* Hack to make COLOR_PAIR(DEFAULT_COLOR_INDEX) 
-                             be the default fg/bg of the terminal */
-	    char *Norm_Vid = SLtt_tgetstr ("me");
-	    
-	    if (Norm_Vid == NULL)
-	        Norm_Vid = SLtt_tgetstr ("se");
-	    if (Norm_Vid == NULL)
-	        Norm_Vid = "\033[0m";
-	    SLtt_set_color_esc (DEFAULT_COLOR_INDEX, Norm_Vid);
+	if (use_colors) {
+#ifdef HAVE_SLANG
+	    /*
+	     * We are relying on undocumented feature of
+	     * S-Lang to make COLOR_PAIR(DEFAULT_COLOR_INDEX)
+	     * the default fg/bg of the terminal.
+	     * Hopefully, future versions of S-Lang will
+	     * document this feature.
+	     */
+	    SLtt_set_color (DEFAULT_COLOR_INDEX, NULL, "default", "default");
+#elif defined(USE_NCURSES)
+	    /* Always white on black */
+	    init_pair(DEFAULT_COLOR_INDEX, COLOR_WHITE, COLOR_BLACK);
+#endif
 	}
-#endif	
 
 	for (i = 0; i < ELEMENTS (color_map); i++){
             if (!color_map [i].name)
