@@ -23,8 +23,9 @@
 
 #include <config.h>
 #include <errno.h>
-#include "tty.h"
 #include <string.h>
+#include "tty.h"
+#include "x.h"
 #include "global.h"		/* home_dir */
 #include "dlg.h"
 #include "widget.h"
@@ -167,7 +168,7 @@ void do_cd_command (char *cmd)
 	}
     } else
 	if (!examine_cd (&cmd [3])) {
-	    message (1, MSG_ERROR, _(" Can't chdir to '%s' \n %s "),
+	    message (1, MSG_ERROR, _(" Cannot chdir to '%s' \n %s "),
 		     &cmd [3], unix_error_string (errno));
 	    return;
 	}
@@ -204,7 +205,7 @@ static int enter (WCommand *cmdline)
 	    for (i = j = 0; i < strlen (cmd); i ++){
 		if (cmd [i] == '%'){
 		    i ++;
-		    s = expand_format (cmd [i], 1);
+		    s = expand_format (NULL, cmd [i], 1);
 		    command = g_realloc (command, strlen (command) + strlen (s)
 				       + strlen (cmd) - i + 1);
 		    strcat (command, s);
