@@ -17,10 +17,9 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include <config.h>
-#include "tty.h"
 #include <stdio.h>
 #include <string.h>
 #ifdef HAVE_UNISTD_H
@@ -57,7 +56,9 @@
 #   include <pwd.h>
 #endif
 
+#include "tty.h"
 #include "global.h"
+#include "x.h"
 #include "win.h"
 #include "color.h"
 #include "dlg.h"
@@ -70,11 +71,11 @@
 #include "../vfs/vfs.h"
 
 /* This flag is used in filename_completion_function */
-int ignore_filenames = 0;
+static int ignore_filenames = 0;
 
 /* This flag is used by command_completion_function */
 /* to hint the filename_completion_function */
-int look_for_executables = 0;
+static int look_for_executables = 0;
 
 static char *
 filename_completion_function (char *text, int state)
@@ -99,37 +100,26 @@ filename_completion_function (char *text, int state)
         if (users_dirname)
             g_free (users_dirname);
 
-        filename = g_strdup (text);
-        if (!*text)
-            text = ".";
-        dirname = g_strdup (text);
-
-        temp = strrchr (dirname, PATH_SEP);
-
-        if (temp){
-	    strcpy (filename, ++temp);
-	    *temp = 0;
+	if ((*text) && (temp = strrchr (text, PATH_SEP))){
+	    filename = g_strdup (++temp);
+	    dirname = g_strndup (text, temp - text);
+	} else {
+	    dirname = g_strdup (".");
+	    filename = g_strdup (text);
 	}
-        else
-	    strcpy (dirname, ".");
 
         /* We aren't done yet.  We also support the "~user" syntax. */
 
         /* Save the version of the directory that the user typed. */
-        users_dirname = g_strdup (dirname);
+        users_dirname = dirname;
         {
-	    char *temp_dirname;
-
-	    temp_dirname = tilde_expand (dirname);
-	    if (!temp_dirname){
-		g_free (dirname);
+	    dirname = tilde_expand (dirname);
+	    if (!dirname){
 		g_free (users_dirname);
 		g_free (filename);
-		dirname = users_dirname = filename = NULL;
+		users_dirname = filename = NULL;
 		return NULL;
 	    }
-	    g_free (dirname);
-	    dirname = temp_dirname;
 	    canonicalize_pathname (dirname);
 	    /* Here we should do something with variable expansion
 	       and `command`.
@@ -359,19 +349,19 @@ static void fetch_hosts (char *filename)
 	}
 
         /* Skip IP #s. */
-        for (; buffer[i] && !cr_whitespace (buffer[i]); i++);
+	while (buffer[i] && !cr_whitespace (buffer[i]))
+	    i++;
 
         /* Get the host names separated by white space. */
         while (buffer[i] && buffer[i] != '#'){
-	    for (; i && cr_whitespace (buffer[i]); i++);
+	    while (buffer[i] && cr_whitespace (buffer[i]))
+		i++;
 	    if (buffer[i] ==  '#')
-	        continue;
+		continue;
 	    for (start = i; buffer[i] && !cr_whitespace (buffer[i]); i++);
 	        if (i - start == 0)
 	            continue;
-	    name = (char *) g_malloc (i - start + 1);
-	    strncpy (name, buffer + start, i - start);
-	    name [i - start] = 0;
+	    name = g_strndup (buffer + start, i - start);
 	    {
 	    	char **host_p;
 	    	
@@ -452,28 +442,27 @@ hostname_completion_function (char *text, int state)
 static char *
 command_completion_function (char *text, int state)
 {
+    static char *path_end;
     static int isabsolute;
     static int phase;
     static int text_len;
-    static char **words;
+    static const char * const * words;
     static char *path;
     static char *cur_path;
     static char *cur_word;
     static int init_state;
-    static char *bash_reserved [] = { "if", "then", "else", "elif", "fi",
-                                      "case", "esac", "for", "select", "while",
-                                      "until", "do", "done", "in", "function" , 0};
-    static char *bash_builtins [] = { "alias", "bg", "bind", "break", "builtin",
-    				      "cd", "command", "continue", "declare", 
-    				      "dirs", "echo", "enable", "eval", "exec",
-    				      "exit", "export", "fc", "fg", "getopts",
-    				      "hash", "help", "history", "jobs", "kill",
-    				      "let", "local", "logout", "popd", "pushd",
-    				      "pwd", "read", "readonly", "return", "set",
-    				      "shift", "source", "suspend", "test", 
-    				      "times", "trap", "type", "typeset",
-    				      "ulimit", "umask", "unalias", "unset",
-    				      "wait" , 0};
+    static const char * const bash_reserved [] = { 
+	"if", "then", "else", "elif", "fi", "case", "esac", "for", "select",
+	"while", "until", "do", "done", "in", "function" , 0
+    };
+    static const char * const bash_builtins [] = { 
+	"alias", "bg", "bind", "break", "builtin", "cd", "command", "continue",
+	"declare", "dirs", "echo", "enable", "eval", "exec", "exit", "export",
+	"fc", "fg", "getopts", "hash", "help", "history", "jobs", "kill", "let",
+	"local", "logout", "popd", "pushd", "pwd", "read", "readonly", "return",
+	"set", "shift", "source", "suspend", "test", "times", "trap", "type", 
+	"typeset", "ulimit", "umask", "unalias", "unset", "wait" , 0
+    };
     char *p, *found;
 
     if (!state){ /* Initialize us a little bit */
@@ -483,17 +472,12 @@ command_completion_function (char *text, int state)
 	    words = bash_reserved;
 	    phase = 0;
 	    text_len = strlen (text);
-	    p = getenv ("PATH");
-	    if (!p)
-	    	path = NULL;
-	    else {
-	    	path = g_malloc (strlen (p) + 2);
-	    	strcpy (path, p);
-	    	path [strlen (p) + 1] = 0;
-	    	p = strchr (path, PATH_ENV_SEP);
-	    	while (p){
-	    	    *p = 0;
-	    	    p = strchr (p + 1, PATH_ENV_SEP);
+	    path = getenv ("PATH");
+	    if (path){
+		p = path = g_strdup (path);
+		path_end = strchr (p, 0);
+		while ((p = strchr (p, PATH_ENV_SEP))){
+		    *p++ = 0;
 	    	}
 	    }
 	}
@@ -532,20 +516,16 @@ command_completion_function (char *text, int state)
 	        if (!cur_word){
 		    char *expanded;
 		    
-	            if (!*cur_path)
+		    if (cur_path >= path_end)
 	            	break;
-		    expanded = tilde_expand (cur_path);
+		    expanded = tilde_expand (*cur_path ? cur_path : ".");
 		    if (!expanded){
 			g_free (path);
 			path = NULL;
 			return NULL;
 		    }
 	            p = canonicalize_pathname (expanded);
-	            cur_word = g_malloc (strlen (p) + 2 + text_len);
-	            strcpy (cur_word, p);
-	            if (cur_word [strlen (cur_word) - 1] != PATH_SEP)
-	            	strcat (cur_word, PATH_SEP_STR);
-	            strcat (cur_word, text);
+		    cur_word = concat_dir_and_file (p, text);
 	            g_free (p);
 	            cur_path = strchr (cur_path, 0) + 1;
 	            init_state = state;
@@ -808,7 +788,7 @@ try_complete (char *text, int *start, int *end, int flags)
     	    }
     	}
     }
-    	
+
     if (word)
     	g_free (word);
 
@@ -827,9 +807,12 @@ void free_completions (WInput *in)
     in->completions = NULL;
 }
 
+#ifndef HAVE_GNOME
 static int query_height, query_width;
 static WInput *input;
-static int start, end, min_end;
+static int min_end;
+#endif /* !HAVE_GNOME */
+static int start, end;
 
 static int insert_text (WInput *in, char *text, int len)
 {
@@ -861,15 +844,14 @@ static int insert_text (WInput *in, char *text, int len)
     return len != 0;
 }
 
+#ifndef HAVE_GNOME
 static int query_callback (Dlg_head * h, int Par, int Msg)
 {
     switch (Msg) {
     	case DLG_DRAW:
-#ifndef HAVE_X
     	    attrset (COLOR_NORMAL);
 	    dlg_erase (h);
     	    draw_box (h, 0, 0, query_height, query_width);
-#endif
     	    break;
     	    
     	case DLG_KEY:
@@ -966,6 +948,7 @@ static int querylist_callback (void *data)
 {
     return 1;
 }
+#endif /* !HAVE_GNOME */
 
 #define DO_INSERTION 1
 #define DO_QUERY     2
@@ -1038,7 +1021,7 @@ complete_engine (WInput *in, int what_to_do)
 	    query_width  = w;
     	    query_dlg = create_dlg (y, x, query_height, query_width,
 				    dialog_colors, query_callback,
-				    "[Completion-query]", "complete", DLG_NONE);
+				    "[Completion]", "complete", DLG_NONE);
     	    query_list = listbox_new (1, 1, w - 2, h - 2, 0, querylist_callback, NULL);
     	    add_widget (query_dlg, query_list);
     	    for (p = in->completions + 1; *p; p++)
