@@ -64,11 +64,10 @@ static signed char console_flag = -1;
    */
 static int console_fd = -1;
 static char *tty_name;
-static int len;
+static int console_minor = 0;
 static char *buffer = NULL;
 static int buffer_size = 0;
 static int columns, rows;
-static char vcs_name [128];
 static int vcs_fd;
 
 static void dwrite (int fd, char *buffer)
@@ -76,7 +75,7 @@ static void dwrite (int fd, char *buffer)
     write (fd, buffer, strlen (buffer));
 }
 
-static void tty_getsize ()
+static void tty_getsize (void)
 {
     struct winsize winsz;
 
@@ -94,7 +93,7 @@ static void tty_getsize ()
     }
 }
 
-inline void tty_cursormove(int y, int x)
+static inline void tty_cursormove(int y, int x)
 {
     char buffer [128];
 
@@ -103,7 +102,7 @@ inline void tty_cursormove(int y, int x)
     dwrite (console_fd, buffer);
 }
 
-int check_file (char *filename, int check_console, char **msg)
+static int check_file (char *filename, int check_console)
 {
     int fd;
     struct stat stat_buf;
@@ -111,8 +110,6 @@ int check_file (char *filename, int check_console, char **msg)
     /* Avoiding race conditions: use of fstat makes sure that
        both 'open' and 'stat' operate on the same file */
 
-    *msg = 0;
-    
     fd = open (filename, O_RDWR);
     if (fd == -1)
 	return -1;
@@ -123,32 +120,35 @@ int check_file (char *filename, int check_console, char **msg)
 
 	/* Must be character device */
 	if (!S_ISCHR (stat_buf.st_mode)){
-	    *msg = "Not a character device";
 	    break;
 	}
 
 #ifdef DEBUG
-	fprintf (stderr, "Device: %x\n", stat_buf.st_rdev);
+	fprintf (stderr,
+		 "Device %s: major %d, minor %d\r\n",
+		 filename,
+		 ((int) stat_buf.st_rdev & 0xff00) >> 8,
+		 ((int) stat_buf.st_rdev & 0xff));
 #endif
+
 	if (check_console){
-	    /* Second time: must be console */
+	    /* Major number must be 4 */
 	    if ((stat_buf.st_rdev & 0xff00) != 0x0400){
-		*msg = "Not a console";
 		break;
 	    }
 
-	    if ((stat_buf.st_rdev & 0x00ff) > 63){
-		*msg = "Minor device number too big";
+	    /* Minor number must be between 1 and 63 */
+	    console_minor = (int) (stat_buf.st_rdev & 0x00ff);
+	    if (console_minor < 1 || console_minor > 63){
 		break;
 	    }
 
 	    /* Must be owned by the user */
 	    if (stat_buf.st_uid != getuid ()){
-		*msg = "Not a owner";
 		break;
 	    }
 	}
-    /* Everything seems to be okay */
+	/* Everything seems to be okay */
 	return fd;
     } while (0);
 
@@ -156,55 +156,69 @@ int check_file (char *filename, int check_console, char **msg)
     return -1;
 }
 
-/* Detect console */
+/* Detect console. Return 0 if successful, -1 otherwise.  */
 /* Because the name of the tty is supplied by the user and this
    can be a setuid program a lot of checks has to done to avoid
    creating a security hole */
-char *detect_console (void)
+static int detect_console (void)
 {
-    char *msg;
-    int  xlen;
-    
+    char console_name [16];
+    static char vcs_name [16];
+
     /* Must be console */
-    /* Handle the case for /dev/tty?? and /dev/vc/??  */
-    if (tty_name[len-5] == 't' || tty_name[len-5] == 'v')
-	xlen = len - 1;
-    else
-	xlen = len;
+    console_fd = check_file (tty_name, 1);
+    if (console_fd == -1)
+	return -1;
 
-    /* General: /dev/ttyn  and /dev/vc/n  */
-    if (tty_name[xlen - 5] != '/' ||
-	! (strncmp(tty_name+xlen-4,"tty",3) == 0 ||
-	   strncmp(tty_name+xlen-4,"vc/",3) == 0) ||
-	!isdigit(tty_name[xlen - 1]) ||
-	!isdigit(tty_name[len - 1]))
-	return "Doesn't look like console";
+    /*
+     * Only allow /dev/ttyMINOR and /dev/vc/MINOR where MINOR is the minor
+     * device number of the console, set in check_file()
+     */
+    switch (tty_name[5])
+    {
+	case 'v':
+	    snprintf (console_name, sizeof (console_name), "/dev/vc/%d",
+		      console_minor);
+	    if (strncmp (console_name, tty_name, sizeof (console_name)) != 0)
+		return -1;
+	    break;
+	case 't':
+	    snprintf (console_name, sizeof (console_name), "/dev/tty%d",
+		      console_minor);
+	    if (strncmp (console_name, tty_name, sizeof (console_name)) != 0)
+		return -1;
+	    break;
+	default:
+	    return -1;
+    }
 
-    snprintf (vcs_name, sizeof (vcs_name), "/dev/vcsa%s", tty_name + xlen - 1);
-    vcs_fd = check_file (vcs_name, 0, &msg);
-    console_fd = check_file (tty_name, 1, &msg);
+    snprintf (vcs_name, sizeof (vcs_name), "/dev/vcsa%d", console_minor);
+    vcs_fd = check_file (vcs_name, 0);
+
+    /* Try devfs name */
+    if (vcs_fd == -1) {
+	snprintf (vcs_name, sizeof (vcs_name), "/dev/vcc/a%d", console_minor);
+	vcs_fd = check_file (vcs_name, 0);
+    }
 
 #ifdef DEBUG
-    fprintf (stderr, "vcs_fd = %d console_fd = %d\n", vcs_fd, console_fd);
+    fprintf (stderr, "vcs_fd = %d console_fd = %d\r\n", vcs_fd, console_fd);
 #endif
     
     if (vcs_fd != -1){
 	console_flag = 3;
     }
 
-    if (console_fd == -1)
-	return msg;
-
-    return NULL;
+    return 0;
 }
 
-void save_console (void)
+static void save_console (void)
 {
     int i;
 
     if (!console_flag)
 	return;
-    buffer [1] = tty_name [len-1] - '0';
+    buffer [1] = console_minor;
     if (console_flag >= 2){
 	/* Linux >= 1.1.67 */
 	/* Get screen contents and cursor position */
@@ -249,7 +263,7 @@ void save_console (void)
     }
 }
 
-void restore_console (void)
+static void restore_console (void)
 {
     if (!console_flag)
 	return;
@@ -257,7 +271,7 @@ void restore_console (void)
 	/* Linux >= 1.1.67 */
 	/* Restore screen contents and cursor position */
 	buffer [0] = 9;
-	buffer [1] = tty_name [len-1] - '0';
+	buffer [1] = console_minor;
 	ioctl (console_fd, TIOCLINUX, buffer);
     }
     if (console_flag == 3){
@@ -274,7 +288,7 @@ void restore_console (void)
     }
 }
 
-void send_contents ()
+static void send_contents (void)
 {
     unsigned char begin_line=0, end_line=0;
     int index, x, y;
@@ -326,7 +340,6 @@ void send_contents ()
 
 int main (int argc, char **argv)
 {
-    char *error;
     unsigned char action = 0;
     int stderr_fd;
     
@@ -359,10 +372,8 @@ int main (int argc, char **argv)
     
     /* Check that the argument is a legal console */
     tty_name = argv [1];
-    len = strlen(tty_name);
-    error = detect_console ();
 
-    if (error){
+    if (detect_console () == -1){
 	/* Not a console -> no need for privileges */
 	setuid (getuid ());
 /*	dwrite (2, error); */
@@ -415,6 +426,6 @@ int main (int argc, char **argv)
 
 #else
 
-#error The Linux console screen saver works only on Linux.
+ #error "The Linux console screen saver works only on Linux"
 
 #endif /* #ifdef linux */
