@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include <config.h>
 #define DIR_H_INCLUDE_HANDLE_DIRENT
@@ -30,7 +30,7 @@
 #include "tree.h"
 #include "../vfs/vfs.h"
 
-/* "$Id: dir.c,v 1.21 2000/04/14 08:58:37 timur Exp $" */
+/* "$Id: dir.c,v 1.25 2001/08/12 16:36:55 proskin Exp $" */
 
 /*
  * If true show files starting with a dot.
@@ -76,7 +76,48 @@ sort_orders_t sort_orders [SORT_TYPES_TOTAL] = {
     { N_("&Group"),       sort_group }
 };
 
-#define string_sortcomp(a,b) (case_sensitive ? strcoll (a,b) : g_strcasecmp (a,b))
+#ifdef HAVE_STRCOLL
+/*
+ * g_strcasecmp() doesn't work well in some locales because it relies on
+ * the locale-specific toupper().  On the other hand, strcoll() is case
+ * sensitive in the "C" and "POSIX" locales, unlike other locales.
+ * Solution: always use strcmp() for case sensitive sort.  For case
+ * insensitive sort use strcoll() if it's case insensitive for ASCII and
+ * g_strcasecmp() otherwise.
+ */
+typedef enum {
+    STRCOLL_NO,
+    STRCOLL_YES,
+    STRCOLL_TEST	
+} strcoll_status;
+
+static int
+string_sortcomp (char *str1, char *str2)
+{
+    static strcoll_status use_strcoll = STRCOLL_TEST;
+
+    if (case_sensitive) {
+	return strcmp (str1, str2);
+    }
+
+    /* Initialize use_strcoll once.  */
+    if (use_strcoll == STRCOLL_TEST) {
+	/* Only use strcoll() if it considers "B" between "a" and "c".  */
+	if (strcoll ("a", "B") * strcoll ("B", "c") > 0) {
+	    use_strcoll = STRCOLL_YES;
+	} else {
+	    use_strcoll = STRCOLL_NO;
+	}
+    }
+
+    if (use_strcoll == STRCOLL_NO)
+	return g_strcasecmp (str1, str2);
+    else
+	return strcoll (str1, str2);
+}
+#else
+#define string_sortcomp(a,b) (case_sensitive ? strcmp (a,b) : g_strcasecmp (a,b))
+#endif
 
 int
 unsorted (const file_entry *a, const file_entry *b)
