@@ -139,22 +139,21 @@ exec_extension (const char *filename, const char *data, char **drops, int *move_
     else
 	do_local_copy = 0;
 
-    if ((file_name = tempnam (NULL, "mcext")) == 0) {
-	message (1, MSG_ERROR, _(" Can't generate unique filename \n %s "),
-		 unix_error_string (errno));
-	return;
-    }
+    /*
+     * All commands should be run in /bin/sh regardless of user shell.
+     * To do that, create temporary shell script and run it.
+     * Sometimes it's not needed (e.g. for %cd and %view commands),
+     * but it's easier to create it anyway.
+     */
+    cmd_file_fd = mc_mkstemps(&file_name, "mcext", SCRIPT_SUFFIX);
 
-    /* #warning FIXME: this is ugly */
-    if ((cmd_file_fd = open (file_name, O_RDWR | O_CREAT | O_TRUNC | O_EXCL, 0600)) == -1){
-	message (1, MSG_ERROR, _(" Can't create temporary command file \n %s "),
+    if (cmd_file_fd == -1){
+	message (1, MSG_ERROR, _(" Cannot create temporary command file \n %s "),
 		 unix_error_string (errno));
-	free (file_name);
 	return;
     }
     cmd_file = fdopen (cmd_file_fd, "w");
-    /* FIXME: This is a hack, that makes us sure, we are using the right syntax */
-    fprintf (cmd_file, "#!/bin/sh\n");
+    fputs ("#!/bin/sh\n", cmd_file);
 
     prompt [0] = 0;
     for (;*data && *data != '\n'; data++){
@@ -170,7 +169,7 @@ exec_extension (const char *filename, const char *data, char **drops, int *move_
 		    if (localcopy) {
 		        mc_ungetlocalcopy (filename, localcopy, 0);
 		    }
-		    free (file_name);
+		    g_free (file_name);
 		    return;
 		}
 		fputs (parameter, cmd_file);
@@ -214,7 +213,7 @@ exec_extension (const char *filename, const char *data, char **drops, int *move_
 			    if (localcopy == NULL) {
 				fclose(cmd_file);
 				unlink(file_name);
-				free (file_name);
+				g_free (file_name);
 				return;
 			    }
 			    mc_stat (localcopy, &mystat);
@@ -226,7 +225,7 @@ exec_extension (const char *filename, const char *data, char **drops, int *move_
 		    } else if (*data == 'q') {
 			text = quote_block (quote_func, drops);
 		    } else
-		        text = expand_format (*data, !is_cd);
+		        text = expand_format (NULL, *data, !is_cd);
 		    if (!is_cd)
 		        fputs (text, cmd_file);
 		    else {
@@ -250,9 +249,19 @@ exec_extension (const char *filename, const char *data, char **drops, int *move_
 	    }
 	}
     } /* for */
-    fputc ('\n', cmd_file);
+
+    /* Make sure that the file removes itself when it finishes */
+    fprintf (cmd_file, "\n/bin/rm -f %s\n", file_name);
     fclose (cmd_file);
-    chmod (file_name, S_IRWXU);
+
+    if ((run_view && !written_nonspace) || is_cd) {
+	unlink (file_name);
+	g_free (file_name);
+	file_name = NULL;
+    } else {
+	chmod (file_name, S_IRWXU);
+    }
+
     if (run_view){
     	altered_hex_mode = 0;
     	altered_nroff_flag = 0;
@@ -288,14 +297,13 @@ exec_extension (const char *filename, const char *data, char **drops, int *move_
     	q[1] = 0;
     	do_cd (p, cd_parse_command);
     } else {
-#ifdef HAVE_GNOME
+#ifdef HAVE_X
 	if (needs_term)
             gnome_open_terminal_with_cmd (file_name);
 	else
 	    shell_execute (file_name, EXECUTE_INTERNAL | EXECUTE_TEMPFILE);
 #else
 	shell_execute (file_name, EXECUTE_INTERNAL | EXECUTE_TEMPFILE);
-#endif
 	if (console_flag)
 	{
 	    handle_console (CONSOLE_SAVE);
@@ -307,22 +315,15 @@ exec_extension (const char *filename, const char *data, char **drops, int *move_
 
 	    }
 	}
-
-#ifdef OLD_CODE
-	if (vfs_current_is_local ())
-	    shell_execute (file_name, EXECUTE_INTERNAL);
-	else
-	    message (1, _(" Warning "), _(" Can't execute commands on a Virtual File System directory "));
-#endif
+#endif /* !HAVE_X */
+    }
+    if (file_name) {
+	g_free (file_name);
     }
-#ifndef PORT_DOES_BACKGROUND_EXEC
-    unlink (file_name);
-#endif
     if (localcopy) {
         mc_stat (localcopy, &mystat);
         mc_ungetlocalcopy (filename, localcopy, localmtime != mystat.st_mtime);
     }
-    free (file_name);
 }
 
 #ifdef FILE_L
@@ -418,8 +419,7 @@ check_stock_mc_ext:
 _("mc.ext file has changed\n\
 with version 3.0. It seems that installation\n\
 failed. Please fetch a fresh new copy from the\n\
-Midnight Commander package or in case you don't\n\
-have any, get it from ftp://ftp.nuclecu.unam.mx."), NULL);
+Midnight Commander package."), NULL);
 	            message (1, msg, msg2);
                     g_free (msg);
                     g_free (msg2);
@@ -450,6 +450,7 @@ file as an example of how to write it.\n\
     old_patterns = easy_patterns;
     easy_patterns = 0; /* Real regular expressions are needed :) */
     include_target = NULL;
+    include_target_len = 0;
     for (p = data; *p; p++) {
     	for (q = p; *q == ' ' || *q == '\t'; q++)
 		;
