@@ -6,8 +6,8 @@
 #ifdef HAVE_UNISTD_H
 #   include <unistd.h>
 #endif
-#ifndef HAS_NO_SYS_PARAM_H
-#include <sys/param.h>
+#ifdef HAVE_SYS_PARAM_H
+#   include <sys/param.h>
 #endif
 #include <sys/stat.h>
 
