@@ -13,23 +13,14 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-#if !defined(NO_INFOMOUNT) || defined(__QNX__)
-
-#if defined(__QNX__)
-#define STAT_STATFS4
-#endif
 
 #include <sys/types.h>
 
-#include "fsusage.h"
-
-int statfs ();  /* We leave the type ambiguous intentionally here */
-
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
 #endif
@@ -46,6 +37,8 @@ int statfs ();  /* We leave the type ambiguous intentionally here */
 #include <sys/filsys.h>		/* SVR2.  */
 #endif
 
+#include <stdlib.h>
+
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
@@ -62,6 +55,11 @@ int statfs ();  /* We leave the type ambiguous intentionally here */
 #include <sys/statvfs.h>
 #endif
 
+#include "fsusage.h"
+
+
+#ifdef HAVE_INFOMOUNT
+
 /* Return the number of TOSIZE-byte blocks used by
    BLOCKS FROMSIZE-byte blocks, rounding away from zero.
    TOSIZE must be positive.  Return -1 if FROMSIZE is not positive.  */
@@ -82,6 +80,31 @@ fs_adjust_blocks (long blocks, int fromsize, int tosize)
 	return (blocks + (blocks < 0 ? -1 : 1)) / (tosize / fromsize);
 }
 
+#if defined(_AIX) && defined(_I386)
+/* AIX PS/2 does not supply statfs.  */
+static int aix_statfs (char *path, struct statfs *fsb)
+{
+    struct stat stats;
+    struct dustat fsd;
+
+    if (stat (path, &stats))
+	return -1;
+    if (dustat (stats.st_dev, 0, &fsd, sizeof (fsd)))
+	return -1;
+    fsb->f_type = 0;
+    fsb->f_bsize = fsd.du_bsize;
+    fsb->f_blocks = fsd.du_fsize - fsd.du_isize;
+    fsb->f_bfree = fsd.du_tfree;
+    fsb->f_bavail = fsd.du_tfree;
+    fsb->f_files = (fsd.du_isize - 2) * fsd.du_inopb;
+    fsb->f_ffree = fsd.du_tinode;
+    fsb->f_fsid.val[0] = fsd.du_site;
+    fsb->f_fsid.val[1] = fsd.du_pckno;
+    return 0;
+}
+#define statfs(path,fsb) aix_statfs(path,fsb)
+#endif				/* _AIX && _I386 */
+
 /* Fill in the fields of FSP with information about space usage for
    the filesystem on which PATH resides.
    Return 0 if successful, -1 if not. */
@@ -166,28 +189,4 @@ int get_fs_usage (char *path, struct fs_usage *fsp)
     return 0;
 }
 
-#if defined(_AIX) && defined(_I386)
-/* AIX PS/2 does not supply statfs.  */
-
-int statfs (char *path, struct statfs *fsb)
-{
-    struct stat stats;
-    struct dustat fsd;
-
-    if (stat (path, &stats))
-	return -1;
-    if (dustat (stats.st_dev, 0, &fsd, sizeof (fsd)))
-	return -1;
-    fsb->f_type = 0;
-    fsb->f_bsize = fsd.du_bsize;
-    fsb->f_blocks = fsd.du_fsize - fsd.du_isize;
-    fsb->f_bfree = fsd.du_tfree;
-    fsb->f_bavail = fsd.du_tfree;
-    fsb->f_files = (fsd.du_isize - 2) * fsd.du_inopb;
-    fsb->f_ffree = fsd.du_tinode;
-    fsb->f_fsid.val[0] = fsd.du_site;
-    fsb->f_fsid.val[1] = fsd.du_pckno;
-    return 0;
-}
-#endif				/* _AIX && _I386 */
-#endif /* NO_INFOMOUNT */
+#endif /* HAVE_INFOMOUNT */
