@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Implements the hypertext file viewer.
    The hypertext file is a file that may have one or more nodes.  Each
@@ -54,15 +54,11 @@
 #include "dlg.h"		/* For Dlg_head */
 #include "widget.h"		/* For Widget */
 
-#ifdef HAVE_TK
-#    include "tkmain.h"
-#endif
-
 #define MAXLINKNAME 80
 #define HISTORY_SIZE 20
 #define HELP_WINDOW_WIDTH 62
 
-/* "$Id: help.c,v 1.9 1999/01/27 01:09:01 timur Exp $" */
+/* "$Id: help.c,v 1.14 2001/08/14 00:55:38 proskin Exp $" */
 
 static char *data;		/* Pointer to the loaded data file */
 static int help_lines = 18;	/* Lines in help viewer */
@@ -70,7 +66,7 @@ static int  history_ptr;	/* For the history queue */
 static char *main_node;		/* The main node */
 static char *last_shown = 0;	/* Last byte shown in a screen */
 static int end_of_node = 0;	/* Flag: the last character of the node shown? */
-char *currentpoint, *startpoint;
+static char *currentpoint, *startpoint;
 static char *selected_item;
 
 /* The widget variables */
@@ -94,7 +90,7 @@ static int inside_link_area = 0;
 static int help_callback (struct Dlg_head *h, int id, int msg);
 
 #ifdef HAS_ACS_AS_PCCHARS
-struct {
+static struct {
     int acscode;
     int pccode;
 } acs2pc_table [] = {
@@ -569,7 +565,7 @@ help_index_cmd (Dlg_head *h)
     currentpoint = startpoint = search_string (data, "[Help]") + 1;
 
     if (!(new_item = search_string (data, "[Contents]")))
-	message (1, MSG_ERROR, _(" Can't find node [Contents] in help file "));
+	message (1, MSG_ERROR, _(" Cannot find node [Contents] in help file "));
     else
 	currentpoint = startpoint = new_item + 1;
     selected_item = NULL;
@@ -759,21 +755,32 @@ interactive_display_finish (void)
 void
 interactive_display (char *filename, char *node)
 {
-    WButtonBar *help_bar;
-    Widget     *md;
-    
-    if ((data = load_file (filename)) == 0){
-	message (1, MSG_ERROR, _(" Can't open file %s \n %s "),
-		 filename, unix_error_string (errno));
-	return;
+    WButtonBar	*help_bar;
+    Widget	*md;
+    char	*hlpfile = filename;
+
+    if (filename)
+	data = load_file (filename);
+    else
+	data = load_mc_home_file ("mc.hlp", &hlpfile);
+
+    if (data == NULL){
+	message (1, MSG_ERROR, _(" Cannot open file %s \n %s "),
+		 hlpfile, unix_error_string (errno));
     }
+
+    if (!filename)
+	g_free (hlpfile);
+
+    if (!data)
+	return;
+
     if (!(main_node = search_string (data, node))){
-	message (1, MSG_ERROR, _(" Can't find node %s in help file "), node);
+	message (1, MSG_ERROR, _(" Cannot find node %s in help file "), node);
 	interactive_display_finish ();
 	return;
     }
 
-#ifndef HAVE_X
     if (help_lines > LINES - 4)
 	help_lines = LINES - 4;
 
@@ -783,7 +790,6 @@ interactive_display (char *filename, char *node)
     /* allow us to process the tab key */
     whelp->raw = 1;
 
-#endif    
     selected_item = search_string_node (main_node, STRING_LINK_START) - 1;
     currentpoint = startpoint = main_node + 1;
 
@@ -793,7 +799,6 @@ interactive_display (char *filename, char *node)
 	history [history_ptr].link = selected_item;
     }
 
-#ifndef HAVE_X
     help_bar = buttonbar_new (keybar_visible);
     help_bar->widget.y -= whelp->y;
     help_bar->widget.x -= whelp->x;
@@ -820,8 +825,5 @@ interactive_display (char *filename, char *node)
     run_dlg (whelp);
     interactive_display_finish ();
     destroy_dlg (whelp);
-#else
-    x_interactive_display ();
-#endif
 }
 
