@@ -68,10 +68,6 @@
 #include "key.h"
 #include "command.h"
 
-#ifdef HAVE_TK
-#    include "tkwidget.h"
-#endif
-
 #define UX		5
 #define UY		2
 
@@ -123,7 +119,7 @@ static struct {
     int		type;		/* LIST_HOTLIST || LIST_VFSLIST */
 }   hotlist_state;
 
-struct _hotlist_but {
+static struct _hotlist_but {
     int ret_cmd, flags, y, x;
     char *text;
     char *tkname;
@@ -151,14 +147,15 @@ static struct hotlist{
     struct hotlist *next;
 } *hotlist = NULL;
 
-struct hotlist *current_group;
+static struct hotlist *current_group;
 
+static void init_movelist (int, struct hotlist *);
+static void add_new_group_cmd (void);
+static void add_new_entry_cmd (void);
 static void remove_from_hotlist (struct hotlist *entry);
-void add_new_group_cmd (void);
 
 #define new_hotlist() g_new0(struct hotlist, 1)
 
-#ifndef HAVE_X
 static void hotlist_refresh (Dlg_head *dlg)
 {
     dialog_repaint (dlg, COLOR_NORMAL, COLOR_HOT_NORMAL);
@@ -169,10 +166,9 @@ static void hotlist_refresh (Dlg_head *dlg)
     if (!hotlist_state.moving)
 	draw_box (dlg, dlg->lines-8, 5, 3, dlg->cols - (UX*2));
 }
-#endif
 
 /* If current->data is 0, then we are dealing with a VFS pathname */
-static INLINE void update_path_name ()
+static INLINE void update_path_name (void)
 {
     char *text, *p;
     WListbox  *list = hotlist_state.moving ? l_movelist : l_hotlist;
@@ -187,14 +183,12 @@ static INLINE void update_path_name ()
 	    else
 		text = _("Subgroup - press ENTER to see list");
 	    
-#ifndef HAVE_X
 	    p = g_strconcat (" ", current_group->label, " ", NULL);
 	    if (!hotlist_state.moving)
 		label_set_text (pname_group, name_trunc (p, dlg->cols - (UX*2+4)));
 	    else
 		label_set_text (movelist_group, name_trunc (p, dlg->cols - (UX*2+4)));
 	    g_free (p);
-#endif
 	} else {
 	    text = list->current->text;
 	}
@@ -270,9 +264,6 @@ unlink_entry (struct hotlist *entry)
 	entry->up = 0;
 }
     
-static void add_new_entry_cmd (void);
-static void init_movelist (int, struct hotlist *);
-
 static int hotlist_button_callback (int action, void *data)
 {
     switch (action) {
@@ -334,9 +325,6 @@ static int hotlist_button_callback (int action, void *data)
 		}
 	    listbox_remove_list (l_hotlist);
 	    fill_listbox ();
-#ifdef HAVE_X
-	    x_listbox_select_nth (l_hotlist, 0);
-#endif
 	    repaint_screen ();
 	    hotlist_state.modified = 1;
 	    return 0;
@@ -389,9 +377,6 @@ static int hotlist_button_callback (int action, void *data)
 	listbox_remove_list (list);
 	current_group = current_group->up;
 	fill_listbox ();
-#ifdef HAVE_X
-	x_listbox_select_nth (list, 0);
-#endif
 	return 0;
 	break;
 	}
@@ -406,11 +391,9 @@ static int hotlist_button_callback (int action, void *data)
 static int hotlist_callback (Dlg_head * h, int Par, int Msg)
 {
     switch (Msg) {
-#ifndef HAVE_X    
     case DLG_DRAW:
 	hotlist_refresh (h);
 	break;
-#endif	
 
     case DLG_UNHANDLED_KEY:
 	switch (Par) {
@@ -518,7 +501,7 @@ static int
 init_i18n_stuff(int list_type, int cols)
 {
 	register int i;
-	static char* cancel_but = "&Cancel";
+	static char* cancel_but = N_("&Cancel");
 
 #ifdef ENABLE_NLS
 	static int hotlist_i18n_flag = 0;
@@ -620,7 +603,6 @@ static void init_hotlist (int list_type)
      */
     pname = label_new (UY-11+LINES, UX+2, "", "the-lab");
     add_widget (hotlist_dlg, pname);
-#ifndef HAVE_X
     if (!hotlist_state.moving) {
 	add_widget (hotlist_dlg, label_new (UY-12+LINES, UX+1, _(" Directory path "), NULL));
 
@@ -628,7 +610,6 @@ static void init_hotlist (int list_type)
 	pname_group = label_new (UY, UX+1, _(" Directory label "), NULL);
 	add_widget (hotlist_dlg, pname_group);
     }
-#endif
     /* get new listbox */
     l_hotlist = listbox_new (UY + 1, UX + 1, COLS-2*UX-8, LINES-14, listbox_cback, l_call, "listbox");
 
@@ -646,8 +627,8 @@ static void init_hotlist (int list_type)
 static void init_movelist (int list_type, struct hotlist *item)
 {
     int i;
-    char *hdr = g_strconcat (_("Moving "), item->label, NULL);
-	int movelist_cols = init_i18n_stuff (list_type, COLS - 6);
+    char *hdr = g_strdup_printf (_("Moving %s"), item->label);
+    int movelist_cols = init_i18n_stuff (list_type, COLS - 6);
 
     do_refresh ();
 
@@ -670,10 +651,8 @@ static void init_movelist (int list_type, struct hotlist *item)
     /* We add the labels.  We are interested in the last one,
      * that one will hold the path name label
      */
-#ifndef HAVE_X
     movelist_group = label_new (UY, UX+1, _(" Directory label "), NULL);
     add_widget (movelist_dlg, movelist_group);
-#endif
     /* get new listbox */
     l_movelist = listbox_new (UY + 1, UX + 1, 
 		movelist_dlg->cols - 2*UX - 2, movelist_dlg->lines - 8,
@@ -685,9 +664,14 @@ static void init_movelist (int list_type, struct hotlist *item)
     /* add listbox to the dialogs */
 }
 
+/*
+ * Destroy the list dialog.
+ * Don't confuse with done_hotlist() for the list in memory.
+ */
 static void hotlist_done (void)
 {
     destroy_dlg (hotlist_dlg);
+    l_hotlist = NULL;
     if (0)
 	update_panels (UP_OPTIMIZE, UP_KEEPSEL);
     repaint_screen ();
@@ -708,8 +692,15 @@ find_group_section (struct hotlist *grp)
 static struct hotlist *
 add2hotlist (char *label, char *directory, enum HotListType type, int pos)
 {
-    struct hotlist *current;
     struct hotlist *new;
+    struct hotlist *current = NULL;
+
+    /*
+     * Hotlist is neither loaded nor loading.
+     * Must be called by "Ctrl-x a" before using hotlist.
+     */
+    if (!current_group)
+	load_hotlist ();
 
     if (l_hotlist && l_hotlist->current)
 	current = l_hotlist->current->data;
@@ -762,6 +753,7 @@ add2hotlist (char *label, char *directory, enum HotListType type, int pos)
 
 }
 
+#ifdef ENABLE_NLS
 /*
  * Support routine for add_new_entry_input()/add_new_group_input()
  * Change positions of buttons (first three widgets).
@@ -787,6 +779,7 @@ static void add_widgets_i18n(QuickWidget* qw, int len)
 		qw [i].x_divisions = len;
 	}
 }
+#endif /* ENABLE_NLS */
 
 static int add_new_entry_input (char *header, char *text1, char *text2, char *help, char **r1, char **r2)
 {
@@ -950,7 +943,7 @@ static int add_new_group_input (char *header, char *label, char **result)
 	return 0;
 }
 
-void add_new_group_cmd (void)
+static void add_new_group_cmd (void)
 {
     char   *label;
     int		ret;
@@ -1122,7 +1115,7 @@ static char *hotlist_file_name;
 static FILE *hotlist_file;
 static time_t hotlist_file_mtime;
 
-static int hot_skip_blanks ()
+static int hot_skip_blanks (void)
 {
     int c;
 
@@ -1132,7 +1125,7 @@ static int hot_skip_blanks ()
     
 }
 
-static int hot_next_token ()
+static int hot_next_token (void)
 {
     int	c;
 
@@ -1588,6 +1581,10 @@ int save_hotlist (void)
     return saved;
 }
 
+/*
+ * Unload list from memory.
+ * Don't confuse with hotlist_done() for GUI.
+ */
 void done_hotlist (void)
 {
     if (hotlist){
