@@ -6,9 +6,7 @@
 #undef ENABLE_NLS
 #endif
 
-#ifdef HAVE_GNOME
-#    include <gnome.h>
-#else
+#ifndef HAVE_GNOME
 #    ifdef ENABLE_NLS
 #    	 include <libintl.h>
 #    	 define _(String) gettext (String)
@@ -19,14 +17,14 @@
 #    	 endif
 #    else
          /* Stubs that do something close enough.  */
-#    	 define textdomain(String) (String)
+#    	 define textdomain(String)
 #    	 define gettext(String) (String)
 #    	 define dgettext(Domain,Message) (Message)
 #    	 define dcgettext(Domain,Message,Type) (Message)
-#    	 define bindtextdomain(Domain,Directory) (Domain)
+#    	 define bindtextdomain(Domain,Directory)
 #    	 define _(String) (String)
 #    	 define N_(String) (String)
 #    endif
-#endif
+#endif /* !HAVE_GNOME */
 
 #endif /* _MC_I18N_H_ */
