@@ -19,7 +19,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include <config.h>
 #include <stdio.h>
@@ -44,7 +44,7 @@
 #include "cons.saver.h"
 #include "../vfs/vfs.h"
 
-#if defined (HAVE_TEXTMODE_X11_SUPPORT) && !defined (HAVE_X)
+#ifdef HAVE_TEXTMODE_X11_SUPPORT
 #include <X11/Xlib.h>
 #endif
 
@@ -72,7 +72,6 @@ int old_esc_mode = 0;
 
 int use_8th_bit_as_meta = 1;
 
-#ifndef HAVE_X
 typedef struct key_def {
     char ch;			/* Holds the matching char code */
     int code;			/* The code returned, valid if child == NULL */
@@ -85,14 +84,12 @@ typedef struct key_def {
 
 /* This holds all the key definitions */
 static key_def *keys = 0;
-#endif
 
 static int input_fd;
 static fd_set select_set;
 static int disabled_channels = 0; /* Disable channels checking */
-int xgetch_second (void);
+static int xgetch_second (void);
 
-#ifndef PORT_HAS_FILE_HANDLERS
 /* File descriptor monitoring add/remove routines */
 typedef struct SelectList {
     int fd;
@@ -101,7 +98,7 @@ typedef struct SelectList {
     struct SelectList *next;
 } SelectList;
 
-SelectList *select_list = 0;
+static SelectList *select_list = 0;
 
 void add_select_channel (int fd, select_fn callback, void *info)
 {
@@ -160,7 +157,6 @@ static void check_selects (fd_set *select_set)
 	if (FD_ISSET (p->fd, select_set))
 	    (*p->callback)(p->fd, p->info);
 }
-#endif
 
 void channels_down (void)
 {
@@ -181,20 +177,14 @@ typedef struct {
     int action;
 } key_define_t;
 
-#ifndef HAVE_X
-key_define_t mc_bindings [] = {
+static key_define_t mc_bindings [] = {
     { KEY_END,    ESC_STR ">", MCKEY_NOACTION },
     { KEY_HOME,   ESC_STR "<", MCKEY_NOACTION },
-
-#ifdef linux
-    /* Incredible, but many Linuxes still have old databases */
-    { KEY_IC,     ESC_STR "[2~", MCKEY_NOACTION },
-#endif
     { 0, 0, MCKEY_NOACTION },
 };
 
 /* Broken terminfo and termcap databases on xterminals */
-key_define_t xterm_key_defines [] = {
+static key_define_t xterm_key_defines [] = {
     { KEY_F(1),   ESC_STR "OP",   MCKEY_NOACTION },
     { KEY_F(2),   ESC_STR "OQ",   MCKEY_NOACTION },
     { KEY_F(3),   ESC_STR "OR",   MCKEY_NOACTION },
@@ -212,42 +202,30 @@ key_define_t xterm_key_defines [] = {
     { 0, 0, MCKEY_NOACTION },
 };
 
-key_define_t mc_default_keys [] = {
+static key_define_t mc_default_keys [] = {
     { ESC_CHAR,	ESC_STR, MCKEY_ESCAPE },
     { ESC_CHAR, ESC_STR ESC_STR, MCKEY_NOACTION },
     { 0, 0, MCKEY_NOACTION },
 };
-#endif
 
 static void
 define_sequences (key_define_t *kd)
 {
-#ifndef HAVE_X
     int i;
     
     for (i = 0; kd [i].code; i++)
 	define_sequence(kd [i].code, kd [i].seq, kd [i].action);
-#endif	
 }
 
-#if defined (HAVE_TEXTMODE_X11_SUPPORT) && !defined (HAVE_X)
-Display *display;
-Window w;
-
-void
-init_textmode_x11_support (void)
-{
-    display = XOpenDisplay (0);
-    if (display)
-        w = DefaultRootWindow (display);
-}
-#endif
+#ifdef HAVE_TEXTMODE_X11_SUPPORT
+static Display *x11_display;
+static Window x11_window;
+#endif /* HAVE_TEXTMODE_X11_SUPPORT */
 
 /* This has to be called before slang_init or whatever routine
    calls any define_sequence */
 void init_key (void)
 {
-#ifndef HAVE_X
     char *term = (char *) getenv ("TERM");
     
     /* This has to be the first define_sequence */
@@ -281,21 +259,23 @@ void init_key (void)
 	use_8th_bit_as_meta = 0;
     }
 #endif /* __QNX__ */
-#endif /* !HAVE_X */
+
+#ifdef HAVE_TEXTMODE_X11_SUPPORT
+    x11_display = XOpenDisplay (0);
+    if (x11_display)
+        x11_window = DefaultRootWindow (x11_display);
+#endif /* HAVE_TEXTMODE_X11_SUPPORT */
 }
 
 /* This has to be called after SLang_init_tty/slint_init */
 void init_key_input_fd (void)
 {
-#ifndef HAVE_X
 #ifdef HAVE_SLANG
     input_fd = SLang_TT_Read_FD;
 #endif
-#endif /* !HAVE_X */
 }
 
 
-#ifndef HAVE_X
 static void
 xmouse_get_event (Gpm_Event *ev)
 {
@@ -303,6 +283,7 @@ xmouse_get_event (Gpm_Event *ev)
     static struct timeval tv1 = { 0, 0 }; /* Force first click as single */
     static struct timeval tv2;
     static int clicks;
+    static int last_btn = 0;
 
     /* Decode Xterm mouse information to a GPM style event */
 
@@ -314,10 +295,16 @@ xmouse_get_event (Gpm_Event *ev)
     /* So we assume all the buttons were released */
 
     if (btn == 3){
-        ev->type = GPM_UP | (GPM_SINGLE << clicks);
-        ev->buttons = 0;
-	GET_TIME (tv1);
-	clicks = 0;
+	if (last_btn) {
+	    ev->type = GPM_UP | (GPM_SINGLE << clicks);
+	    ev->buttons = 0;
+	    last_btn = 0;
+	    GET_TIME (tv1);
+	    clicks = 0;
+	} else {
+	    /* Bogus event, maybe mouse wheel */
+	    ev->type = 0;
+	}
     } else {
         ev->type = GPM_DOWN;
 	GET_TIME (tv2);
@@ -339,8 +326,11 @@ xmouse_get_event (Gpm_Event *ev)
             break;
 	default:
             /* Nothing */
+	    ev->type = 0;
+	    ev->buttons = 0;
             break;
         }
+	last_btn = ev->buttons;
     }
     /* Coordinates are 33-based */
     /* Transform them to 1-based */
@@ -384,27 +374,29 @@ static int push_char (int c)
     *seq_append = 0;
     return 1;
 }
-#endif /* !HAVE_X */
 
-void define_sequence (int code, char *seq, int action)
+/*
+ * Return 1 on success, 0 on error.
+ * An error happens if SEQ is a beginning of an existing longer sequence.
+ */
+int define_sequence (int code, char *seq, int action)
 {
-#ifndef HAVE_X
     key_def *base;
 
     if (strlen (seq) > sizeof (seq_buffer)-1)
-	return;
+	return 0;
     
     for (base = keys; (base != 0) && *seq; ){
 	if (*seq == base->ch){
 	    if (base->child == 0){
 		if (*(seq+1)){
 		    base->child = create_sequence (seq+1, code, action);
-		    return;
+		    return 1;
 		} else {
-		    /* The sequence clashes */
+		    /* The sequence matches an existing one.  */
                     base->code = code;
                     base->action = action;
-		    return;
+		    return 1;
 		}
 	    } else {
 		base = base->child;
@@ -415,17 +407,21 @@ void define_sequence (int code, char *seq, int action)
 		base = base->next;
 	    else {
 		base->next = create_sequence (seq, code, action);
-		return;
+		return 1;
 	    }
 	}
     }
+
+    if (!*seq) {
+	/* Attempt to redefine a sequence with a shorter sequence.  */
+	return 0;
+    }
+
     keys = create_sequence (seq, code, action);
-#endif    
+    return 1;
 }
 
-#ifndef HAVE_X
 static int *pending_keys;
-#endif
 
 static int
 correct_key_code (int c)
@@ -455,7 +451,6 @@ correct_key_code (int c)
 
 int get_key_code (int no_delay)
 {
-#ifndef HAVE_X
     int c;
     static key_def *this = NULL, *parent;
     static struct timeval esctime = { -1, -1 };
@@ -620,12 +615,8 @@ int get_key_code (int no_delay)
     }
     this = NULL;
     return correct_key_code (c);
-#else
-    return ERR;
-#endif /* HAVE_X */
 }
 
-#ifndef PORT_HAS_FILE_HANDLERS
 /* If set timeout is set, then we wait 0.1 seconds, else, we block */
 static void
 try_channels (int set_timeout)
@@ -656,7 +647,6 @@ try_channels (int set_timeout)
     }
 }
 
-#ifndef HAVE_X
 /* Workaround for System V Curses vt100 bug */
 static int getch_with_delay (void)
 {
@@ -678,16 +668,13 @@ static int getch_with_delay (void)
     /* Success -> return the character */
     return c;
 }
-#endif /* !HAVE_X */
 
 #ifndef HAVE_LIBGPM
 #define gpm_flag 0
 #endif
-#endif /* !HAVE_FILE_HANDLERS */
 
 extern int max_dirt_limit;
 
-#ifndef HAVE_X
 /* Returns a character read from stdin with appropriate interpretation */
 /* Also takes care of generated mouse events */
 /* Returns EV_MOUSE if it is a mouse event */
@@ -811,20 +798,15 @@ int get_event (Gpm_Event *event, int redo_event, int block)
     
     if (c == MCKEY_MOUSE) { /* Mouse event */
         xmouse_get_event (event);
-        return EV_MOUSE;
+	if (event->type)
+	    return EV_MOUSE;
+	else
+	    return EV_NONE;
     }
 
     return c;
 }
-#else
-/* X11 version of the get_event routine */
-int get_event (Gpm_Event *event, int redo_event, int block)
-{
-    return EV_NONE;
-}
-#endif
 
-#ifndef PORT_HAS_GETCH
 /* Returns a key press, mouse events are discarded */
 int mi_getch ()
 {
@@ -832,12 +814,12 @@ int mi_getch ()
     int       key;
 
     ev.x = -1;
-    while ((key = get_event (&ev, 0, 1)) == 0)
+    while ((key = get_event (&ev, 0, 1)) == EV_NONE)
 	;
     return key;
 }
 
-int xgetch_second (void)
+static int xgetch_second (void)
 {
     fd_set Read_FD_Set;
     int c;
@@ -861,9 +843,7 @@ int xgetch_second (void)
 #endif
     return c;
 }
-#endif
 
-#ifndef HAVE_X
 static void
 learn_store_key (char *buffer, char **p, int c)
 {
@@ -956,7 +936,6 @@ application_keypad_mode (void)
     }
 }
 
-#endif /* !HAVE_X */
 
 /* A function to check if we're idle.
    Currently checks only for key presses.
@@ -980,8 +959,8 @@ int is_idle (void)
 int
 get_modifier (void)
 {
-#if defined (HAVE_TEXTMODE_X11_SUPPORT) && !defined (HAVE_X)
-    if (display) {
+#ifdef HAVE_TEXTMODE_X11_SUPPORT
+    if (x11_display) {
         Window root, child;
         int root_x, root_y;
         int win_x, win_y;
@@ -989,7 +968,7 @@ get_modifier (void)
         Bool b;
 	int result = 0;
 
-	b = XQueryPointer(display, w, &root, &child,
+	b = XQueryPointer(x11_display, x11_window, &root, &child,
                                   &root_x, &root_y,
                                   &win_x, &win_y,
              			  &mask);
@@ -1018,19 +997,16 @@ get_modifier (void)
 }
 
 int
-ctrl_pressed ()
+ctrl_pressed (void)
 {
-#ifdef __linux__
     if (get_modifier () & CONTROL_PRESSED)
 	return 1;
-#endif
-    return 0;
+    else
+	return 0;
 }
 
 #ifdef HAVE_MAD
-#ifndef HAVE_X
-
-void k_dispose (key_def *k)
+static void k_dispose (key_def *k)
 {
     if (!k)
 	return;
@@ -1039,7 +1015,7 @@ void k_dispose (key_def *k)
     g_free (k);
 }
 
-void s_dispose (SelectList *sel)
+static void s_dispose (SelectList *sel)
 {
     if (!sel)
 	return;
@@ -1047,26 +1023,17 @@ void s_dispose (SelectList *sel)
     s_dispose (sel->next);
     g_free (sel);
 }
+#endif /* HAVE_MAD */
 
 void done_key ()
 {
+#ifdef HAVE_MAD
     k_dispose (keys);
     s_dispose (select_list);
-}
-
-#else
-void done_key () 
-{
-}
-
-#endif /* HAVE_X */
 #endif /* HAVE_MAD */
 
-#if defined (HAVE_TEXTMODE_X11_SUPPORT) && !defined (HAVE_X)
-void
-done_textmode_x11_support (void)
-{
-    if (display)
-	XCloseDisplay (display);
+#ifdef HAVE_TEXTMODE_X11_SUPPORT
+    if (x11_display)
+	XCloseDisplay (x11_display);
+#endif /* HAVE_TEXTMODE_X11_SUPPORT */
 }
-#endif
