@@ -4,8 +4,6 @@
 void init_key (void);
 void init_key_input_fd (void);
 void done_key (void);
-void init_textmode_x11_support (void);
-void done_textmode_x11_support (void);
 
 int get_event (Gpm_Event *event, int redo_event, int block);
 int is_idle (void);
@@ -65,7 +63,7 @@ int is_quit_char (int c);
 #define MCKEY_MOUSE     -2
 
 void do_define_key (int code, char *strcap);
-void define_sequence (int code, char *seq, int action);
+int define_sequence (int code, char *seq, int action);
 
 /* internally used in key.c, defined in keyxtra.c */
 void load_xtra_key_defines (void);
