@@ -15,7 +15,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  
  */
 
 #include <config.h>
@@ -51,7 +51,7 @@
 
 #define BUTTONS 	2
 
-struct {
+static struct {
     int ret_cmd, flags, y, x;
 	unsigned int hotkey;
     char *text;
@@ -73,7 +73,6 @@ static int learnok;
 static int learnchanged;
 static char* learn_title = N_(" Learn keys ");
 
-#ifndef HAVE_X
 static void learn_refresh (void)
 {
     attrset (COLOR_NORMAL);
@@ -85,7 +84,6 @@ static void learn_refresh (void)
     dlg_move (learn_dlg, 1, (learn_dlg->cols - strlen (learn_title)) / 2);
     addstr (learn_title);
 }
-#endif
 
 static int learn_button (int action, void *param)
 {
@@ -109,6 +107,8 @@ _("Please press the %s\n"
 	/* Esc hides the dialog and do not allow definitions of
 	 * regular characters
 	 */
+	int seq_ok;
+
 	if (*seq && strcmp (seq, "\\e") && strcmp (seq, "\\e\\e")
 	    && strcmp (seq, "^m" ) 
             && (seq [1] || (*seq < ' ' || *seq > '~'))){
@@ -116,9 +116,13 @@ _("Please press the %s\n"
 	    learnchanged = 1;
 	    learnkeys [action - B_USER].sequence = seq;
 	    seq = convert_controls (seq);
-	    define_sequence (key_name_conv_tab [action - B_USER].code, seq, 
-			     MCKEY_NOACTION);
+	    seq_ok = define_sequence (key_name_conv_tab [action - B_USER].code,
+				      seq, MCKEY_NOACTION);
 	} else {
+	    seq_ok = 0;
+	}
+
+	if (!seq_ok) {
 	    message (0, _(" Cannot accept this key "),
 		_(" You have entered \"%s\""), seq);
 	}
@@ -234,11 +238,9 @@ static void init_learn (void)
     int x, y, i, j;
     key_code_name_t *key;
     char buffer [BUF_TINY];
-	static int i18n_flag = 0;
-
-    do_refresh ();
 
 #ifdef ENABLE_NLS
+	static int i18n_flag = 0;
 	if (!i18n_flag)
 	{
 		char* cp;
@@ -261,6 +263,8 @@ static void init_learn (void)
 	}
 #endif /* ENABLE_NLS */
 
+    do_refresh ();
+
     learn_dlg = create_dlg (0, 0, 23, 78, dialog_colors,
 			      learn_callback, "[Learn keys]", "Learn keys",
 			      DLG_CENTER);
@@ -322,7 +326,7 @@ learn_save (void)
 	    profile_changed = 1;
 	    WritePrivateProfileString (section, key_name_conv_tab [i].name,
 	        learnkeys [i].sequence, profile_name);
-        }
+	}
     }
 
     /* On the one hand no good idea to save the complete setup but 
@@ -332,7 +336,9 @@ learn_save (void)
      * disk is much worse.
      */
     if (profile_changed)
-        sync_profiles ();
+	sync_profiles ();
+
+    g_free (section);
 }
 
 void learn_keys (void)
@@ -344,9 +350,7 @@ void learn_keys (void)
     alternate_plus_minus = 1; /* don't translate KP_ADD, KP_SUBTRACT and
                                  KP_MULTIPLY to '+', '-' and '*' in
                                  correct_key_code */
-#ifndef HAVE_X
     application_keypad_mode ();
-#endif
     init_learn ();
 
     run_dlg (learn_dlg);
@@ -354,11 +358,8 @@ void learn_keys (void)
     old_esc_mode = save_old_esc_mode;
     alternate_plus_minus = save_alternate_plus_minus;
 
-#ifndef HAVE_X
     if (!alternate_plus_minus)
         numeric_keypad_mode ();
-
-#endif
     
     switch (learn_dlg->ret_value) {
     case B_ENTER:
