@@ -150,7 +150,7 @@
 #endif
 #endif
 
-/* "$Id: main.c,v 1.124 2001/02/26 16:54:23 proskin Exp $" */
+/* "$Id: main.c,v 1.161 2001/08/20 05:39:21 proskin Exp $" */
 
 /* When the modes are active, left_panel, right_panel and tree_panel */
 /* Point to a proper data structure.  You should check with the functions */
@@ -164,8 +164,10 @@ WPanel *right_panel;
 /* The pointer to the tree */
 WTree *the_tree;
 
+#ifndef HAVE_X
 /* The Menubar */
 WMenu *the_menubar;
+#endif /* HAVE_X */
 
 /* Pointers to the selected and unselected panel */
 WPanel *current_panel = NULL;
@@ -213,12 +215,14 @@ int   pause_after_run = pause_on_dumb_terminals;
 /* It true saves the setup when quitting */
 int auto_save_setup = 1;
 
+#if !defined(HAVE_CHARSET) && !defined(HAVE_X)
 /* If true, be eight bit clean */
 int eight_bit_clean = 1;
 
 /* If true, then display chars 0-255, else iso-8859-1,
    requires eight_bit_clean */
 int full_eight_bits = 1;
+#endif /* !HAVE_CHARSET && !HAVE_X */
 
 /* If true use the internal viewer */
 int use_internal_view = 1;
@@ -232,8 +236,10 @@ int mouse_move_pages = 1;
 /* If true: l&r arrows are used to chdir if the input line is empty */
 int navigate_with_arrows = 0;
 
+#if 0
 /* If it is set, the commander will iconify itself when executing a program */
 int iconify_on_exec = 1;
+#endif
 
 /* If true use +, -, | for line drawing */
 int force_ugly_line_drawing = 0;
@@ -302,8 +308,14 @@ char *program_name;
 /* The home directory */
 char *home_dir;
 
+#ifndef HAVE_X
 /* The value of the other directory, only used when loading the setup */
 char *other_dir = 0;
+
+/* Only used at program boot */
+int boot_current_is_left = 1;
+#endif /* !HAVE_X */
+
 char *this_dir = 0;
 
 /* If this is true, then when browsing the tree the other window will
@@ -345,20 +357,11 @@ int midnight_shutdown = 0;
 /* to show nice prompts */
 static int last_paused = 0;
 
-/* Only used at program boot */
-int boot_current_is_left = 1;
-
 /* Used for keeping track of the original stdout */
 int stdout_fd = 0;
 
-/*
- * Ugh.  Pavel, you shell hack in sfs is BAD.
- * We need to kill shell from vfs
- */
-#ifndef USE_VFS
 /* The user's shell */
 char *shell;
-#endif
 
 /* mc_home: The home of MC */
 char *mc_home;
@@ -371,27 +374,28 @@ char cmd_buf [512];
 /* Used during argument processing */
 int finish_program = 0;
 
+#ifdef HAVE_GNOME
 /* If set, then no windows are displayed in the GNOME edition */
 int   nowindows = 0, nodesktop = 0, twopanel;
 
 /* If set it displays the directory that holds the gnome .links files */
 int display_linksdir = 0;
+#endif
 
 /* Forward declarations */
-char *get_mc_lib_dir ();
+char *get_mc_lib_dir (void);
 int panel_event    (Gpm_Event *event, WPanel *panel);
 int menu_bar_event (Gpm_Event *event, void *);
-static void menu_cmd (void);
 
 #ifndef HAVE_GNOME
 WPanel *
-get_current_panel ()
+get_current_panel (void)
 {
 	return current_panel;
 }
 
 WPanel *
-get_other_panel ()
+get_other_panel (void)
 {
 	return (WPanel *) get_panel_widget (get_other_index ());
 }
@@ -502,7 +506,7 @@ panel_clean_dir (WPanel *panel)
 }
 
 #ifndef PORT_HAS_UPDATE_PANELS
-void
+static void
 update_one_panel (int which, int force_update, char *current_file)
 {
     WPanel *panel;
@@ -719,7 +723,7 @@ do_possible_cd (char *new_dir)
 }
 
 void
-do_update_prompt ()
+do_update_prompt (void)
 {
     if (update_prompt){
 	printf ("%s", subshell_prompt);
@@ -736,7 +740,7 @@ restore_console (void)
 }
 
 void
-exec_shell ()
+exec_shell (void)
 {
     do_execute (shell, 0, 0);
 }
@@ -763,7 +767,7 @@ do_execute (const char *shell, const char *command, int flags)
 #ifndef __os2__
     unlink (control_file);
 #endif
-    if (!use_subshell && !(flags & EXECUTE_INTERNAL)){
+    if (!use_subshell && !(flags & EXECUTE_INTERNAL && command)) {
 	printf ("%s%s%s\n", last_paused ? "\r\n":"", prompt, command);
 	last_paused = 0;
     }
@@ -849,12 +853,14 @@ execute (char *command)
     shell_execute (command, 0);
 }
 
+#ifndef HAVE_X
 void
 change_panel (void)
 {
     free_completions (input_w (cmdline));
     dlg_one_down (midnight_dlg);
 }
+#endif /* !HAVE_X */
 
 static int
 quit_cmd_internal (int quiet)
@@ -1027,14 +1033,16 @@ _do_panel_cd (WPanel *panel, char *new_dir, enum cd_enum cd_type)
     if (mc_chdir (directory) == -1){
 	strcpy (panel->cwd, olddir);
 	g_free (olddir);
-       g_free (translated_url);
+	g_free (translated_url);
 	return 0;
     }
     g_free (translated_url);
 
     /* Success: save previous directory, shutdown status of previous dir */
     strcpy (panel->lwd, olddir);
+#ifndef HAVE_X
     free_completions (input_w (cmdline));
+#endif /* !HAVE_X */
     
     mc_get_current_wd (panel->cwd, sizeof (panel->cwd) - 2);
 
@@ -1097,6 +1105,7 @@ directory_history_prev (WPanel * panel)
     panel_update_marks (panel);
 }
 
+#ifndef HAVE_X
 void
 directory_history_list (WPanel * panel)
 {
@@ -1115,6 +1124,7 @@ directory_history_list (WPanel * panel)
 	}
     }
 }
+#endif /* !HAVE_X */
 
 #ifdef HAVE_SUBSHELL_SUPPORT
 int
@@ -1122,8 +1132,9 @@ load_prompt (int fd, void *unused)
 {
     if (!read_subshell_prompt (QUIETLY))
 	return 0;
-    
-    if (command_prompt){
+
+    /* Don't actually change the prompt if it's invisible */
+    if (current_dlg == midnight_dlg && command_prompt){
 	int  prompt_len;
 
 	prompt = strip_ctrl_codes (subshell_prompt);
@@ -1141,10 +1152,8 @@ load_prompt (int fd, void *unused)
 	 * get_event channels, the prompt updating does not take place
 	 * automatically: force a cursor update and a screen refresh
 	 */
-	if (current_dlg == midnight_dlg){
-	    update_cursor (midnight_dlg);
-	    mc_refresh ();
-	}
+	update_cursor (midnight_dlg);
+	mc_refresh ();
     }
     update_prompt = 1;
     return 0;
@@ -1165,6 +1174,7 @@ menu_bar_event (Gpm_Event *event, void *x)
 int
 maybe_cd (int char_code, int move_up_dir)
 {
+#ifndef HAVE_X
     if (navigate_with_arrows){
 	if (!input_w (cmdline)->buffer [0]){
 	    if (!move_up_dir){
@@ -1178,8 +1188,10 @@ maybe_cd (int char_code, int move_up_dir)
 	    }
 	}
     }
+#endif /* !HAVE_X */
     return 0;
 }
+
 #if 0
 static void
 set_sort_to (WPanel *p, sortfn *sort_order)
@@ -1198,6 +1210,7 @@ set_sort_to (WPanel *p, sortfn *sort_order)
     do_re_sort (p);
 }
 #endif
+#ifndef HAVE_GNOME
 void
 sort_cmd (void)
 {
@@ -1214,7 +1227,6 @@ sort_cmd (void)
 
 }
 
-#ifndef HAVE_GNOME
 static void
 tree_box (void)
 {
@@ -1239,10 +1251,7 @@ listmode_cmd (void)
 #endif /* LISTMODE_EDITOR */
 #endif /* !HAVE_GNOME */
 
-#ifdef HAVE_GNOME
-void init_menu (void) {};
-void done_menu (void) {};
-#else
+#ifndef HAVE_GNOME
 /* NOTICE: hotkeys specified here are overriden in menubar_paint_idx (alex) */
 static menu_entry PanelMenu [] = {
     { ' ', N_("&Listing mode..."),          'L', listing_cmd },
@@ -1292,7 +1301,6 @@ static menu_entry RightMenu [] = {
     { ' ', N_("&Rescan         C-r"),    'R', reread_cmd }
 };
 
-#ifndef HAVE_GNOME
 static menu_entry FileMenu [] = {
     { ' ', N_("&User menu          F2"), 'U', user_file_menu_cmd },
     { ' ', N_("&View               F3"), 'V', view_cmd },
@@ -1319,7 +1327,6 @@ static menu_entry FileMenu [] = {
     { ' ', "", ' ', 0 },
     { ' ', N_("e&Xit              F10"), 'X', (callfn) quit_cmd }
 };
-#endif
 
 void external_panelize (void);
 static menu_entry CmdMenu [] = {
@@ -1327,9 +1334,7 @@ static menu_entry CmdMenu [] = {
      * as a panel still has some problems, I have not yet finished
      * the WTree widget port, sorry.
      */
-#ifndef HAVE_GNOME
     { ' ', N_("&Directory tree"),               'D', tree_box },
-#endif
     { ' ', N_("&Find file            M-?"),     'F', find_cmd },
     { ' ', N_("s&Wap panels          C-u"),     'W', swap_cmd },
     { ' ', N_("switch &Panels on/off C-o"),     'P', view_other_cmd },
@@ -1369,12 +1374,12 @@ static menu_entry OptMenu [] = {
     { ' ', N_("&Layout..."),           'L', layout_cmd },
     { ' ', N_("c&Onfirmation..."),     'O', confirm_box },
     { ' ', N_("&Display bits..."),     'D', display_bits_box },
-#if !defined(HAVE_X) && !defined(OS2_NT)
+#ifndef OS2_NT
     { ' ', N_("learn &Keys..."),       'K', learn_keys },
-#endif
+#endif /* !OS2_NT */
 #ifdef USE_VFS    
     { ' ', N_("&Virtual FS..."),       'V', configure_vfs },
-#endif
+#endif /* !USE_VFS */
     { ' ', "", ' ', 0 }, 
     { ' ', N_("&Save setup"),          'S', save_setup_cmd }
 };
@@ -1382,32 +1387,17 @@ static menu_entry OptMenu [] = {
 #define menu_entries(x) sizeof(x)/sizeof(menu_entry)
 
 Menu MenuBar [5];
-#ifndef HAVE_X
-static Menu MenuBarEmpty [5];
-#endif
 
 void
 init_menu (void)
 {
-    int i;
-
-#ifdef HAVE_X    
-    MenuBar [0] = create_menu (_(" &Left "), PanelMenu, menu_entries (PanelMenu));
-#else
     MenuBar [0] = create_menu ( horizontal_split ? _(" &Above ") : _(" &Left "), 
                                 PanelMenu, menu_entries (PanelMenu));
-#endif
     MenuBar [1] = create_menu (_(" &File "), FileMenu, menu_entries (FileMenu));
     MenuBar [2] = create_menu (_(" &Command "), CmdMenu, menu_entries (CmdMenu));
     MenuBar [3] = create_menu (_(" &Options "), OptMenu, menu_entries (OptMenu));
-#ifdef HAVE_X
-    MenuBar [4] = create_menu (_(" &Right "), RightMenu, menu_entries (PanelMenu));
-#else
     MenuBar [4] = create_menu (horizontal_split ? _(" &Below ") : _(" &Right "), 
 			       RightMenu, menu_entries (PanelMenu));
-    for (i = 0; i < 5; i++)
-	MenuBarEmpty [i] = create_menu (MenuBar [i]->name, 0, 0);
-#endif /* HAVE_X */
 }
 
 void
@@ -1417,12 +1407,8 @@ done_menu (void)
 
     for (i = 0; i < 5; i++){
 	destroy_menu (MenuBar [i]);
-#ifndef HAVE_X
-	destroy_menu (MenuBarEmpty [i]);
-#endif
     }
 }
-#endif
     
 static void
 menu_last_selected_cmd (void)
@@ -1445,6 +1431,7 @@ menu_cmd (void)
 	the_menubar->selected = 4;
     menu_last_selected_cmd ();
 }
+#endif /* !HAVE_GNOME */
 
 /* Flag toggling functions */
 void
@@ -1507,6 +1494,7 @@ toggle_align_extensions (void)
  * Just a hack for allowing url-like pathnames to be accepted from the
  * command line.
  */
+#ifndef PORT_HAS_CREATE_PANELS
 static void
 translated_mc_chdir (char *dir)
 {
@@ -1517,7 +1505,6 @@ translated_mc_chdir (char *dir)
 	g_free (newdir);
 }
 
-#ifndef PORT_HAS_CREATE_PANELS
 void
 create_panels (void)
 {
@@ -1587,6 +1574,7 @@ create_panels (void)
 }
 #endif
 
+#ifndef HAVE_GNOME
 static void copy_current_pathname (void)
 {
     if (!command_prompt)
@@ -1712,7 +1700,7 @@ static void do_suspend_cmd (void)
 	/* Restore previous SIGTSTP action */
 	sigaction (SIGTSTP, &sigtstp_action, NULL);
     }
-#endif
+#endif /* SIGTSTP */
     
     if (console_flag && !use_subshell)
 	handle_console (CONSOLE_SAVE);
@@ -1740,40 +1728,34 @@ init_labels (Widget *paneletc)
 
 static const key_map ctl_x_map [] = {
     { XCTRL('c'),   (callfn) quit_cmd },
+    { 'd',          compare_dirs_cmd },
 #ifdef USE_VFS
     { 'a',          reselect_vfs },
-#endif
-    { 'd',          compare_dirs_cmd },
-#ifndef HAVE_GNOME
+#endif /* USE_VFS */
     { 'p',          copy_current_pathname },
     { XCTRL('p'),   copy_other_pathname },
     { 't',          copy_current_tagged },
     { XCTRL('t'),   copy_other_tagged },
     { 'c',          chmod_cmd },
-#endif
 #ifndef OS2_NT
-#ifndef HAVE_GNOME
     { 'o',          chown_cmd },
-#endif
+    { 'r',          copy_current_readlink },
+    { XCTRL('r'),   copy_other_readlink },
     { 'l',          link_cmd },
     { XCTRL('l'),   other_symlink_cmd },
     { 's',          symlink_cmd },
     { XCTRL('s'),   edit_symlink_cmd },
-    { 'r',          copy_current_readlink },
-    { XCTRL('r'),   copy_other_readlink },
-#endif
-#ifndef HAVE_GNOME
+#endif /* !OS2_NT */
     { 'i',          info_cmd_no_menu },
     { 'q',          quick_cmd_no_menu },
-#endif
     { 'h',          add2hotlist_cmd },
     { '!',          external_panelize },
 #ifdef WITH_BACKGROUND
     { 'j',          jobs_cmd },
-#endif
+#endif /* WITH_BACKGROUND */
 #ifdef HAVE_SETSOCKOPT
     { '%',          source_routing },
-#endif
+#endif /* HAVE_SETSOCKOPT */
     { 0,  0 }
 };
 
@@ -1783,8 +1765,9 @@ static void ctl_x_cmd (int ignore)
 {
 	ctl_x_map_enabled = 1;
 }
+#endif /* !HAVE_GNOME */
 
-static void nothing ()
+static void nothing (void)
 {
 }
 
@@ -1816,18 +1799,19 @@ static const key_map default_map [] = {
     /* Panel refresh */
     { XCTRL('r'), reread_cmd },
 
+#ifndef HAVE_X
+    /* Toggle listing between long, user defined and full formats */
     { ALT('t'),   toggle_listing_cmd },
     
-#ifndef HAVE_X
     /* Swap panels */
     { XCTRL('u'), swap_cmd },
 
     /* View output */
     { XCTRL('o'), view_other_cmd },
-#endif
     
     /* Control-X keybindings */
     { XCTRL('x'), ctl_x_cmd },
+#endif /* !HAVE_X */
 
     /* Trap dlg's exit commands */
     { ESC_CHAR,   nothing },
@@ -1837,7 +1821,7 @@ static const key_map default_map [] = {
 };
 
 #ifndef HAVE_X
-static void setup_sigwinch ()
+static void setup_sigwinch (void)
 {
 #if (defined(HAVE_SLANG) || (NCURSES_VERSION_MAJOR >= 4)) && \
    !defined(OS2_NT) && defined(SIGWINCH)
@@ -1853,58 +1837,60 @@ static void setup_sigwinch ()
 }
 
 static void
-setup_pre ()
+setup_pre (void)
 {
     /* Call all the inits */
+#ifdef HAVE_CHARSET
+/*
+ * Don't restrict the output on the screen manager level,
+ * the translation tables take care of it.
+ */
+#define full_eight_bits (1)
+#define eight_bit_clean (1)
+#endif /* !HAVE_CHARSET */
+
 #ifndef HAVE_SLANG
     meta (stdscr, eight_bit_clean);
 #else
     SLsmg_Display_Eight_Bit = full_eight_bits ? 128 : 160;
 #endif
 }
-#else
-#define setup_pre()
-#define setup_sigwinch()
-#endif
 
 static void
-setup_post ()
+setup_post (void)
 {
     setup_sigwinch ();
     
-    init_uid_gid_cache ();
-
-#ifndef HAVE_X
     if (baudrate () < 9600 || slow_terminal){
 	verbose = 0;
     }
     if (use_mouse_p)
 	init_mouse ();
-#endif
 
     midnight_colors [0] = 0;
     midnight_colors [1] = REVERSE_COLOR;     /* FOCUSC */
     midnight_colors [2] = INPUT_COLOR;       /* HOT_NORMALC */
     midnight_colors [3] = NORMAL_COLOR;	     /* HOT_FOCUSC */
 }
+#endif /* !HAVE_X */
 
 static void setup_mc (void)
 {
+#ifndef HAVE_X
     setup_pre ();
     init_menu ();
     create_panels ();
-
-#ifdef HAVE_GNOME
-    return;
-#endif
     setup_panels ();
-    
+
 #ifdef HAVE_SUBSHELL_SUPPORT
     if (use_subshell)
 	add_select_channel (subshell_pty, load_prompt, 0);
-#endif
-    
+#endif /* !HAVE_SUBSHELL_SUPPORT */
+
     setup_post ();
+#else
+    create_panels ();
+#endif /* !HAVE_X */
 }
 
 static void setup_dummy_mc (const char *file)
@@ -1924,9 +1910,11 @@ static void setup_dummy_mc (const char *file)
     cpanel->dir.list[0].fname = (char *) file;
 }
 
-static void done_mc ()
+static void done_mc (void)
 {
+#ifndef HAVE_X
     done_menu ();
+#endif /* !HAVE_X */
     
     /* Setup shutdown
      *
@@ -1935,18 +1923,22 @@ static void done_mc ()
      */
     if (auto_save_setup)
 	save_setup ();   /* does also call save_hotlist */
+#ifndef HAVE_X
     else
 	save_hotlist();
     done_screen ();
+#endif /* !HAVE_X */
     vfs_add_current_stamps ();
+#ifndef HAVE_X
     if (xterm_flag && xterm_hintbar)
         set_hintbar(_("Thank you for using GNU Midnight Commander"));
+#endif /* !HAVE_X */
 }
 
 /* This should be called after destroy_dlg since panel widgets
  *  save their state on the profiles
  */
-static void done_mc_profile ()
+static void done_mc_profile (void)
 {
     if (!auto_save_setup)
 	profile_forget_profile (profile_name);
@@ -1960,7 +1952,7 @@ static void done_mc_profile ()
  * and use get_panel_widget (i) and make the test done below
  */
 static void
-make_panels_dirty ()
+make_panels_dirty (void)
 {
     if (cpanel->dirty)
 	panel_update_contents (cpanel);
@@ -1988,6 +1980,7 @@ midnight_callback (struct Dlg_head *h, int id, int msg)
 	return MSG_HANDLED;
 	
     case DLG_KEY:
+#ifndef HAVE_X
 	if (ctl_x_map_enabled){
 		ctl_x_map_enabled = 0;
 		for (i = 0; ctl_x_map [i].key_code; i++)
@@ -1997,7 +1990,11 @@ midnight_callback (struct Dlg_head *h, int id, int msg)
 			}
 	}
 	    
-	if (id == KEY_F(10) && !the_menubar->active){
+	/* FIXME: should handle all menu shortcuts before this point */
+	if (the_menubar->active)
+	    break;
+
+	if (id == KEY_F(10)){
 	    quit_cmd ();
 	    return MSG_HANDLED;
 	}
@@ -2056,6 +2053,7 @@ midnight_callback (struct Dlg_head *h, int id, int msg)
 	    }   
 	} 
 	break;
+#endif /* !HAVE_X */
 
     case DLG_HOTKEY_HANDLED:
 	if (get_current_type () == view_listing)
@@ -2063,6 +2061,7 @@ midnight_callback (struct Dlg_head *h, int id, int msg)
 	break;
 	
     case DLG_UNHANDLED_KEY:
+#ifndef HAVE_X
 	if (command_prompt){
 	    int v;
 	    
@@ -2070,14 +2069,16 @@ midnight_callback (struct Dlg_head *h, int id, int msg)
 	    if (v)
 		return v;
 	}
-	if (ctl_x_map_enabled){
+	if (ctl_x_map_enabled) {
 		ctl_x_map_enabled = 0;
 		for (i = 0; ctl_x_map [i].key_code; i++)
 			if (id == ctl_x_map [i].key_code){
 				(*ctl_x_map [i].fn)(id);
 				return MSG_HANDLED;
 			}
-	} else {
+	} else
+#endif /* !HAVE_X */
+	{
 		for (i = 0; default_map [i].key_code; i++){
 			if (id == default_map [i].key_code){
 				(*default_map [i].fn)(id);
@@ -2111,7 +2112,7 @@ widget_data containers [2];
 int containers_no = 2;
 
 void
-xtoolkit_panel_setup ()
+xtoolkit_panel_setup (void)
 {
     containers [0] = x_create_panel_container (0);
     containers [1] = x_create_panel_container (1);
@@ -2136,7 +2137,7 @@ xtoolkit_panel_setup ()
 #endif
 
 #ifndef PORT_HAS_LOAD_HINT
-void load_hint ()
+void load_hint (void)
 {
     char *hint;
 
@@ -2159,18 +2160,17 @@ void load_hint ()
 }
 #endif
 
+#ifndef HAVE_GNOME
 static void
-setup_panels_and_run_mc ()
+setup_panels_and_run_mc (void)
 {
     int first, second;
 
     xtoolkit_panel_setup ();
-#ifndef HAVE_X
     add_widget (midnight_dlg, the_hint);
-#endif /* HAVE_X */
     load_hint ();
-    add_widgetl (midnight_dlg, cmdline, XV_WLAY_RIGHTOF);
-    add_widgetl (midnight_dlg, the_prompt, XV_WLAY_DONTCARE);
+    add_widget (midnight_dlg, cmdline);
+    add_widget (midnight_dlg, the_prompt);
     add_widget (midnight_dlg, the_bar);
 
     if (boot_current_is_left){
@@ -2190,6 +2190,7 @@ setup_panels_and_run_mc ()
     /* Run the Midnight Commander if no file was specified in the command line */
     run_dlg (midnight_dlg);
 }
+#endif /* !HAVE_GNOME */
 
 /* result must be free'd (I think this should go in util.c) */
 static char *
@@ -2211,12 +2212,10 @@ prepend_cwd_on_local (char *filename)
 	return g_strdup (filename);
 }
 
-#ifdef USE_INTERNAL_EDIT
-
 static int
 mc_maybe_editor_or_viewer (void)
 {
-    char *path;
+    char *path = NULL;
 
     if (!(view_one_file || edit_one_file))
 	    return 0;
@@ -2229,6 +2228,7 @@ mc_maybe_editor_or_viewer (void)
 	    setup_dummy_mc (path);
 	    view_file (path, 0, 1);
     }
+#ifdef USE_INTERNAL_EDIT
     else {
 	    path = prepend_cwd_on_local ("");
 #ifndef HAVE_GNOME
@@ -2240,25 +2240,22 @@ mc_maybe_editor_or_viewer (void)
 	    exit (1);
 #endif
     }
+#endif /* USE_INTERNAL_EDIT */
     g_free (path);
     midnight_shutdown = 1;
     done_mc ();
     return 1;
 }
 
-#endif	/* USE_INTERNAL_EDIT */
-
 static void
 do_nc (void)
 {
     midnight_dlg = create_dlg (0, 0, LINES, COLS, midnight_colors, midnight_callback, "[main]", "midnight", 0);
     midnight_dlg->has_menubar = 1;
 
-#ifdef USE_INTERNAL_EDIT
     /* Check if we were invoked as an editor or file viewer */
     if (mc_maybe_editor_or_viewer ())
 	    return;
-#endif
     
     setup_mc ();
 
@@ -2291,7 +2288,7 @@ do_nc (void)
 char control_file [sizeof (CONTROL_FILE) + 8];
 
 void
-OS_Setup ()
+OS_Setup (void)
 {
     SetConsoleTitle ("GNU Midnight Commander");
     
@@ -2365,19 +2362,17 @@ init_sigfatals (void)
 char control_file [sizeof (CONTROL_FILE) + 8];
 
 static void
-OS_Setup ()
+OS_Setup (void)
 {
-    char   *termvalue;
     char   *mc_libdir;
+#ifndef HAVE_X
+    char   *termvalue;
 	
     termvalue = getenv ("TERM");
-    if (!termvalue){
-#ifndef HAVE_X
+    if (!termvalue || !(*termvalue)){
 	fprintf (stderr, _("The TERM environment variable is unset!\n"));
-#endif
-	termvalue = "";
+	exit (1);
     }
-#ifndef HAVE_X
     if (force_xterm || (strncmp (termvalue, "xterm", 5) == 0 || strcmp (termvalue, "dtterm") == 0)){
 	use_mouse_p = XTERM_MOUSE;
 	xterm_flag = 1;
@@ -2408,6 +2403,7 @@ static void
 sigchld_handler_no_subshell (int sig)
 {
 #ifndef HAVE_X
+#if defined(linux) || defined(__linux__)
     int pid, status;
 
     if (!console_flag)
@@ -2420,27 +2416,26 @@ sigchld_handler_no_subshell (int sig)
     /* That comment is no longer true.  We need to wait() on a sigchld
        handler (that's at least what the tarfs code expects currently). */
 
-#ifndef SCO_FLAVOR
     pid = waitpid (cons_saver_pid, &status, WUNTRACED | WNOHANG);
     
     if (pid == cons_saver_pid){
-	/* {{{ Someone has stopped or killed cons.saver; restart it */
 
-#  ifdef SIGTSTP
+#ifdef SIGTSTP
 	if (WIFSTOPPED (status))
+	    /* Someone has stopped cons.saver - restart it */
 	    kill (pid, SIGCONT);
 	else
-#  endif
+#endif /* SIGTSTP */
 	{
+	    /* cons.saver has died - disable console saving */
 	    handle_console (CONSOLE_DONE);
-	    handle_console (CONSOLE_INIT);
+	    console_flag = 0;
 	}
-	/* }}} */
     }
-#endif /* ! SCO_FLAVOR */
+#endif /* linux || __linux__ */
 
     /* If we get here, some other child exited; ignore it */
-#endif /* ! HAVE_X  */
+#endif /* !HAVE_X */
 }
 
 void
@@ -2451,18 +2446,26 @@ init_sigchld (void)
     sigchld_action.sa_handler =
 #ifdef HAVE_SUBSHELL_SUPPORT
 	use_subshell ? sigchld_handler :
-#endif
+#endif /* HAVE_SUBSHELL_SUPPORT */
 	sigchld_handler_no_subshell;
 
     sigemptyset (&sigchld_action.sa_mask);
 
 #ifdef SA_RESTART
-        sigchld_action.sa_flags = SA_RESTART;
+    sigchld_action.sa_flags = SA_RESTART;
 #else
-        sigchld_action.sa_flags = 0;
-#endif
+    sigchld_action.sa_flags = 0;
+#endif /* !SA_RESTART */
 
-    sigaction (SIGCHLD, &sigchld_action, NULL);
+    if (sigaction (SIGCHLD, &sigchld_action, NULL) == -1) {
+#ifdef HAVE_SUBSHELL_SUPPORT
+	/*
+	 * This may happen on QNX Neutrino 6, where SA_RESTART
+	 * is defined but not implemented.  Fallback to no subshell.
+	 */
+	use_subshell = 0;
+#endif /* HAVE_SUBSHELL_SUPPORT */
+    }
 }	
 
 #endif /* _OS_NT, __os2__, UNIX */
@@ -2527,21 +2530,20 @@ print_mc_usage (void)
 #endif
     N_("\n"
        "Please send any bug reports (including the output of `mc -V')\n"
-       "to mc-bugs@nuclecu.unam.mx\n"),
+       "to mc-devel@gnome.org\n"),
     NULL    
     };
 
     version (0);
     
     for (ptr = usage; *ptr; ptr++)
-	fprintf (stderr, _(*ptr));
+	fputs (_(*ptr), stderr);
 }
 
 static void
 print_color_usage (void)
 {
-    fprintf (stderr, _(
-	     "--colors KEYWORD={FORE},{BACK}\n\n"
+    fputs (_("--colors KEYWORD={FORE},{BACK}\n\n"
 	     "{FORE} and {BACK} can be ommited, and the default will be used\n"
 	     "\n"
 	     "Keywords:\n"
@@ -2555,7 +2557,7 @@ print_color_usage (void)
 	     "Colors:\n"
 	     "   black, gray, red, brightred, green, brightgreen, brown,\n"
 	     "   yellow, blue, brightblue, magenta, brightmagenta, cyan,\n"
-	     "   brightcyan, lightgray and white\n\n"));
+	     "   brightcyan, lightgray and white\n\n"), stderr);
 }
 #endif /* !HAVE_X */
 
@@ -2601,7 +2603,7 @@ process_args (int c, const char *option_arg)
     case 'l':
 	ftpfs_set_debug (option_arg);
 #ifdef WITH_SMBFS
-	smbfs_set_debug (option_arg);
+/*	smbfs_set_debug (option_arg); */
 #endif
 	break;
 #endif
@@ -2628,29 +2630,11 @@ process_args (int c, const char *option_arg)
 	use_mouse_p = NO_MOUSE;
 	break;
 		
-    case 'X':
 #ifdef HAVE_SUBSHELL_SUPPORT
-	debug_subshell = 1;
-#endif
-	break;
-		
-    case 'U':
-#ifdef HAVE_SUBSHELL_SUPPORT
-	use_subshell = 1;
-#endif
-	break;
-		
     case 'u':
-#ifdef HAVE_SUBSHELL_SUPPORT
 	use_subshell = 0;
-#endif
-	break;
-
-    case 'r':
-#ifdef HAVE_SUBSHELL_SUPPORT
-	force_subshell_execution = 1;
-#endif
 	break;
+#endif	/* HAVE_SUBSHELL_SUPPORT */
 	    
 #ifndef HAVE_X
     case 'H':
@@ -2674,10 +2658,10 @@ static void parse_an_arg (poptContext state,
 	process_args (opt->shortName, arg);
 }
 
-#endif
-
 char *cmdline_geometry = NULL;
 
+#endif
+
 static const struct poptOption argument_table [] = {
 #ifdef HAVE_GNOME
 	{ NULL, '\0', POPT_ARG_CALLBACK, parse_an_arg, 0},
@@ -2696,8 +2680,11 @@ static const struct poptOption argument_table [] = {
 #ifdef HAVE_SUBSHELL_SUPPORT
     { "dbgsubshell", 	'X', POPT_ARG_NONE, 	&debug_subshell, 	 0 },
 #endif
+
+#ifdef USE_INTERNAL_EDIT
     { "edit", 		'e', POPT_ARG_STRING, 	&edit_one_file, 	 0,
       N_("Edits one file") },
+#endif
 
 #ifndef HAVE_GNOME
     { "help", 		'h', POPT_ARG_NONE, 	NULL, 			 'h',
@@ -2722,7 +2709,7 @@ static const struct poptOption argument_table [] = {
 #ifdef HAVE_SUBSHELL_SUPPORT
     { "nosubshell", 	'u', POPT_ARG_NONE, 	NULL, 			 'u',
       N_("Disables subshell support") },
-    { "forceexec", 	'r', POPT_ARG_NONE, 	NULL, 			 'r' },
+    { "forceexec",	'r', POPT_ARG_NONE, 	&force_subshell_execution,0 },
 #endif
     { "printwd", 	'P', POPT_ARG_NONE, 	&print_last_wd, 	  0,
       N_("Prints working directory at program exit") },
@@ -2735,7 +2722,7 @@ static const struct poptOption argument_table [] = {
       N_("Use stickchars to draw") },
 #endif
 #ifdef HAVE_SUBSHELL_SUPPORT
-    { "subshell", 	'U', POPT_ARG_NONE, 	NULL, 			  'U',
+    { "subshell", 	'U', POPT_ARG_NONE, 	&use_subshell,		  0,
       N_("Enables subshell support (default)")},
 #endif
 #if !defined(HAVE_X)
@@ -2819,9 +2806,12 @@ corba_create_window (char *startup_dir)
 static void
 handle_args (int argc, char *argv [])
 {
-    char   *tmp, *option_arg, *base;
-    int    c;
+    char   *tmp;
     poptContext   ctx;
+#ifndef HAVE_GNOME
+    char   *option_arg, *base;
+    int    c;
+#endif /* !HAVE_GNOME */
 
 #ifdef HAVE_GNOME
     /* special case, handle --desktop-linksdir without initing X */
@@ -2870,7 +2860,7 @@ handle_args (int argc, char *argv [])
 	finish_program = 1;
     }
     probably_finish_program ();
-#endif /* HAVE_GNOME */
+#endif /* !HAVE_GNOME */
 
     tmp = poptGetArg (ctx);
 
@@ -2907,15 +2897,17 @@ handle_args (int argc, char *argv [])
 	    probably_finish_program ();
  	}
     } else
-#endif /* HAVE_GNOME */
+#endif /* !HAVE_GNOME */
     {
        	/* sets the current dir and the other dir */
 	if (tmp) {
     	    char buffer[MC_MAXPATHLEN + 2];
 	    this_dir = g_strdup (tmp);
 	    mc_get_current_wd (buffer, sizeof (buffer) - 2);
+#ifndef HAVE_X
 	    if ((tmp = poptGetArg (ctx)))
 	        other_dir = g_strdup (tmp);
+#endif /* !HAVE_X */
 	}
     }
 
@@ -2984,7 +2976,7 @@ compatibility_move_mc_files (void)
 	do_compatibility_move (mc_dir);
 	g_free (mc_dir);
 }
-#endif
+#endif	/* OS2_NT */
 
 int
 main (int argc, char *argv [])
@@ -3051,20 +3043,14 @@ main (int argc, char *argv [])
 #ifndef HAVE_X
 #ifdef HAVE_SLANG
     SLtt_Ignore_Beep = 1;
-#endif
 #endif
     
     /* NOTE: This has to be called before slang_init or whatever routine
        calls any define_sequence */
     init_key ();
 
-#if defined (HAVE_TEXTMODE_X11_SUPPORT) && !defined (HAVE_X)
-    init_textmode_x11_support ();
-#endif
-
-#ifndef HAVE_GNOME
     handle_args (argc, argv);
-#endif
+#endif /* HAVE_X */
     
     /* Used to report the last working directory at program end */
     if (print_last_wd){
@@ -3109,17 +3095,23 @@ main (int argc, char *argv [])
     
     compatibility_move_mc_files ();
     
-#   ifdef HAVE_X
+#ifdef HAVE_X
     /* We need this, since ncurses endwin () doesn't restore the signals */
+    /* Very strange comment given that ifdef HAVE_X stands here since
+       revision 1.1 - Pavel Roskin */
     save_stop_handler ();
-#   endif
+
+#else /* !HAVE_X */
 
     /* Must be done before init_subshell, to set up the terminal size: */
     /* FIXME: Should be removed and LINES and COLS computed on subshell */
+#ifdef HAVE_SLANG
     slang_init ();
+#endif
     /* NOTE: This call has to be after slang_init. It's the small part from
     the previous init_key which had to be moved after the call of slang_init */ 
     init_key_input_fd ();
+#endif /* !HAVE_X */
 
     load_setup ();
 
@@ -3242,14 +3234,10 @@ main (int argc, char *argv [])
 	g_free (last_wd_string);
     }
 
-#ifdef HAVE_MAD
+#if defined(HAVE_MAD) && !defined(HAVE_X)
     done_key ();
 #endif
 
-#if defined (HAVE_TEXTMODE_X11_SUPPORT) && !defined (HAVE_X)
-    done_textmode_x11_support ();
-#endif
-
     mad_finalize (__FILE__, __LINE__);
 #ifdef HAVE_X
     xtoolkit_end ();
