@@ -9,15 +9,20 @@
 #   endif /* not STDC_HEADERS and HAVE_MEMORY_H */
 
 #   ifndef index
-#define index strchr
+#	define index strchr
 #   endif
 
 #   ifndef rindex 
 #       define rindex strrchr
 #   endif
 
+#   undef bcopy
 #   define bcopy(s,d,n) memcpy ((d), (s), (n))
+
+#   undef bcmp
 #   define bcmp(s1,s2,n) memcmp ((s1), (s2), (n))
+
+#   undef bzero
 #   define bzero(s,n) memset ((s), 0, (n))
 
 #else /* not STDC_HEADERS and not HAVE_STRING_H */
