@@ -13,16 +13,17 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include <config.h>
-#include "tty.h"
 #include <string.h>
 #include <stdarg.h>
 #include <sys/types.h>
 #include <ctype.h>
 #include "global.h"
+#include "tty.h"
 #include "menu.h"
+#include "help.h"
 #include "dialog.h"
 #include "color.h"
 #include "main.h"
@@ -30,7 +31,7 @@
 #include "win.h"
 #include "key.h"	/* For mi_getch() */
 
-/* "$Id: menu.c,v 1.19 1999/08/08 12:43:37 norbert Exp $" */
+/* "$Id: menu.c,v 1.22 2001/08/06 22:22:04 proskin Exp $" */
 
 extern int is_right;
 int menubar_visible = 1;	/* This is the new default */
@@ -78,7 +79,7 @@ Menu create_menu (char *name, menu_entry *entries, int count)
 	}
     }
 
-    menu->name = g_strdup ( _(name) );
+    menu->name = g_strdup (name);
     menu_scan_hotkey(menu);
     menu->start_x = 0;
     return menu;
@@ -269,6 +270,29 @@ static int menubar_handle_key (WMenu *menubar, int key)
 	return 1;
     }
 
+    if (key == KEY_F(1)) {
+	if (menubar->dropped) {
+	    switch (menubar->selected) {
+	    case 1:
+		interactive_display (NULL, "[File Menu]");
+		break;
+	    case 2:
+		interactive_display (NULL, "[Command Menu]");
+		break;
+	    case 3:
+		interactive_display (NULL, "[Options Menu]");
+		break;
+	    default:
+		interactive_display (NULL, "[Left and Right Menus]");
+		break;
+	    }
+	} else {
+	    interactive_display (NULL, "[Menu Bar]");
+	}
+	menubar_draw (menubar);
+	return 1;
+    }
+
     if (key == KEY_LEFT || key == XCTRL('b')){
 	menubar_left (menubar);
 	return 1;
