@@ -15,49 +15,12 @@ enum states {
     seen_m
 };
 
-void
-omain (void)
-{
-    enum states state = header;
-    int prev = 0;
-    int c;
-    
-    while ((c = getchar ()) != EOF){
-	if (c != '\n'){
-	    switch (state){ 
-	    case header:
-		putchar ('_');
-		putchar ('\b');
-		break;
-		
-	    case definition:
-		putchar (c);
-		putchar ('\b');
-		break;
-	    default:
-		break;	/* inhibit compiler warnings */
-	    }
-	}
-	putchar (c);
-	if ((state != plain) && c == ':')
-	    state = definition;
-
-	if (c == '\n' && prev == '\n')
-	    state = plain;
-
-	if (state == definition && c == '\n')
-	    state = header;
-	
-	prev = c;
-    }
-}
-
 int
 main (void)
 {
-    int state = newline;
-    int space_seen;
     int c;
+    int state = newline;
+    int space_seen = 0;
     
     while ((c = getchar ()) != EOF){
 	switch (state){
@@ -70,7 +33,9 @@ main (void)
 	case newline:
 	    if (c == 'F')
 		state = seen_f;
-	    else {
+            else if (c == '\n')
+                putchar ('\n');
+ 	    else {
 		state = plain;
 		putchar (c);
 	    }
