@@ -13,16 +13,15 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-#ifndef NO_INFOMOUNT
 
-#include <stdio.h>
 #include <sys/types.h>
-#include "mountlist.h"
+#include <stdio.h>
+#include <fcntl.h>
 
 #ifdef STDC_HEADERS
 #include <stdlib.h>
@@ -39,6 +38,10 @@ void free (void *ptr);
 #include <sys/param.h>
 #endif
 
+#ifdef HAVE_UNISTD_H
+#    include <unistd.h>
+#endif
+
 #if defined (MOUNTED_GETFSSTAT)	/* __alpha running OSF_1 */
 #include <sys/mount.h>
 #include <sys/fs_types.h>
@@ -84,6 +87,19 @@ void free (void *ptr);
 #include <sys/vfs.h>
 #endif
 
+#ifdef HAVE_SYS_STATFS_H
+#include <sys/statfs.h>
+#endif
+
+#ifdef HAVE_INFOMOUNT_QNX
+#include <sys/disk.h>
+#include <sys/fsys.h>
+#endif
+
+#include "mountlist.h"
+#include "fsusage.h"
+#include "util.h"
+
 /* void error (void);  FIXME -- needed? */
 
 #ifdef DOLPHIN
@@ -92,6 +108,10 @@ void free (void *ptr);
 #define MOUNTED_GETMNTTBL
 #endif
 
+#ifdef HAVE_INFOMOUNT_LIST
+
+static struct mount_entry *mount_list = NULL;
+
 #ifdef MOUNTED_GETMNTENT1	/* 4.3BSD, SunOS, HP-UX, Dynix, Irix.  */
 /* Return the value of the hexadecimal number represented by CP.
    No prefix (like '0x') or suffix (like 'h') is expected to be
@@ -115,7 +135,7 @@ static int xatoi (char *cp)
     }
     return val;
 }
-#endif				/* MOUNTED_GETMNTENT1.  */
+#endif /* MOUNTED_GETMNTENT1 */
 
 #if defined (MOUNTED_GETMNTINFO) && !defined (HAVE_F_FSTYPENAME)
 static char *fstype_to_string (short t)
@@ -149,7 +169,7 @@ static char *fstype_to_string (short t)
 	return "?";
     }
 }
-#endif				/* MOUNTED_GETMNTINFO */
+#endif /* MOUNTED_GETMNTINFO && !HAVE_F_FSTYPENAME */
 
 #ifdef MOUNTED_VMOUNT		/* AIX.  */
 static char *fstype_to_string (int t)
@@ -162,7 +182,7 @@ static char *fstype_to_string (int t)
     else
 	return e->vfsent_name;
 }
-#endif				/* MOUNTED_VMOUNT */
+#endif /* MOUNTED_VMOUNT */
 
 /* Return a list of the currently mounted filesystems, or NULL on error.
    Add each entry to the tail of the list so that they stay in order.
@@ -173,14 +193,14 @@ static char *fstype_to_string (int t)
 
 struct mount_entry *read_filesystem_list (int need_fs_type, int all_fs)
 {
-    struct mount_entry *mount_list;
+    struct mount_entry *mlist;
     struct mount_entry *me;
     struct mount_entry *mtail;
 
     /* Start the list off with a dummy entry. */
     me = (struct mount_entry *) malloc (sizeof (struct mount_entry));
     me->me_next = NULL;
-    mount_list = mtail = me;
+    mlist = mtail = me;
 
 #ifdef MOUNTED_GETMNTENT1	/* 4.3BSD, SunOS, HP-UX, Dynix, Irix.  */
     {
@@ -220,7 +240,7 @@ struct mount_entry *read_filesystem_list (int need_fs_type, int all_fs)
 	if (endmntent (fp) == 0)
 	    return NULL;
     }
-#endif				/* MOUNTED_GETMNTENT1. */
+#endif /* MOUNTED_GETMNTENT1 */
 
 #ifdef MOUNTED_GETMNTINFO	/* 4.4BSD.  */
     {
@@ -248,7 +268,7 @@ struct mount_entry *read_filesystem_list (int need_fs_type, int all_fs)
 	    fsp++;
 	}
     }
-#endif				/* MOUNTED_GETMNTINFO */
+#endif /* MOUNTED_GETMNTINFO */
 
 #ifdef MOUNTED_GETMNT		/* Ultrix.  */
     {
@@ -272,9 +292,9 @@ struct mount_entry *read_filesystem_list (int need_fs_type, int all_fs)
 	if (val < 0)
 	    return NULL;
     }
-#endif				/* MOUNTED_GETMNT. */
+#endif /* MOUNTED_GETMNT */
 
-#if defined (MOUNTED_GETFSSTAT)	/* __alpha running OSF_1 */
+#ifdef MOUNTED_GETFSSTAT	/* __alpha running OSF_1 */
     {
 	int numsys, counter, bufsize;
 	struct statfs *stats;
@@ -306,7 +326,7 @@ struct mount_entry *read_filesystem_list (int need_fs_type, int all_fs)
 
 	free (stats);
     }
-#endif				/* MOUNTED_GETFSSTAT */
+#endif /* MOUNTED_GETFSSTAT */
 
 #if defined (MOUNTED_FREAD) || defined (MOUNTED_FREAD_FSTYP)	/* SVR[23].  */
     {
@@ -350,7 +370,7 @@ struct mount_entry *read_filesystem_list (int need_fs_type, int all_fs)
 	if (fclose (fp) == EOF)
 	    return NULL;
     }
-#endif				/* MOUNTED_FREAD || MOUNTED_FREAD_FSTYP.  */
+#endif /* MOUNTED_FREAD || MOUNTED_FREAD_FSTYP */
 
 #ifdef MOUNTED_GETMNTTBL	/* DolphinOS goes it's own way */
     {
@@ -369,7 +389,7 @@ struct mount_entry *read_filesystem_list (int need_fs_type, int all_fs)
 	}
 	endmnttbl ();
     }
-#endif
+#endif /* MOUNTED_GETMNTTBL */
 
 #ifdef MOUNTED_GETMNTENT2	/* SVR4.  */
     {
@@ -399,7 +419,7 @@ struct mount_entry *read_filesystem_list (int need_fs_type, int all_fs)
 	if (fclose (fp) == EOF)
 	    return NULL;
     }
-#endif				/* MOUNTED_GETMNTENT2.  */
+#endif /* MOUNTED_GETMNTENT2 */
 
 #ifdef MOUNTED_VMOUNT		/* AIX.  */
     {
@@ -443,17 +463,17 @@ struct mount_entry *read_filesystem_list (int need_fs_type, int all_fs)
 	}
 	free (entries);
     }
-#endif				/* MOUNTED_VMOUNT. */
+#endif /* MOUNTED_VMOUNT */
 
     /* Free the dummy head. */
-    me = mount_list;
-    mount_list = mount_list->me_next;
+    me = mlist;
+    mlist = mlist->me_next;
     free (me);
-    return mount_list;
+    return mlist;
 }
-#endif /* NO_INFOMOUNT */
+#endif /* HAVE_INFOMOUNT_LIST */
 
-#if defined(NO_INFOMOUNT) && defined(__QNX__)
+#ifdef HAVE_INFOMOUNT_QNX
 /*
 ** QNX has no [gs]etmnt*(), [gs]etfs*(), or /etc/mnttab, but can do
 ** this via the following code.
@@ -462,19 +482,6 @@ struct mount_entry *read_filesystem_list (int need_fs_type, int all_fs)
 ** this hack.
 */
 
-#include <fcntl.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#ifdef HAVE_UNISTD_H
-#    include <unistd.h>
-#endif
-#include <sys/disk.h>
-#include <sys/fsys.h>
-#include <sys/statfs.h>
-
-#include "mountlist.h"
-
 struct mount_entry *read_filesystem_list(int need_fs_type, int all_fs)
 {
 	struct _disk_entry	de;
@@ -529,9 +536,85 @@ struct mount_entry *read_filesystem_list(int need_fs_type, int all_fs)
 		de.disk_type, tp, _DRIVER_NAME_LEN, _DRIVER_NAME_LEN, de.driver_name, de.disk_drv);
 	fprintf(stderr, "fsys_get_mount_dev():\n\tdevice='%s'\n", dev);
 	fprintf(stderr, "fsys_get_mount_pt():\n\tmount point='%s'\n", dir);
-#endif
+#endif /* DEBUG */
 
 	return (me);
 }
-#endif /* __QNX__ */
+#endif /* HAVE_INFOMOUNT_QNX */
+
+void init_my_statfs (void)
+{
+#ifdef HAVE_INFOMOUNT_LIST
+    mount_list = read_filesystem_list (1, 1);
+#endif /* HAVE_INFOMOUNT_LIST */
+}
+
+void my_statfs (struct my_statfs *myfs_stats, char *path)
+{
+#ifdef HAVE_INFOMOUNT_LIST
+    int i, len = 0;
+    struct mount_entry *entry = NULL;
+    struct mount_entry *temp = mount_list;
+    struct fs_usage fs_use;
+
+    while (temp){
+	i = strlen (temp->me_mountdir);
+	if (i > len && (strncmp (path, temp->me_mountdir, i) == 0))
+	    if (!entry || (path [i] == PATH_SEP || path [i] == 0)){
+		len = i;
+		entry = temp;
+	    }
+	temp = temp->me_next;
+    }
+
+    if (entry){
+	get_fs_usage (entry->me_mountdir, &fs_use);
+
+	myfs_stats->type = entry->me_dev;
+	myfs_stats->typename = entry->me_type;
+	myfs_stats->mpoint = entry->me_mountdir;
+	myfs_stats->device = entry->me_devname;
+	myfs_stats->avail = getuid () ? fs_use.fsu_bavail/2 : fs_use.fsu_bfree/2;
+	myfs_stats->total = fs_use.fsu_blocks/2;
+	myfs_stats->nfree = fs_use.fsu_ffree;
+	myfs_stats->nodes = fs_use.fsu_files;
+    } else
+#endif /* HAVE_INFOMOUNT_LIST */
+
+#ifdef HAVE_INFOMOUNT_QNX
+/*
+** This is the "other side" of the hack to read_filesystem_list() in
+** mountlist.c.
+** It's not the most efficient approach, but consumes less memory. It
+** also accomodates QNX's ability to mount filesystems on the fly.
+*/
+	struct mount_entry	*entry;
+    struct fs_usage		fs_use;
+
+	if ((entry = read_filesystem_list(0, 0)) != NULL)
+	{
+		get_fs_usage(entry->me_mountdir, &fs_use);
+
+		myfs_stats->type = entry->me_dev;
+		myfs_stats->typename = entry->me_type;
+		myfs_stats->mpoint = entry->me_mountdir;
+		myfs_stats->device = entry->me_devname;
+
+		myfs_stats->avail = fs_use.fsu_bfree / 2;
+		myfs_stats->total = fs_use.fsu_blocks / 2;
+		myfs_stats->nfree = fs_use.fsu_ffree;
+		myfs_stats->nodes = fs_use.fsu_files;
+	}
+	else
+#endif /* HAVE_INFOMOUNT_QNX */
+    {
+	myfs_stats->type = 0;
+	myfs_stats->mpoint = "unknown";
+	myfs_stats->device = "unknown";
+	myfs_stats->avail = 0;
+	myfs_stats->total = 0;
+	myfs_stats->nfree = 0;
+	myfs_stats->nodes = 0;
+    }
+}
 
