@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #ifndef __MOUNTLIST_H
 #define __MOUNTLIST_H
@@ -29,4 +29,20 @@ struct mount_entry
 };
 
 struct mount_entry *read_filesystem_list (int need_fs_type, int all_fs);
+
+/* Filesystem status */
+struct my_statfs {
+    int type;
+    char *typename;
+    char *mpoint;
+    char *device;
+    int avail;
+    int total;
+    int nfree;
+    int nodes;
+};
+
+void init_my_statfs (void);
+void my_statfs (struct my_statfs *myfs_stats, char *path);
+
 #endif 	/* __MOUNTLIST_H	*/
