@@ -36,7 +36,11 @@
 #   include <grp.h>
 #   include <pwd.h>
 #endif
+
+/* Needed for the extern declarations of integer parameters */
+#define DIR_H_INCLUDE_HANDLE_DIRENT
 #include "tty.h"
+#include "x.h"
 #include "global.h"
 #include "win.h"
 #include "color.h"
@@ -45,9 +49,6 @@
 #include "dialog.h"		/* For do_refresh() */
 #include "setup.h"		/* For profile_bname */
 #include "profile.h"		/* Load/save directories panelize */
-
-/* Needed for the extern declarations of integer parameters */
-#define DIR_H_INCLUDE_HANDLE_DIRENT
 #include "dir.h"
 #include "panel.h"		/* Needed for the externs */
 #include "file.h"
@@ -68,37 +69,36 @@ void do_external_panelize (char *command);
 #define B_ADD		B_USER
 #define B_REMOVE        B_USER + 1
 
+#ifndef HAVE_X
 static WListbox *l_panelize;
-
 static Dlg_head *panelize_dlg;
-
+static int last_listitem;
 static WInput *pname;
 
-static char *panelize_section = "Panelize";
-
-static int last_listitem;
-
-struct {
+static struct {
     int ret_cmd, flags, y, x;
     char *text;
     char *tkname;
-} panelize_but[BUTTONS] = {
+} panelize_but [BUTTONS] = {
     { B_CANCEL, NORMAL_BUTTON, 0, 53, N_("&Cancel"),  "c"},
     { B_ADD, NORMAL_BUTTON,    0, 28, N_("&Add new"), "a"},
     { B_REMOVE, NORMAL_BUTTON, 0, 16, N_("&Remove"),  "r"},
     { B_ENTER, DEFPUSH_BUTTON, 0,  0, N_("Pane&lize"),"l"},
 };
+#endif /* !HAVE_X */
+
+static char *panelize_section = "Panelize";
 
 /* Directory panelize */
-static struct panelize{
+static struct panelize {
     char *command;
     char *label;
     struct panelize *next;
 } *panelize = NULL;
 
+#ifndef HAVE_X
 static char* panelize_title = N_(" External panelize ");
 
-#ifndef HAVE_X
 static void
 panelize_refresh (void)
 {
@@ -112,10 +112,9 @@ panelize_refresh (void)
     dlg_move (panelize_dlg, 1, (panelize_dlg->cols - strlen(panelize_title)) / 2);
     addstr (panelize_title);
 }
-#endif
 
 static void
-update_command ()
+update_command (void)
 {
     if (l_panelize->pos != last_listitem) {
     	last_listitem = l_panelize->pos;
@@ -130,11 +129,9 @@ static int
 panelize_callback (Dlg_head * h, int Par, int Msg)
 {
     switch (Msg) {
-#ifndef HAVE_X    
     case DLG_DRAW:
 	panelize_refresh ();
 	break;
-#endif	
 
     case DLG_POST_KEY:
 	/* fall */
@@ -196,13 +193,12 @@ static void init_panelize (void)
 #define XTRACT(i) BY+panelize_but[i].y, BX+panelize_but[i].x, panelize_but[i].ret_cmd, panelize_but[i].flags, panelize_but[i].text, 0, 0, panelize_but[i].tkname
 
     for (i = 0; i < BUTTONS; i++)
-	add_widgetl (panelize_dlg, button_new (XTRACT (i)), (i == BUTTONS - 1) ?
-	    XV_WLAY_CENTERROW : XV_WLAY_RIGHTOF);
+	add_widget(panelize_dlg, button_new (XTRACT (i)));
 
     pname = input_new (UY+14, UX, INPUT_COLOR, panelize_dlg->cols-10, "", "in");
-    add_widgetl (panelize_dlg, pname, XV_WLAY_RIGHTOF);
+    add_widget (panelize_dlg, pname);
 
-    add_widgetl (panelize_dlg, label_new (UY+13, UX, _("Command"), "label-command"), XV_WLAY_NEXTROW);
+    add_widget (panelize_dlg, label_new (UY+13, UX, _("Command"), "label-command"));
 
     /* get new listbox */
     l_panelize = listbox_new (UY + 1, UX + 1, panelize_dlg->cols-12, 10, 0, l_call, "li");
@@ -213,7 +209,7 @@ static void init_panelize (void)
     }
 
     /* add listbox to the dialogs */
-    add_widgetl (panelize_dlg, l_panelize, XV_WLAY_EXTENDWIDTH); 
+    add_widget (panelize_dlg, l_panelize); 
 
     listbox_select_entry (l_panelize, 
         listbox_search_text (l_panelize, _("Other command")));
@@ -224,6 +220,7 @@ static void panelize_done (void)
     destroy_dlg (panelize_dlg);
     repaint_screen ();
 }
+#endif /* !HAVE_X */
 
 static void add2panelize (char *label, char *command)
 {
@@ -251,6 +248,7 @@ static void add2panelize (char *label, char *command)
     }
 }
 
+#ifndef HAVE_X
 void
 add2panelize_cmd (void)
 {
@@ -336,6 +334,7 @@ external_panelize (void)
 
     panelize_done ();
 }
+#endif /* !HAVE_X */
 
 void load_panelize (void)
 {
