@@ -36,7 +36,7 @@
 #include "global.h"
 #include "cons.saver.h"
 
-int rxvt_extensions = 0;
+static int rxvt_extensions = 0;
 
 int look_for_rxvt_extensions (void)
 {
@@ -71,7 +71,7 @@ static int rxvt_getc (void)
 
 extern int keybar_visible;
 
-static int anything_ready ()
+static int anything_ready (void)
 {
     fd_set fds;
     struct timeval tv;
