@@ -36,7 +36,6 @@
 #include "main.h"
 #include "ext.h"		/* regexp_command */
 #include "mouse.h"		/* For Gpm_Event */
-#include "cons.saver.h"		/* For console_flag */
 #include "layout.h"		/* Most layout variables are here */
 #include "dialog.h"		/* for message (...) */
 #include "cmd.h"
@@ -84,7 +83,12 @@ WPanel *the_info_panel = 0;
 Hook *select_file_hook = 0;
 
 static int panel_callback (Dlg_head *h, WPanel *p, int Msg, int Par);
-int panel_event (Gpm_Event *event, WPanel *panel);
+
+#ifndef HAVE_X
+static int panel_event (Gpm_Event *event, WPanel *panel);
+#else
+#define panel_event NULL
+#endif /* HAVE_X */
 
 #ifndef PORT_HAS_PANEL_ADJUST_TOP_FILE
 #   define x_adjust_top_file(p)
@@ -193,7 +197,6 @@ char *
 string_file_size (file_entry *fe, int len)
 {
     static char buffer [BUF_TINY];
-    int i;
 
 #ifdef HAVE_ST_RDEV
     if (S_ISBLK (fe->buf.st_mode) || S_ISCHR (fe->buf.st_mode))
@@ -203,16 +206,7 @@ string_file_size (file_entry *fe, int len)
     else
 #endif
     {
-        g_snprintf (buffer, sizeof (buffer), "%lu", (unsigned long) fe->buf.st_size);
-        if (len && (i = strlen (buffer)) > len) {
-            if (i - 2 > len) {
-                if (i - 5 > len)
-                    g_snprintf (buffer, sizeof (buffer), "%luG", (unsigned long) ((fe->buf.st_size) >> 30));
-                else
-                    g_snprintf (buffer, sizeof (buffer), "%luM", (unsigned long) ((fe->buf.st_size) >> 20));
-            } else
-                g_snprintf (buffer, sizeof (buffer), "%luK", (unsigned long) ((fe->buf.st_size) >> 10));
-        }
+	size_trunc_len (buffer, len, fe->buf.st_size);
     }
     return buffer;
 }
@@ -659,8 +653,9 @@ display_mini_info (WPanel *panel)
 	attrset (MARKED_COLOR);
 	printw  ("%*s", cols, " ");
 	widget_move (&panel->widget, llines (panel)+3, 1);
-	g_snprintf (buffer, sizeof (buffer), _((panel->marked == 1) ?
-		 N_("%s bytes in %d file") : N_("%s bytes in %d files")),
+	/* FIXME: use ngettext() here when gettext-0.10.35 becomes history */
+	g_snprintf (buffer, sizeof (buffer), (panel->marked == 1) ?
+		 _("%s bytes in %d file") : _("%s bytes in %d files"),
 		 size_trunc_sep (panel->total), panel->marked);
 	if (strlen (buffer) > cols-2){
 	    buffer [cols] = 0;
@@ -788,7 +783,7 @@ show_dir (WPanel *panel)
 }
 #endif
 
-#ifndef HAVE_TK
+#ifndef PORT_HAS_PAINT_FRAME
 /* To be used only by long_frame and full_frame to adjust top_file */
 static void
 adjust_top_file (WPanel *panel)
@@ -799,14 +794,7 @@ adjust_top_file (WPanel *panel)
 	panel->top_file = panel->selected;
     if (old_top - panel->count > llines (panel))
 	panel->top_file = panel->count - llines (panel);
-
-#ifdef HAVE_TK
-    if (old_top != panel->top_file)
-	x_adjust_top_file (panel);
-#endif
 }
-#else
-#define adjust_top_file(p)
 #endif
 
 /* Repaints the information that changes after a command */
@@ -968,7 +956,7 @@ is_a_panel (Widget *w)
 /* Panel creation */
 /* The parameter specifies the name of the panel for setup retieving */
 WPanel *
-panel_new (char *panel_name)
+panel_new (const char *panel_name)
 {
 #ifdef HAVE_GNOME
     static int panel_id = 0;
@@ -1197,7 +1185,7 @@ parse_panel_size (WPanel *panel, char *format, int isstatus)
 static format_e *
 parse_display_format (WPanel *panel, char *format, char **error, int isstatus, int *res_total_cols)
 {
-    format_e *darr, *old, *home = 0;   	/* The formats we return */
+    format_e *darr, *old = 0, *home = 0; /* The formats we return */
     int  total_cols = 0;		/* Used columns by the format */
     int  set_justify;                  	/* flag: set justification mode? */
     int  justify = 0;                  	/* Which mode. */
@@ -1510,14 +1498,10 @@ mini_status_format (WPanel *panel)
 int
 ITEMS (WPanel *p)
 {
-#ifdef HAVE_TK
-    return p->widget.lines;
-#else
     if (p->split)
 	return llines (p) * 2;
     else
 	return llines (p);
-#endif
 }
 
 /* This function sets redisplays the selection */
@@ -1797,15 +1781,17 @@ prev_page (WPanel *panel)
     select_item (panel);
 #ifndef HAVE_X
     paint_dir (panel);
-#endif
+#endif /* !HAVE_X */
 }
 
 static void
 prev_page_key (WPanel *panel)
 {
-    if (console_flag && ctrl_pressed ()){
+#ifndef HAVE_X
+    if (ctrl_pressed ()){
 	do_cd ("..", cd_exact);
     } else
+#endif /* !HAVE_X */
 	prev_page (panel);
 }
 
@@ -1837,16 +1823,18 @@ next_page (WPanel *panel)
     select_item (panel);
 #ifndef HAVE_X
     paint_dir (panel);
-#endif
+#endif /* !HAVE_X */
 }
 
 static void next_page_key (WPanel *panel)
 {
-    if (console_flag&&ctrl_pressed()&&
+#ifndef HAVE_X
+    if (ctrl_pressed() &&
 	(S_ISDIR(selection (panel)->buf.st_mode) ||
 	 link_isdir (selection (panel))))
         do_cd (selection (panel)->fname, cd_exact);
     else
+#endif /* !HAVE_X */
 	next_page (panel);
 }
 
@@ -2198,6 +2186,7 @@ do_enter (WPanel *panel)
     return do_enter_on_file_entry (selection (panel));
 }
 
+#ifndef HAVE_X
 static void
 chdir_other_panel (WPanel *panel)
 {
@@ -2263,6 +2252,7 @@ chdir_to_readlink (WPanel *panel)
 	g_free (new_dir);
     }
 }
+#endif /* !HAVE_X */
 
 static const key_map panel_keymap [] = {
     { KEY_DOWN,   move_down },
@@ -2299,13 +2289,15 @@ static const key_map panel_keymap [] = {
     { XCTRL('s'), start_search },	/* C-s like emacs */
     { ALT('s'),   start_search },	/* M-s not like emacs */
     { XCTRL('t'), mark_file },
+#ifndef HAVE_X
     { ALT('o'),   chdir_other_panel },
     { ALT('l'),   chdir_to_readlink },
+    { ALT('H'),   directory_history_list },
+#endif /* HAVE_X */
     { KEY_F(13),  view_simple_cmd },
     { KEY_F(14),  edit_cmd_new },
     { ALT('y'),   directory_history_prev },
     { ALT('u'),   directory_history_next },
-    { ALT('H'),   directory_history_list },
     { ALT('+'),	  select_cmd_panel },
     { KEY_KP_ADD, select_cmd_panel },
     { ALT('\\'),  unselect_cmd_panel },
@@ -2372,7 +2364,10 @@ panel_key (WPanel *panel, int key)
 	    return 1;
 	}
 
-	if (!command_prompt) {
+#ifndef HAVE_X
+	if (!command_prompt)
+#endif /* !HAVE_X */
+	{
 	    start_search (panel);
 	    do_search (panel, key);
 	    return 1;
@@ -2382,7 +2377,11 @@ panel_key (WPanel *panel, int key)
     return 0;
 }
 
-void user_file_menu_cmd (void) { user_menu_cmd (NULL); }
+#ifndef HAVE_X
+void user_file_menu_cmd (void) {
+    user_menu_cmd (NULL);
+}
+#endif /* !HAVE_X */
 
 static int
 panel_callback (Dlg_head *h, WPanel *panel, int msg, int par)
@@ -2390,16 +2389,8 @@ panel_callback (Dlg_head *h, WPanel *panel, int msg, int par)
     switch (msg){
     case WIDGET_INIT:
 #ifdef HAVE_X
-	define_label (h, (Widget *)panel, 1, _("Help"), help_cmd);
-	define_label (h, (Widget *)panel, 2, _("Menu"), user_file_menu_cmd);
-	define_label (h, (Widget *)panel, 3, _("View"), view_panel_cmd);
-	define_label (h, (Widget *)panel, 4, _("Edit"), edit_panel_cmd);
-	define_label (h, (Widget *)panel, 5, _("Copy"), copy_cmd);
-	define_label (h, (Widget *)panel, 6, _("RenMov"), ren_cmd);
-	define_label (h, (Widget *)panel, 7, _("Mkdir"), mkdir_panel_cmd);
-	define_label (h, (Widget *)panel, 8, _("Delete"), delete_cmd);
 	x_create_panel (h, h->wdata, panel);
-#endif
+#endif /* !HAVE_X */
 	return 1;
 
     case WIDGET_DRAW:
@@ -2412,7 +2403,7 @@ panel_callback (Dlg_head *h, WPanel *panel, int msg, int par)
 #endif
 	panel->active = 1;
 	if (mc_chdir (panel->cwd) != 0){
-	    message (1, MSG_ERROR, _(" Can't chdir to \"%s\" \n %s "),
+	    message (1, MSG_ERROR, _(" Cannot chdir to \"%s\" \n %s "),
 		     panel->cwd, unix_error_string (errno));
 	} else
 	    subshell_chdir (panel->cwd);
@@ -2458,6 +2449,34 @@ panel_callback (Dlg_head *h, WPanel *panel, int msg, int par)
     return default_proc (h, msg, par);
 }
 
+void
+file_mark (WPanel *panel, int index, int val)
+{
+    panel->dir.list [index].f.marked = val;
+    x_panel_select_item (panel, index, val);
+}
+
+#ifdef HAVE_X
+sortfn *
+get_sort_fn (char *name)
+{
+    int i;
+
+    /* First, try the long name options, from dir.c */
+    for (i = 0; i < SORT_TYPES_TOTAL; i++)
+	if (strcmp (name, sort_orders [i].sort_name) == 0)
+	    return (sortfn *)sort_orders [i].sort_fn;
+
+    /* Then try the short name options, from our local table */
+    for (i = 0; i < ELEMENTS (formats); i++){
+	if (strcmp (name, formats [i].id) == 0 && formats [i].sort_routine)
+	    return formats [i].sort_routine;
+    }
+    return NULL;
+}
+
+#else
+
 /*                                     */
 /* Panel mouse events support routines */
 /*                                     */
@@ -2492,84 +2511,7 @@ mark_if_marking (WPanel *panel, Gpm_Event *event)
     return 0;
 }
 
-void
-file_mark (WPanel *panel, int index, int val)
-{
-    panel->dir.list [index].f.marked = val;
-    x_panel_select_item (panel, index, val);
-}
-
-#ifdef PORT_WANTS_GET_SORT_FN
-sortfn *
-get_sort_fn (char *name)
-{
-    int i;
-
-    /* First, try the long name options, from dir.c */
-    for (i = 0; i < SORT_TYPES_TOTAL; i++)
-	if (strcmp (name, sort_orders [i].sort_name) == 0)
-	    return (sortfn *)sort_orders [i].sort_fn;
-
-    /* Then try the short name options, from our local table */
-    for (i = 0; i < ELEMENTS (formats); i++){
-	if (strcmp (name, formats [i].id) == 0 && formats [i].sort_routine)
-	    return formats [i].sort_routine;
-    }
-    return NULL;
-}
-
-/* not static because it's called from Tk's version */
-int
-panel_event (Gpm_Event *event, WPanel *panel)
-{
-    const int lines = panel->count;
-
-    int my_index;
-
-    event->y -= 2;
-    if ((event->type & (GPM_DOWN|GPM_DRAG))){
-
-	if (panel != (WPanel *) current_dlg->current->widget)
-	    change_panel ();
-
-	if (event->y <= 0){
-	    mark_if_marking (panel, event);
-	    return MOU_REPEAT;
-	}
-
-	if (!((panel->top_file + event->y <= panel->count) &&
-	      event->y <= lines)){
-	    mark_if_marking (panel, event);
-	    return MOU_REPEAT;
-	}
-	my_index = panel->top_file + event->y - 1;
-	if (panel->split){
-	    if (event->x > ((panel->widget.cols-2)/2))
-		my_index += llines (panel);
-	}
-
-	if (my_index >= panel->count)
-	    my_index = panel->count - 1;
-
-	if (my_index != panel->selected){
-	    unselect_item (panel);
-	    panel->selected = my_index;
-	    select_item (panel);
-	}
-
-	/* This one is new */
-	mark_if_marking (panel, event);
-
-    } else if ((event->type & (GPM_UP|GPM_DOUBLE)) == (GPM_UP|GPM_DOUBLE)){
-            if (event->y > 0 && event->y <= lines)
-		do_enter (panel);
-    }
-    return MOU_NORMAL;
-}
-
-#else
-
-int
+static int
 panel_event (Gpm_Event *event, WPanel *panel)
 {
     const int lines = llines (panel);
@@ -2639,7 +2581,7 @@ panel_event (Gpm_Event *event, WPanel *panel)
     }
     return MOU_NORMAL;
 }
-#endif
+#endif /* !HAVE_X */
 
 void
 panel_update_marks (WPanel *panel)
