@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include <config.h>
 #include <sys/types.h>		/* Needed to include local .h files */
@@ -54,14 +54,13 @@
 #     define PORT_LIST_MODE_DEFAULT "full"
 #endif
 
+#ifdef HAVE_CHARSET
+#include "charsets.h"
+#endif
+
 #include "../vfs/vfs.h"
 #ifdef USE_NETCODE
 #   include "../vfs/ftpfs.h"
-extern int use_netrc;
-extern int ftpfs_retry_seconds;
-extern int ftpfs_use_passive_connections;
-extern int ftpfs_use_unix_list_options;
-extern int ftpfs_first_cd_then_ls;
 #endif
 
 #ifdef HAVE_GNOME
@@ -70,7 +69,7 @@ extern int we_can_afford_the_speed;
 int use_magic = 0;
 #endif
 
-/* "$Id: setup.c,v 1.37 2000/04/14 01:19:58 timur Exp $" */
+/* "$Id: setup.c,v 1.52 2001/08/16 21:01:12 proskin Exp $" */
 
 #ifdef USE_VFS
 extern int vfs_timeout;
@@ -136,25 +135,25 @@ static const struct {
     { 0, 0 }
 };
 
+#ifndef HAVE_GNOME
 static const struct {
     char *opt_name;
     int *opt_addr;
 } layout [] = {
-#ifndef HAVE_GNOME
     { "equal_split", &equal_split },
     { "first_panel_size", &first_panel_size },
     { "message_visible", &message_visible },
     { "keybar_visible", &keybar_visible },
     { "xterm_hintbar", &xterm_hintbar },
     { "output_lines", &output_lines },
-#endif
-    { "menubar_visible", &menubar_visible },
     { "command_prompt", &command_prompt },
+    { "menubar_visible", &menubar_visible },
     { "show_mini_info", &show_mini_info },
     { "permission_mode", &permission_mode },
     { "filetype_mode", &filetype_mode },
     { 0, 0 }
 };
+#endif
 
 
 #undef SAVE_CHANGES_OUTSIDE_OPTIONS_MENU
@@ -191,11 +190,15 @@ static const struct {
     { "confirm_execute", &confirm_execute },
     { "confirm_exit", &confirm_exit },
     { "safe_delete", &know_not_what_am_i_doing },
+#ifndef HAVE_X
     { "mouse_repeat_rate", &mou_auto_repeat },
     { "double_click_speed", &double_click_speed },
+#ifndef HAVE_CHARSET
     { "eight_bit_clean", &eight_bit_clean },
     { "full_eight_bits", &full_eight_bits },
+#endif
     { "use_8th_bit_as_meta", &use_8th_bit_as_meta },
+#endif
     { "confirm_view_dir", &confirm_view_dir },
     { "mouse_move_pages", &mouse_move_pages },
     { "mouse_move_pages_viewer", &mouse_move_pages_viewer },
@@ -204,13 +207,15 @@ static const struct {
     { "advanced_chown", &advanced_chfns },
     { "drop_menus", &drop_menus },
     { "wrap_mode",  &global_wrap_mode},
+#ifndef HAVE_X
     { "old_esc_mode", &old_esc_mode },
-#ifndef HAVE_GNOME
     { "cd_symlinks", &cd_symlinks },
 #endif
     { "show_all_if_ambiguous", &show_all_if_ambiguous },
     { "have_fast_cpu", &have_fast_cpu },
+#if 0
     { "iconify_on_exec", &iconify_on_exec },
+#endif
     { "torben_fj_mode", &torben_fj_mode },
     { "use_file_to_guess_type", &use_file_to_check_type },
     { "alternate_plus_minus", &alternate_plus_minus },
@@ -335,6 +340,7 @@ panel_save_setup (WPanel *panel, char *section)
 			       profile_name);
 }
 
+#ifndef HAVE_X
 void
 save_layout (void)
 {
@@ -352,6 +358,7 @@ save_layout (void)
 
     g_free (profile);
 }
+#endif /* !HAVE_X */
 
 void
 save_configure (void)
@@ -372,6 +379,7 @@ save_configure (void)
     g_free (profile);
 }
 
+#ifndef PORT_HAS_SAVE_PANEL_TYPES
 static void
 panel_save_type (char *section, int type)
 {
@@ -385,7 +393,6 @@ panel_save_type (char *section, int type)
 	}
 }
 
-#ifndef PORT_HAS_SAVE_PANEL_TYPES
 void
 save_panel_types ()
 {
@@ -406,17 +413,14 @@ void
 save_setup (void)
 {
     char *profile;
-#ifdef USE_VFS
-#ifdef USE_NETCODE
-    extern char *ftpfs_anonymous_passwd;
-    extern char *ftpfs_proxy_host;
-#endif
-#endif
+
     saving_setup = 1;
     profile = concat_dir_and_file (home_dir, PROFILE_NAME);
 
-    save_layout ();
     save_configure ();
+
+#ifndef HAVE_X
+    save_layout ();
     save_string ("Dirs", "other_dir",
 			       get_other_type () == view_listing
 			       ? opanel->cwd : ".", profile);
@@ -424,6 +428,8 @@ save_setup (void)
 	    WritePrivateProfileString ("Dirs", "current_is_left",
 				       get_current_index () == 0 ? "1" : "0", profile);
     save_hotlist ();
+#endif /* !HAVE_X */
+
     save_panelize ();
     save_panel_types ();
 /*     directory_history_save (); */
@@ -437,6 +443,12 @@ save_setup (void)
 				   ftpfs_proxy_host, profile);
 #endif
 #endif
+
+#ifdef HAVE_CHARSET
+    save_string( "Misc", "display_codepage",
+    		 get_codepage_id( display_codepage ), profile_name );
+#endif
+
     g_free (profile);
     saving_setup = 0;
 }
@@ -493,6 +505,7 @@ panel_load_setup (WPanel *panel, char *section)
 
 }
 
+#ifndef HAVE_X
 static void
 load_layout (char *profile_name)
 {
@@ -503,6 +516,7 @@ load_layout (char *profile_name)
 	    load_int ("Layout", layout [i].opt_name,
 				  *layout [i].opt_addr);
 }
+#endif /* !HAVE_X */
 
 static int
 load_mode (char *section)
@@ -540,24 +554,21 @@ do_load_string (char *s, char *ss, char *def)
 char *
 setup_init (void)
 {
-    char *buffer;
     char   *profile;
     char   *inifile;
 
     if (profile_name)
 	    return profile_name;
 
-    buffer = concat_dir_and_file (home_dir, PROFILE_NAME);
-    inifile = concat_dir_and_file (mc_home, "mc.ini");
-    if (exist_file (buffer)){
-	profile = buffer;
-    } else if (exist_file (inifile)){
-	profile = g_strdup (inifile);
-	g_free (buffer);
-    } else {
-	profile = buffer;
+    profile = concat_dir_and_file (home_dir, PROFILE_NAME);
+    if (!exist_file (profile)){
+	inifile = concat_dir_and_file (mc_home, "mc.ini");
+	if (exist_file (inifile)){
+	    g_free (profile);
+	    profile = inifile;
+	} else
+	    g_free (inifile);
     }
-    g_free (inifile);
 
     profile_name = profile;
 
@@ -568,11 +579,7 @@ void
 load_setup (void)
 {
     char *profile;
-
     int    i;
-#ifdef USE_NETCODE
-    extern char *ftpfs_proxy_host;
-#endif
 
     profile = setup_init ();
     /* Load integer boolean options */
@@ -580,12 +587,12 @@ load_setup (void)
 	*options [i].opt_addr =
 	    get_int (profile, options [i].opt_name, *options [i].opt_addr);
 
-#ifdef HAVE_GNOME
+#ifdef HAVE_X
     g_free (default_user_format);
     default_user_format = do_load_string (app_text, "default_user_format", DEFAULT_USER_FORMAT);
-#endif
-
+#else
     load_layout (profile);
+#endif
 
     load_panelize ();
 
@@ -596,6 +603,7 @@ load_setup (void)
     if (startup_left_mode != view_listing && startup_right_mode!=view_listing)
 	startup_left_mode = view_listing;
 
+#ifndef HAVE_X
     if (!other_dir){
 	char *buffer;
 
@@ -607,11 +615,14 @@ load_setup (void)
 	else
 	    g_free (buffer);
     }
+
+    boot_current_is_left =
+	GetPrivateProfileInt ("Dirs", "current_is_left", 1, profile);
+#endif /* !HAVE_X */
+
 #ifdef USE_NETCODE
     ftpfs_proxy_host = do_load_string ("Misc", "ftp_proxy_host", "gate");
 #endif
-    boot_current_is_left =
-	GetPrivateProfileInt ("Dirs", "current_is_left", 1, profile);
 
     load_string ("Misc", "find_ignore_dirs", "", setup_color_string,
 		 sizeof (setup_color_string));
@@ -636,6 +647,19 @@ load_setup (void)
     ftpfs_init_passwd ();
 #endif
 #endif
+
+#ifdef HAVE_CHARSET
+    if ( load_codepages_list() > 0 ) {
+	char cpname[128];
+	load_string( "Misc", "display_codepage", "",
+		     cpname, sizeof(cpname) );
+	if ( cpname[0] != '\0' )
+	    display_codepage = get_codepage_index( cpname );
+    }
+
+    init_printable_table( display_codepage );
+    init_translation_table( source_codepage, display_codepage );
+#endif
 }
 
 #ifdef USE_VFS
@@ -657,11 +681,14 @@ load_anon_passwd ()
 void done_setup (void)
 {
     g_free (profile_name);
+#ifndef HAVE_X
     done_hotlist ();
+#endif /* HAVE_X */
     done_panelize ();
 /*    directory_history_free (); */
 }
 
+#ifndef HAVE_X
 static void
 load_keys_from_section (char *terminal, char *profile_name)
 {
@@ -683,10 +710,11 @@ load_keys_from_section (char *terminal, char *profile_name)
     while (profile_keys){
 	profile_keys = profile_iterator_next (profile_keys, &key, &value);
 	key_code = lookup_key (key);
-	valcopy = convert_controls (value);
-	if (key_code)
+	if (key_code){
+	    valcopy = convert_controls (value);
 	    define_sequence (key_code, valcopy, MCKEY_NOACTION);
-	g_free (valcopy);
+	    g_free (valcopy);
+	}
     }
     g_free (section_name);
     return;
@@ -695,13 +723,18 @@ load_keys_from_section (char *terminal, char *profile_name)
 void load_key_defs (void)
 {
     char *libfile = concat_dir_and_file (mc_home, "mc.lib");
-    load_keys_from_section (getenv ("TERM"), profile_name);
-    load_keys_from_section ("general", profile_name);
 
-    load_keys_from_section (getenv ("TERM"), libfile);
+    /*
+     * Load keys from mc.lib before ~/.mc/ini, so that the user
+     * definitions override global settings.
+     */
     load_keys_from_section ("general", libfile);
+    load_keys_from_section (getenv ("TERM"), libfile);
+    load_keys_from_section ("general", profile_name);
+    load_keys_from_section (getenv ("TERM"), profile_name);
 
     /* We don't want a huge database loaded in core */
     free_profile_name (libfile);
     g_free (libfile);
 }
+#endif
