@@ -24,6 +24,10 @@
 
 /* {{{ Declarations */
 
+#ifndef _GNU_SOURCE
+#   define _GNU_SOURCE 1
+#endif
+
 #include <stdio.h>      
 #include <stdlib.h>	/* For errno, putenv, etc.	      */
 #include <errno.h>	/* For errno on SunOS systems	      */
@@ -62,15 +66,13 @@
 #   define WIFEXITED(stat_val) (((stat_val) & 255) == 0)
 #endif
 
-#ifdef HAVE_GRANTPT
-#   include <stropts.h> /* For I_PUSH			      */
-#else
-#   include <grp.h>	/* For the group struct & getgrnam()  */
-#endif
+#ifdef HAVE_STROPTS_H
+#   include <stropts.h> /* For I_PUSH */
+#endif /* HAVE_STROPTS_H */
 
-#ifdef SCO_FLAVOR
+#ifdef HAVE_GRP_H
 #   include <grp.h>	/* For the group struct & getgrnam()  */
-#endif /* SCO_FLAVOR */
+#endif /* HAVE_GRP_H */
 
 #ifdef __QNX__
 #   include <unix.h>	/* exec*() from <process.h> */
@@ -87,6 +89,7 @@
 #include "subshell.h"
 
 /* Local functions */
+static void init_raw_mode (void);
 static int feed_subshell (int how, int fail_on_error);
 static void synchronize (void);
 static int pty_open_master (char *pty_name);
@@ -169,24 +172,17 @@ static volatile int subshell_alive, subshell_stopped;
    sanity if we have to exit abruptly */
 static struct termios shell_mode;
 
+/* This is a transparent mode for the terminal where MC is running on */
+/* It is used when the shell is active, so that the control signals */
+/* are delivered to the shell pty */
+static struct termios raw_mode;
+
 /* This counter indicates how many characters of prompt we have read */
 /* FIXME: try to figure out why this had to become global */
 static int prompt_pos;
 
 /* }}} */
 
-/* {{{ init_subshell */
-
-/*
- *  Fork the subshell, and set up many, many things.
- *
- *  Possibly modifies the global variables:
- *	shell_mode
- *	subshell_type, subshell_alive, subshell_stopped, subshell_pid
- *	use_subshell - Is set to FALSE if we can't run the subshell
- *	quit - Can be set to SUBSHELL_EXIT by the SIGCHLD handler
- */
-
 #ifdef HAVE_GRANTPT
 #    define SYNC_PTY_SIDES
 #else
@@ -202,13 +198,175 @@ static void sigusr1_handler (int sig)
 }
 #endif
 
+/*
+ *  Prepare child process to running the shell and run it.
+ *
+ *  Modifies the global variables (in the child process only):
+ *	shell_mode
+ *
+ *  Returns: never.
+ */
+static void init_subshell_child (const char *pty_name)
+{
+    int pty_slave;
+    char *init_file = NULL;
+	
+    setsid ();  /* Get a fresh terminal session */
+
+    /* {{{ Open the slave side of the pty: again */
+    pty_slave = pty_open_slave (pty_name);
+
+    /* This must be done before closing the master side of the pty, */
+    /* or it will fail on certain idiotic systems, such as Solaris.	*/
+
+    /* Close master side of pty.  This is important; apart from	*/
+    /* freeing up the descriptor for use in the subshell, it also	*/
+    /* means that when MC exits, the subshell will get a SIGHUP and	*/
+    /* exit too, because there will be no more descriptors pointing	*/
+    /* at the master side of the pty and so it will disappear.	*/
+
+    close (subshell_pty);
+
+#ifdef SYNC_PTY_SIDES
+    /* Give our parent process (MC) the go-ahead */
+    kill (getppid (), SIGUSR1);
+#endif
+
+    /* }}} */
+    /* {{{ Make sure that it has become our controlling terminal */
+
+    /* Redundant on Linux and probably most systems, but just in case: */
+
+#ifdef TIOCSCTTY
+    ioctl (pty_slave, TIOCSCTTY, 0);
+#endif
+
+    /* }}} */
+    /* {{{ Configure its terminal modes and window size */
+
+    /* Set up the pty with the same termios flags as our own tty, plus  */
+    /* TOSTOP, which keeps background processes from writing to the pty */
+
+    shell_mode.c_lflag |= TOSTOP;  /* So background writers get SIGTTOU */
+    if (tcsetattr (pty_slave, TCSANOW, &shell_mode))
+    {
+        perror (__FILE__": couldn't set pty terminal modes");
+        _exit (FORK_FAILURE);
+    }
+
+    /* Set the pty's size (80x25 by default on Linux) according to the */
+    /* size of the real terminal as calculated by ncurses, if possible */
+#if defined TIOCSWINSZ && !defined SCO_FLAVOR
+    {
+	struct winsize tty_size;
+	tty_size.ws_row = LINES;
+	tty_size.ws_col = COLS;
+	tty_size.ws_xpixel = tty_size.ws_ypixel = 0;
+
+	if (ioctl (pty_slave, TIOCSWINSZ, &tty_size))
+	    perror (__FILE__": couldn't set pty size");
+    }
+#endif
+
+    /* }}} */
+    /* {{{ Set up the subshell's environment and init file name */
+
+    /* It simplifies things to change to our home directory here, */
+    /* and the user's startup file may do a `cd' command anyway   */
+    chdir (home_dir);  /* FIXME? What about when we re-run the subshell? */
+
+    switch (subshell_type)
+    {
+        case BASH:
+	    init_file = ".mc/bashrc";
+	    if (access (init_file, R_OK) == -1)
+		init_file = ".bashrc";
+
+	    /* Make MC's special commands not show up in bash's history */
+	    putenv ("HISTCONTROL=ignorespace");
+
+	    /* Allow alternative readline settings for MC */
+	    if (access (".mc/inputrc", R_OK) == 0)
+		putenv ("INPUTRC=.mc/inputrc");
+
+	    break;
+
+	case TCSH:
+	    init_file = ".mc/tcshrc";
+	    if (access (init_file, R_OK) == -1)
+		init_file += 3;
+	break;
+
+	case ZSH:
+	    break;
+
+	default:
+	    fprintf (stderr, __FILE__": unimplemented subshell type %d\n",
+		     subshell_type);
+	    _exit (FORK_FAILURE);
+    }
+
+    /* }}} */
+    /* {{{ Attach all our standard file descriptors to the pty */
+
+    /* This is done just before the fork, because stderr must still	 */
+    /* be connected to the real tty during the above error messages; */
+    /* otherwise the user will never see them.			 */
+
+    dup2 (pty_slave, STDIN_FILENO);
+    dup2 (pty_slave, STDOUT_FILENO);
+    dup2 (pty_slave, STDERR_FILENO);
+
+    /* }}} */
+    /* {{{ Execute the subshell at last */
+
+    close (subshell_pipe[READ]);
+    close (pty_slave);  /* These may be FD_CLOEXEC, but just in case... */
+
+    switch (subshell_type)
+    {
+        case BASH:
+	    execl (shell, "bash", "-rcfile", init_file, NULL);
+	    break;
+
+        case TCSH:
+	    execl (shell, "tcsh", NULL);  /* What's the -rcfile equivalent? */
+	    break;
+
+        case ZSH:
+	    /* change from "+Z" to "-Z" by Michael Bramer
+	     * (Debian-mc-maintainer) <grisu@debian.org> from a patch from
+	     * Radovan Garabik <garabik@center.fmph.uniba.sk>
+	     */
+	    execl (shell, "zsh", "-Z", NULL);
+
+	    break;
+    }
+
+    /* If we get this far, everything failed miserably */
+    _exit (FORK_FAILURE);
+
+    /* }}} */
+}
+
+/* {{{ init_subshell */
+
+/*
+ *  Fork the subshell, and set up many, many things.
+ *
+ *  Possibly modifies the global variables:
+ *	subshell_type, subshell_alive, subshell_stopped, subshell_pid
+ *	use_subshell - Is set to FALSE if we can't run the subshell
+ *	quit - Can be set to SUBSHELL_EXIT by the SIGCHLD handler
+ */
+
 void init_subshell (void)
 {
     /* {{{ Local variables */
 
     /* This must be remembered across calls to init_subshell() */
     static char pty_name[BUF_SMALL];
-    int pty_slave;
+    int pty_slave = -1;
 
     /* Braindead tcsh can't redirect output to a file descriptor? */
     char tcsh_fifo[sizeof "/tmp/mc.pipe.1234567890"];
@@ -221,6 +379,10 @@ void init_subshell (void)
 
     /* }}} */
 
+    /* Take the current (hopefully pristine) tty mode and make */
+    /* a raw mode based on it now, before we do anything else with it */
+    init_raw_mode ();
+
     if (subshell_pty == 0)  /* First time through */
     {
 	/* {{{ Find out what type of shell we have */
@@ -329,147 +491,13 @@ void init_subshell (void)
 
     if (subshell_pid == 0)  /* We are in the child process */
     {
-	char *init_file = NULL;
-	
-	setsid ();  /* Get a fresh terminal session */
-
-	/* {{{ Open the slave side of the pty: again */
-	pty_slave = pty_open_slave (pty_name);
-
-	/* This must be done before closing the master side of the pty, */
-	/* or it will fail on certain idiotic systems, such as Solaris.	*/
-
-	/* Close master side of pty.  This is important; apart from	*/
-	/* freeing up the descriptor for use in the subshell, it also	*/
-	/* means that when MC exits, the subshell will get a SIGHUP and	*/
-	/* exit too, because there will be no more descriptors pointing	*/
-	/* at the master side of the pty and so it will disappear.	*/
-
-	close (subshell_pty);
-
-#ifdef SYNC_PTY_SIDES
-	    /* Give our parent process (MC) the go-ahead */
-	    kill (getppid (), SIGUSR1);
-#endif
-
-	/* }}} */
-	/* {{{ Make sure that it has become our controlling terminal */
-
-	/* Redundant on Linux and probably most systems, but just in case: */
-
-#	ifdef TIOCSCTTY
-	ioctl (pty_slave, TIOCSCTTY, 0);
-#	endif
-
-	/* }}} */
-	/* {{{ Configure its terminal modes and window size */
-
-	/* Set up the pty with the same termios flags as our own tty, plus  */
-	/* TOSTOP, which keeps background processes from writing to the pty */
-
-	shell_mode.c_lflag |= TOSTOP;  /* So background writers get SIGTTOU */
-	if (tcsetattr (pty_slave, TCSANOW, &shell_mode))
-	{
-	    perror (__FILE__": couldn't set pty terminal modes");
-	    _exit (FORK_FAILURE);
-	}
-
-	/* Set the pty's size (80x25 by default on Linux) according to the */
-	/* size of the real terminal as calculated by ncurses, if possible */
-#	if defined TIOCSWINSZ && !defined SCO_FLAVOR
-	{
-	    struct winsize tty_size;
-	    tty_size.ws_row = LINES;
-	    tty_size.ws_col = COLS;
-	    tty_size.ws_xpixel = tty_size.ws_ypixel = 0;
-
-	    if (ioctl (pty_slave, TIOCSWINSZ, &tty_size))
-		perror (__FILE__": couldn't set pty size");
-	}
-#	endif
-
-	/* }}} */
-	/* {{{ Set up the subshell's environment and init file name */
-
-	/* It simplifies things to change to our home directory here, */
-	/* and the user's startup file may do a `cd' command anyway   */
-	chdir (home_dir);  /* FIXME? What about when we re-run the subshell? */
-
-	switch (subshell_type)
-	{
-	    case BASH:
-		init_file = ".mc/bashrc";
-		if (access (init_file, R_OK) == -1)
-		    init_file = ".bashrc";
-
-		/* Make MC's special commands not show up in bash's history */
-		putenv ("HISTCONTROL=ignorespace");
-
-		/* Allow alternative readline settings for MC */
-		if (access (".mc/inputrc", R_OK) == 0)
-		    putenv ("INPUTRC=.mc/inputrc");
-
-		break;
-
-	    case TCSH:
-		init_file = ".mc/tcshrc";
-		if (access (init_file, R_OK) == -1)
-		    init_file += 3;
-		break;
-
-	    case ZSH:
-		break;
-
-	    default:
-		fprintf (stderr, __FILE__": unimplemented subshell type %d\n",
-			 subshell_type);
-		_exit (FORK_FAILURE);
-	}
-
-	/* }}} */
-	/* {{{ Attach all our standard file descriptors to the pty */
-
-	/* This is done just before the fork, because stderr must still	 */
-	/* be connected to the real tty during the above error messages; */
-	/* otherwise the user will never see them.			 */
-
-	dup2 (pty_slave, STDIN_FILENO);
-	dup2 (pty_slave, STDOUT_FILENO);
-	dup2 (pty_slave, STDERR_FILENO);
-
-	/* }}} */
-	/* {{{ Execute the subshell at last */
-
-	close (subshell_pipe[READ]);
-	close (pty_slave);  /* These may be FD_CLOEXEC, but just in case... */
-
-	switch (subshell_type)
-	{
-	    case BASH:
-	    execl (shell, "bash", "-rcfile", init_file, NULL);
-	    break;
-
-	    case TCSH:
-	    execl (shell, "tcsh", NULL);  /* What's the -rcfile equivalent? */
-	    break;
-
-	    case ZSH:
-	    /* change from "+Z" to "-Z" by Michael Bramer
-	     * (Debian-mc-maintainer) <grisu@debian.org> from a patch from
-	     * Radovan Garabik <garabik@center.fmph.uniba.sk>
-	     */
-	    execl (shell, "zsh", "-Z", NULL);
-
-	    break;
-	}
-
-	/* If we get this far, everything failed miserably */
-	_exit (FORK_FAILURE);
-
-	/* }}} */
+	init_subshell_child (pty_name);
     }
 
-    close(pty_slave);
+    /* pty_slave is only opened when called the first time */
+    if (pty_slave != -1) {
+	close(pty_slave);
+    }
 
 #ifdef SYNC_PTY_SIDES
 	sigsuspend (&old_mask);
@@ -511,7 +539,10 @@ void init_subshell (void)
 	goto write_it;
 
 	case TCSH:
-	g_snprintf (precmd, sizeof (precmd), "alias precmd 'echo $cwd:q >>%s;kill -STOP $$'\n", tcsh_fifo);
+	g_snprintf (precmd, sizeof (precmd),
+		    "set echo_style=both;"
+		    "alias precmd 'echo $cwd:q >>%s;kill -STOP $$'\n",
+		    tcsh_fifo);
 
 	write_it:
 	write (subshell_pty, precmd, strlen (precmd));
@@ -533,21 +564,18 @@ void init_subshell (void)
 }
 
 /* }}} */
-/* {{{ invoke_subshell */
 
-int invoke_subshell (const char *command, int how, char **new_dir)
+static void init_raw_mode ()
 {
-    /* {{{ Fiddle with terminal modes */
+    static int initialized = 0;
 
-    static struct termios raw_mode = {0};
-    
     /* MC calls reset_shell_mode() in pre_exec() to set the real tty to its */
     /* original settings.  However, here we need to make this tty very raw, */
     /* so that all keyboard signals, XON/XOFF, etc. will get through to the */
     /* pty.  So, instead of changing the code for execute(), pre_exec(),    */
     /* etc, we just set up the modes we need here, before each command.     */
 
-    if (raw_mode.c_iflag == 0)  /* First time: initialise `raw_mode' */
+    if (initialized == 0)  /* First time: initialise `raw_mode' */
     {
 	tcgetattr (STDOUT_FILENO, &raw_mode);
 	raw_mode.c_lflag &= ~ICANON;  /* Disable line-editing chars, etc.   */
@@ -558,7 +586,15 @@ int invoke_subshell (const char *command, int how, char **new_dir)
 	raw_mode.c_oflag &= ~OPOST;   /* Don't postprocess output	    */
 	raw_mode.c_cc[VTIME] = 0;     /* IE: wait forever, and return as    */
 	raw_mode.c_cc[VMIN] = 1;      /* soon as a character is available   */
+	initialized = 1;
     }
+}
+
+/* {{{ invoke_subshell */
+
+int invoke_subshell (const char *command, int how, char **new_dir)
+{
+    /* {{{ Make the MC terminal transparent */
 
     tcsetattr (STDOUT_FILENO, TCSANOW, &raw_mode);
 
@@ -751,6 +787,67 @@ int exit_subshell (void)
 
 /* }}} */
 
+/*
+ * Carefully quote directory name to allow entering any directory safely,
+ * no matter what weird characters it may contain in its name.
+ * NOTE: Treat directory name an untrusted data, don't allow it to cause
+ * executing any commands in the shell. Escape all control characters.
+ * Use following technique:
+ *
+ * for bash - echo with `-e', 3-digit octal numbers:
+ *   cd "`echo -e '\ooo...\ooo'`"
+ *
+ * for zsh and tcsh - echo without `-e', 4-digit octal numbers:
+ *   cd "`echo '\oooo...\oooo'`"
+ */
+static char *
+subshell_name_quote (const char *s)
+{
+    char *ret, *d;
+    const char bash_start[] = "\"`echo -e '";
+    const char nonbash_start[] = "\"`echo '";
+    const char common_end[] = "'`\"";
+
+    /*
+     * Factor 5 because we need \, 0 and 3 other digits per character
+     * in the worst case (tcsh and zsh).
+     */
+    d = ret = g_malloc (5 * strlen (s) + 16);
+
+    /* Prevent interpreting leading `-' as a switch for `cd' */
+    if (*s == '-') {
+        *d++ = '.';
+        *d++ = '/';
+    }
+
+    /*
+     * Print every character in octal format with the leading backslash.
+     * tcsh and zsh require leading 0, bash doesn't like 4-digit octals
+     * and requires `-e' for echo.
+     */
+    if (subshell_type == BASH) {
+	memcpy (d, bash_start, sizeof (bash_start) - 1);
+	d += sizeof (bash_start) - 1;
+	for (; *s; s++) {
+	    sprintf(d, "\\%03o", (unsigned char) *s);
+	    d += 4;
+	}
+    } else {
+	memcpy (d, nonbash_start, sizeof (nonbash_start) - 1);
+	d += sizeof (nonbash_start) - 1;
+	for (; *s; s++) {
+	    sprintf(d, "\\0%03o", (unsigned char) *s);
+	    d += 5;
+	}
+    }
+
+    memcpy (d, common_end, sizeof (common_end));
+
+    return ret;
+}
+
+
+
 /* {{{ do_subshell_chdir */
 /* If it actually changed the directory it returns true */
 void do_subshell_chdir (const char *directory, int do_update, int reset_prompt)
@@ -769,23 +866,10 @@ void do_subshell_chdir (const char *directory, int do_update, int reset_prompt)
        because we set "HISTCONTROL=ignorespace") */
     write (subshell_pty, " cd ", 4);
     if (*directory) {
-	struct termios old_mode, new_mode;
 	char *temp;
-
-	/* FIXME: Lines below are dirty hack to prevent command execution
-	 *        for directory names containing 0x03 (intr) 0x14.
-	 *	  See http://www.securityfocus.com/vdb/?id=2016 for details.
-	 *        Subshell still can't chdir to such directories */
-	tcgetattr (subshell_pty, &old_mode);
-	new_mode = old_mode;
-	new_mode.c_lflag &= ~ISIG;    /* Disable intr, quit & suspend chars */
-	tcsetattr (subshell_pty, TCSANOW, &new_mode);
-
-	temp = name_quote (directory, 0);
+	temp = subshell_name_quote (directory);
 	write (subshell_pty, temp, strlen (temp));
 	g_free (temp);
-
-	tcsetattr (subshell_pty, TCSANOW, &old_mode);
     } else {
 	write (subshell_pty, "/", 1);
     }
@@ -858,30 +942,25 @@ void sigchld_handler (int sig)
 	/* }}} */
     }
 
-#ifndef HAVE_X
-#ifndef SCO_FLAVOR
+#if defined(linux) || defined(__linux__)
     pid = waitpid (cons_saver_pid, &status, WUNTRACED | WNOHANG);
     
     if (pid == cons_saver_pid) {
-	/* {{{ Someone has stopped or killed cons.saver; restart it */
 
 #  ifdef SIGTSTP
 	if (WIFSTOPPED (status))
+	    /* Someone has stopped cons.saver - restart it */
 	    kill (pid, SIGCONT);
 	else
 #  endif
 	{
+	    /* cons.saver has died - disable confole saving */
 	    handle_console (CONSOLE_DONE);
-	    handle_console (CONSOLE_INIT);
-	    /* Ought to do: if (in_subshell) handle_console (CONSOLE_SAVE)
-	       Can't do this without adding a new variable `in_subshell';
-	       it hardly seems to be worth the trouble. */
+	    console_flag = 0;
 	}
 
-	/* }}} */
     }
-#endif /* ! SCO_FLAVOR */
-#endif /* ! HAVE_X */
+#endif /* linux || __linux__ */
     /* If we get here, some other child exited; ignore it */
 #  ifdef __EMX__				/* Need to report */
     pid = wait(&status);
@@ -905,12 +984,12 @@ static int feed_subshell (int how, int fail_on_error)
     struct timeval *wptr;
     /* }}} */
 
-    /* we wait up to 10 seconds if fail_on_error */
+    /* we wait up to 10 seconds if fail_on_error, forever otherwise */
     wtime.tv_sec = 10;
     wtime.tv_usec = 0;
+    wptr = fail_on_error ? &wtime : NULL;
     
-    for (wptr = fail_on_error ? &wtime : NULL;;)
-    {
+    while (1) {
 	if (!subshell_alive)
 	    return FALSE;
 
@@ -933,9 +1012,6 @@ static int feed_subshell (int how, int fail_on_error)
 	}
 	/* }}} */
 
-	/* From now on: block forever on the select call */
-	wptr = NULL;
-	
 	if (FD_ISSET (subshell_pty, &read_set))
 	    /* {{{ Read from the subshell, write to stdout */
 
@@ -1067,11 +1143,12 @@ static int pty_open_master (char *pty_name)
     {
 	g_snprintf(ptr, 9, "%d",num);	/* surpriiise ... SCO lacks itoa() */
 	/* Try to open master */
-	if ((pty_master = open (pty_name, O_RDWR)) == -1)
+	if ((pty_master = open (pty_name, O_RDWR)) == -1) {
 	    if (errno == ENOENT)  /* Different from EIO */
 		return -1;	      /* Out of pty devices */
 	    else
 		continue;	      /* Try next pty device */
+	}
 	pty_name [5] = 't';	      /* Change "pty" to "tty" */
 	if (access (pty_name, 6)){
 	    close (pty_master);
@@ -1105,7 +1182,7 @@ static int pty_open_slave (const char *pty_name)
 
 /* }}} */
 
-#elif HAVE_GRANTPT
+#elif HAVE_GRANTPT /* !HAVE_SCO */
 
 /* {{{ System V version of pty_open_master */
 
@@ -1122,8 +1199,10 @@ static int pty_open_master (char *pty_name)
     strcpy (pty_name, "/dev/ptmx");
     pty_master = open (pty_name, O_RDWR);
 #endif 
-    if (pty_master == -1
-	|| grantpt (pty_master) == -1		  /* Grant access to slave */
+    if (pty_master == -1)
+	return -1;
+
+    if (grantpt (pty_master) == -1		  /* Grant access to slave */
 	|| unlockpt (pty_master) == -1		  /* Clear slave's lock flag */
 	|| !(slave_name = ptsname (pty_master)))  /* Get slave's name */
     {
@@ -1182,7 +1261,7 @@ static int pty_open_slave (const char *pty_name)
 
 /* }}} */
 
-#else
+#else /* !HAVE_SCO && !HAVE_GRANTPT */
 
 /* {{{ BSD version of pty_open_master */
 
@@ -1200,11 +1279,12 @@ static int pty_open_master (char *pty_name)
 	    pty_name [9] = *ptr2;
 
 	    /* Try to open master */
-	    if ((pty_master = open (pty_name, O_RDWR)) == -1)
+	    if ((pty_master = open (pty_name, O_RDWR)) == -1) {
 		if (errno == ENOENT)  /* Different from EIO */
 		    return -1;	      /* Out of pty devices */
 		else
 		    continue;	      /* Try next pty device */
+	    }
 	    pty_name [5] = 't';	      /* Change "pty" to "tty" */
 	    if (access (pty_name, 6)){
 		close (pty_master);
@@ -1239,7 +1319,7 @@ static int pty_open_slave (const char *pty_name)
 
 /* }}} */
 
-#endif
+#endif /* !HAVE_SCO && !HAVE_GRANTPT */
 
 /* }}} */
 
