@@ -53,13 +53,15 @@ extern int command_prompt;
 #define TREE_NORMALC HOT_FOCUSC
 
 /* Specifies the display mode: 1d or 2d */
-int tree_navigation_flag;
+static int tree_navigation_flag;
 
 /* Forwards */
+static void save_tree (WTree *tree);
+static void tree_rescan_cmd (WTree *tree);
 static int tree_callback (Dlg_head *h, WTree *tree, int msg, int par);
 #define tcallback (callback_fn) tree_callback
 
-/* "$Id: tree.c,v 1.24 2001/01/08 18:21:37 bansz Exp $" */
+/* "$Id: tree.c,v 1.29 2001/08/14 00:55:38 proskin Exp $" */
 
 static tree_entry *back_ptr (tree_entry *ptr, int *count)
 {
@@ -85,8 +87,9 @@ static tree_entry *forw_ptr (tree_entry *ptr, int *count)
     return ptr;
 }
 
+#if 0
 /* Add a directory to the list of directories */
-tree_entry *tree_add_entry (WTree *tree, char *name)
+static tree_entry *tree_add_entry (WTree *tree, char *name)
 {
     if (!tree)
 	return 0;
@@ -94,7 +97,6 @@ tree_entry *tree_add_entry (WTree *tree, char *name)
     return tree_store_add_entry (name);
 }
 
-#if 0
 /* Append a directory to the list of directories */
 static tree_entry *tree_append_entry (WTree *tree, char *name)
 {
@@ -142,7 +144,7 @@ static tree_entry *tree_append_entry (WTree *tree, char *name)
 }
 #endif
 
-void
+static void
 remove_callback (tree_entry *entry, void *data)
 {
 	WTree *tree = data;
@@ -155,12 +157,12 @@ remove_callback (tree_entry *entry, void *data)
 	}
 }
 
-void tree_remove_entry (WTree *tree, char *name)
+static void tree_remove_entry (WTree *tree, char *name)
 {
     tree_store_remove_entry (name);
 }
 
-void tree_destroy (WTree *tree)
+static void tree_destroy (WTree *tree)
 {
     tree_store_remove_entry_remove_hook (remove_callback);
     save_tree (tree);
@@ -173,7 +175,7 @@ void tree_destroy (WTree *tree)
 }
 
 /* Loads the .mc.tree file */
-void load_tree (WTree *tree)
+static void load_tree (WTree *tree)
 {
     tree_store_load ();
 
@@ -182,14 +184,14 @@ void load_tree (WTree *tree)
 }
 
 /* Save the .mc.tree file */
-void save_tree (WTree *tree)
+static void save_tree (WTree *tree)
 {
     int error;
 
     error = tree_store_save ();
 
     if (error){
-	fprintf (stderr, _("Can't open the %s file for writing:\n%s\n"), MC_TREE,
+	fprintf (stderr, _("Cannot open the %s file for writing:\n%s\n"), MC_TREE,
 		 unix_error_string (error));
 	return;
     }
@@ -227,7 +229,7 @@ static void tree_show_mini_info (WTree *tree, int tree_lines, int tree_cols)
     }
 }
 
-void show_tree (WTree *tree)
+static void show_tree (WTree *tree)
 {
     Dlg_head *h = tree->widget.parent;
     tree_entry *current;
@@ -353,8 +355,8 @@ void show_tree (WTree *tree)
 	attrset (TREE_NORMALC);
 
 	/* Calculate the next value for current */
+	current = current->next;
 	if (tree_navigation_flag){
-	    current = current->next;
 	    while (current){
 		if (current->sublevel < tree->selected_ptr->sublevel){
 		    if (strncmp (current->name, tree->selected_ptr->name,
@@ -372,8 +374,7 @@ void show_tree (WTree *tree)
 		}
 		current = current->next;
 	    }
-	} else
-	    current = current->next;
+	}
     }
     tree_show_mini_info (tree, tree_lines, tree_cols);
 }
@@ -386,7 +387,7 @@ static void check_focus (WTree *tree)
 	tree->topdiff = tlines (tree) - 3 - 1;
 }
 
-void tree_move_backward (WTree *tree, int i)
+static void tree_move_backward (WTree *tree, int i)
 {
     tree_entry *current;
     int j = 0;
@@ -408,7 +409,7 @@ void tree_move_backward (WTree *tree, int i)
     check_focus (tree);
 }
 
-void tree_move_forward (WTree *tree, int i)
+static void tree_move_forward (WTree *tree, int i)
 {
     tree_entry *current;
     int j = 0;
@@ -430,7 +431,7 @@ void tree_move_forward (WTree *tree, int i)
     check_focus (tree);
 }
 
-void tree_move_to_child (WTree *tree)
+static void tree_move_to_child (WTree *tree)
 {
     tree_entry *current;
 
@@ -457,7 +458,7 @@ void tree_move_to_child (WTree *tree)
     }
 }
 
-int tree_move_to_parent (WTree *tree)
+static int tree_move_to_parent (WTree *tree)
 {
     tree_entry *current;
     tree_entry *old;
@@ -477,13 +478,13 @@ int tree_move_to_parent (WTree *tree)
     return tree->selected_ptr != old;
 }
 
-void tree_move_to_top (WTree *tree)
+static void tree_move_to_top (WTree *tree)
 {
     tree->selected_ptr = tree->store->tree_first;
     tree->topdiff = 0;
 }
 
-void tree_move_to_bottom (WTree *tree)
+static void tree_move_to_bottom (WTree *tree)
 {
     tree->selected_ptr = tree->store->tree_last;
     tree->topdiff = tlines (tree) - 3 - 1;
@@ -507,7 +508,7 @@ sync_tree (char *path)
 }
 
 /* Handle mouse click */
-void tree_event (WTree *tree, int y)
+static void tree_event (WTree *tree, int y)
 {
     if (tree->tree_shown [y]){
 	tree->selected_ptr = tree->tree_shown [y];
@@ -557,7 +558,7 @@ static int event_callback (Gpm_Event *event, WTree *tree)
 }
 
 /* Search tree for text */
-int search_tree (WTree *tree, char *text)
+static int search_tree (WTree *tree, char *text)
 {
     tree_entry *current;
     int len;
@@ -606,7 +607,7 @@ static void tree_do_search (WTree *tree, int key)
     maybe_chdir (tree);
 }
 
-void tree_rescan_cmd (WTree *tree)
+static void tree_rescan_cmd (WTree *tree)
 {
     char old_dir [MC_MAXPATHLEN];
 
@@ -618,14 +619,14 @@ void tree_rescan_cmd (WTree *tree)
     mc_chdir (old_dir);
 }
 
-int tree_forget_cmd (WTree *tree)
+static int tree_forget_cmd (WTree *tree)
 {
     if (tree->selected_ptr)
 	tree_remove_entry (tree, tree->selected_ptr->name);
     return 1;
 }
 
-void tree_copy (WTree *tree, char *default_dest)
+static void tree_copy (WTree *tree, char *default_dest)
 {
     char   *dest;
     long   count = 0;
@@ -637,7 +638,12 @@ void tree_copy (WTree *tree, char *default_dest)
     g_snprintf (cmd_buf, sizeof(cmd_buf), _("Copy \"%s\" directory to:"),
 	     name_trunc (tree->selected_ptr->name, 50));
     dest = input_expand_dialog (_(" Copy "), cmd_buf, default_dest);
-    if (!dest || !*dest){
+
+    if (!dest)
+	return;
+
+    if (!*dest){
+	g_free (dest);
 	return;
     }
 
@@ -651,9 +657,7 @@ void tree_copy (WTree *tree, char *default_dest)
 
 static void tree_help_cmd (void)
 {
-    char *hlpfile = concat_dir_and_file (mc_home, _("mc.hlp"));
-    interactive_display (hlpfile,  "[Directory Tree]");
-    g_free (hlpfile);
+    interactive_display (NULL,  "[Directory Tree]");
 }
 
 static int tree_copy_cmd (WTree *tree)
@@ -662,7 +666,7 @@ static int tree_copy_cmd (WTree *tree)
     return 1;
 }
 
-void tree_move (WTree *tree, char *default_dest)
+static void tree_move (WTree *tree, char *default_dest)
 {
     char   *dest;
     struct stat buf;
@@ -675,17 +679,20 @@ void tree_move (WTree *tree, char *default_dest)
     g_snprintf (cmd_buf, sizeof (cmd_buf), _("Move \"%s\" directory to:"),
 	     name_trunc (tree->selected_ptr->name, 50));
     dest = input_expand_dialog (_(" Move "), cmd_buf, default_dest);
-    if (!dest || !*dest){
+    if (!dest)
+	return;
+    if (!*dest){
+	g_free (dest);
 	return;
     }
     if (stat (dest, &buf)){
-	message (1, _(" Error "), _(" Can't stat the destination \n %s "),
+	message (1, MSG_ERROR, _(" Cannot stat the destination \n %s "),
 		 unix_error_string (errno));
 	g_free (dest);
 	return;
     }
     if (!S_ISDIR (buf.st_mode)){
-	message (1, _(" Error "), _(" The destination isn't a directory "));
+	message (1, MSG_ERROR, _(" The destination isn't a directory "));
 	g_free (dest);
 	return;
     }
@@ -705,6 +712,7 @@ tree_move_cmd (WTree *tree)
     return 1;
 }
 
+#if 0
 static int
 tree_mkdir_cmd (WTree *tree)
 {
@@ -723,6 +731,7 @@ tree_mkdir_cmd (WTree *tree)
     chdir (old_dir);
     return 1;
 }
+#endif
 
 static void
 tree_rmdir_cmd (WTree *tree)
@@ -769,7 +778,7 @@ tree_toggle_navig (Dlg_head *h)
     set_navig_label (h);
 }
 
-void
+static void
 set_navig_label (Dlg_head *h)
 {
     define_label_data (h, (Widget *)tree,
@@ -863,7 +872,7 @@ chdir_sel (WTree *tree)
 	paint_panel (cpanel);
 	select_item (cpanel);
     } else {
-	message (1, MSG_ERROR, _(" Can't chdir to \"%s\" \n %s "),
+	message (1, MSG_ERROR, _(" Cannot chdir to \"%s\" \n %s "),
 		 tree->selected_ptr->name, unix_error_string (errno));
     }
     change_panel ();
@@ -899,7 +908,7 @@ tree_start_search (WTree *tree)
     }
 }
 
-static key_map tree_keymap [] = {
+static const key_map tree_keymap [] = {
     { XCTRL('n'), move_down    },
     { XCTRL('p'), move_up      },
     { KEY_DOWN,   move_down    },
