@@ -43,6 +43,7 @@
 #include <stdio.h>
 #include <string.h>
 #include "global.h"
+#include "x.h"
 #include "treestore.h"
 #include "../vfs/vfs.h"
 #ifdef NEEDS_IO_H
@@ -57,7 +58,7 @@ static TreeStore ts;
 
 void (*tree_store_dirty_notify)(int state) = NULL;
 
-void
+static void
 tree_store_dirty (int state)
 {
 	ts.dirty = state;
@@ -357,7 +358,7 @@ tree_store_save_to (char *name)
 			}
 			
 			if (i == EOF){
-				fprintf (stderr, _("Can't write to the %s file:\n%s\n"), name,
+				fprintf (stderr, _("Cannot write to the %s file:\n%s\n"), name,
 					 unix_error_string (errno));
 				break;
 			}
@@ -502,7 +503,7 @@ tree_store_add_entry (char *name)
 	return new;
 }
 
-tree_entry *
+static tree_entry *
 remove_entry (tree_entry *entry)
 {
 	tree_entry *current = entry->prev;
@@ -746,7 +747,7 @@ process_special_dirs (GList **special_dirs, char *file)
 	g_free (buffer);
 }
 
-gboolean
+static gboolean
 should_skip_directory (char *dir)
 {
 	static GList *special_dirs;
