@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include <config.h>
 #include <stdio.h>
@@ -26,6 +26,7 @@
 #include <errno.h>
 #include <fcntl.h>
 #include "global.h"
+#include "x.h"
 #include "dialog.h"
 #include "color.h"
 #include "dir.h"
@@ -44,14 +45,15 @@
 
 #include "view.h" /* for default_* externs */
 
-/* "$Id: user.c,v 1.18 2000/05/25 16:21:42 pavel Exp $" */
+/* "$Id: user.c,v 1.29 2001/08/14 00:55:38 proskin Exp $" */
 
 #define MAX_ENTRIES 16
 #define MAX_ENTRY_LEN 60
 
+#ifndef HAVE_X
 static int debug_flag = 0;
 static int debug_error = 0;
-static WEdit *s_editwidget;
+#endif /* !HAVE_X */
 static char *menu = NULL;
 
 /* Formats defined:
@@ -63,9 +65,9 @@ static char *menu = NULL;
    %s  "Selected files"; the tagged files if any, otherwise the current file
    %t  Tagged files
    %u  Tagged files (and they are untagged on return from expand_format)
-   %view Runs the commands and pipes standard output to the view command
-       if %view is directly followed by '{', a list of keywords
-       ascii, hex, nroff, unformated and
+   %view Runs the commands and pipes standard output to the view command.
+       If %view is immediately followed by '{', recognize keywords
+       ascii, hex, nroff and unform
 
    If the format letter is in uppercase, it refers to the other panel.
    
@@ -82,22 +84,22 @@ static char *menu = NULL;
 int check_format_view (const char *p)
 {
     const char *q = p;
-    if (!strncmp (p, "view", 4)){
+    if (!strncmp (p, "view", 4)) {
     	q += 4;
     	if (*q == '{'){
-    	    for (q++;*q && *q != '}';q++){
-    	    	if (!strncmp (q, "ascii", 5)){
+    	    for (q++;*q && *q != '}';q++) {
+    	    	if (!strncmp (q, "ascii", 5)) {
     	    	    default_hex_mode = 0;
     	    	    q += 4;
-    	    	} else if (!strncmp (q, "hex", 3)){
+    	    	} else if (!strncmp (q, "hex", 3)) {
     	    	    default_hex_mode = 1;
     	    	    q += 2;
-    	    	} else if (!strncmp (q, "nroff", 5)){
+    	    	} else if (!strncmp (q, "nroff", 5)) {
     	    	    default_nroff_flag = 1;
     	    	    q += 4;
-    	    	} else if (!strncmp (q, "unformated", 10)){
+    	    	} else if (!strncmp (q, "unform", 6)) {
     	    	    default_nroff_flag = 0;
-    	    	    q += 9;
+    	    	    q += 5;
     	    	} 
     	    }
     	    if (*q == '}')
@@ -135,8 +137,8 @@ int check_format_var (const char *p, char **v)
 	if (!dots || dots == q+5){
 	    message (1,
 		     _(" Format error on file Extensions File "),
-		     _(!dots ? N_(" The %%var macro does not have a default ")
-		     :         N_(" The %%var macros does not have a variable ")));
+		     !dots ? _(" The %%var macro has no default ")
+		     :       _(" The %%var macro has no variable "));
 	    return 0;
 	}
 	
@@ -175,7 +177,7 @@ strip_ext(char *ss)
     return ss;
 }
 
-char *expand_format (char c, int quote)
+char *expand_format (WEdit *edit_widget, char c, int quote)
 {
     WPanel *panel;
     char *(*quote_func)(const char *, int);
@@ -205,30 +207,39 @@ char *expand_format (char c, int quote)
     switch (c){
     case 'f': 
     case 'p': return (*quote_func) (fname, 0);
-    case 'b': return strip_ext((*quote_func) (fname, 0));
     case 'x': return (*quote_func) (extension(fname), 0);
     case 'd': return (*quote_func) (panel->cwd, 0);
-    case 's': if (!panel->marked)
-		return (*quote_func) (fname, 0);
     case 'i': /* indent equal number cursor position in line */
-        if (s_editwidget)
-	        return g_strnfill (s_editwidget->curs_col, ' ');
+        if (edit_widget)
+	        return g_strnfill (edit_widget->curs_col, ' ');
         break;
     case 'y': /* syntax type */
-        if (s_editwidget && s_editwidget->syntax_type)
-	        return g_strdup (s_editwidget->syntax_type);
+        if (edit_widget && edit_widget->syntax_type)
+	        return g_strdup (edit_widget->syntax_type);
         break;
     case 'e': /* error file name */
-    case 'k': /* block file name */ {
-	char *file = g_strconcat (home_dir, (c == 'e') ? ERROR_FILE : BLOCK_FILE, NULL);
-	fname = (*quote_func) (file, 0);
-	g_free (file);
-	return fname;
+    case 'b': /* block file name / strip extension */ {
+	if (edit_widget) {
+	    char *file = g_strconcat (home_dir,
+				      (c == 'e') ? ERROR_FILE : BLOCK_FILE,
+				      NULL);
+	    fname = (*quote_func) (file, 0);
+	    g_free (file);
+	    return fname;
+	} else if (c == 'e') {
+	    return strip_ext((*quote_func) (fname, 0));
+	}
     }
+    case 'n': /* strip extension in editor */
+	if (edit_widget)
+	    return strip_ext((*quote_func) (fname, 0));
+	break;
     case 'm': /* menu file name */
 	if (menu)
 	    return (*quote_func) (menu, 0);
 	break;
+    case 's': if (!panel->marked)
+		return (*quote_func) (fname, 0);
 
 	/* Fall through */
 
@@ -240,7 +251,7 @@ char *expand_format (char c, int quote)
 	
 	for (i = 0; i < panel->count; i++)
 	    if (panel->dir.list [i].f.marked)
-		length += strlen (panel->dir.list [i].fname) + 1;
+		length += strlen (panel->dir.list [i].fname) + 1; /* for space */
 
 	block = g_malloc (length*2+1);
 	*block = 0;
@@ -258,6 +269,7 @@ char *expand_format (char c, int quote)
     return g_strdup ("");
 }
 
+#ifndef HAVE_X
 /* Checks for shell patterns definition */
 char *check_patterns (char *p)
 {
@@ -340,7 +352,7 @@ static int test_type (WPanel *panel, char *arg)
 
 /* Calculates the truth value of the next condition starting from
    p. Returns the point after condition. */
-static char *test_condition (char *p, int *condition)
+static char *test_condition (WEdit *edit_widget, char *p, int *condition)
 {
     WPanel *panel;
     char arg [256];
@@ -362,7 +374,7 @@ static char *test_condition (char *p, int *condition)
 
 	switch (*p++){
 	case '!':
-	    p = test_condition (p, condition);
+	    p = test_condition (edit_widget, p, condition);
 	    *condition = ! *condition;
 	    p--;
 	    break;
@@ -371,10 +383,10 @@ static char *test_condition (char *p, int *condition)
 	    *condition = panel && regexp_match (arg, panel->dir.list [panel->selected].fname, match_file);
 	    break;
 	case 'y': /* syntax pattern */
-            if (s_editwidget && s_editwidget->syntax_type) {
+            if (edit_widget && edit_widget->syntax_type) {
 	        p = extract_arg (p, arg);
 	        *condition = panel &&
-                    regexp_match (arg, s_editwidget->syntax_type, match_normal);
+                    regexp_match (arg, edit_widget->syntax_type, match_normal);
 	    }
                 break;
 	case 'd':
@@ -458,7 +470,7 @@ debug_out (char *start, char *end, int cond)
 
 /* Calculates the truth value of one lineful of conditions. Returns
    the point just before the end of line. */
-static char *test_line (char *p, int *result)
+static char *test_line (WEdit *edit_widget, char *p, int *result)
 {
     int condition;
     char operator;
@@ -486,7 +498,7 @@ static char *test_line (char *p, int *result)
 	condition = 1;	/* True by default */
 
 	debug_start = p;
-	p = test_condition (p, &condition);
+	p = test_condition (edit_widget, p, &condition);
 	debug_end = p;
 	/* Add one debug statement */
 	debug_out (debug_start, debug_end, condition);
@@ -521,7 +533,7 @@ static char *test_line (char *p, int *result)
 
 /* FIXME: recode this routine on version 3.0, it could be cleaner */
 static void
-execute_menu_command (char *commands)
+execute_menu_command (WEdit *edit_widget, char *commands)
 {
     FILE *cmd_file;
     int  cmd_file_fd;
@@ -540,22 +552,11 @@ execute_menu_command (char *commands)
 	return;
     }
 
-    if ((file_name = tempnam (NULL, "mcusr")) == 0) {
-	message (1, MSG_ERROR, _(" Can't generate unique filename \n %s "),
-		 unix_error_string (errno));
-	return;
-    }
+    cmd_file_fd = mc_mkstemps(&file_name, "mcusr", SCRIPT_SUFFIX);
 
-#ifdef OS2_NT
-    /* OS/2 and NT requires the command to end in .cmd */
-    p = file_name;
-    file_name = g_strconcat (file_name, ".cmd", NULL);
-    free (p);
-#endif
-    if ((cmd_file_fd = open (file_name, O_RDWR | O_CREAT | O_TRUNC | O_EXCL, 0600)) == -1){
-	message (1, MSG_ERROR, _(" Can't create temporary command file \n %s "),
+    if (cmd_file_fd == -1){
+	message (1, MSG_ERROR, _(" Cannot create temporary command file \n %s "),
 		 unix_error_string (errno));
-        free (file_name);
 	return;
     }
     cmd_file = fdopen (cmd_file_fd, "w");
@@ -580,7 +581,7 @@ execute_menu_command (char *commands)
 		    /* User canceled */
 		    fclose (cmd_file);
 		    unlink (file_name);
-                    free (file_name);
+                    g_free (file_name);
 		    return;
 		}
 		if (do_quote) {
@@ -605,7 +606,7 @@ execute_menu_command (char *commands)
 	    if (*commands == '{')
 		parameter = prompt;
 	    else{
-		char *text = expand_format (*commands, do_quote);
+		char *text = expand_format (edit_widget, *commands, do_quote);
 		fputs (text, cmd_file);
 		g_free (text);
 	    }
@@ -621,7 +622,7 @@ execute_menu_command (char *commands)
     chmod (file_name, S_IRWXU);
     execute (file_name);
     unlink (file_name);
-    free (file_name);
+    g_free (file_name);
 }
 
 /* 
@@ -665,7 +666,6 @@ void user_menu_cmd (WEdit *edit_widget)
     int  col, i, accept_entry = 1;
     int  selected, old_patterns;
     Listbox *listbox;
-    s_editwidget = edit_widget;
     
     if (!vfs_current_is_local ()){
 	message (1, _(" Oops... "),
@@ -686,7 +686,7 @@ void user_menu_cmd (WEdit *edit_widget)
     }
 
     if ((data = load_file (menu)) == NULL){
-	message (1, MSG_ERROR, _(" Can't open file %s \n %s "),
+	message (1, MSG_ERROR, _(" Cannot open file %s \n %s "),
 		 menu, unix_error_string (errno));
 	g_free (menu);
 	menu = NULL;
@@ -723,23 +723,23 @@ void user_menu_cmd (WEdit *edit_widget)
 	    } else if (*p == '+'){
 		if (*(p+1) == '='){
 		    /* Combined adding and default */
-		    p = test_line (p, &accept_entry);
+		    p = test_line (edit_widget, p, &accept_entry);
 		    if (selected == 0 && accept_entry)
 			selected = menu_lines;
 		} else {
 		    /* A condition for adding the entry */
-		    p = test_line (p, &accept_entry);
+		    p = test_line (edit_widget, p, &accept_entry);
 		}
 	    } else if (*p == '='){
 		if (*(p+1) == '+'){
 		    /* Combined adding and default */
-		    p = test_line (p, &accept_entry);
+		    p = test_line (edit_widget, p, &accept_entry);
 		    if (selected == 0 && accept_entry)
 			selected = menu_lines;
 		} else {
 		    /* A condition for making the entry default */
 		    i = 1;
-		    p = test_line (p, &i);
+		    p = test_line (edit_widget, p, &i);
 		    if (selected == 0 && i)
 			selected = menu_lines;
 		}
@@ -787,7 +787,7 @@ void user_menu_cmd (WEdit *edit_widget)
     
     selected = run_listbox (listbox);
     if (selected >= 0)
-	execute_menu_command (entries [selected]);
+	execute_menu_command (edit_widget, entries [selected]);
 
     do_refresh ();
     }
@@ -799,3 +799,4 @@ void user_menu_cmd (WEdit *edit_widget)
 	g_free (entries);
     g_free (data);
 }
+#endif /* !HAVE_X */
