@@ -6,10 +6,10 @@
 #define MIDNIGHT
 #include "../gtkedit/edit-widget.h"
 #undef MIDNIGHT
-void user_menu_cmd (WEdit *edit_widget);
 #endif
 
-char *expand_format (char, int);
+void user_menu_cmd (WEdit *edit_widget);
+char *expand_format (WEdit *edit_widget, char c, int quote);
 int check_format_view (const char *);
 int check_format_var (const char *, char **);
 int check_format_cd (const char *);
