@@ -19,7 +19,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include <config.h>
 #include <stdio.h>
@@ -72,11 +72,17 @@
 #include <regex.h>
 #endif
 #include "global.h"
+#include "x.h"
 #include "profile.h"
-#include "user.h"		/* expand_format */
+#include "main.h"		/* mc_home */
+#include "cmd.h"		/* guess_message_value */
 #include "../vfs/vfs.h"
 
-/* "$Id: util.c,v 1.31 2000/06/15 07:03:49 andrew Exp $" */
+#ifdef HAVE_CHARSET
+#include "charsets.h"
+#endif
+
+/* "$Id: util.c,v 1.48 2001/08/16 03:52:51 proskin Exp $" */
 
 char app_text [] = "Midnight-Commander";
 
@@ -84,11 +90,10 @@ int easy_patterns = 1;
 int align_extensions = 1;
 int tilde_trunc = 1;
 
-struct mount_entry *mount_list = NULL;
-
 #ifndef VFS_STANDALONE
 int is_printable (int c)
 {
+#ifndef HAVE_X
     static const unsigned char xterm_printable[] = {
         0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
         1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
@@ -101,14 +106,17 @@ int is_printable (int c)
     };
 
     extern int xterm_flag;
-    extern int eight_bit_clean;
-    extern int full_eight_bits;
 
-#ifdef HAVE_GNOME
-    return 1;
-#endif
-    
     c &= 0xff;
+#ifdef HAVE_CHARSET
+    if (display_codepage < 0) {
+	if (xterm_flag)
+	    return xterm_printable[c];
+	else
+	    return (c > 31 && c != 127 && c != 155);
+    } else
+	return printable[ c ];
+#else
     if (eight_bit_clean){
         if (full_eight_bits){
 	    if (xterm_flag)
@@ -119,6 +127,10 @@ int is_printable (int c)
 	    return ((c >31 && c < 127) || c >= 160);
     } else
 	return (c > 31 && c < 127);
+#endif /* !HAVE_CHARSET */
+#else
+    return 1;
+#endif /* HAVE_X */
 }
 
 /* Returns the message dimensions (lines and columns) */
@@ -153,7 +165,7 @@ char *trim (char *s, char *d, int len)
 	strcpy (d, s);
     return d;
 }
-#endif
+#endif /* !VFS_STANDALONE */
 
 char *
 name_quote (const char *s, int quote_percent)
@@ -294,6 +306,38 @@ char *size_trunc_sep (double size)
     return d;
 }
 
+/*
+ * Print file SIZE to BUFFER, but don't exceed LEN characters,
+ * not including trailing 0. BUFFER should be at least LEN+1 long.
+ * This function is called for every file on panels, so avoid
+ * floating point by any means.
+ */
+void
+size_trunc_len (char *buffer, int len, off_t size)
+{
+    /* Avoid taking power for every file.  */
+    static const off_t power10 [] =
+	{1, 10, 100, 1000, 10000, 100000, 1000000, 10000000, 100000000,
+	 1000000000};
+    static const char * const suffix [] =
+	{"", "K", "M", "G", "T", "P", "E", "Z", "Y", NULL};
+    int j = 0;
+
+    /* Don't print more than 9 digits - use suffix.  */
+    if (len == 0 || len > 9)
+	len = 9;
+
+    for (j = 0; suffix [j] != NULL; j++) {
+	if (size < power10 [len - (j > 0)]) {
+	    g_snprintf (buffer, len + 1, "%lu%s", (unsigned long) size, suffix[j]);
+	    break;
+	}
+
+	/* Powers of 1024, no rounding.  */
+	size = size >> 10;
+    }
+}
+
 int is_exe (mode_t mode)
 {
     if ((S_IXUSR & mode) || (S_IXGRP & mode) || (S_IXOTH & mode))
@@ -311,7 +355,7 @@ char *string_perm (mode_t mode_bits)
     if (ismode (mode_bits, S_IFDIR)) mode [0] = 'd';
 #ifdef S_IFSOCK
     if (ismode (mode_bits, S_IFSOCK)) mode [0] = 's';
-#endif
+#endif /* S_IFSOCK */
     if (ismode (mode_bits, S_IXOTH)) mode [9] = 'x';
     if (ismode (mode_bits, S_IWOTH)) mode [8] = 'w';
     if (ismode (mode_bits, S_IROTH)) mode [7] = 'r';
@@ -329,7 +373,7 @@ char *string_perm (mode_t mode_bits)
     if (ismode (mode_bits, S_ISVTX)) mode [9] = (mode [9] == 'x') ? 't' : 'T';
     if (ismode (mode_bits, S_IFLNK)) mode [0] = 'l';
     if (ismode (mode_bits, S_IFIFO)) mode [0] = 'p';
-#endif
+#endif /* !OS2_NT */
     return mode;
 }
 
@@ -345,7 +389,7 @@ char *string_perm (mode_t mode_bits)
 char *
 strip_password (char *p, int has_prefix)
 {
-    static struct {
+    static const struct {
 	char *name;
         size_t len;
     } prefixes[] = { {"/#ftp:", 6},
@@ -489,6 +533,7 @@ int regexp_match (char *pattern, char *string, int match_type)
 	if (old_pattern){
 	    regfree (&r);
 	    g_free (old_pattern);
+	    old_pattern = NULL;
 	}
 	pattern = convert_pattern (pattern, match_type, 0);
 	if (regcomp (&r, pattern, REG_EXTENDED|REG_NOSUB|MC_ARCH_FLAGS)) {
@@ -569,10 +614,11 @@ char *load_file (char *filename)
     char *data;
     long read_size;
     
-    if (stat (filename, &s) != 0){
+    if ((data_file = fopen (filename, "r")) == NULL){
 	return 0;
     }
-    if ((data_file = fopen (filename, "r")) == NULL){
+    if (fstat (fileno (data_file), &s) != 0){
+	fclose (data_file);
 	return 0;
     }
     data = (char *) g_malloc (s.st_size+1);
@@ -588,6 +634,43 @@ char *load_file (char *filename)
     }
 }
 
+char *load_mc_home_file (const char *filename, char ** allocated_filename)
+{
+    char *hintfile_base, *hintfile;
+    char *lang;
+    char *data;
+
+    hintfile_base = concat_dir_and_file (mc_home, filename);
+    lang = guess_message_value (0);
+
+    hintfile = g_strdup_printf ("%s.%s", hintfile_base, lang);
+    data = load_file (hintfile);
+
+    if (!data) {
+	g_free (hintfile);
+	hintfile = g_strdup_printf ("%s.%.2s", hintfile_base, lang);
+	data = load_file (hintfile);
+
+	if (!data) {
+	    g_free (hintfile);
+	    hintfile = hintfile_base;
+	    data = load_file (hintfile_base);
+	}
+    }
+
+    g_free (lang);
+
+    if (hintfile != hintfile_base)
+	g_free (hintfile_base);
+
+    if (allocated_filename)
+	*allocated_filename = hintfile;
+    else
+	g_free (hintfile);
+
+    return data;
+}
+
 /* Check strftime() results. Some systems (i.e. Solaris) have different
 short-month-name sizes for different locales */ 
 size_t i18n_checktimelength (void)
@@ -613,7 +696,8 @@ char *file_date (time_t when)
     static char timebuf [MAX_I18NTIMELENGTH + 1];
     time_t current_time = time ((time_t) 0);
     static size_t i18n_timelength = 0;
-    static char *fmt, *fmtyear, *fmttime;
+    static char *fmtyear, *fmttime;
+    char *fmt;
 
     if (i18n_timelength == 0){
 	i18n_timelength = i18n_checktimelength() + 1;
@@ -709,31 +793,7 @@ void my_putenv (char *name, char *data)
     /* WARNING: NEVER FREE THE full VARIABLE!!!!!!!!!!!!!!!!!!!!!!!! */
     /* It is used by putenv. Freeing it will corrupt the environment */
 }
-
-#if 0
-static void my_putenv_expand (char *name, char macro_code)
-{
-    char *data;
-
-    data = expand_format (macro_code);
-    my_putenv (name, data);
-    g_free (data);
-}
-
-/* Puts some status information in to the environment so that
-   processes to be executed can access it. */
-static void prepare_environment (void)
-{
-    my_putenv_expand ("MC_CURRENT_DIR", 'd');
-    my_putenv_expand ("MC_OTHER_DIR", 'D');
-    my_putenv_expand ("MC_CURRENT_FILE", 'f');
-    my_putenv_expand ("MC_OTHER_FILE", 'F');
-    my_putenv_expand ("MC_CURRENT_TAGGED", 't');
-    my_putenv_expand ("MC_OTHER_TAGGED", 'T');
-    /* MC_CONTROL_FILE has been added to environment on startup */
-}
-#endif
-#endif /* VFS_STANDALONE */
+#endif /* !VFS_STANDALONE */
 
 char *unix_error_string (int error_num)
 {
@@ -755,13 +815,6 @@ long blocks2kilos (int blocks, int bsize)
 	return blocks;
 }
 
-void init_my_statfs (void)
-{
-#ifndef NO_INFOMOUNT
-    mount_list = read_filesystem_list (1, 1);
-#endif
-}
-
 char *skip_separators (char *s)
 {
     for (;*s; s++)
@@ -788,55 +841,53 @@ char *skip_numbers (char *s)
  * terminfo databases, except the Hewlett-Packard 70092 and some Wyse
  * terminals.  If I hear from a single person who uses such a terminal
  * with MC, I'll be glad to add support for it.  (Dugan)
+ * Non-printable characters are also removed.
  */
 
 char *strip_ctrl_codes (char *s)
 {
-    int i;  /* Current length of the string's correct (stripped) prefix */
-    int j;  /* Number of control characters we have skipped so far */
+    char *w; /* Current position where the stripped data is written */
+    char *r; /* Current position where the original data is read */
 
     if (!s)
 	return 0;
-    
-    for (i = 0, j = 0; s [i+j]; ++i)
-	if (s [i+j] != ESC_CHAR){
-	    if (j)
-		s [i] = s [i+j];
+
+    for (w = s, r = s; *r; ++r)
+	if (*r != ESC_CHAR){
+	    if (is_printable(*r))
+		*w++ = *r;
 	} else {
-	    ++j;
-	    if (s [i+j++] == '[')
-		while (strchr ("0123456789;?", s [i+j++]))
+	    if (*(++r) == '[') {
+		while (strchr ("0123456789;?", *(++r)))
 		    /* Skip the control sequence's arguments */ ;
-	    --i;
+	    }
 	}
-    s[i] = 0;
+    *w = 0;
     return s;
 }
 
-#endif /* VFS_STANDALONE */
+#endif /* !VFS_STANDALONE */
 
-/*
- * Ok, on systems running glibc, getcwd does not use popen pwd on
- * Linux at least
- */
-#ifdef __GLIBC__
-#  ifdef linux
-#     undef HAVE_GETWD
-#  endif
-#endif
-
-/* getwd is better than getcwd, the later uses a popen ("pwd"); */
+#ifndef USE_VFS
 char *get_current_wd (char *buffer, int size)
 {
     char *p;
+    int len;
 
-#ifdef HAVE_GETWD
-    p = (char *) getwd (buffer);
-#else
-    p = getcwd (buffer, size);
-#endif
-    return p;
+    p = g_get_current_dir ();
+    len = strlen(p) + 1;
+
+    if (len > size) {
+	g_free (p);
+	return NULL;
+    }
+
+    strncpy (buffer, p, len);
+    g_free (p);
+
+    return buffer;
 }
+#endif /* !USE_VFS */
 
 #define CHECK(x) if (x == -1) return 0;
 
@@ -1237,7 +1288,7 @@ int my_ftruncate (int fd, long size)
     lk.l_len = 0;
     
     return fcntl (fd, F_FREESP, &lk);
-#endif
+#endif /* !OS2_NT */
 }
 
 int truncate (const char *path, long size)
@@ -1256,8 +1307,8 @@ int truncate (const char *path, long size)
 
 }
 
-#endif
-#endif /* VFS_STANDALONE */
+#endif /* !HAVE_TRUNCATE */
+#endif /* !VFS_STANDALONE */
 
 /* If filename is NULL, then we just append PATH_SEP to the dir */
 char *
@@ -1271,3 +1322,90 @@ concat_dir_and_file (const char *dir, const char *file)
 	return  g_strconcat (dir, PATH_SEP_STR, file, NULL);
 }
 
+/* Following code heavily borrows from libiberty, mkstemps.c */
+
+/* Number of attempts to create a temporary file */
+#ifndef TMP_MAX
+#define TMP_MAX 16384
+#endif /* !TMP_MAX */
+
+/*
+ * Arguments:
+ * pname (output) - pointer to the name of the temp file (needs g_free).
+ *                  NULL if the function fails.
+ * prefix - part of the filename before the random part.
+ *          Prepend $TMPDIR or /tmp if there are no path separators.
+ * suffix - if not NULL, part of the filename after the random part.
+ *
+ * Result:
+ * handle of the open file or -1 if couldn't open any.
+ */
+int mc_mkstemps(char **pname, const char *prefix, const char *suffix)
+{
+    static const char letters[]
+	= "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
+    static unsigned long value;
+    struct timeval tv;
+    char *tmpbase;
+    char *tmpname;
+    char *XXXXXX;
+    int count;
+
+    if (strchr(prefix, PATH_SEP) == NULL) {
+	char *tmpdir;
+
+	tmpdir = getenv("TMPDIR");
+	if (!tmpdir) {
+	    tmpdir = TMPDIR_DEFAULT;
+	}
+
+	/* Add prefix first to find the position of XXXXXX */
+	tmpbase = concat_dir_and_file (tmpdir, prefix);
+    } else {
+	tmpbase = g_strdup (prefix);
+    }
+
+    tmpname = g_strconcat (tmpbase, "XXXXXX", suffix, NULL);
+    *pname = tmpname;
+    XXXXXX = &tmpname[strlen (tmpbase)];
+    g_free(tmpbase);
+
+    /* Get some more or less random data.  */
+    gettimeofday (&tv, NULL);
+    value += (tv.tv_usec << 16) ^ tv.tv_sec ^ getpid ();
+
+    for (count = 0; count < TMP_MAX; ++count) {
+	unsigned long v = value;
+	int fd;
+
+	/* Fill in the random bits.  */
+	XXXXXX[0] = letters[v % 62];
+	v /= 62;
+	XXXXXX[1] = letters[v % 62];
+	v /= 62;
+	XXXXXX[2] = letters[v % 62];
+	v /= 62;
+	XXXXXX[3] = letters[v % 62];
+	v /= 62;
+	XXXXXX[4] = letters[v % 62];
+	v /= 62;
+	XXXXXX[5] = letters[v % 62];
+
+	fd = open (tmpname, O_RDWR|O_CREAT|O_EXCL, 0600);
+	if (fd >= 0) {
+	    /* Successfully created.  */
+	    return fd;
+	}
+
+	/* This is a random value.  It is only necessary that the next
+	 TMP_MAX values generated by adding 7777 to VALUE are different
+	 with (module 2^32).  */
+	value += 7777;
+    }
+
+    /* Unsuccessful. Free the filename. */
+    g_free (tmpname);
+    tmpname = NULL;
+
+    return -1;
+}
