@@ -69,7 +69,6 @@
 #include "x.h"
 
 struct sigaction startup_handler;
-extern struct mount_entry *mount_list;
 
 uid_t current_user_uid;
 user_in_groups *current_user_gid;
@@ -162,19 +161,8 @@ typedef struct {
     char *string;
 } int_cache;
 
-int_cache uid_cache [UID_CACHE_SIZE];
-int_cache gid_cache [GID_CACHE_SIZE];
-
-void init_uid_gid_cache (void)
-{
-    int i;
-
-    for (i = 0; i < UID_CACHE_SIZE; i++)
-	uid_cache [i].string = 0;
-
-    for (i = 0; i < GID_CACHE_SIZE; i++)
-	 gid_cache [i].string = 0;
-}
+static int_cache uid_cache [UID_CACHE_SIZE];
+static int_cache gid_cache [GID_CACHE_SIZE];
 
 static char *i_cache_match (int id, int_cache *cache, int size)
 {
@@ -289,7 +277,7 @@ int my_system (int flags, const char *shell, const char *command)
 #    elif defined (HAVE_SETREUID)
 	    setreuid (vfs_uid, vfs_uid);
 #    else
-	    ; /* Can't drop privileges */
+	    ; /* Cannot drop privileges */
 #    endif
 #endif
 	
@@ -472,7 +460,6 @@ int mc_doublepopen (int inhandle, int inlen, pid_t *the_pid, char *command, ...)
     pid_t pid;
 
 #define closepipes() close(pipe0[0]);close(pipe0[1]);close(pipe1[0]);close(pipe1[1])
-#define is_a_pipe_fd(f) ((pipe0[0] == f) || (pipe0[1] == f) || (pipe1[0] == f) || (pipe1[1] == f))
     
     pipe (pipe0); pipe (pipe1);
     ignore.sa_handler = SIG_IGN;
@@ -493,7 +480,7 @@ int mc_doublepopen (int inhandle, int inlen, pid_t *the_pid, char *command, ...)
 	    switch (pid = fork ()) {
 	    	case -1:
 	    	    closepipes ();
-	    	    exit (1);
+	    	    _exit (1);
 	    	case 0: {
 #define MAXARGS 16
 		     int argno;
@@ -501,8 +488,6 @@ int mc_doublepopen (int inhandle, int inlen, pid_t *the_pid, char *command, ...)
 		     va_list ap;
 		     int nulldevice;
 
-		     port_shutdown_extra_fds ();
-	    
 		     nulldevice = open ("/dev/null", O_WRONLY);
 		     close (0);
 		     dup (pipe0 [0]);
@@ -521,7 +506,9 @@ int mc_doublepopen (int inhandle, int inlen, pid_t *the_pid, char *command, ...)
 		         }
 		     va_end (ap);
 		     execvp (command, args);
-		     exit (0);
+
+		     /* If we are here exec has failed */
+		     _exit (0);
 		}
 	    	default:
 	    	    {
@@ -541,13 +528,13 @@ int mc_doublepopen (int inhandle, int inlen, pid_t *the_pid, char *command, ...)
 				    break;
 			    }
 	    	    	}
+			close (inhandle);
 	    	    	close (pipe0 [1]);
 	   		while (waitpid (pid, &i, 0) < 0)
 			    if (errno != EINTR)
 				break;
 
-			port_shutdown_extra_fds ();
-	   		exit (i);
+	   		_exit (i);
 	    	    }
 	    }
     }
@@ -638,10 +625,6 @@ char *canonicalize_pathname (char *path)
 	    i = start + 1;
 	}
 
-        /* Handle backquoted `/'. */
-        if (start > 0 && path[start - 1] == '\\')
-	    continue;
-
         /* Check for trailing `/'. */
         if (start && !path[i]) {
 	zero_last:
@@ -763,75 +746,6 @@ putenv (const char *string)
 }
 #endif /* !HAVE_PUTENV */
 
-void my_statfs (struct my_statfs *myfs_stats, char *path)
-{
-    int i, len = 0;
-
-#ifndef NO_INFOMOUNT
-    struct mount_entry *entry = NULL;
-    struct mount_entry *temp = mount_list;
-    struct fs_usage fs_use;
-
-    while (temp){
-	i = strlen (temp->me_mountdir);
-	if (i > len && (strncmp (path, temp->me_mountdir, i) == 0))
-	    if (!entry || (path [i] == PATH_SEP || path [i] == 0)){
-		len = i;
-		entry = temp;
-	    }
-	temp = temp->me_next;
-    }
-
-    if (entry){
-	get_fs_usage (entry->me_mountdir, &fs_use);
-
-	myfs_stats->type = entry->me_dev;
-	myfs_stats->typename = entry->me_type;
-	myfs_stats->mpoint = entry->me_mountdir;
-	myfs_stats->device = entry->me_devname;
-	myfs_stats->avail = getuid () ? fs_use.fsu_bavail/2 : fs_use.fsu_bfree/2;
-	myfs_stats->total = fs_use.fsu_blocks/2;
-	myfs_stats->nfree = fs_use.fsu_ffree;
-	myfs_stats->nodes = fs_use.fsu_files;
-    } else
-#endif
-#if defined(NO_INFOMOUNT) && defined(__QNX__)
-/*
-** This is the "other side" of the hack to read_filesystem_list() in
-** mountlist.c.
-** It's not the most efficient approach, but consumes less memory. It
-** also accomodates QNX's ability to mount filesystems on the fly.
-*/
-	struct mount_entry	*entry;
-    struct fs_usage		fs_use;
-
-	if ((entry = read_filesystem_list(0, 0)) != NULL)
-	{
-		get_fs_usage(entry->me_mountdir, &fs_use);
-
-		myfs_stats->type = entry->me_dev;
-		myfs_stats->typename = entry->me_type;
-		myfs_stats->mpoint = entry->me_mountdir;
-		myfs_stats->device = entry->me_devname;
-
-		myfs_stats->avail = fs_use.fsu_bfree / 2;
-		myfs_stats->total = fs_use.fsu_blocks / 2;
-		myfs_stats->nfree = fs_use.fsu_ffree;
-		myfs_stats->nodes = fs_use.fsu_files;
-	}
-	else
-#endif
-    {
-	myfs_stats->type = 0;
-	myfs_stats->mpoint = "unknown";
-	myfs_stats->device = "unknown";
-	myfs_stats->avail = 0;
-	myfs_stats->total = 0;
-	myfs_stats->nfree = 0;
-	myfs_stats->nodes = 0;
-    }
-}
-
 #ifdef HAVE_GET_PROCESS_STATS
 #    include <sys/procstats.h>
 
