@@ -26,8 +26,6 @@
 /* }}} */
 /* {{{ Declarations */
 #include <config.h>
-#include "tty.h"
-#include "x.h"
 #include <stdio.h>
 #ifdef NEEDS_IO_H
 #   include <io.h>
@@ -49,7 +47,11 @@
 #include <errno.h>
 #include <limits.h>
 #include <sys/param.h>
+
 #include "global.h"
+#include "tty.h"
+#include "x.h"
+#include "cmd.h"		/* For view_other_cmd */
 #include "dlg.h"		/* Needed by widget.h */
 #include "widget.h"		/* Needed for buttonbar_new */
 #include "color.h"
@@ -73,6 +75,11 @@
 #define WANT_WIDGETS
 #include "view.h"
 
+#ifdef HAVE_CHARSET
+#include "charsets.h"
+#include "selcodepage.h"
+#endif
+
 #ifndef MAP_FILE
 #define MAP_FILE 0
 #endif
@@ -95,6 +102,10 @@ int max_dirt_limit =
 10;
 #endif
 
+#ifdef HAVE_X
+#define is_idle() 1
+#endif
+
 extern Hook *idle_hook;
 
 /* Our callback */
@@ -102,7 +113,7 @@ static int view_callback (Dlg_head *h, WView *view, int msg, int par);
 static int regexp_view_search (WView *view, char *pattern, char *string, int match_type);
 
 /* If set, show a ruler */
-int ruler = 0;
+static int ruler = 0;
 
 /* Scrolling is done in pages or line increments */
 int mouse_move_pages_viewer = 1;
@@ -122,7 +133,7 @@ int altered_magic_flag = 0;
 int altered_nroff_flag = 0;
 /* }}} */
 
-/* "$Id: view.c,v 1.43 2001/01/08 18:21:37 bansz Exp $" */
+/* "$Id: view.c,v 1.63 2001/08/20 07:46:04 proskin Exp $" */
 
 static const char hex_char[] = "0123456789ABCDEF";
 
@@ -220,17 +231,11 @@ get_byte (WView *view, unsigned int byte_index)
     int page   = byte_index / VIEW_PAGE_SIZE + 1;
     int offset = byte_index % VIEW_PAGE_SIZE;
     int i, n;
-    block_ptr_t *tmp;
-    
+
     if (view->growing_buffer){
 	if (page > view->blocks){
-	    tmp = g_new (block_ptr_t, page);
-	    if (view->block_ptr){
-		bcopy (view->block_ptr, tmp, sizeof (block_ptr_t) *
-		       view->blocks);
-		g_free (view->block_ptr);
-	    } 
-	    view->block_ptr = tmp;
+	    view->block_ptr = g_realloc (view->block_ptr,
+					 sizeof (block_ptr_t) * page);
 	    for (i = view->blocks; i < page; i++){
 		char *p = g_malloc (VIEW_PAGE_SIZE);
 		view->block_ptr [i].data = p;
@@ -240,12 +245,10 @@ get_byte (WView *view, unsigned int byte_index)
 		    n = fread (p, 1, VIEW_PAGE_SIZE, view->stdfile);
 		else
 		    n = mc_read (view->file, p, VIEW_PAGE_SIZE);
-
 /*
  * FIXME: Errors are ignored at this point
  * Also should report preliminary EOF
  */
-
 		if (n != -1)
 		    view->bytes_read += n;
 		if (view->s.st_size < view->bytes_read){
@@ -391,7 +394,7 @@ save_edit_changes (WView *view)
     free_change_list (view);
 }
 
-static int
+int
 view_ok_to_quit (WView *view)
 {
     int r;
@@ -446,7 +449,7 @@ init_growing_view (WView *view, char *name, char *filename)
 	open_error_pipe ();
 	if ((view->stdfile = popen (name, "r")) == NULL){
 	    close_error_pipe (view->have_frame?-1:1, view->data);
-	    return set_view_init_error (view, _(" Can't spawn child program "));
+	    return set_view_init_error (view, _(" Cannot spawn child program "));
 	}
 
 	/* First, check if filter produced any output */
@@ -475,20 +478,20 @@ static char *load_view_file (WView *view, char *filename)
 {
     if ((view->file = mc_open (filename, O_RDONLY)) < 0){
 	set_view_init_error (view, 0);
-	return ( g_strconcat (_(" Can't open file \""),
+	return ( g_strconcat (_(" Cannot open file \""),
 			      filename, "\"\n ",
 			      unix_error_string (errno), " ", NULL));
     }
     if (mc_fstat (view->file, &view->s) < 0){
 	set_view_init_error (view, 0);
 	close_view_file (view);
-	return  g_strconcat (_(" Can't stat file \n "),
+	return  g_strconcat (_(" Cannot stat file \n "),
 			     unix_error_string (errno), " ", NULL);
     }
     if (S_ISDIR (view->s.st_mode) || S_ISSOCK (view->s.st_mode)
 	|| S_ISFIFO (view->s.st_mode)){
 	close_view_file (view);
-	return set_view_init_error (view, _(" Can't view: not a regular file "));
+	return set_view_init_error (view, _(" Cannot view: not a regular file "));
     }
 
     if (view->s.st_size == 0){
@@ -500,16 +503,15 @@ static char *load_view_file (WView *view, char *filename)
 #ifdef HAVE_MMAP
     view->data = mc_mmap (0, view->s.st_size, PROT_READ, MAP_FILE | MAP_SHARED,
 		          view->file, 0);
-    if ((caddr_t) view->data == (caddr_t) -1)
-        goto no_mmap;
+    if ((caddr_t) view->data != (caddr_t) -1) {
+	/* mmap worked */
+	view->first = 0;
+	view->bytes_read = view->s.st_size;
+	view->mmapping = 1;
+	return NULL;
+    }
+#endif /* HAVE_MMAP */
 
-    view->first = 0;
-    view->bytes_read = view->s.st_size;
-    view->mmapping = 1;
-    return NULL;
-#endif
-
-no_mmap:
     /* For those OS that dont provide mmap call. Try to load all the
      * file into memory (alex@bcs.zaporizhzhe.ua). Also, mmap can fail
      * for any reason, so we use this as fallback (pavel@ucw.cz) */
@@ -569,7 +571,7 @@ do_view_init (WView *view, char *_command, const char *_file, int start_line)
 	if ((fd = mc_open(_file, O_RDONLY)) == -1) {
             char tmp[BUF_MEDIUM];
 	    g_snprintf (tmp, sizeof (tmp), 
-                        _(" Can't open \"%s\"\n %s "),
+                        _(" Cannot open \"%s\"\n %s "),
 			_file, unix_error_string (errno));
 	    view->filename = g_strdup (_file);
             error = set_view_init_error (view, tmp);
@@ -578,7 +580,7 @@ do_view_init (WView *view, char *_command, const char *_file, int start_line)
 	if (mc_fstat (fd, &view->s) == -1) {
             char tmp[BUF_MEDIUM];
 	    g_snprintf (tmp, sizeof (tmp), 
-                        _(" Can't stat \"%s\"\n %s "),
+                        _(" Cannot stat \"%s\"\n %s "),
 			_file, unix_error_string (errno));
 	    mc_close(fd);
 	    view->filename = g_strdup (_file);
@@ -601,7 +603,7 @@ do_view_init (WView *view, char *_command, const char *_file, int start_line)
 finish:
     if (error){
 	if (!view->have_frame){
-	    message (1, MSG_ERROR, error);
+	    message (1, MSG_ERROR, "%s", error);
 	    g_free (error);
 	    return -1;
 	}
@@ -718,8 +720,8 @@ view_status (WView *view, gboolean update_gui)
     }
 
     if (w < i18n_adjust + 6)
-    	printw ("%s", name_trunc (view->filename ? view->filename:
-					view->command ? view->command:"", w));
+	addstr (name_trunc (view->filename ? view->filename:
+			    view->command ? view->command:"", w));
     else{
     	i = (w > 22 ? 22 : w ) - i18n_adjust ;
     	printw (file_label, name_trunc (view->filename ? view->filename:
@@ -775,13 +777,11 @@ view_display_clean (WView *view, int height, int width)
 #define view_gotoyx(v,r,c)    widget_move (v,r,c)
 #endif
 
-#ifndef HAVE_TK
 /* Both the text mode and gnome editions use this */
 #define BOLD_COLOR        MARKED_COLOR
 #define UNDERLINE_COLOR   VIEW_UNDERLINED_COLOR
 #define MARK_COLOR        SELECTED_COLOR
 #define DEF_COLOR         NORMAL_COLOR
-#endif
 
 #ifndef PORT_HAS_VIEW_FREEZE
 #    define view_freeze(view)
@@ -842,10 +842,11 @@ display (WView *view)
 	    view_add_character (view, r_buff[0]);
 	    if ((cl != 0) && (cl % 10) == 0){
 		g_snprintf(r_buff, sizeof (r_buff), "%03d", cl);
-		if (ruler == 1)
+		if (ruler == 1) {
 		    widget_move (view, row + 1, c - 1);
-		else
+		} else {
 		    widget_move (view, row + height - 3, c - 1);
+		}
                 view_add_string (view, r_buff);
 	    }   
 	}    
@@ -944,6 +945,10 @@ display (WView *view)
                 /* Print the corresponding ascii character */
 		view_gotoyx (view, row, text_start + bytes);
 		
+#ifdef HAVE_CHARSET
+		c = conv_displ[ c ];
+#endif
+
                 if (!is_printable (c))
                     c = '.';
                 switch (boldflag) {
@@ -1023,6 +1028,11 @@ display (WView *view)
 		&& col < width-view->start_col)
 	    {
 		view_gotoyx (view, row, col+view->start_col);
+
+#ifdef HAVE_CHARSET
+		c = conv_displ[ c ];
+#endif
+
        		if (!is_printable (c))
 		    c = '.';
 
@@ -1038,9 +1048,6 @@ display (WView *view)
 	    if (view->growing_buffer && from+1 == view->last_byte)
 		 get_byte (view, from+1);
         }
-#ifdef HAVE_TK
-	view_gotoyx (view, view->current_line+1, 0);
-#endif
     }
     view->last = from;
     view_thaw (view);
@@ -1403,49 +1410,48 @@ static char *
 get_line_at (WView *view, unsigned long *p, unsigned long *skipped)
 {
     char *buffer = 0;
-    int  buffer_size, usable_size;
-    int  ch = 0;
-    int  direction;
+    int  buffer_size = 0;
+    int  usable_size = 0;
+    int  ch;
+    int  direction = view->direction;
     unsigned long pos = *p;
     long i = 0;
-    int  prev;
+    int  prev = 0;
 
-    direction = view->direction;
-    buffer_size = usable_size = 0;
-    
-    prev = (pos) ? ((prev = get_byte (view, pos - 1) == -1) ? 0 : prev) : 0;
-    *skipped = 0;
-    while ((ch = get_byte (view, pos)) != -1){
+    /* skip over all the possible zeros in the file */
+    while ((ch = get_byte (view, pos)) == 0) {
+	pos += direction; i++;
+    }
+    *skipped = i;
+
+    if (pos) {
+	prev = get_byte (view, pos - 1);
+	if ((prev == -1) || (prev == '\n'))
+	    prev = 0;
+    }
+
+    for (i = 0; ch != -1; ch = get_byte (view, pos)){
 
-	/* skip over all the possible zeros in the file */
-	if (ch == 0 && i == 0){
-	    do {
-		pos += direction; i++;
-	    } while ((ch = get_byte (view, pos)) == 0);
-	    *skipped = i;
-	    i = 0;
-	    if (ch == -1)
-		break;
-	}
 	if (i == usable_size){
 	    buffer = grow_string_buffer (buffer, &buffer_size);
 	    usable_size = buffer_size - 2;
 	}
 
 	pos += direction; i++;
-	buffer [i] = ch;
 
 	if (ch == '\n' || !ch){
 	    break;
 	}
+	buffer [i] = ch;
     }
     if (buffer){
 	buffer [0] = prev;
 	buffer [i] = 0;
-	
+
 	/* If we are searching backwards, reverse the string */
-	if (view->direction < 0)
-	    reverse_string (buffer);
+	if (direction < 0) {
+	    reverse_string (buffer + 1);
+	}
     }
 
     *p = pos;
@@ -1489,11 +1495,13 @@ search (WView *view, char *text, int (*search)(WView *, char *, char *, int))
     char *s = NULL;		/*  The line we read from the view buffer */
     long p, beginning;
     int found_len, search_start;
-    Dlg_head *d = 0;
     int search_status;
 #ifdef HAVE_GNOME
+    char *msg;
     int abort;
     GtkWidget *gd;
+#else
+    Dlg_head *d = 0;
 #endif
     
     /* Used to keep track of where the line starts, when looking forward */
@@ -1507,10 +1515,12 @@ search (WView *view, char *text, int (*search)(WView *, char *, char *, int))
 
 #ifdef HAVE_GNOME
     abort = 0;
-    gd = gnome_message_box_new (_("Searching for `%s'"),
+    msg = g_strdup_printf (_("Searching for `%s'"), text);
+    gd = gnome_message_box_new (msg,
 				GNOME_MESSAGE_BOX_INFO,
 				GNOME_STOCK_BUTTON_CANCEL,
 				NULL);
+    g_free (msg);
     gnome_dialog_button_connect (GNOME_DIALOG (gd), 0, GTK_SIGNAL_FUNC (cancel_pressed), &abort);
     gtk_widget_show (gd);
 #else
@@ -1635,7 +1645,7 @@ block_search (WView *view, char *buffer, int len)
     search_update_steps (view);
     update_activate = 0;
     
-    for (; e < view->last_byte; e++){
+    while (e < view->last_byte){
 	if (e >= update_activate){
 	    update_activate += update_steps;
 	    if (verbose){
@@ -1645,102 +1655,93 @@ block_search (WView *view, char *buffer, int len)
 	    if (got_interrupt ())
 		break;
 	}
-	b = get_byte (view, e);
+	b = get_byte (view, e++);
 	
 	if (*d == b){
 	    d++;
+	    if (d - buffer == len){
+		disable_interrupt_key ();
+		return e - len;
+	    }
 	} else {
 	    e -= d - buffer;
 	    d = buffer;
 	}
-	if (d - buffer == len){
-	    disable_interrupt_key ();
-	    return e - len;
-	}
     }
     disable_interrupt_key ();
     return -1;
 }
 
-/* States of our funny recognizer */
-enum {
-    normal,
-    inside_quotes,
-    zero,
-    hex1,
-    hex2,
-    oct1
-};
-
-/* This routine doesn't report all the user mistakes, it just ignores them */
+/*
+ * Search in the hex mode.  Supported input:
+ * - numbers (oct, dec, hex).  Each of them matches one byte.
+ * - strings in double quotes.  Matches exactly without quotes.
+ */
 static void
 hex_search (WView *view, char *text)
 {
-    char buffer [120];		/* Where we hold the information */
-    int  i, block_len;
-    int  v = 0;
+    char *buffer;		/* Where we hold the information */
     long pos;			/* Where did we found the string */
-    char *p;			/* Temporary */
-    int  state = normal;	/* Initial state of the micro-scanner */
-    
-    /* First convert the string to a stream of bytes */
-    for (i = block_len = 0; text [i] && block_len < sizeof (buffer); i++){
-	switch (state){
-	case inside_quotes:
-	    if (text [i] == '"')
-		state = normal;
-	    else
-		buffer [block_len++] = text [i];
-	    break;
+    int  block_len = 0;
+    int  parse_error = 0;
 
-	case normal:
-	    if (text [i] == '"'){
-		state = inside_quotes;
-		break;
-	    }
-	    if (text [i] == '0'){
-		state = zero;
-		break;
-	    }
-	    if (text [i] == 'x'){
-		state = hex1;
-		break;
-	    }
-	    break;
-
-	case zero:
-	    if (text [i] == 'x')
-		state = hex1;
-	    break;
-
-	case hex1:
-	    v = 0;
-	    text [i] = toupper (text [i]);
-	    if ((p = strchr (hex_char, text [i])) != 0){
-		v = (p - hex_char) << 4;
-		state = hex2;
-	    }
-	    break;
-
-	case hex2:
-	    text [i] = toupper (text [i]);
-	    if ((p = strchr (hex_char, text [i])) != 0){
-		v |= (p - hex_char);
-		state = normal;
-	    }
-	    buffer [block_len++] = v;
-	    break;
-	}
+    if (!*text) {
+	view->found_len = 0;
+	return;
     }
+
+    /* buffer will never be longer that text */
+    buffer = g_new (char, strlen (text));
+
+    /* First convert the string to a stream of bytes */
+    while (*text) {
+	int val;
+	int ptr;
+
+	/* %i matches octal, decimal, and hexadecimal numbers */
+	if (sscanf (text, "%i%n", &val, &ptr) > 0) {
+	    /* Allow signed and unsigned char in the user input */
+	    if (val < -128 || val > 255) {
+		parse_error = 1;
+		break;
+	    }
+
+	    buffer [block_len++] = (char) val;
+	    text += ptr;
+	    continue;
+	}
+
+	/* Try quoted string, strip quotes */
+	if (sscanf (text, "\"%[^\"]\"%n", buffer + block_len, &ptr) > 0) {
+	    text += ptr;
+	    block_len += ptr - 2;
+	    continue;
+	}
+
+	parse_error = 1;
+	break;
+    }
+
+    /* No valid bytes in the user input */
+    if (block_len <= 0 || parse_error) {
+	message (0, _(" Search "), _("Invalid hex search expression"));
+	g_free (buffer);
+	view->found_len = 0;
+	return;
+    }
+
     /* Then start the search */
     pos = block_search (view, buffer, block_len);
+
+    g_free (buffer);
+
     if (pos == -1){
 	message (0, _(" Search "), _(" Search string not found "));
 	view->found_len = 0;
 	return;
     }
     
-    view->search_start = pos + 1;
+    view->search_start = pos;
     view->found_len = block_len;
     /* Set the edit cursor to the search position, left nibble */
     view->edit_cursor = view->search_start;
@@ -1816,11 +1817,9 @@ static void do_normal_search (void *xview, char *text)
 /* {{{ Mouse and keyboard handling */
 
 /* Real view only */
-static void help_cmd (void)
+static void view_help_cmd (void)
 {
-    char *hlpfile = concat_dir_and_file (mc_home, _("mc.hlp"));
-    interactive_display (hlpfile, "[Internal File Viewer]");
-    g_free (hlpfile);
+    interactive_display (NULL, "[Internal File Viewer]");
     /*
     view_refresh (0);
     */
@@ -1914,7 +1913,7 @@ goto_line (WView *view)
 }
 
 /* Hex view */
-void
+static void
 goto_addr (WView *view)
 {
     char *line, *error, prompt [BUF_SMALL];
@@ -1989,6 +1988,12 @@ normal_search (WView *view, int direction)
     char *exp = "";
 
     exp = old ? old : exp;
+
+#ifdef HAVE_CHARSET
+    if ( *exp )
+	convert_to_display( exp );
+#endif
+
     exp = input_dialog (_(" Search "), _(" Enter search string:"), exp);
     if ((!exp)){
 	return;
@@ -2001,6 +2006,10 @@ normal_search (WView *view, int direction)
 	g_free (old);
     old = exp;
 
+#ifdef HAVE_CHARSET
+    convert_from_input( exp );
+#endif
+
     view->direction = direction;
     do_normal_search (view, exp);
     view->last_search = do_normal_search;
@@ -2063,7 +2072,7 @@ view_labels (WView *view)
 {
     Dlg_head *h = view->widget.parent;
     
-    define_label (h, (Widget *) view, 1, _("Help"), help_cmd);
+    define_label (h, (Widget *) view, 1, _("Help"), view_help_cmd);
     
     my_define (h, 10, _("Quit"), view_quit_cmd, view);
     my_define (h, 4, view->hex_mode ? _("Ascii"): _("Hex"), toggle_hex_mode, view);
@@ -2141,7 +2150,13 @@ view_handle_key (WView *view, int c)
     int prev_monitor = view->monitor;
 
     set_monitor (view, off);
-    
+
+#ifdef HAVE_CHARSET
+    if (c >= 128 && c <= 255) {
+ 	c = conv_input[ c ];
+    }
+#endif
+
     if (view->hex_mode) {
         switch (c) {
         case 0x09:		/* Tab key */
@@ -2267,9 +2282,16 @@ view_handle_key (WView *view, int c)
         view_move_forward (view, vheight - 1);
         return 1;
 
+#ifndef HAVE_X
+    case XCTRL('o'):
+	view_other_cmd ();
+	return 1;
+
+    /* Unlike Ctrl-O, run a new shell if the subshell is not running.  */
     case '!':
 	exec_shell ();
 	return 1;
+#endif /* !HAVE_X */
 	
     case 'F':
 	set_monitor (view, on);
@@ -2311,6 +2333,14 @@ view_handle_key (WView *view, int c)
 	    view->view_quit = 1;
 	return 1;
 
+#ifdef HAVE_CHARSET
+    case XCTRL('t'):
+	do_select_codepage();
+	view->dirty++;
+	view_update( view, TRUE );
+	return 1;
+#endif
+
     }
     if (c >= '0' && c <= '9')
 	view->marker = c - '0';
@@ -2374,13 +2404,13 @@ real_view_event (Gpm_Event *event, void *x)
 /* }}} */
 /* {{{ Window creation, destruction and a driver stub for real view */
 
+#ifndef PORT_WANTS_VIEW
 static int
 view_mode_callback (struct Dlg_head *h, int id, int msg)
 {
     return default_dlg_callback (h, id, msg);
 }
 
-#ifndef PORT_WANTS_VIEW
 void
 view_adjust_size (Dlg_head *h)
 {
@@ -2537,27 +2567,19 @@ view_callback (Dlg_head *h, WView *view, int msg, int par)
 WView *
 view_new (int y, int x, int cols, int lines, int is_panel)
 {
-    WView *view = g_new (WView, 1);
+    WView *view = g_new0 (WView, 1);
     
     init_widget (&view->widget, y, x, lines, cols,
 		 (callback_fn) view_callback,
 		 (destroy_fn) view_destroy,
 		 (mouse_h) real_view_event, NULL);
 
-    view->filename = 0;
-    view->view_active = 0;
-    view->bottom_first = 0;
-    view->start_col = 0;
-    view->dirty = 0;
     view->hex_mode = default_hex_mode;
     view->hexedit_mode = default_hexedit_mode;
     view->viewer_magic_flag = default_magic_flag;
     view->viewer_nroff_flag = default_nroff_flag;
-    view->view_quit = 0;
-    view->move_dir = 0;
     view->have_frame = is_panel;
     view->last_byte = -1;
-    view->monitor = 0;
     view->wrap_mode = global_wrap_mode;
     
     x_init_view (view);
