@@ -67,7 +67,7 @@
 #endif
 
 #ifndef PORT_HAS_RADIO_TOGGLE
-#   define x_radio_toggle
+#   define x_radio_toggle(r)
 #endif
 
 static int button_event (Gpm_Event *event, WButton *b);
@@ -229,7 +229,7 @@ button_len (const char *text, unsigned int flags)
  * and shifting data past it to the left results to one unused byte.
  * This does not harm though :)
  */
-void
+static void
 button_scan_hotkey(WButton* b)
 {
     char* cp = strchr (b->text, '&');
@@ -385,16 +385,6 @@ radio_callback (Dlg_head *h, WRadio *r, int Msg, int Par)
     return default_proc (h, Msg, Par);
 }
 
-#ifdef HAVE_TK
-    static void Radio_destroy (WRadio *r)
-    {
-	x_destroy_cmd (r);
-    }
-#   define radio_destroy (destroy_fn) Radio_destroy
-#else
-#   define radio_destroy 0
-#endif
-
 static int
 radio_event (Gpm_Event *event, WRadio *r)
 {
@@ -430,7 +420,7 @@ radio_new (int y, int x, int count, char **texts, int use_hotkey, char *tkname)
     }
 
     init_widget (&r->widget, y, x, count, max, (callback_fn) radio_callback,
-		 radio_destroy, (mouse_h) radio_event, tkname);
+		 0, (mouse_h) radio_event, tkname);
     r->state = 1;
     r->pos = 0;
     r->sel = 0;
@@ -637,7 +627,7 @@ label_destroy (WLabel *l)
 }
 
 WLabel *
-label_new (int y, int x, char *text, char *tkname)
+label_new (int y, int x, const char *text, char *tkname)
 {
     WLabel *l = g_new (WLabel, 1);
 
@@ -1300,7 +1290,7 @@ backward_word (WInput *in)
     in->point = p - in->buffer;
 }
 
-#ifdef __linux__
+#ifndef HAVE_X
 static void
 key_left (WInput *in)
 {
@@ -1321,7 +1311,7 @@ key_right (WInput *in)
 #else
 #define key_left  backward_char
 #define key_right forward_char
-#endif
+#endif /* HAVE_X */
     
 static void
 backward_delete (WInput *in)
@@ -1594,9 +1584,6 @@ handle_char (WInput *in, int c_code)
 
     v = 0;
 
-#ifdef HAVE_TK    
-    in->inserted_one = 0;
-#endif
     if (quote){
     	free_completions (in);
 	v = insert_char (in, c_code);
@@ -1663,6 +1650,7 @@ input_callback (Dlg_head *h, WInput *in, int Msg, int Par)
 	return x_create_input (h, h->wdata, in);
 
     case WIDGET_KEY:
+#ifndef HAVE_X
 	if (Par == XCTRL('q')){
 	    int v;
 	    
@@ -1671,6 +1659,7 @@ input_callback (Dlg_head *h, WInput *in, int Msg, int Par)
 	    quote = 0;
 	    return v;
 	}
+#endif /* !HAVE_X */
 	if (Par == KEY_UP || Par == KEY_DOWN ||
 	    Par == ESC_CHAR || Par == KEY_F(10) ||
 	    Par == XCTRL('g'))
@@ -1691,7 +1680,7 @@ input_callback (Dlg_head *h, WInput *in, int Msg, int Par)
     case WIDGET_CURSOR:
 	widget_move (&in->widget, 0, in->point - in->first_shown);
 	return 1;
-#endif
+#endif /* !HAVE_X */
 	
     }
     return default_proc (h, Msg, Par);
