@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include <config.h>
 #include "tty.h"
@@ -31,8 +31,9 @@
 #include "key.h"		/* XCTRL and ALT macros  */
 #include "layout.h"
 
-/* "$Id: win.c,v 1.5 1999/01/27 01:09:42 timur Exp $" */
+/* "$Id: win.c,v 1.7 2001/06/06 21:41:44 proskin Exp $" */
 
+#ifndef HAVE_X
 typedef void (*fnptr)(void);
 
 typedef struct Fkey_Table_List {
@@ -43,7 +44,6 @@ typedef struct Fkey_Table_List {
 
 static Fkey_Table_List *fkey_table_list = NULL;
 
-#ifndef HAVE_X
 /* Width of output is always seven characters */
 void sprint_bytesize (char *buffer, int size, int scale)
 {
@@ -68,7 +68,6 @@ void print_bytesize (int size, int scale)
     sprint_bytesize (buffer, size, scale);
     printw (buffer);
 }
-#endif
 
 /* Return values: 0 = not a fkey, other = was a fkey */
 int check_fkeys (int c)
@@ -119,6 +118,7 @@ int check_fkeys (int c)
     else
 	return 0;
 }
+#endif /* !HAVE_X */
 
 /* Return values: 0 = not a movement key, 1 = was a movement key */
 int check_movement_keys (int c, int additional, int page_size, void *data,
@@ -182,15 +182,14 @@ int check_movement_keys (int c, int additional, int page_size, void *data,
     return 0;
 }
 
-#ifdef HAVE_X
-void mc_raw_mode (void)
+/* Classification routines */
+int is_abort_char (int c)
 {
+    return (c == XCTRL('c') || c == XCTRL('g') || c == ESC_CHAR ||
+	    c == KEY_F(10));
 }
 
-void mc_noraw_mode (void)
-{
-}
-#else
+#ifndef HAVE_X
 void mc_raw_mode (void)
 {
     raw ();
@@ -200,14 +199,6 @@ void mc_noraw_mode (void)
 {
     noraw ();
 }
-#endif
-
-/* Classification routines */
-int is_abort_char (int c)
-{
-    return (c == XCTRL('c') || c == XCTRL('g') || c == ESC_CHAR ||
-	    c == KEY_F(10));
-}
 
 int is_quit_char (int c)
 {
@@ -286,3 +277,4 @@ int lookup_key (char *keyname)
     return 0;
 }
 
+#endif /* !HAVE_X */
