@@ -28,7 +28,7 @@
 
 /* }}} */
 
-/*  [] = "$Id: wtools.c,v 1.19 2000/08/22 22:50:16 proskin Exp $" */
+/*  [] = "$Id: wtools.c,v 1.25 2001/06/20 17:12:47 proskin Exp $" */
 
 #include <config.h>
 #include <string.h>
@@ -51,14 +51,11 @@
 /* }}} */
 
 /* {{{ Common dialog callback */
-#ifdef HAVE_X
-void dialog_repaint (struct Dlg_head *h, int back, int title_fore)
-{
-}
-#else
+
 void
 dialog_repaint (struct Dlg_head *h, int back, int title_fore)
 {
+#ifndef HAVE_X
     attrset (back);
     dlg_erase (h);
     draw_box (h, 1, 1, h->lines - 2, h->cols - 2);
@@ -67,8 +64,9 @@ dialog_repaint (struct Dlg_head *h, int back, int title_fore)
 	dlg_move (h, 1, (h->cols-strlen (h->title))/2);
 	addstr (h->title);
     }
-}
 #endif
+}
+
 void
 common_dialog_repaint (struct Dlg_head *h)
 {
@@ -86,19 +84,17 @@ common_dialog_callback (struct Dlg_head *h, int id, int msg)
 /* }}} */
 /* {{{ Listbox utility functions */
 
-static void
-listbox_refresh (Dlg_head *h)
-{
-    dialog_repaint (h, COLOR_NORMAL, COLOR_HOT_NORMAL);
-}
+#ifdef HAVE_X
+#define listbox_refresh(h)
+#else
+#define listbox_refresh(h)	common_dialog_repaint(h)
+#endif
 
 static int listbox_callback (Dlg_head *h, int id, int msg)
 {
     switch (msg) {
     case DLG_DRAW:
-#ifndef HAVE_X
         listbox_refresh(h);
-#endif
         return 1;
     }
     return 0;
@@ -137,9 +133,7 @@ Listbox *create_listbox_window (int cols, int lines, char *title, char *help)
 		button_new (lines+3, (cols/2 + 2) - len/2, 
 		B_CANCEL, NORMAL_BUTTON, cancel_string, 0, 0, "c"));
     add_widget (listbox->dlg, listbox->list);
-#ifndef HAVE_X
     listbox_refresh(listbox->dlg);
-#endif /* !HAVE_X */
     return listbox;
 }
 
@@ -170,12 +164,12 @@ struct text_struct {
 
 static int query_callback (struct Dlg_head *h, int Id, int Msg)
 {
+#ifndef HAVE_X    
     struct text_struct *info;
 
     info = (struct text_struct *) h->data;
     
     switch (Msg){
-#ifndef HAVE_X    
     case DLG_DRAW:
 	/* designate window */
 	attrset (NORMALC);
@@ -185,8 +179,8 @@ static int query_callback (struct Dlg_head *h, int Id, int Msg)
 	dlg_move (h, 1, (h->cols-strlen (info->header))/2);
 	addstr (info->header);
 	break;
-#endif
     }
+#endif
     return 0;
 }
 
@@ -219,14 +213,14 @@ int query_dialog (char *header, char *text, int flags, int count, ...)
     query_colors [3] = (flags & D_ERROR) ? COLOR_HOT_NORMAL :  COLOR_HOT_FOCUS;
     
     if (header == MSG_ERROR)
-	    header = _(" Error ");
+	header = _(" Error ");
     
     if (count > 0){
 	va_start (ap, count);
 	for (i = 0; i < count; i++)
 	{
 		char* cp = va_arg (ap, char *);
-	    win_len += strlen (cp) + 6;
+		win_len += strlen (cp) + 6;
 		if (strchr (cp, '&') != NULL)
 			win_len--;
 	}
@@ -286,18 +280,12 @@ int query_dialog (char *header, char *text, int flags, int count, ...)
 	destroy_dlg (query_dlg);
     } else {
 #ifdef HAVE_X
-	add_widgetl (query_dlg, button_new(0, 0, B_EXIT, NORMAL_BUTTON, _("&Ok"), 0, 0, NULL),
-	    XV_WLAY_CENTERROW);
+	add_widget (query_dlg, button_new(0, 0, B_EXIT, NORMAL_BUTTON,
+					  _("&Ok"), 0, 0, NULL));
 
 	add_widget (query_dlg, label_new (2, 3, text, NULL));
-#ifdef HAVE_TK
-	if (flags & D_INSERT){
-	} else
-#endif
-	{
-	    run_dlg (query_dlg);
-	    destroy_dlg (query_dlg);
-	}
+	run_dlg (query_dlg);
+	destroy_dlg (query_dlg);
 #else
 	add_widget (query_dlg, label_new (2, 3, text, NULL));
 	add_widget (query_dlg, button_new(0, 0, 0, HIDDEN_BUTTON, "-", 0, 0, NULL));
@@ -318,7 +306,7 @@ void query_set_sel (int new_sel)
 /* {{{ The message function */
 
 /* To show nice messages to the users */
-Dlg_head *message (int error, char *header, char *text, ...)
+Dlg_head *message (int error, char *header, const char *text, ...)
 {
     va_list  args;
     char     buffer [4096];
@@ -327,7 +315,7 @@ Dlg_head *message (int error, char *header, char *text, ...)
     /* Setup the display information */
     strcpy (buffer, "\n");
     va_start (args, text);
-    g_vsnprintf (&buffer [1], sizeof (buffer), text, args);
+    g_vsnprintf (&buffer [1], sizeof (buffer) - 1, text, args);
     strcat (buffer, "\n");
     va_end (args);
     
@@ -405,10 +393,11 @@ void destroy_chooser (Chooser *c)
 
 /* {{{ Quick dialog routines */
 
+#ifndef HAVE_X
+
 static int quick_callback (struct Dlg_head *h, int id, int Msg)
 {
     switch (Msg){
-#ifndef HAVE_X    
     case DLG_DRAW:
 	attrset (COLOR_NORMAL);
 	dlg_erase (h);
@@ -418,7 +407,6 @@ static int quick_callback (struct Dlg_head *h, int id, int Msg)
 	dlg_move (h, 1,((h->cols-strlen (h->data))/2));
 	addstr (h->data);
 	break;
-#endif	
     case DLG_KEY:
 	if (id == '\n'){
 	    h->ret_value = B_ENTER;
@@ -467,12 +455,8 @@ int quick_dialog_skip (QuickDialog *qd, int nskip)
     dd->data  = qd->title;
 
     for (qw = qd->widgets; qw->widget_type; qw++){
-#ifdef HAVE_X
-	xpos = ypos = 0;
-#else
 	xpos = (qd->xlen * qw->relative_x)/qw->x_divisions;
 	ypos = (qd->ylen * qw->relative_y)/qw->y_divisions;
-#endif
 	
 	switch (qw->widget_type){
 	case quick_checkbox:
@@ -511,7 +495,7 @@ int quick_dialog_skip (QuickDialog *qd, int nskip)
 	    break;
 	}
 	qw->the_widget = widget;
-	add_widgetl (dd, widget, qw->layout);
+	add_widget (dd, widget);
     }
 
     while (nskip--)
@@ -552,18 +536,17 @@ int quick_dialog (QuickDialog *qd)
 
 /* {{{ Input routines */
 
-#ifndef HAVE_GNOME
 #define INPUT_INDEX 2
 char *real_input_dialog_help (char *header, char *text, char *help, char *def_text)
 {
     QuickDialog Quick_input;
     QuickWidget quick_widgets [] = {
     { quick_button, 6, 10, 1, 0, N_("&Cancel"), 0, B_CANCEL, 0, 0,
-	  XV_WLAY_RIGHTOF, "button-cancel" },
+	  "button-cancel" },
     { quick_button, 3, 10, 1, 0, N_("&Ok"), 0, B_ENTER, 0, 0,
-	  XV_WLAY_CENTERROW, "button-ok" },
-    { quick_input,  4, 80, 0, 0, "", 58, 0, 0, 0, XV_WLAY_NEXTROW, 0 },
-    { quick_label,  3, 80, 2, 0, "", 0, 0, 0, 0, XV_WLAY_NEXTROW, "label" },
+	  "button-ok" },
+    { quick_input,  4, 80, 0, 0, "", 58, 0, 0, 0, 0 },
+    { quick_label,  3, 80, 2, 0, "", 0, 0, 0, 0, "label" },
     { 0 } };
     
     int len;
@@ -584,7 +567,8 @@ char *real_input_dialog_help (char *header, char *text, char *help, char *def_te
     
     /* Translators should take care as "Password" or its translations
     are used to identify password boxes and hide characters with "*" */
-    if (strncmp (text, _("Password:"), strlen (_("Password:"))-1) == 0){
+    my_str = _("Password:");
+    if (strncmp (text, my_str, strlen (my_str)-1) == 0){
 	quick_widgets [INPUT_INDEX].value = 1;
 	tk_name[3]=0;
     } else {
@@ -626,7 +610,7 @@ char *real_input_dialog_help (char *header, char *text, char *help, char *def_te
     } else
 	return 0;
 }
-#endif
+#endif /* !HAVE_X */
 
 char *input_dialog (char *header, char *text, char *def_text)
 {
@@ -644,8 +628,7 @@ char *input_expand_dialog (char *header, char *text, char *def_text)
 	if (expanded){
 	    g_free (result);
 	    return expanded;
-	} else 
-	    return result;
+	}
     }
     return result;
 }
