@@ -3,7 +3,7 @@
    
    Written by: 2000 Jan Hudec
 
-   $Id: cpio.c,v 1.5 2000/04/05 13:08:43 pavel Exp $
+   $Id: cpio.c,v 1.14 2001/08/19 03:38:53 proskin Exp $
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License
@@ -17,16 +17,13 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
+#include <config.h>
 #include "xdirentry.h"
-#include "../src/util.h"
+#include "utilvfs.h"
 #include <glib.h>
 #include <errno.h>
-#ifdef SCO_FLAVOR
-#include <sys/timeb.h>
-#endif /* SCO_FLAVOR */
-#include <time.h>
 
 /* #include "utilvfs.h" */
 
@@ -101,12 +98,13 @@ static int cpio_create_entry(vfs *me, vfs_s_super *super, struct stat *stat, cha
 static int cpio_read(void *fh, char *buffer, int count);
 
 #define CPIO_POS(super) cpio_position
-//#define CPIO_POS(super) (super)->u.cpio.fd /* If some time reentrancy should be needed */
+/* If some time reentrancy should be needed change it to */
+/* #define CPIO_POS(super) (super)->u.cpio.fd */
 
 #define CPIO_SEEK_SET(super, where) mc_lseek((super)->u.cpio.fd, CPIO_POS(super) = (where), SEEK_SET)
 #define CPIO_SEEK_CUR(super, where) mc_lseek((super)->u.cpio.fd, CPIO_POS(super) += (where), SEEK_SET)
 
-struct defer_inode * defer_find(struct defer_inode *l, struct defer_inode *i)
+static struct defer_inode * defer_find(struct defer_inode *l, struct defer_inode *i)
 {
     if(!l) return NULL;
     return l->inumber == i->inumber && l->device == i->device ? l : 
@@ -122,6 +120,9 @@ static int cpio_skip_padding(vfs_s_super *super)
     case CPIO_NEWC:
     case CPIO_CRC:
 	return CPIO_SEEK_CUR(super, (4 - (CPIO_POS(super) % 4)) % 4);
+    default:
+	g_assert_not_reached();
+	return 42; /* & the compiler is happy :-) */
     }
 }
 
@@ -182,8 +183,7 @@ static int cpio_open_cpio_file(vfs *me, vfs_s_super *super, char *name)
 
 static int cpio_read_head(vfs *me, vfs_s_super *super)
 {
-    cpio_find_head(me, super);
-    switch(super->u.cpio.type) {
+    switch(cpio_find_head(me, super)) {
     case CPIO_UNKNOWN:
 	return -1;
     case CPIO_BIN:
@@ -528,7 +528,7 @@ static int cpio_open_archive(vfs *me, vfs_s_super *super, char *name, char *op)
 }
 
 /* Remaining functions are exactly same as for tarfs (and were in fact just copied) */
-void *cpio_super_check(vfs *me, char *archive_name, char *op)
+static void *cpio_super_check(vfs *me, char *archive_name, char *op)
 {
     static struct stat sb;
     if(mc_stat(archive_name, &sb))
@@ -536,7 +536,7 @@ void *cpio_super_check(vfs *me, char *archive_name, char *op)
     return &sb;
 }
 
-int cpio_super_same(vfs *me, struct vfs_s_super *parc, char *archive_name, char *op, void *cookie)
+static int cpio_super_same(vfs *me, struct vfs_s_super *parc, char *archive_name, char *op, void *cookie)
 {	
     struct stat *archive_stat = cookie;	/* stat of main archive */
 
@@ -613,7 +613,7 @@ static struct vfs_s_data cpiofs_data = {
 
 vfs vfs_cpiofs_ops = {
     NULL, /* next pointer */
-    "CPIO dearchiver",
+    "cpiofs",
     0, /* flags */
     "ucpio", /* prefix */
     &cpiofs_data, /* vfs_s_data */
