@@ -3,7 +3,7 @@
  *
  * Written at 1998 by Pavel Machek <pavel@ucw.cz>, distribute under LGPL.
  *
- * $Id: direntry.c,v 1.34 2000/10/31 15:43:49 pavel Exp $
+ * $Id: direntry.c,v 1.38 2001/08/16 22:23:05 proskin Exp $
  *
  * Very loosely based on tar.c from midnight and archives.[ch] from
  * avfs by Miklos Szeredi (mszeredi@inf.bme.hu)
@@ -26,7 +26,7 @@
  * Paths here do _not_ begin with '/', so root directory of
  * archive/site is simply "". Beware. */
 
-static volatile int total_inodes = 0, total_entries = 0;
+#include <config.h>
 
 #include "utilvfs.h"
 #include "xdirentry.h"
@@ -34,6 +34,8 @@ static volatile int total_inodes = 0, total_entries = 0;
 
 #define CALL(x) if (MEDATA->x) MEDATA->x
 
+static volatile int total_inodes = 0, total_entries = 0;
+
 vfs_s_inode *
 vfs_s_new_inode (vfs *me, vfs_s_super *super, struct stat *initstat)
 {
@@ -76,7 +78,7 @@ vfs_s_new_entry (vfs *me, char *name, vfs_s_inode *inode)
     return entry;
 }
 
-void
+static void
 vfs_s_free_inode (vfs *me, vfs_s_inode *ino)
 {
     if (!ino)
@@ -406,7 +408,7 @@ vfs_s_new_super (vfs *me)
     return super;
 }
 
-void
+static void
 vfs_s_insert_super (vfs *me, vfs_s_super *super)
 {
     super->next = MEDATA->supers;
@@ -428,10 +430,12 @@ vfs_s_free_super (vfs *me, vfs_s_super *super)
 #if 0
     /* FIXME: We currently leak small ammount of memory, sometimes. Fix it if you can. */
     if (super->ino_usage)
-	message_1s1d (1, _(" Direntry warning "), _("Super ino_usage is %d, memory leak"), super->ino_usage);
+	message_1s1d (1, " Direntry warning ",
+			 "Super ino_usage is %d, memory leak",
+			 super->ino_usage);
 
     if (super->want_stale)
-	message_1s (1, _(" Direntry warning "), _("Super has want_stale set"));
+	message_1s (1, " Direntry warning ", "Super has want_stale set");
 #endif
 
     if (super->prevp){
@@ -754,6 +758,7 @@ vfs_s_open (vfs *me, char *file, int flags, int mode)
 	char *dirname, *name, *save;
 	vfs_s_entry *ent;
 	vfs_s_inode *dir;
+	int tmp_handle;
 	if (!(flags & O_CREAT))
 	    return NULL;
 
@@ -766,7 +771,10 @@ vfs_s_open (vfs *me, char *file, int flags, int mode)
 	ent = vfs_s_generate_entry (me, name, dir, 0755);
 	ino = ent->ino;
 	vfs_s_insert_entry (me, dir, ent);
-	ino->localname = g_tempnam (NULL, me->name);
+	tmp_handle = mc_mkstemps (&ino->localname, me->name, NULL);
+	if (tmp_handle == -1)
+	    return NULL;
+	close (tmp_handle);
 	was_changed = 1;
     }
 
@@ -935,9 +943,8 @@ vfs_s_retrieve_file(vfs *me, struct vfs_s_inode *ino)
     memset(&fh, 0, sizeof(fh));
     
     fh.ino = ino;
-    if (!(ino->localname = g_tempnam (NULL, me->name))) ERRNOR (ENOMEM, 0);
 
-    handle = open(ino->localname, O_RDWR | O_CREAT | O_TRUNC | O_EXCL, 0600);
+    handle = mc_mkstemps (&ino->localname, me->name, NULL);
     if (handle == -1) {
 	me->verrno = errno;
 	goto error_4;
@@ -1185,20 +1192,3 @@ vfs_s_get_line_interruptible (vfs *me, char *buffer, int size, int fd)
     buffer [size-1] = 0;
     return 0;
 }
-
-
-/* Roland: on most non-GNU/Linux platforms malloc()!=g_malloc() which 
- * may cause crashes. This wrapper ensures that memory from tempnam 
- * can safely free'ed with g_free() 
- */
-char *
-g_tempnam( const char *dir, const char *prefix )
-{
-    char *tmp = (char *)tempnam( dir, prefix );
-    char *name;
-    
-    name = g_strdup( tmp );
-    free( tmp );
-    return( name );
-}
-
