@@ -5,7 +5,7 @@
    Rewritten by: 1998 Pavel Machek
    Additional changes by: 1999 Andrew T. Veliath
 
-   $Id: extfs.c,v 1.36 2001/02/20 16:55:58 proskin Exp $
+   $Id: extfs.c,v 1.44 2001/08/16 20:43:47 proskin Exp $
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License
@@ -47,6 +47,40 @@
 #undef ERRNOR
 #define ERRNOR(x,y) do { my_errno = x; return y; } while(0)
 
+struct inode {
+    nlink_t nlink;
+    struct entry *first_in_subdir; /* only used if this is a directory */
+    struct entry *last_in_subdir;
+    ino_t inode;        /* This is inode # */
+    dev_t dev;		/* This is an internal identification of the extfs archive */
+    struct archive *archive; /* And this is an archive structure */
+    dev_t rdev;
+    mode_t mode;
+    uid_t uid;
+    gid_t gid;
+    int size;
+    time_t mtime;
+    char linkflag;
+    char *linkname;
+    time_t atime;
+    time_t ctime;
+    char *local_filename;
+};
+
+struct entry {
+    struct entry *next_in_dir;
+    struct entry *dir;
+    char *name;
+    struct inode *inode;
+};
+
+struct pseudofile {
+    struct archive *archive;
+    unsigned int has_changed:1;
+    int local_handle;
+    struct entry *entry;
+};
+
 static struct entry *
 find_entry (struct entry *dir, char *name, int make_dirs, int make_file);
 static int extfs_which (vfs *me, char *path);
@@ -84,7 +118,6 @@ static void make_dot_doubledot (struct entry *ent)
     
     parent = (parentry != NULL) ? parentry->inode : NULL;
     entry->name = g_strdup (".");
-    entry->has_changed = 0;
     entry->inode = inode;
     entry->dir = ent;
     inode->local_filename = NULL;
@@ -94,7 +127,6 @@ static void make_dot_doubledot (struct entry *ent)
     entry->next_in_dir = g_new (struct entry, 1);
     entry=entry->next_in_dir;
     entry->name = g_strdup ("..");
-    entry->has_changed = 0;
     inode->last_in_subdir = entry;
     entry->next_in_dir = NULL;
     if (parent != NULL) {
@@ -119,7 +151,6 @@ static struct entry *generate_entry (struct archive *archive,
     entry = g_new (struct entry, 1);
     
     entry->name = g_strdup (name);
-    entry->has_changed = 0;
     entry->next_in_dir = NULL;
     entry->dir = parentry;
     if (parent != NULL) {
@@ -128,7 +159,6 @@ static struct entry *generate_entry (struct archive *archive,
     }
     inode = g_new (struct inode, 1);
     entry->inode = inode;
-    inode->has_changed = 0;
     inode->local_filename = NULL;
     inode->linkname = 0;
     inode->inode = (archive->__inode_counter)++;
@@ -305,7 +335,6 @@ static int read_archive (int fstype, char *name, struct archive **pparc)
                 }
 		entry = g_new (struct entry, 1);
 		entry->name = g_strdup (p);
-		entry->has_changed = 0;
 		entry->next_in_dir = NULL;
 		entry->dir = pent;
 		if (pent != NULL) {
@@ -330,7 +359,6 @@ static int read_archive (int fstype, char *name, struct archive **pparc)
 		    inode = g_new (struct inode, 1);
 		    entry->inode = inode;
 		    inode->local_filename = NULL;
-		    inode->has_changed = 0;
 		    inode->inode = (current_archive->__inode_counter)++;
 		    inode->nlink = 1;
 		    inode->dev = current_archive->rdev;
@@ -530,13 +558,6 @@ static struct entry *my_resolve_symlinks (struct entry *entry)
     return res;
 }
 
-struct pseudofile {
-    struct archive *archive;
-    unsigned int has_changed:1;
-    int local_handle;
-    struct entry *entry;
-};
-
 static char *get_archive_name (struct archive *archive)
 {
     char *archive_name;
@@ -552,10 +573,7 @@ static char *get_archive_name (struct archive *archive)
 	return archive_name;
 }
 
-/* FIXME: we really should not have non-static procedures - it
- * pollutes namespace.  */
-
-void extfs_run (char *file)
+static void extfs_run (char *file)
 {
     struct archive *archive;
     char *p, *q, *archive_name, *mc_extfsdir;
@@ -603,11 +621,10 @@ static void *extfs_open (vfs *me, char *file, int flags, int mode)
         char *cmd;
 	char *archive_name, *p;
         
-        entry->inode->local_filename = g_tempnam (NULL, "extfs");
 	{
 	    int handle;
+	    handle = mc_mkstemps (&entry->inode->local_filename, "extfs", NULL);
 
-	    handle = open(entry->inode->local_filename, O_RDWR | O_CREAT | O_EXCL, 0600);
 	    if (handle == -1)
 		return NULL;
 	    close(handle);
@@ -641,7 +658,7 @@ static void *extfs_open (vfs *me, char *file, int flags, int mode)
     extfs_info = g_new (struct pseudofile, 1);
     extfs_info->archive = archive;
     extfs_info->entry = entry;
-    extfs_info->has_changed = 0;
+    extfs_info->has_changed = do_create;
     extfs_info->local_handle = local_handle;
 
     /* i.e. we had no open files and now we have one */
@@ -725,7 +742,273 @@ static int extfs_close (void *data)
 }
 
 #define RECORDSIZE 512
-#include "shared_tar_ext.c"
+
+static char *get_path (char *inname, struct archive **archive, int is_dir,
+    int do_not_open)
+{
+    char *buf = g_strdup (inname);
+    char *res = get_path_mangle( buf, archive, is_dir, do_not_open );
+    char *res2 = NULL;
+    if (res)
+        res2 = g_strdup(res);
+    g_free(buf);
+    return res2;
+}
+
+static struct entry*
+__find_entry (struct entry *dir, char *name, 
+		     struct loop_protect *list, int make_dirs, int make_file)
+{
+    struct entry *pent, *pdir;
+    char *p, *q, *name_end;
+    char c;
+
+    if (*name == '/') { /* Handle absolute paths */
+    	name++;
+    	dir = dir->inode->archive->root_entry;
+    }
+
+    pent = dir;
+    p = name;
+    name_end = name + strlen (name);
+    q = strchr (p, '/');
+    c = '/';
+    if (!q)
+	q = strchr (p, 0);
+    
+    for (; pent != NULL && c && *p; ){
+	c = *q;
+	*q = 0;
+
+	if (strcmp (p, ".")){
+	    if (!strcmp (p, "..")) 
+		pent = pent->dir;
+	    else {
+		if ((pent = __resolve_symlinks (pent, list))==NULL){
+		    *q = c;
+		    return NULL;
+		}
+		if (!S_ISDIR (pent->inode->mode)){
+		    *q = c;
+		    notadir = 1;
+		    return NULL;
+		}
+		pdir = pent;
+		for (pent = pent->inode->first_in_subdir; pent; pent = pent->next_in_dir)
+		    /* Hack: I keep the original semanthic unless
+		       q+1 would break in the strchr */
+		    if (!strcmp (pent->name, p)){
+			if (q + 1 > name_end){
+			    *q = c;
+			    notadir = !S_ISDIR (pent->inode->mode);
+			    return pent;
+			}
+			break;
+		    }
+		
+		/* When we load archive, we create automagically
+		 * non-existant directories
+		 */
+		if (pent == NULL && make_dirs) { 
+		    pent = generate_entry (dir->inode->archive, p, pdir, S_IFDIR | 0777);
+		}
+		if (pent == NULL && make_file) { 
+		    pent = generate_entry (dir->inode->archive, p, pdir, 0777);
+		}
+	    }
+	}
+	/* Next iteration */
+	*q = c;
+	p = q + 1;
+	q = strchr (p, '/');
+	if (!q)
+	    q = strchr (p, 0);
+    }
+    if (pent == NULL)
+    	my_errno = ENOENT;
+    return pent;
+}
+
+static struct entry *find_entry (struct entry *dir, char *name, int make_dirs, int make_file)
+{
+    struct entry *res;
+    
+    errloop = 0;
+    notadir = 0;
+    res = __find_entry (dir, name, NULL, make_dirs, make_file);
+    if (res == NULL) {
+    	if (errloop)
+    	    my_errno = ELOOP;
+    	else if (notadir)
+    	    my_errno = ENOTDIR;
+    }
+    return res;
+}
+
+
+static int s_errno (vfs *me)
+{
+    return my_errno;
+}
+
+static void * s_opendir (vfs *me, char *dirname)
+{
+    struct archive *archive;
+    char *q;
+    struct entry *entry;
+    struct entry **info;
+
+    if ((q = get_path_mangle (dirname, &archive, 1, 0)) == NULL)
+	return NULL;
+    entry = find_entry (archive->root_entry, q, 0, 0);
+    if (entry == NULL)
+    	return NULL;
+    if ((entry = my_resolve_symlinks (entry)) == NULL)
+	return NULL;
+    if (!S_ISDIR (entry->inode->mode)) ERRNOR (ENOTDIR, NULL);
+
+    info = g_new (struct entry *, 2);
+    info[0] = entry->inode->first_in_subdir;
+    info[1] = entry->inode->first_in_subdir;
+
+    return info;
+}
+
+static void * s_readdir (void *data)
+{
+    static struct {
+	struct dirent dir; 
+#ifdef NEED_EXTRA_DIRENT_BUFFER
+	char extra_buffer [MC_MAXPATHLEN];
+#endif
+    } dir;
+
+    struct entry **info = (struct entry **) data;
+
+    if (!*info)
+    	return NULL;
+
+    strcpy (&(dir.dir.d_name [0]), (*info)->name);
+    
+#ifndef DIRENT_LENGTH_COMPUTED
+    dir.d_namlen = strlen (dir.dir.d_name);
+#endif
+    *info = (*info)->next_in_dir;
+    
+    return (void *)&dir;
+}
+
+static int s_telldir (void *data)
+{
+    struct entry **info = (struct entry **) data;
+    struct entry *cur;
+    int num = 0;
+
+    cur = info[1];
+    while (cur!=NULL) {
+        if (cur == info[0]) return num;
+	num++;
+	cur = cur->next_in_dir;
+    }
+    return -1;
+}
+
+static void s_seekdir (void *data, int offset)
+{
+    struct entry **info = (struct entry **) data;
+    int i;
+    info[0] = info[1];
+    for (i=0; i<offset; i++)
+        s_readdir( data );
+}
+
+static int s_closedir (void *data)
+{
+    g_free (data);
+    return 0;
+}
+
+static void stat_move( struct stat *buf, struct inode *inode )
+{
+    buf->st_dev = inode->dev;
+    buf->st_ino = inode->inode;
+    buf->st_mode = inode->mode;
+    buf->st_nlink = inode->nlink;
+    buf->st_uid = inode->uid;
+    buf->st_gid = inode->gid;
+#ifdef HAVE_ST_RDEV
+    buf->st_rdev = inode->rdev;
+#endif
+    buf->st_size = inode->size;
+#ifdef HAVE_ST_BLKSIZE
+    buf->st_blksize = RECORDSIZE;
+#endif
+#ifdef HAVE_ST_BLOCKS
+    buf->st_blocks = (inode->size + RECORDSIZE - 1) / RECORDSIZE;
+#endif
+    buf->st_atime = inode->atime;
+    buf->st_mtime = inode->mtime;
+    buf->st_ctime = inode->ctime;
+}
+
+static int s_internal_stat (char *path, struct stat *buf, int resolve)
+{
+    struct archive *archive;
+    char *q;
+    struct entry *entry;
+    struct inode *inode;
+
+    if ((q = get_path_mangle (path, &archive, 0, 0)) == NULL)
+	return -1;
+    entry = find_entry (archive->root_entry, q, 0, 0);
+    if (entry == NULL)
+    	return -1;
+    if (resolve && (entry = my_resolve_symlinks (entry)) == NULL)
+	return -1;
+    inode = entry->inode;
+    stat_move( buf, inode );
+    return 0;
+}
+
+static int s_stat (vfs *me, char *path, struct stat *buf)
+{
+    return s_internal_stat (path, buf, 1);
+}
+
+static int s_lstat (vfs *me, char *path, struct stat *buf)
+{
+    return s_internal_stat (path, buf, 0);
+}
+
+static int s_fstat (void *data, struct stat *buf)
+{
+    struct pseudofile *file = (struct pseudofile *)data;
+    struct inode *inode;
+    
+    inode = file->entry->inode;
+    stat_move( buf, inode );
+    return 0;
+}
+
+static int s_readlink (vfs *me, char *path, char *buf, int size)
+{
+    struct archive *archive;
+    char *q;
+    int i;
+    struct entry *entry;
+
+    if ((q = get_path_mangle (path, &archive, 0, 0)) == NULL)
+	return -1;
+    entry = find_entry (archive->root_entry, q, 0, 0);
+    if (entry == NULL)
+    	return -1;
+    if (!S_ISLNK (entry->inode->mode)) ERRNOR (EINVAL, -1);
+    if (size > (i = strlen (entry->inode->linkname))) {
+    	size = i;
+    }
+    strncpy (buf, entry->inode->linkname, i);
+    return i;
+}
 
 static int extfs_chmod (vfs *me, char *path, int mode)
 {
@@ -1030,7 +1313,6 @@ static int extfs_ungetlocalcopy (vfs *me, char *path, char *local, int has_chang
     if (fp == NULL)
         return 0;
     if (!strcmp (fp->entry->inode->local_filename, local)) {
-        fp->entry->inode->has_changed = has_changed;
         fp->archive->fd_usage--;
         extfs_close ((void *) fp);
         return 0;
@@ -1050,11 +1332,11 @@ static int extfs_init (vfs *me)
 
     mc_extfsini = concat_dir_and_file (mc_home, "extfs/extfs.ini");
     cfg = fopen (mc_extfsini, "r");
-    g_free (mc_extfsini);
 
     if (!cfg) {
-        fprintf( stderr, "Warning: " LIBDIR "extfs/extfs.ini not found\n" );
-        return 0;
+	fprintf(stderr, _("Warning: file %s not found\n"), mc_extfsini);
+	g_free (mc_extfsini);
+	return 0;
     }
 
     extfs_no = 0;
@@ -1073,8 +1355,10 @@ static int extfs_init (vfs *me)
 	/* We may not use vfs_die() message or message_1s or similar,
          * UI is not initialized at this time and message would not
 	 * appear on screen. */
-	    fprintf( stderr, "Warning: You need to update your " LIBDIR "extfs/extfs.ini file.\n" );
+	    fprintf(stderr, "Warning: You need to update your %s file.\n",
+		    mc_extfsini);
 	    fclose(cfg);
+	    g_free (mc_extfsini);
 	    return 0;
 	}
 	if (*key == '#')
@@ -1096,6 +1380,7 @@ static int extfs_init (vfs *me)
 	extfs_no++;
     }
     fclose(cfg);
+    g_free (mc_extfsini);
     return 1;
 }
 
@@ -1130,7 +1415,7 @@ static int extfs_setctl (vfs *me, char *path, int ctlop, char *arg)
 
 vfs vfs_extfs_ops = {
     NULL,	/* This is place of next pointer */
-    "Extended filesystems",
+    "extfs",
     F_EXEC,	/* flags */
     NULL,	/* prefix */
     NULL,	/* data */
