@@ -6,7 +6,7 @@
    Written by: 1998 Pavel Machek
    Spaces fix: 2000 Michal Svec
 
-   $Id: fish.c,v 1.27 2000/04/10 12:00:43 pavel Exp $
+   $Id: fish.c,v 1.37 2001/08/23 17:13:43 proskin Exp $
 
    Derived from ftpfs.c.
    
@@ -22,7 +22,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 /*
  * Read README.fish for protocol specification.
@@ -36,6 +36,8 @@
 
 /* Define this if your ssh can take -I option */
 
+#include <config.h>
+
 #undef HAVE_HACKED_SSH
 
 #include "utilvfs.h"
@@ -138,7 +140,7 @@ free_archive (vfs *me, vfs_s_super *super)
 {
     if ((SUP.sockw != -1) || (SUP.sockr != -1)){
 	print_vfs_message (_("fish: Disconnecting from %s"), super->name?super->name:"???");
-	command(me, super, NONE, "#BYE\nlogout\n");
+	command(me, super, NONE, "#BYE\nexit\n");
 	close(SUP.sockw);
 	close(SUP.sockr);
 	SUP.sockw = SUP.sockr = -1;
@@ -172,7 +174,8 @@ pipeopen(vfs_s_super *super, char *path, char *argv[])
 	close(fileset1[0]); close(fileset1[1]);
 	close(1); close(2);
 	dup(fileset2[1]);
-	dup(fileset2[1]);
+	/* stderr to /dev/null */
+	open ("/dev/null", O_WRONLY);
 	close(fileset2[0]); close(fileset2[1]);
 	execvp(path, argv);
 	vfs_die("Exec failed.");
@@ -246,7 +249,13 @@ open_archive_int (vfs *me, vfs_s_super *super)
     }
 
     print_vfs_message( _("fish: Sending initial line...") );
-    if (command (me, super, WAIT_REPLY, "#FISH\necho; start_fish_server; echo '### 200'\n") != COMPLETE)
+    /*
+     * Run `start_fish_server'. If it doesn't exist - no problem,
+     * we'll talk directly to the shell.
+     */
+    if (command (me, super, WAIT_REPLY,
+                 "#FISH\necho; start_fish_server 2>&1;"
+                 " echo '### 200'\n") != COMPLETE)
         ERRNOR (E_PROTO, -1);
 
     print_vfs_message( _("fish: Handshaking version...") );
@@ -352,12 +361,12 @@ dir_load(vfs *me, vfs_s_inode *dir, char *remote_path)
 
     command(me, super, NONE,
 	    "#LIST /%s\n"
-	    "ls -lLa \"/%s\" | grep '^[^cbt]' | (\n"
+	    "ls -lLa \"/%s\" 2>/dev/null | grep '^[^cbt]' | (\n"
 	      "while read p x u g s m d y n; do\n"
 	        "echo \"P$p $u.$g\nS$s\nd$m $d $y\n:$n\n\"\n"
 	      "done\n"
 	    ")\n"
-	    "ls -lLa \"/%s\" | grep '^[cb]' | (\n"
+	    "ls -lLa \"/%s\" 2>/dev/null | grep '^[cb]' | (\n"
 	      "while read p x u g a i m d y n; do\n"
 	        "echo \"P$p $u.$g\nE$a$i\nd$m $d $y\n:$n\n\"\n"
 	      "done\n"
@@ -393,7 +402,7 @@ dir_load(vfs *me, vfs_s_inode *dir, char *remote_path)
 
 	switch(buffer[0]) {
 	case ':': {
-	              char *c;
+		      /* char *c; */
 		      if (!strcmp(buffer+1, ".") || !strcmp(buffer+1, ".."))
 			  break;  /* We'll do . and .. ourself */
 		      ent->name = g_strdup(buffer+1); 
@@ -529,7 +538,7 @@ static int linear_start(vfs *me, vfs_s_fh *fh, int offset)
 	return 0;
     offset = command(me, FH_SUPER, WANT_STRING,
 		"#RETR /%s\n"
-		"ls -l \"/%s\" | (\n"
+		"ls -l \"/%s\" 2>/dev/null | (\n"
 		  "read var1 var2 var3 var4 var5 var6\n"
 		  "echo \"$var5\"\n"
 		")\n"
@@ -646,7 +655,9 @@ static int
 fish_chmod (vfs *me, char *path, int mode)
 {
     PREFIX
-    g_snprintf(buf, sizeof(buf), "#CHMOD %4.4o /%s\nchmod %4.4o \"/%s\"; echo '### 000'\n", 
+    g_snprintf(buf, sizeof(buf), "#CHMOD %4.4o /%s\n"
+				 "chmod %4.4o \"/%s\" 2>/dev/null\n"
+				 "echo '### 000'\n", 
 	    mode & 07777, rpath,
 	    mode & 07777, rpath);
     POSTFIX(OPT_FLUSH);
@@ -667,15 +678,19 @@ static int fish_##name (vfs *me, char *path1, char *path2) \
 }
 
 #define XTEST if (bucket1 != bucket2) { ERRNOR (EXDEV, -1); }
-FISH_OP(rename, XTEST, "#RENAME /%s /%s\nmv \"/%s\" \"/%s\"; echo '### 000'" );
-FISH_OP(link,   XTEST, "#LINK /%s /%s\nln \"/%s\" \"/%s\"; echo '### 000'" );
+FISH_OP(rename, XTEST, "#RENAME /%s /%s\n"
+		       "mv \"/%s\" \"/%s\" 2>/dev/null\n"
+		       "echo '### 000'" )
+FISH_OP(link,   XTEST, "#LINK /%s /%s\n"
+		       "ln \"/%s\" \"/%s\" 2>/dev/null\n"
+		       "echo '### 000'" )
 
 static int fish_symlink (vfs *me, char *setto, char *path)
 {
     PREFIX
     g_snprintf(buf, sizeof(buf),
             "#SYMLINK %s /%s\n"
-	    "ln -s \"%s\" \"/%s\"\n"
+	    "ln -s \"%s\" \"/%s\" 2>/dev/null\n"
 	    "echo '### 000'\n",
 	    setto, rpath, setto, rpath);
     POSTFIX(OPT_FLUSH);
@@ -685,12 +700,21 @@ static int
 fish_chown (vfs *me, char *path, int owner, int group)
 {
     char *sowner, *sgroup;
+    struct passwd *pw;
+    struct group *gr;
     PREFIX
-    sowner = getpwuid( owner )->pw_name;
-    sgroup = getgrgid( group )->gr_name;
+
+    if ((pw = getpwuid (owner)) == NULL)
+	return 0;
+
+    if ((gr = getgrgid (group)) == NULL)
+	return 0;
+
+    sowner = pw->pw_name;
+    sgroup = gr->gr_name;
     g_snprintf(buf, sizeof(buf),
             "#CHOWN /%s /%s\n"
-	    "chown %s \"/%s\"\n"
+	    "chown %s \"/%s\" 2>/dev/null\n"
 	    "echo '### 000'\n", 
 	    sowner, rpath,
 	    sowner, rpath);
@@ -698,11 +722,11 @@ fish_chown (vfs *me, char *path, int owner, int group)
                   /* FIXME: what should we report if chgrp succeeds but chown fails? */
     g_snprintf(buf, sizeof(buf),
             "#CHGRP /%s /%s\n"
-	    "chgrp %s \"/%s\"\n"
+	    "chgrp %s \"/%s\" 2>/dev/null\n"
 	    "echo '### 000'\n", 
 	    sgroup, rpath,
 	    sgroup, rpath);
-    //send_fish_command(me, super, buf, OPT_FLUSH); 
+    /* send_fish_command(me, super, buf, OPT_FLUSH); */
     POSTFIX(OPT_FLUSH)
 }
 
@@ -711,7 +735,7 @@ static int fish_unlink (vfs *me, char *path)
     PREFIX
     g_snprintf(buf, sizeof(buf),
             "#DELE /%s\n"
-	    "rm -f \"/%s\"\n"
+	    "rm -f \"/%s\" 2>/dev/null\n"
 	    "echo '### 000'\n",
 	    rpath, rpath);
     POSTFIX(OPT_FLUSH);
@@ -722,7 +746,7 @@ static int fish_mkdir (vfs *me, char *path, mode_t mode)
     PREFIX
     g_snprintf(buf, sizeof(buf),
             "#MKD /%s\n"
-	    "mkdir \"/%s\"\n"
+	    "mkdir \"/%s\" 2>/dev/null\n"
 	    "echo '### 000'\n",
 	    rpath, rpath);
     POSTFIX(OPT_FLUSH);
@@ -733,7 +757,7 @@ static int fish_rmdir (vfs *me, char *path)
     PREFIX
     g_snprintf(buf, sizeof(buf),
             "#RMD /%s\n"
-	    "rmdir \"/%s\"\n"
+	    "rmdir \"/%s\" 2>/dev/null\n"
 	    "echo '### 000'\n",
 	    rpath, rpath);
     POSTFIX(OPT_FLUSH);
@@ -779,7 +803,7 @@ static struct vfs_s_data fish_data = {
 
 vfs vfs_fish_ops = {
     NULL,	/* This is place of next pointer */
-    "FIles tranferred over SHell",
+    "fish",
     F_EXEC,	/* flags */
     "sh:",	/* prefix */
     &fish_data,	/* data */
