@@ -7,7 +7,7 @@
 	       1997 Norbert Warmuth
 	       1998 Pavel Machek
 
-   $Id: ftpfs.c,v 1.75 2001/02/20 16:55:58 proskin Exp $   
+   $Id: ftpfs.c,v 1.80 2001/08/06 15:39:08 andrew Exp $   
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License
@@ -56,6 +56,7 @@ What to do with this?
 
 /* Namespace pollution: horrible */
 
+#include <config.h>
 #include <sys/types.h>          /* POSIX-required by sys/socket.h and netdb.h */
 #include <netdb.h>		/* struct hostent */
 #include <sys/socket.h>		/* AF_INET */
@@ -132,7 +133,9 @@ static FILE *logfile = NULL;
 /* If true, the directory cache is forced to reload */
 static int force_expiration = 0;
 
+#ifdef FIXME_LATER_ALIGATOR
 static struct linklist *connections_list;
+#endif
 
 /* command wait_flag: */
 #define NONE        0x00
@@ -518,7 +521,7 @@ static struct no_proxy_entry {
 } *no_proxy;
 
 static void
-load_no_proxy_list ()
+load_no_proxy_list (void)
 {
     /* FixMe: shouldn't be hardcoded!!! */
     char	s[BUF_LARGE]; /* provide for BUF_LARGE characters */
@@ -696,7 +699,7 @@ ftpfs_open_socket (vfs *me, vfs_s_super *super)
     return my_socket;
 }
 
-int
+static int
 open_archive_int (vfs *me, vfs_s_super *super)
 {
     int retry_seconds, count_down;
@@ -1167,7 +1170,10 @@ dir_load(vfs *me, vfs_s_inode *dir, char *remote_path)
 {
     vfs_s_entry *ent;
     vfs_s_super *super = dir->super;
-    int sock, has_symlinks = 0, num_entries = 0;
+    int sock, num_entries = 0;
+#ifdef FIXME_LATER
+    int has_symlinks = 0;
+#endif
     char buffer[BUF_8K];
     
     int cd_first = (strchr (remote_path, ' ') != NULL) || ftpfs_first_cd_then_ls || (SUP.strict == RFC_STRICT);
@@ -1437,7 +1443,7 @@ linear_close (vfs *me, vfs_s_fh *fh)
         linear_abort(me, fh);
 }
 
-int ftpfs_ctl (void *fh, int ctlop, int arg)
+static int ftpfs_ctl (void *fh, int ctlop, int arg)
 {
     switch (ctlop) {
         case MCCTL_IS_NOTREADY:
@@ -1674,16 +1680,30 @@ static struct vfs_s_data ftp_data = {
     linear_close
 };
 
+static void
+ftpfs_fill_names (vfs *me, void (*func)(char *))
+{
+    struct vfs_s_super * super = ftp_data.supers;
+    char *name;
+    
+    while (super){
+	name = g_strconcat ("/#ftp:", SUP.user, "@", SUP.host, "/", SUP.cwdir, NULL);
+	(*func)(name);
+	g_free (name);
+	super = super->next;
+    }
+}
+
 vfs vfs_ftpfs_ops = {
     NULL,	/* This is place of next pointer */
-    N_("File Transfer Protocol (ftp)"),
+    "ftpfs",
     F_NET,	/* flags */
     "ftp:",	/* prefix */
     &ftp_data,	/* data */
     0,		/* errno */
     NULL,	/* init */
     NULL,	/* done */
-    vfs_s_fill_names,
+    ftpfs_fill_names,
     NULL,
 
     vfs_s_open,
