@@ -1,11 +1,11 @@
 /*  ftpfs.h */
 
-/*  $Id: ftpfs.h,v 1.11 2000/02/25 12:53:06 pavel Exp $ */
+/*  $Id: ftpfs.h,v 1.14 2001/08/03 10:15:17 andrew Exp $ */
 
 #if !defined(__FTPFS_H)
 #define __FTPFS_H
 
-#include "vfs/xdirentry.h"
+#include "xdirentry.h"
 
 struct direntry
 {
@@ -56,7 +56,6 @@ struct connection {
     int lock;
     int failed_on_login;	/* used to pass the failure reason to upper levels */
     int use_proxy;		/* use a proxy server */
-    int result_pending;
     int use_source_route;
     int use_passive_connection;
     int remote_is_amiga;       /* No leading slash allowed for AmiTCP (Amiga) */
@@ -91,6 +90,12 @@ extern char *ftpfs_proxy_host;
 extern int ftpfs_directory_timeout;
 extern int ftpfs_always_use_proxy;
 
+extern int use_netrc;
+extern int ftpfs_retry_seconds;
+extern int ftpfs_use_passive_connections;
+extern int ftpfs_use_unix_list_options;
+extern int ftpfs_first_cd_then_ls;
+
 void ftpfs_init_passwd (void);
 
 #define OPT_FLUSH        1
