@@ -6,7 +6,7 @@
               Andrej Borsenkow
 	      Norbert Warmuth
    
-   $Id: mcfs.c,v 1.19 2001/03/08 01:04:58 proskin Exp $
+   $Id: mcfs.c,v 1.22 2001/08/14 00:55:39 proskin Exp $
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License
@@ -227,7 +227,7 @@ open_tcp_link  (char *host, int *port, int *version, char *caller)
 	       sizeof (inaddr));
     else {
 	if ((hp = gethostbyname (host)) == NULL){
-	    message_2s (1, caller, _(" Can't locate hostname: %s "), host);
+	    message_2s (1, caller, _(" Cannot locate hostname: %s "), host);
 	    return 0;
 	}
 	bcopy ((char *) hp->h_addr, (char *) &server_address.sin_addr,
@@ -245,13 +245,13 @@ open_tcp_link  (char *host, int *port, int *version, char *caller)
     server_address.sin_port = htons (*port);
     
     if ((my_socket = socket (AF_INET, SOCK_STREAM, 0)) < 0){
-	message_2s (1, caller, _(" Can't create socket: %s "),
+	message_2s (1, caller, _(" Cannot create socket: %s "),
 		 unix_error_string(errno));
 	return 0;
     }
     if (connect (my_socket, (struct sockaddr *) &server_address,
 	     sizeof (server_address)) < 0){
-	message_2s (1, caller, _(" Can't connect to server: %s "),
+	message_2s (1, caller, _(" Cannot connect to server: %s "),
 		 unix_error_string (errno));
 	close (my_socket);
 	return 0;
@@ -278,7 +278,7 @@ static int mcfs_open_tcp_link (char *host, char *user,
 }
 
 static int mcfs_get_free_bucket_init = 1;
-static mcfs_connection *mcfs_get_free_bucket ()
+static mcfs_connection *mcfs_get_free_bucket (void)
 {
     int i;
     
@@ -1120,7 +1120,7 @@ mcfs_setctl (vfs *me, char *path, int ctlop, char *arg)
 
 vfs vfs_mcfs_ops = {
     NULL,	/* This is place of next pointer */
-    N_("Midnight Commander's private remote filesystem"),
+    "mcfs",
     F_NET,	/* flags */
     "mc:",	/* prefix */
     NULL,	/* data */
