@@ -3,6 +3,8 @@
  *
  * Copyright 1998 Pavel Machek, distribute under GPL
  *
+ * $Id: sfs.c,v 1.31 2001/08/11 04:57:17 proskin Exp $
+ *
  * This defines whole class of filesystems which contain single file
  * inside. It is somehow similar to extfs, except that extfs makes
  * whole virtual trees and we do only single virtual files. 
@@ -10,7 +12,7 @@
  * If you want to gunzip something, you should open it with #ugz
  * suffix, DON'T try to gunzip it yourself.
  *
- * Namespace: exports vfs_sfs_ops, shell (FIXME) */
+ * Namespace: exports vfs_sfs_ops */
 
 #include <config.h>
 #include <errno.h>
@@ -25,9 +27,6 @@
 #include "vfs.h"
 #include "local.h"
 
-/* This is needed, or libvfs.so will lack symbol shell. Should look up who requires it */
-char *shell = "/bin/sh";
-
 struct cachedfile {
     char *name, *cache;
     uid_t uid;
@@ -124,10 +123,9 @@ redirect (vfs *me, char *name)
 	cur = cur->next;
     }
 
-    cache = tempnam (NULL, "sfs");
-    handle = open (cache, O_RDWR | O_CREAT | O_EXCL, 0600);
+    handle = mc_mkstemps (&cache, "sfs", NULL);
+
     if (handle == -1) {
-	g_free (cache);
 	return "/SOMEONE_PLAYING_DIRTY_TMP_TRICKS_ON_US";
     }
 
@@ -146,6 +144,8 @@ redirect (vfs *me, char *name)
 
 	return cache;
     }
+    
+    unlink (cache);
     g_free (cache);
     return "/I_MUST_NOT_EXIST";
 }
@@ -177,7 +177,7 @@ static int sfs_lstat (vfs *me, char *path, struct stat *buf)
 {
     path = redirect (me, path);
 #ifndef HAVE_STATLSTAT
-    return lstat (path,buf);
+    return lstat (path, buf);
 #else
     return statlstat (path, buf);
 #endif
@@ -291,48 +291,53 @@ static int sfs_ungetlocalcopy (vfs *me, char *path, char *local, int has_changed
 
 static int sfs_init (vfs *me)
 {
-    FILE *cfg = fopen (LIBDIR "extfs/sfs.ini", "r");
+    char *mc_sfsini;
+    FILE *cfg;
+
+    mc_sfsini = concat_dir_and_file (mc_home, "extfs/sfs.ini");
+    cfg = fopen (mc_sfsini, "r");
 
     if (!cfg){
-        fprintf (stderr, "Warning: " LIBDIR "extfs/sfs.ini not found\n");
-        return 0;
+	fprintf (stderr, _("Warning: file %s not found\n"), mc_sfsini);
+	g_free (mc_sfsini);
+	return 0;
     }
+    g_free (mc_sfsini);
 
     sfs_no = 0;
     while (sfs_no < MAXFS){
-        char key[256];
+	char key[256];
 	char *c, *semi = NULL, flags = 0;
-	int i;
 
-        if (!fgets (key, 250, cfg))
+        if (!fgets (key, sizeof (key), cfg))
 	    break;
 
 	if (*key == '#')
 	    continue;
 
-	for (i = 0; i < strlen (key); i++)
-	    if ((key[i]==':') || (key[i]=='/')){
-		semi = key+i;
-		if (key [i] == '/'){
-		    key [i] = 0;
+	for (c = key; *c; c++)
+	    if ((*c == ':') || (*c == '/')){
+		semi = c;
+		if (*c == '/'){
+		    *c = 0;
 		    flags |= F_FULLMATCH;
 		}
 		break;
 	    }
 
 	if (!semi){
-	    fprintf (stderr, "Warning: Invalid line %s in sfs.ini.\n", key);
+	    fprintf (stderr, _("Warning: Invalid line in sfs.ini:\n%s\n"), key);
 	    continue;
 	}
 
 	c = semi + 1;
-	while ((*c != ' ') && (*c != 9)) {
+	while ((*c != ' ') && (*c != '\t')) {
 	    switch (*c) {
 	    case '1': flags |= F_1; break;
 	    case '2': flags |= F_2; break;
 	    case 'R': flags |= F_NOLOCALCOPY; break;
 	    default:
-	      fprintf (stderr, "Warning: Invalid flag %c in sfs.ini line %s.\n", *c, key);
+	      fprintf (stderr, _("Warning: Invalid flag %c in sfs.ini:\n%s\n"), *c, key);
 	    }	    
 	    c++;
 	}
@@ -376,13 +381,12 @@ sfs_which (vfs *me, char *path)
 	    if (!strncmp (path, sfs_prefix [i], strlen (sfs_prefix [i])))
 	        return i;
 
-    
     return -1;
 }
 
 vfs vfs_sfs_ops = {
     NULL,	/* This is place of next pointer */
-    "Signle file filesystems",
+    "sfs",
     F_EXEC,	/* flags */
     NULL,	/* prefix */
     NULL,	/* data */
