@@ -2,9 +2,10 @@
    
    Copyright (C) 1995, 1996, 1997 The Free Software Foundation
 
-   Written by Wayne Roberts
-    <wroberts1@home.com>
-   
+   Written by Wayne Roberts <wroberts1@home.com>
+
+   $Id: smbfs.c,v 1.27 2001/08/14 00:55:39 proskin Exp $
+
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License
    as published by the Free Software Foundation; either version 2 of
@@ -19,53 +20,46 @@
    License along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-/* Namespace: exports smbfs_vfs_ops, tcp_invalidate_socket */
+/* Namespace: exports smbfs_vfs_ops */
 #include <stdio.h>
 #include <sys/types.h>
 
-#include "../config.h"
+#include <config.h>
+#include "utilvfs.h"
 #include "samba/include/config.h"
 /* don't load crap in "samba/include/includes.h" we don't use and which 
    conflicts with definitions in other includes */
 #undef HAVE_LIBREADLINE
 #define NO_CONFIG_H
 #define BOOL_DEFINED
+#undef	VERSION
 #include "samba/include/includes.h"
 
 #include <string.h>
-#include <errno.h>
-
-#include "../src/global.h"
-
-#include "../src/tty.h"         /* enable/disable interrupt key */
-#include "../src/main.h"
 
 #include "vfs.h"
 #include "smbfs.h"
 #include "tcputil.h"
 #include "../src/dialog.h"
-#include "../src/widget.h"
-#include "../src/color.h"
-#include "../src/wtools.h"
 
 #define SMBFS_MAX_CONNECTIONS 16
-char *IPC = "IPC$";
-char *URL_HEADER = "/#smb:";
+static const char * const IPC = "IPC$";
+static const char * const URL_HEADER = "/#smb:";
 #define HEADER_LEN	6
 
 static int my_errno;
-uint32 err;
+static uint32 err;
 
 /* stuff that is same with each connection */
 extern int DEBUGLEVEL;
 static pstring myhostname;
-mode_t myumask = 0755;
+static mode_t myumask = 0755;
 extern pstring global_myname;
 static int smbfs_open_connections = 0;
-gboolean got_user = FALSE;
-gboolean got_pass = FALSE;
-pstring password;
-pstring username;
+static gboolean got_user = FALSE;
+static gboolean got_pass = FALSE;
+static pstring password;
+static pstring username;
 
 static struct _smbfs_connection {
 	struct cli_state *cli;
@@ -84,7 +78,7 @@ static struct _smbfs_connection {
 /* unique to each connection */
 
 typedef struct _smbfs_connection smbfs_connection;
-smbfs_connection *current_bucket;
+static smbfs_connection *current_bucket;
 
 typedef struct {
 	struct cli_state *cli;
@@ -93,128 +87,10 @@ typedef struct {
 	uint16 attr;
 } smbfs_handle;
 
-struct authinfo {
-    char *host;
-    char *share;
-    char *domain;
-    char *user;
-    char *password;
-/*	struct timeval timestamp;*/
-};
-
-GSList *auth_list;
-
-static struct authinfo *
-authinfo_get_authinfo_from_user (const char *host, 
-                                 const char *share, 
-                                 const char *domain, 
-                                 const char *user)
-{
-    static int dialog_x = 44;
-    int dialog_y = 12;
-    struct authinfo *return_value;
-    static char* labs[] = {N_("Domain:"), N_("Username:"), N_("Password: ")};
-    static char* buts[] = {N_("&Ok"), N_("&Cancel")};
-    static int ilen = 30, istart = 14;
-    static int b0 = 3, b2 = 30;
-    char *title;
-    WInput *in_password;
-    WInput *in_user;
-    WInput *in_domain;
-    Dlg_head *auth_dlg;
-
-#ifdef ENABLE_NLS
-    static int i18n_flag = 0;
-    
-    if (!i18n_flag)
-    {
-        register int i = sizeof(labs)/sizeof(labs[0]);
-        int l1, maxlen = 0;
-        
-        while (i--)
-        {
-            l1 = strlen (labs [i] = _(labs [i]));
-            if (l1 > maxlen)
-                maxlen = l1;
-        }
-        i = maxlen + ilen + 7;
-        if (i > dialog_x)
-            dialog_x = i;
-        
-        for (i = sizeof(buts)/sizeof(buts[0]), l1 = 0; i--; )
-        {
-            l1 += strlen (buts [i] = _(buts [i]));
-        }
-        l1 += 15;
-        if (l1 > dialog_x)
-            dialog_x = l1;
-
-        ilen = dialog_x - 7 - maxlen; /* for the case of very long buttons :) */
-        istart = dialog_x - 3 - ilen;
-        
-        b2 = dialog_x - (strlen(buts[1]) + 6);
-        
-        i18n_flag = 1;
-    }
-    
-#endif /* ENABLE_NLS */
-
-    if (!domain)
-    domain = "";
-    if (!user)
-    user = "";
-
-    auth_dlg = create_dlg (0, 0, dialog_y, dialog_x, dialog_colors,
-                       common_dialog_callback, "[Smb Authinfo]", "smbauthinfo",
-                       DLG_CENTER | DLG_GRID);
-
-    title = g_strdup_printf (_("Password for \\\\%s\\%s"), host, share);
-    x_set_dialog_title (auth_dlg, title);
-    g_free (title);
-
-    in_user  = input_new (5, istart, INPUT_COLOR, ilen, user, "auth_name");
-    add_widgetl (auth_dlg, in_user, XV_WLAY_BELOWOF);
-
-    in_domain = input_new (3, istart, INPUT_COLOR, ilen, domain, "auth_domain");
-    add_widgetl (auth_dlg, in_domain, XV_WLAY_NEXTCOLUMN);
-    add_widgetl (auth_dlg, button_new (9, b2, B_CANCEL, NORMAL_BUTTON,
-                 buts[1], 0 ,0, "cancel"), XV_WLAY_RIGHTOF);
-    add_widgetl (auth_dlg, button_new (9, b0, B_ENTER, DEFPUSH_BUTTON,
-                 buts[0], 0, 0, "ok"), XV_WLAY_CENTERROW);
-
-    in_password  = input_new (7, istart, INPUT_COLOR, ilen, "", "auth_password");
-    in_password->completion_flags = 0;
-    in_password->is_password = 1;
-    add_widgetl (auth_dlg, in_password, XV_WLAY_BELOWOF);
-
-    add_widgetl (auth_dlg, label_new (7, 3, labs[2], "label-passwd"), XV_WLAY_BELOWOF);
-    add_widgetl (auth_dlg, label_new (5, 3, labs[1], "label-user"), XV_WLAY_BELOWOF);
-    add_widgetl (auth_dlg, label_new (3, 3, labs[0], "label-domain"), XV_WLAY_NEXTCOLUMN);
-
-    run_dlg (auth_dlg);
-
-    switch (auth_dlg->ret_value) {
-    case B_CANCEL:
-        return_value = 0;
-        break;
-    default:
-        return_value = g_new (struct authinfo, 1);
-        if (return_value) {
-            return_value->host = g_strdup (host);
-            return_value->share = g_strdup (share);
-            return_value->domain = g_strdup (in_domain->buffer);
-            return_value->user = g_strdup (in_user->buffer);
-            return_value->password = g_strdup (in_password->buffer);
-        }
-    }
-
-    destroy_dlg (auth_dlg);
-             
-    return return_value;
-}
+static GSList *auth_list;
 
 static void 
-authinfo_free (struct authinfo const *a)
+authinfo_free (struct smb_authinfo const *a)
 {
     g_free (a->host);
     g_free (a->share);
@@ -236,8 +112,8 @@ authinfo_free_all ()
 static gint
 authinfo_compare_host_and_share (gconstpointer _a, gconstpointer _b)
 {
-    struct authinfo const *a = (struct authinfo const *)_a;
-    struct authinfo const *b = (struct authinfo const *)_b;
+    struct smb_authinfo const *a = (struct smb_authinfo const *)_a;
+    struct smb_authinfo const *b = (struct smb_authinfo const *)_b;
 
     if (!a->host || !a->share || !b->host || !b->share)
         return 1;
@@ -251,8 +127,8 @@ authinfo_compare_host_and_share (gconstpointer _a, gconstpointer _b)
 static gint
 authinfo_compare_host (gconstpointer _a, gconstpointer _b)
 {
-    struct authinfo const *a = (struct authinfo const *)_a;
-    struct authinfo const *b = (struct authinfo const *)_b;
+    struct smb_authinfo const *a = (struct smb_authinfo const *)_a;
+    struct smb_authinfo const *b = (struct smb_authinfo const *)_b;
 
     if (!a->host || !b->host)
         return 1;
@@ -267,7 +143,7 @@ static void
 authinfo_add (const char *host, const char *share, const char *domain,
               const char *user, const char *password)
 {
-    struct authinfo *auth = g_new (struct authinfo, 1);
+    struct smb_authinfo *auth = g_new (struct smb_authinfo, 1);
     
     if (!auth)
         return;
@@ -284,8 +160,8 @@ authinfo_add (const char *host, const char *share, const char *domain,
 static void
 authinfo_remove (const char *host, const char *share)
 {
-    struct authinfo data;
-    struct authinfo *auth;
+    struct smb_authinfo data;
+    struct smb_authinfo *auth;
     GSList *list;
 
     data.host = g_strdup (host);
@@ -310,8 +186,8 @@ bucket_set_authinfo (smbfs_connection *bucket,
         const char *domain, const char *user, const char *pass,
         int fallback_to_host)
 {
-    struct authinfo data;
-    struct authinfo *auth;
+    struct smb_authinfo data;
+    struct smb_authinfo *auth;
     GSList *list;
 
     if (domain && user && pass) {
@@ -347,10 +223,10 @@ bucket_set_authinfo (smbfs_connection *bucket,
         return 1;
     }
 
-    auth = authinfo_get_authinfo_from_user (bucket->host, 
-                                bucket->service,
-                                (domain ? domain : lp_workgroup ()),
-                                user);
+    auth = vfs_smb_get_authinfo (bucket->host, 
+				 bucket->service,
+				 (domain ? domain : lp_workgroup ()),
+				 user);
     if (auth) {
         g_free (bucket->domain);
         g_free (bucket->user);
@@ -389,7 +265,7 @@ smbfs_init(vfs *me)
         DEBUG(0,("Failed to get my hostname.\n"));
 
 	if (!lp_load(servicesf,True,False,False))
-		DEBUG(0, ("Can't load %s - run testparm to debug it\n", servicesf));
+		DEBUG(0, ("Cannot load %s - run testparm to debug it\n", servicesf));
 
     codepage_initialise(lp_client_code_page());
 
@@ -422,7 +298,18 @@ smbfs_init(vfs *me)
 static void
 smbfs_fill_names (vfs *me, void (*func)(char *))
 {
-	DEBUG(3, ("smbfs_fill_names()\n"));
+    int i;
+    char *path;
+    for (i = 0; i < SMBFS_MAX_CONNECTIONS; i++) {
+	if (smbfs_connections [i].cli) {
+	    path = g_strconcat (URL_HEADER,
+		smbfs_connections[i].host, 
+		"/", smbfs_connections[i].service,
+		NULL);
+	    (*func)(path);
+	    g_free (path);
+	}
+    }
 }
 
 #define CNV_LANG(s) dos_to_unix(s,False)
@@ -492,23 +379,20 @@ typedef struct {
     dir_entry *current;
 } opendir_info;
 
-opendir_info
+static opendir_info
 	*previous_info,
 	*current_info,
 	*current_share_info,
 	*current_server_info;
 
-gboolean first_direntry;
-/* browse for shares on server */
-static void
-browsing_helper(const char *name, uint32 type, const char *comment)
-{
-	fstring typestr;
-	dir_entry *new_entry;
-	new_entry = g_new (dir_entry, 1);
-    new_entry->text = dos_to_unix (g_strdup (name), 1);
+static gboolean first_direntry;
 
-    new_entry->next = 0;
+static dir_entry * 
+new_dir_entry (const char * name)
+{
+	dir_entry *new_entry;
+	new_entry = g_new0 (dir_entry, 1);
+	new_entry->text = dos_to_unix (g_strdup (name), 1);
 
 	if (first_direntry) {
 		current_info->entries = new_entry;
@@ -518,23 +402,31 @@ browsing_helper(const char *name, uint32 type, const char *comment)
 	}
 	current_info->current = new_entry;
 
-	bzero(&new_entry->my_stat, sizeof(struct stat));
-	new_entry->merrno = 0;
-	*typestr=0;
+	return new_entry;
+}
+
+/* browse for shares on server */
+static void
+browsing_helper(const char *name, uint32 type, const char *comment)
+{
+	char *typestr = "";
+
+	dir_entry *new_entry = new_dir_entry (name);
+
 	switch (type) {
 		case STYPE_DISKTREE:
-			fstrcpy(typestr,"Disk");
+			typestr = "Disk";
 			/*	show this as dir	*/
 			new_entry->my_stat.st_mode = S_IFDIR|S_IRUSR|S_IRGRP|S_IROTH;
 			break;
 		case STYPE_PRINTQ:
-			fstrcpy(typestr,"Printer"); break;
+			typestr = "Printer"; break;
 		case STYPE_DEVICE:
-			fstrcpy(typestr,"Device"); break;
+			typestr = "Device"; break;
 		case STYPE_IPC:
-			fstrcpy(typestr, "IPC"); break;
+			typestr = "IPC"; break;
 	}
-	DEBUG(3, ("\t%-15.15s%-10.10s%s\n", name, typestr,comment)); 
+	DEBUG(3, ("\t%-15.15s%-10.10s%s\n", name, typestr, comment));
 }
 
 static void
@@ -542,25 +434,12 @@ loaddir_helper(file_info *finfo, const char *mask)
 {
 	dir_entry *new_entry;
 	time_t t = finfo->mtime; /* the time is assumed to be passed as GMT */
-
+#if 0	/* I want to see dot files */
 	if (finfo->mode & aHIDDEN)
-		return;	/* dont bother with hidden files, "~$" screws up mc */
+		return;	/* don't bother with hidden files, "~$" screws up mc */
+#endif
+	new_entry = new_dir_entry (finfo->name);
 
-	new_entry = g_new (dir_entry, 1);
-    new_entry->text = dos_to_unix (g_strdup(finfo->name), 1);
-
-    new_entry->next = 0;
-
-	if (first_direntry) {
-		current_info->entries = new_entry;
-		current_info->current = new_entry;
-		first_direntry = FALSE;
-	} else {
-		current_info->current->next = new_entry;
-		current_info->current = new_entry;
-	}
-
-	bzero(&new_entry->my_stat, sizeof(struct stat));
 	new_entry->my_stat.st_size = finfo->size;
 	new_entry->my_stat.st_mtime = finfo->mtime;
 	new_entry->my_stat.st_atime = finfo->atime;
@@ -569,8 +448,8 @@ loaddir_helper(file_info *finfo, const char *mask)
 	new_entry->my_stat.st_gid = finfo->gid;
 
 
-	new_entry->my_stat.st_mode =	S_IRUSR|S_IRGRP|S_IROTH |
-									S_IWUSR|S_IWGRP|S_IWOTH;
+	new_entry->my_stat.st_mode =
+		S_IRUSR|S_IRGRP|S_IROTH|S_IWUSR|S_IWGRP|S_IWOTH;
 								
 /*  if (finfo->mode & aVOLID);	 nothing similar in real world */
 	if (finfo->mode & aDIR)
@@ -580,9 +459,9 @@ loaddir_helper(file_info *finfo, const char *mask)
 /*  if (finfo->mode & aARCH);	DOS archive	*/
 /*  if (finfo->mode & aHIDDEN);	like a dot file? */
 /*  if (finfo->mode & aSYSTEM); like a kernel? */
-  if (finfo->mode & aRONLY)
+	if (finfo->mode & aRONLY)
 		new_entry->my_stat.st_mode &= ~(S_IRUSR|S_IRGRP|S_IROTH);
- 
+
 	DEBUG(3, ("  %-30s%7.7s%8.0f  %s",
 		CNV_LANG(finfo->name),
 		attrib_string(finfo->mode),
@@ -590,7 +469,7 @@ loaddir_helper(file_info *finfo, const char *mask)
 		asctime(LocalTime(&t)))); 
 }
 
-/* takes "/foo/bar/file" and gives "\\foo\\bar\\file" */
+/* takes "/foo/bar/file" and gives malloced "\\foo\\bar\\file" */
 static int
 convert_path(char **remote_file, gboolean trailing_asterik)
 {
@@ -612,9 +491,7 @@ convert_path(char **remote_file, gboolean trailing_asterik)
     if (p)
         my_remote = p;   /* strip off share/service name */
     /* create remote filename as understood by smb clientgen */
-    p = *remote_file = g_strconcat (my_remote, 
-							        trailing_asterik ? "/*" : "", 
-								    0);
+    p = *remote_file = g_strconcat (my_remote, trailing_asterik ? "/*" : "", 0);
     unix_to_dos (*remote_file, 1);
     while ((p = strchr(p, '/')))
         *p = '\\';
@@ -624,23 +501,7 @@ convert_path(char **remote_file, gboolean trailing_asterik)
 static void
 server_browsing_helper(const char *name, uint32 m, const char *comment)
 {
-	dir_entry *new_entry;
-	new_entry = g_new (dir_entry, 1);
-    new_entry->text = dos_to_unix (g_strdup (name), 1);
-
-    new_entry->next = 0;
-
-	if (first_direntry) {
-		current_info->entries = new_entry;
-		current_info->current = new_entry;
-		first_direntry = FALSE;
-	} else {
-		current_info->current->next = new_entry;
-		current_info->current = new_entry;
-	}
-
-	bzero(&new_entry->my_stat, sizeof(struct stat));
-	new_entry->merrno = 0;
+	dir_entry *new_entry = new_dir_entry (name);
 
 	/*	show this as dir	*/
 	new_entry->my_stat.st_mode = S_IFDIR|S_IRUSR|S_IRGRP|S_IROTH;
@@ -649,7 +510,8 @@ server_browsing_helper(const char *name, uint32 m, const char *comment)
 }
 
 static BOOL
-reconnect(smbfs_connection *conn, int *retries) {
+reconnect(smbfs_connection *conn, int *retries)
+{
 	char *host;
 	DEBUG(3, ("RECONNECT\n"));
 
@@ -661,7 +523,6 @@ reconnect(smbfs_connection *conn, int *retries) {
 	cli_shutdown(conn->cli);
 
    	if (!(conn->cli = do_connect(host, conn->service))) {
-		my_errno = cli_error(conn->cli, NULL, &err, NULL);
 		message_2s (1, MSG_ERROR,
 			_(" reconnect to %s failed\n "), conn->host);
 		g_free(host);
@@ -771,10 +632,7 @@ smbfs_loaddir (opendir_info *smbfs_info)
 {
 	uint16 attribute = aDIR | aSYSTEM | aHIDDEN;
 	int servlen = strlen(smbfs_info->conn->service);
-	char *p;
-/*	int retries = 0;	*/
-	char *my_dirname = g_strdup(smbfs_info->dirname);
-	p = my_dirname;
+	char *my_dirname = smbfs_info->dirname;
 
 	DEBUG(3, ("smbfs_loaddir: dirname:%s\n", my_dirname));
 	first_direntry = TRUE;
@@ -809,35 +667,41 @@ smbfs_loaddir (opendir_info *smbfs_info)
 		}
 		goto done;
 	}
+
 	/* do regular directory listing */
 	if(strncmp(smbfs_info->conn->service, my_dirname+1, servlen) == 0) {
 		/* strip share name from dir */
-		my_dirname += servlen;
-		*my_dirname = '/';
-	}
-	convert_path(&my_dirname, TRUE);
+		char *p = my_dirname = g_strdup(my_dirname + servlen);
+		*p = '/';
+		convert_path(&my_dirname, TRUE);
+		g_free (p);
+	} else
+		convert_path(&my_dirname, TRUE);
 
 	DEBUG(6, ("smbfs_loaddir: service: %s\n", smbfs_info->conn->service));
 	DEBUG(6, ("smbfs_loaddir: cli->share: %s\n", smbfs_info->conn->cli->share));
 	DEBUG(6, ("smbfs_loaddir: calling cli_list with mask %s\n", my_dirname));
 	/* do file listing: cli_list returns number of files */
-    if (cli_list(
+	if (cli_list(
 		smbfs_info->conn->cli, my_dirname, attribute, loaddir_helper) < 0) {
 		/* cli_list returns -1 if directory empty or cannot read socket */
 		my_errno = cli_error(smbfs_info->conn->cli, NULL, &err, NULL);
+		g_free (my_dirname);
 		return 0;
 	}
-	if (strlen(my_dirname) == 0)
+	if (*(my_dirname) == 0)
 		smbfs_info->dirname = smbfs_info->conn->service;
-	g_free(p);
-/*    do_dskattr();	*/
+	g_free (my_dirname);
+/*	do_dskattr();	*/
 
 done:
 /*	current_info->parent = smbfs_info->dirname;	*/
-    smbfs_info->current = smbfs_info->entries;
+
+	smbfs_info->current = smbfs_info->entries;
 	return 1; /* 1 = ok */
 }
 
+#ifdef	SMBFS_FREE_DIR
 static void
 smbfs_free_dir (dir_entry *de)
 {
@@ -847,6 +711,7 @@ smbfs_free_dir (dir_entry *de)
     g_free (de->text);
     g_free (de);
 }
+#endif
 
 /* Explanation:
  * On some operating systems (Slowaris 2 for example)
@@ -864,14 +729,13 @@ static struct {
 /* The readdir routine loads the complete directory */
 /* It's too slow to ask the server each time */
 /* It now also sends the complete lstat information for each file */
-static struct stat *cached_lstat_info;
 static void *
 smbfs_readdir (void *info)
 {
-    char *dirent_dest;
-	opendir_info  *smbfs_info = (opendir_info *) info;
+    static char * const dirent_dest = &(smbfs_readdir_data.dent.d_name [0]);
+    opendir_info  *smbfs_info = (opendir_info *) info;
 
-	DEBUG(4, ("smbfs_readdir(%s)\n", smbfs_info->dirname));
+    DEBUG(4, ("smbfs_readdir(%s)\n", smbfs_info->dirname));
 	
     if (!smbfs_info->entries)
 	    if (!smbfs_loaddir (smbfs_info))
@@ -879,14 +743,13 @@ smbfs_readdir (void *info)
 
     if (smbfs_info->current == 0) {	/* reached end of dir entries */
 		DEBUG(3, ("smbfs_readdir: smbfs_info->current = 0\n"));
-/*	    cached_lstat_info = 0;
+#ifdef	SMBFS_FREE_DIR
 	    smbfs_free_dir (smbfs_info->entries);
-	    smbfs_info->entries = 0;	*/
+	    smbfs_info->entries = 0;
+#endif
 	    return NULL;
     }
-    dirent_dest = &(smbfs_readdir_data.dent.d_name [0]);
     pstrcpy (dirent_dest, smbfs_info->current->text);
-    cached_lstat_info = &smbfs_info->current->my_stat;
     smbfs_info->current = smbfs_info->current->next;
 
 #ifndef DIRENT_LENGTH_COMPUTED
@@ -958,6 +821,7 @@ smbfs_symlink (vfs *me, char *n1, char *n2)
 
 /* Extract the hostname and username from the path */
 /* path is in the form: hostname:user/remote-dir */
+#if 0
 static char *
 smbfs_get_host_and_username
 (char **path, char **host, char **user, int *port, char **pass)
@@ -969,14 +833,17 @@ smbfs_get_host_and_username
 
 #if 0
 	if ((p = strchr(*path, '@')))	/* user:pass@server */
-		*path = ++p;				/* dont want user:pass@ in path */
+		*path = ++p;		/* don't want user:pass@ in path */
 	if ((p = strchr(ret, '@')))	/* user:pass@server */
-		ret = ++p;				/* dont want user:pass@ in path */
+		ret = ++p;		/* don't want user:pass@ in path */
 #endif
 
 	return ret;
 }
-
+#else
+#define smbfs_get_host_and_username(path, host, user, port, pass) \
+	vfs_split_url (*path, host, user, port, pass, SMB_PORT, 0)
+#endif
 /***************************************************** 
 	return a connection to a SMB server
 	current_bucket needs to be set before calling
@@ -986,7 +853,6 @@ do_connect (char *server, char *share)
 {
 	struct cli_state *c;
 	struct nmb_name called, calling;
-	char *server_n;
 	struct in_addr ip;
 	extern struct in_addr ipzero;
 
@@ -999,14 +865,13 @@ do_connect (char *server, char *share)
 		share++;
 	}
 
-	server_n = server;
-	
 	ip = ipzero;
 
 	make_nmb_name(&calling, global_myname, 0x0, "");
 	make_nmb_name(&called , server, current_bucket->name_type, "");
 
- again:
+    for (;;) {
+
 	ip = ipzero;
 	if (current_bucket->have_ip) ip = current_bucket->dest_ip;
 
@@ -1020,10 +885,9 @@ do_connect (char *server, char *share)
 	pwd_set_cleartext(&(c->pwd), current_bucket->password);
 
 	if ((cli_set_port(c, current_bucket->port) == 0) ||
-			!cli_connect(c, server_n, &ip)) {
-		my_errno = cli_error(c, NULL, &err, NULL);
-		DEBUG(1, ("Connection to %s failed\n", server_n));
-		return NULL;
+			!cli_connect(c, server, &ip)) {
+		DEBUG(1, ("Connection to %s failed\n", server));
+		break;
 	}
 
 	if (!cli_session_request(c, &calling, &called)) {
@@ -1032,7 +896,7 @@ do_connect (char *server, char *share)
 		cli_shutdown(c);
 		if (strcmp(called.name, "*SMBSERVER")) {
 			make_nmb_name(&called , "*SMBSERVER", 0x20, "");
-			goto again;
+			continue;
 		}
 		return NULL;
 	}
@@ -1040,19 +904,17 @@ do_connect (char *server, char *share)
 	DEBUG(3, (" session request ok\n"));
 
 	if (!cli_negprot(c)) {
-		my_errno = cli_error(c, NULL, &err, NULL);
 		DEBUG(1, ("protocol negotiation failed\n"));
-		cli_shutdown(c);
-		return NULL;
+		break;
 	}
 
 	if (!cli_session_setup(c, current_bucket->user, 
 			       current_bucket->password, strlen(current_bucket->password),
 			       current_bucket->password, strlen(current_bucket->password),
 			       current_bucket->domain)) {
-		my_errno = cli_error(c, NULL, &err, NULL);
 		DEBUG(1,("session setup failed: %s\n", cli_errstr(c)));
-		return NULL;
+		authinfo_remove (server, share);
+		break;
 	}
 
 	if (*c->server_domain || *c->server_os || *c->server_type)
@@ -1063,16 +925,20 @@ do_connect (char *server, char *share)
 
 	if (!cli_send_tconX(c, share, "?????",
 			    current_bucket->password, strlen(current_bucket->password)+1)) {
-		my_errno = cli_error(c, NULL, &err, NULL);
 		DEBUG(1,("%s: tree connect failed: %s\n", share, cli_errstr(c)));
-		cli_shutdown(c);
-		return NULL;
+		break;
 	}
 
 	DEBUG(3, (" tconx ok\n"));
 
 	my_errno = 0;
 	return c;
+    }
+
+    my_errno = cli_error(c, NULL, &err, NULL);
+    cli_shutdown(c);
+    return NULL;
+    
 }
 
 static int
@@ -1099,8 +965,6 @@ get_master_browser(char **host)
 	return 0;
 }
 
-static int smbfs_get_free_bucket_init = 1;
-
 static void 
 free_bucket (smbfs_connection *bucket)
 {
@@ -1118,11 +982,6 @@ smbfs_get_free_bucket ()
 {
     int i;
     
-    if (smbfs_get_free_bucket_init) {
-		smbfs_get_free_bucket_init = 0;
-		for (i = 0; i < SMBFS_MAX_CONNECTIONS; i++)
-	    	bzero (&smbfs_connections[i], sizeof (smbfs_connection));
-    }
     for (i = 0; i < SMBFS_MAX_CONNECTIONS; i++)
 		if (!smbfs_connections [i].cli) return &smbfs_connections [i];
 
@@ -1148,7 +1007,7 @@ smbfs_get_free_bucket ()
 /* This routine keeps track of open connections */
 /* Returns a connected socket to host */
 static smbfs_connection *
-smbfs_open_link(char *host, char *path, char *user, int *port, char *this_pass)
+smbfs_open_link(char *host, char *path, const char *user, int *port, char *this_pass)
 {
     int i;
     smbfs_connection *bucket;
@@ -1174,14 +1033,10 @@ smbfs_open_link(char *host, char *path, char *user, int *port, char *this_pass)
 	}
 
 	if (got_user)
-		user = g_strdup(username);	/* global from getenv */
+		user = username;	/* global from getenv */
 
     /* Is the link actually open? */
-    if (smbfs_get_free_bucket_init) {
-        smbfs_get_free_bucket_init = 0;
-        for (i = 0; i < SMBFS_MAX_CONNECTIONS; i++)
-	    	bzero (&smbfs_connections[i], sizeof (smbfs_connection));
-    } else for (i = 0; i < SMBFS_MAX_CONNECTIONS; i++) {
+    for (i = 0; i < SMBFS_MAX_CONNECTIONS; i++) {
 		if (!smbfs_connections[i].cli)
 		    continue;
 		if ((strcmp (host, smbfs_connections [i].host) == 0) &&
@@ -1219,9 +1074,10 @@ smbfs_open_link(char *host, char *path, char *user, int *port, char *this_pass)
 	bucket->user = g_strdup(user);
 	bucket->service = g_strdup (service);
 
-	if (!strlen(host)) {	/* if blank host name, browse for servers */
+	if (!(*host)) {		/* if blank host name, browse for servers */
 		if (!get_master_browser(&host))	/* set host to ip of master browser */
 			return 0;		/* couldnt find master browser? */
+		g_free (host);
 		bucket->host = g_strdup("");	/* blank host means master browser */
 	} else
 		bucket->host = g_strdup(host);
@@ -1291,12 +1147,13 @@ smbfs_get_path(smbfs_connection **sc, char *path)
 			char *s;
 	        s = concat_dir_and_file( (*sc)->home, remote_path +3-f );
 			g_free (remote_path);
-			remote_path = s;
+		return s;
 		}
 	}
 	return remote_path;
 }
 
+#if 0
 static int
 is_error (int result, int errno_num)
 {
@@ -1306,6 +1163,7 @@ is_error (int result, int errno_num)
 		my_errno = errno_num;
     return 1;
 }
+#endif
 
 static void *
 smbfs_opendir (vfs *me, char *dirname)
@@ -1332,13 +1190,13 @@ smbfs_opendir (vfs *me, char *dirname)
 }
 
 static int
-fake_server_stat(char *server_url, char *path, struct stat *buf)
+fake_server_stat(char *server_url, const char *path, struct stat *buf)
 {
 	dir_entry *dentry;
 	char *p;
 
-	while ((p = strchr(path, '/')))
-		path++;		/* advance until last '/' */
+	if ((p = strrchr(path, '/')))
+		path = p + 1;		/* advance until last '/' */
 
 	if (!current_info->entries) {
 		if (!smbfs_loaddir(current_info));	/* browse host */
@@ -1391,15 +1249,22 @@ fake_share_stat(char *server_url, char *path, struct stat *buf)
 }
 
 /* stat a single file, get_remote_stat callback  */
-dir_entry *single_entry;
+static dir_entry *single_entry;
 static void
 statfile_helper(file_info *finfo, const char *mask)
 {
 	time_t t = finfo->mtime; /* the time is assumed to be passed as GMT */
+
+#if 0 /* single_entry is never freed now. And only my_stat is used */
 	single_entry = g_new (dir_entry, 1);
+
 	single_entry->text = dos_to_unix (g_strdup (finfo->name), 1);
 
-    single_entry->next = 0;
+	single_entry->next = 0;
+#endif
+	if (!single_entry)
+		single_entry = g_new0 (dir_entry, 1);
+
 	single_entry->my_stat.st_size = finfo->size;
 	single_entry->my_stat.st_mtime = finfo->mtime;
 	single_entry->my_stat.st_atime = finfo->atime;
@@ -1407,9 +1272,9 @@ statfile_helper(file_info *finfo, const char *mask)
 	single_entry->my_stat.st_uid = finfo->uid;
 	single_entry->my_stat.st_gid = finfo->gid;
 
-	single_entry->my_stat.st_mode =	S_IRUSR|S_IRGRP|S_IROTH |
-									S_IWUSR|S_IWGRP|S_IWOTH;
-								
+	single_entry->my_stat.st_mode =
+	    S_IRUSR|S_IRGRP|S_IROTH|S_IWUSR|S_IWGRP|S_IWOTH;
+
 /*  if (finfo->mode & aVOLID);	 nothing similar in real world */
 	if (finfo->mode & aDIR)
 		single_entry->my_stat.st_mode |= S_IFDIR;
@@ -1439,9 +1304,9 @@ get_remote_stat(smbfs_connection *sc, char *path, struct stat *buf)
 
 	convert_path(&mypath, FALSE);
 
-    if (cli_list(sc->cli, mypath, attribute, statfile_helper) < 1) {
+	if (cli_list(sc->cli, mypath, attribute, statfile_helper) < 1) {
 		my_errno = ENOENT;
-        g_free (mypath);
+		g_free (mypath);
 		return -1;	/* cli_list returns number of files */
 	}
 
@@ -1450,12 +1315,12 @@ get_remote_stat(smbfs_connection *sc, char *path, struct stat *buf)
 /* dont free here, use for smbfs_fstat() */
 /*	g_free(single_entry->text);
 	g_free(single_entry);	*/
-    g_free (mypath);
+	g_free (mypath);
 	return 0;
 }
 
 static int
-search_dir_entry (dir_entry *dentry, char *text, struct stat *buf)
+search_dir_entry (dir_entry *dentry, const char *text, struct stat *buf)
 {
 	while (dentry) {
 		if (strcmp(text, dentry->text) == 0) {
@@ -1472,16 +1337,15 @@ search_dir_entry (dir_entry *dentry, char *text, struct stat *buf)
 static int
 get_stat_info (smbfs_connection *sc, char *path, struct stat *buf)
 {
-	char *p, *mpp;
+	char *p;
 #if 0
 	dir_entry *dentry = current_info->entries;
 #endif
-	char *mypath;
-	mpp = mypath = g_strdup(path);
+	const char *mypath = path;
 
 	mypath++;				/* cut off leading '/' */
-	while ((p = strchr(mypath, '/')))
-		mypath++;			/* advance until last file/dir name */
+	if ((p = strrchr(mypath, '/')))
+		mypath = p + 1;			/* advance until last file/dir name */
 	DEBUG(3, ("get_stat_info: mypath:%s, current_info->dirname:%s\n",
 		mypath, current_info->dirname));
 #if 0
@@ -1492,28 +1356,23 @@ get_stat_info (smbfs_connection *sc, char *path, struct stat *buf)
 #endif
 	if (!single_entry)	/* when found, this will be written too */
 		single_entry = g_new (dir_entry, 1);
-	if (search_dir_entry(current_info->entries, mypath, buf) == 0)
+	if (search_dir_entry(current_info->entries, mypath, buf) == 0) {
 		return 0;
+	}
 		/* now try to identify mypath as PARENT dir */
 	{
 		char *mdp;
 		char *mydir;
 		mdp = mydir = g_strdup(current_info->dirname);
-		while ((p = strchr(mydir, '/')))
-			mydir++;				/* advance util last '/' */
-		mydir--;
-		*mydir = 0;					/* cut off last name	*/
-		mydir = mdp;				/* reset to start */
-		while ((p = strchr(mydir, '/')))
-			mydir++;				/* advance util last '/' */
+		if ((p = strrchr(mydir, '/')))
+			*p = 0;				/* advance util last '/' */
+		if ((p = strrchr(mydir, '/')))
+			mydir = p + 1;			/* advance util last '/' */
 		if (strcmp(mydir, mypath) == 0) {	/* fake a stat for ".." */
-			struct stat fake_stat;
-			bzero(&fake_stat, sizeof(struct stat));
-			fake_stat.st_mode = S_IFDIR | S_IRUSR | S_IRGRP | S_IROTH;
-			memcpy(buf, &fake_stat, sizeof(struct stat));
-			memcpy(&single_entry->my_stat, &fake_stat, sizeof(struct stat));
+			bzero(buf, sizeof(struct stat));
+			buf->st_mode = S_IFDIR | S_IRUSR | S_IRGRP | S_IROTH;
+			memcpy(&single_entry->my_stat, buf, sizeof(struct stat));
 			g_free(mdp);
-			g_free(mpp);
 			DEBUG(1, ("	PARENT:found in %s\n", current_info->dirname));
 			return 0;
 		}
@@ -1527,16 +1386,12 @@ get_stat_info (smbfs_connection *sc, char *path, struct stat *buf)
 		if (*dnp == '/')
 			dnp++;
 		else {
-			g_free(mpp);
 			return -1;
 		}
 		if (strcmp(mypath, dnp) == 0) {
-			struct stat fake_stat;
-			bzero(&fake_stat, sizeof(struct stat));
-			fake_stat.st_mode = S_IFDIR | S_IRUSR | S_IRGRP | S_IROTH;
-			memcpy(buf, &fake_stat, sizeof(struct stat));
-			memcpy(&single_entry->my_stat, &fake_stat, sizeof(struct stat));
-			g_free(mpp);
+			bzero(buf, sizeof(struct stat));
+			buf->st_mode = S_IFDIR | S_IRUSR | S_IRGRP | S_IROTH;
+			memcpy(&single_entry->my_stat, buf, sizeof(struct stat));
 			DEBUG(1, ("	CURRENT:found in %s\n", current_info->dirname));
 			return 0;
 		}
@@ -1557,7 +1412,6 @@ get_stat_info (smbfs_connection *sc, char *path, struct stat *buf)
 		return 0;
 	DEBUG(3, ("'%s' not found in server_info '%s'\n", path, current_server_info->dirname));
 	/* nothing found. get stat file info from server */
-	g_free(mpp);
 	return get_remote_stat(sc, path, buf);
 }
 
@@ -1570,12 +1424,13 @@ smbfs_chdir (vfs *me, char *path)
 	DEBUG(3, ("smbfs_chdir(path:%s)\n", path));
     if (!(remote_dir = smbfs_get_path (&sc, path)))
 		return -1;
+    g_free (remote_dir);
 	
     return 0;
 }
 
 static int 
-loaddir(vfs *me, char *path)
+loaddir(vfs *me, const char *path)
 {
 	void *info;
 	char *mypath, *p;
@@ -1604,13 +1459,14 @@ smbfs_stat (vfs *me, char *path, struct stat *buf)
 	char *remote_dir;
 	smbfs_connection *sc;
 	pstring server_url;
-	char *service, *p, *mypath, *pp;
+	char *service, *pp;
+	const char *p;
 
 	DEBUG(3, ("smbfs_stat(path:%s)\n", path));
 
 #if 0
 	if (p = strchr(path, '@'))	/* user:pass@server */
-		path = ++p;				/* dont want user:pass@ in path */
+		path = ++p;		/* don't want user:pass@ in path */
 #endif
 
 	if (!current_info) {
@@ -1623,37 +1479,32 @@ smbfs_stat (vfs *me, char *path, struct stat *buf)
 	pstrcat(server_url, current_bucket->host);
 
 	/* check if stating server */
-	p = mypath = g_strdup(path);
+	p = path;
 	if (strncmp(p, URL_HEADER, HEADER_LEN)) {
 		DEBUG(1, ("'%s' doesnt start with '%s' (length %d)\n",
 			p, URL_HEADER, HEADER_LEN));
 		return -1;
-	} else
-		p += HEADER_LEN;
+	}
+
+	p += HEADER_LEN;
 	if (*p == '/')
 		p++;
-	if (!strchr(p, '/')) {
-		g_free(mypath);
+	p = strchr(p, '/');	/* advance past next '/' */
+	if (!p) {
 		if (!current_info->server_list) {
 			if (loaddir(me, path) < 0)
 				return -1;
 		}
 		return fake_server_stat(server_url, path, buf);
 	}
-	if (strlen(p) == 0)
-		DEBUG(1, ("zero length p, mypath:'%s'", mypath));
-	p = strchr(p, '/');	/* advance past next '/' */
-	p++;
-	if (!strchr(p, '/')) {
-		g_free(mypath);
+	if (!strchr(++p, '/')) {
 		return fake_share_stat(server_url, path, buf);
 	}
-	g_free(mypath);
 
 	/* stating inside share at this point */
-    if (!(remote_dir = smbfs_get_path (&sc, path))) /* connects if necessary */
+	if (!(remote_dir = smbfs_get_path (&sc, path))) /* connects if necessary */
 		return -1;
-
+	g_free (remote_dir);
 	{
 		char *sp, *pp = path;
 		int hostlen = strlen(current_bucket->host);
@@ -1669,11 +1520,12 @@ smbfs_stat (vfs *me, char *path, struct stat *buf)
 		}
 	}
 	/* check if current_info is in share requested */
-	p = service = g_strdup(path);
-	if (strcmp(p, URL_HEADER))
+	p = path;
+	if (strncmp(p, URL_HEADER, HEADER_LEN) == 0)
 		p += HEADER_LEN;
-	if (*p== '/')
+	if (*p == '/')
 		p++;
+	p = service = g_strdup(p);
 	pp = strchr(p, '/');
 	if (pp)
 		p = ++pp;	/* advance past server name */
@@ -1681,18 +1533,19 @@ smbfs_stat (vfs *me, char *path, struct stat *buf)
 	if (pp)
 		*pp = 0;	/* cut off everthing after service name */
 	else
-		p = g_strdup(IPC);	/* browsing for services */
+		p = IPC;	/* browsing for services */
 	pp = current_info->dirname;
 	if (*pp == '/');
 		pp++;
 	if (strncmp(p, pp, strlen(p)) != 0) {
 		DEBUG(6, ("desired '%s' is not loaded, we have '%s'\n", p, pp));
-		if (loaddir(me, path) < 0)
+		if (loaddir(me, path) < 0) {
+			g_free (service);
 			return -1;
+		}
 		DEBUG(6, ("loaded dir: '%s'\n", current_info->dirname));
 	}
-	if (service)
-		g_free(service);
+	g_free(service);
 	/* stat dirs & files under shares now */
 	return get_stat_info(sc, path, buf);
 }
@@ -1729,16 +1582,18 @@ smbfs_mkdir (vfs *me, char *path, mode_t mode)
 	DEBUG(3, ("smbfs_mkdir(path:%s, mode:%d)\n", path, mode));
 	if ((remote_file = smbfs_get_path (&sc, path)) == 0)
 		return -1;
- 
+	g_free (remote_file);
 	convert_path(&path, FALSE);
 
 	if (!cli_mkdir(sc->cli, path)) {
 		my_errno = cli_error(sc->cli, NULL, &err, NULL);
-        message_3s (1, MSG_ERROR, _(" %s mkdir'ing %s "), 
+		message_3s (1, MSG_ERROR, _(" %s mkdir'ing %s "), 
 			cli_errstr(sc->cli), CNV_LANG(path));
+		g_free (path);
 		return -1;
 	} 
-    return 0;
+	g_free (path);
+	return 0;
 }
 
 static int
@@ -1750,16 +1605,19 @@ smbfs_rmdir (vfs *me, char *path)
 	DEBUG(3, ("smbfs_rmdir(path:%s)\n", path));
 	if ((remote_file = smbfs_get_path (&sc, path)) == 0)
 		return -1;
-
+	g_free (remote_file);
 	convert_path(&path, FALSE);
 
 	if (!cli_rmdir(sc->cli, path)) {
 		my_errno = cli_error(sc->cli, NULL, &err, NULL);
-        message_3s (1, MSG_ERROR, _(" %s rmdir'ing %s "), 
+		message_3s (1, MSG_ERROR, _(" %s rmdir'ing %s "), 
 			cli_errstr(sc->cli), CNV_LANG(path));
+		g_free (path);
 		return -1;
 	} 
-    return 0;
+
+	g_free (path);
+	return 0;
 }
 
 static int
@@ -1815,25 +1673,21 @@ my_forget (char *path)
     if (path[0] == '/' && path[1] == '/')
 	path += 2;
 
-    if ((p = smbfs_get_host_and_username (&path, &host, &user, &port, NULL))
-		== 0) {
-		g_free (host);
-		g_free (user);
-		return;
-    }
-    g_free (p);
-    for (i = 0; i < SMBFS_MAX_CONNECTIONS; i++) {
+    if ((p = smbfs_get_host_and_username (&path, &host, &user, &port, NULL))) {
+	g_free (p);
+	for (i = 0; i < SMBFS_MAX_CONNECTIONS; i++) {
 		if ((strcmp (host, smbfs_connections [i].host) == 0) &&
 		    (strcmp (user, smbfs_connections [i].user) == 0) &&
 		    (port == smbfs_connections [i].port)) {
 
 		    /* close socket: the child owns it now */
-			cli_shutdown(smbfs_connections [i].cli);
+		    cli_shutdown(smbfs_connections [i].cli);
 
 		    /* reopen the connection */
 		    smbfs_connections [i].cli =
 				do_connect(host, smbfs_connections[i].service);
 		}
+	}
     }
     g_free (host);
     g_free (user);
@@ -1906,45 +1760,54 @@ open_read (smbfs_handle *remote_handle, char *rname, int flags, int mode)
 static void *
 smbfs_open (vfs *me, char *file, int flags, int mode)
 {
-    char *remote_file;
-	void *ret;
+    char *remote_file, *p;
+    void *ret;
     smbfs_connection	*sc;
-    smbfs_handle		*remote_handle;
+    smbfs_handle	*remote_handle;
 
-	DEBUG(3, ("smbfs_open(file:%s, flags:%d, mode:%d)\n", file, flags, mode));
+    DEBUG(3, ("smbfs_open(file:%s, flags:%d, mode:%d)\n", file, flags, mode));
 
     if (!(remote_file = smbfs_get_path (&sc, file)))
-		return 0;
+	return 0;
 
-	convert_path(&remote_file, FALSE);
+    p = remote_file;
+    convert_path(&remote_file, FALSE);
+    g_free (p);
 
-    remote_handle			= g_new (smbfs_handle, 2);
+    remote_handle		= g_new (smbfs_handle, 2);
     remote_handle->cli		= sc->cli;
-	remote_handle->nread	= 0;
+    remote_handle->nread	= 0;
 
-	if (flags & O_CREAT)
-		ret = open_write(remote_handle, remote_file, flags, mode);
-	else
-		ret = open_read(remote_handle, remote_file, flags, mode);
-	return ret;
+    if (flags & O_CREAT)
+	ret = open_write(remote_handle, remote_file, flags, mode);
+    else
+	ret = open_read(remote_handle, remote_file, flags, mode);
+
+    g_free (remote_file);
+
+    return ret;
 }
 
 static int
 smbfs_unlink (vfs *me, char *path)
 {
     smbfs_connection *sc;
-	char *remote_file;
+    char *remote_file, *p;
 
     if ((remote_file = smbfs_get_path (&sc, path)) == 0)
-	    return -1;
- 
-	convert_path(&remote_file, FALSE);
+	return -1;
+
+    p = remote_file;
+    convert_path(&remote_file, FALSE);
+    g_free (p);
 
     if (!cli_unlink(sc->cli, remote_file)) {
-        message_3s (1, MSG_ERROR, _(" %s opening remote file %s "), 
+	message_3s (1, MSG_ERROR, _(" %s removing remote file %s "), 
 			cli_errstr(sc->cli), CNV_LANG(remote_file));
-		return -1;
+	g_free (remote_file);
+	return -1;
     }   
+    g_free (remote_file);
     return 0;
 }
 
@@ -1952,21 +1815,34 @@ static int
 smbfs_rename (vfs *me, char *a, char *b)
 {
     smbfs_connection *sc;
-	char *ra, *rb;
+    char *ra, *rb;
+    char *p;
+    int retval;
 
     if ((ra = smbfs_get_path (&sc, a)) == 0)
-	    return -1;
+	return -1;
  
-    if ((rb = smbfs_get_path (&sc, b)) == 0)
-	    return -1;
- 
-	convert_path(&ra, FALSE);
-	convert_path(&rb, FALSE);
+    if ((rb = smbfs_get_path (&sc, b)) == 0) {
+	g_free (ra);
+	return -1;
+    }
 
-    if (!cli_rename(sc->cli, ra, rb)) {
-        message_2s (1, MSG_ERROR, _(" %s renaming files\n"), 
+    p = ra;
+    convert_path(&ra, FALSE);
+    g_free (p);
+    p = rb;
+    convert_path(&rb, FALSE);
+    g_free (p);
+
+    retval = cli_rename(sc->cli, ra, rb);
+
+    g_free (ra);
+    g_free (rb);
+
+    if (!retval) {
+	message_2s (1, MSG_ERROR, _(" %s renaming files\n"), 
 			cli_errstr(sc->cli));
-		return -1;
+	return -1;
     }   
     return 0;
 }
@@ -1982,15 +1858,15 @@ smbfs_fstat (void *data, struct stat *buf)
 	if (single_entry)
 		memcpy(buf, &single_entry->my_stat, sizeof(struct stat));
 	else {	/* single_entry not set up: bug */
+		my_errno = EFAULT;
 		return -EFAULT;
-		my_errno = -EFAULT;
 	}
 	return 0;
 }
 
 vfs vfs_smbfs_ops = {
     NULL,	/* This is place of next pointer */
-    N_("netbios over tcp/ip"),
+    "smbfs",
     F_NET,	/* flags */
     "smb:",	/* prefix */
     NULL,	/* data */
