@@ -20,9 +20,10 @@
 
 /* Namespace: vfs_tarfs_ops */
 
-#include "xdirentry.h"
+#include <config.h>
 #include <errno.h>
 
+#include "xdirentry.h"
 #include "utilvfs.h"
 
 #include "../src/dialog.h"	/* For MSG_ERROR */
@@ -188,7 +189,7 @@ typedef enum {
     STATUS_BADCHECKSUM,
     STATUS_SUCCESS,
     STATUS_EOFMARK,
-    STATUS_EOF,
+    STATUS_EOF
 } ReadStatus;
 /*
  * Return 1 for success, 0 if the checksum is bad, EOF on eof,
@@ -433,7 +434,7 @@ static int open_archive (vfs *me, vfs_s_super *archive, char *name, char *op)
     return 0;
 }
 
-void *tar_super_check(vfs *me, char *archive_name, char *op)
+static void *tar_super_check(vfs *me, char *archive_name, char *op)
 {
     static struct stat stat_buf;
     if (mc_stat (archive_name, &stat_buf))
@@ -441,7 +442,7 @@ void *tar_super_check(vfs *me, char *archive_name, char *op)
     return &stat_buf;
 }
 
-int tar_super_same(vfs *me, struct vfs_s_super *parc, char *archive_name, char *op, void *cookie)
+static int tar_super_same(vfs *me, struct vfs_s_super *parc, char *archive_name, char *op, void *cookie)
 {	
     struct stat *archive_stat = cookie;	/* stat of main archive */
 
@@ -519,7 +520,7 @@ static struct vfs_s_data tarfs_data = {
 vfs vfs_tarfs_ops =
 {
     NULL,	/* This is place of next pointer */
-    "TApe aRchiver decompressor",
+    "tarfs",
     0,		/* flags */
     "utar",	/* prefix */
     &tarfs_data,
