@@ -15,7 +15,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include <config.h>
 #include <unistd.h>
@@ -239,12 +239,7 @@ void rpc_add_get_callback (int sock, void (*cback)(int))
     sock_callbacks = new;
 }
 
-#if defined(IS_AIX) || defined(linux) || defined(SCO_FLAVOR) \
-    || defined(__QNX__) || defined(__FreeBSD__) || defined(__bsdi__)
 static void sig_pipe (int unused)
-#else
-static void sig_pipe (void)
-#endif
 {
     got_sigpipe = 1;
 }
