@@ -11,7 +11,7 @@
                1997 Norbert Warmuth.
 	       2000 Pavel Machek
    
-   $Id: undelfs.c,v 1.13 2000/04/10 12:23:00 pavel Exp $
+   $Id: undelfs.c,v 1.15 2001/06/11 21:58:58 proskin Exp $
  
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License
@@ -25,7 +25,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 /* Assumptions:
  *
@@ -681,7 +681,7 @@ undelfs_init(vfs *me) {
 
 vfs vfs_undelfs_ops = {
     NULL,	/* This is place of next pointer */
-    N_("Undelete filesystem for ext2"),
+    "undelfs",
     0,	/* flags */
     "undel:",	/* prefix */
     NULL,	/* data */
