@@ -5,7 +5,7 @@
                1995 Jakub Jelinek
 	       1998 Pavel Machek
    
-   $Id: vfs.c,v 1.60 2000/05/25 14:47:48 pavel Exp $
+   $Id: vfs.c,v 1.76 2001/08/19 16:11:39 proskin Exp $
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License
@@ -19,7 +19,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 /* Warning: funtions like extfs_lstat() have right to destroy any
  * strings you pass to them. This is acutally ok as you g_strdup what
@@ -42,11 +42,6 @@
 #include <sys/types.h>
 #include <fcntl.h>
 #include <signal.h>
-#ifdef SCO_FLAVOR
-#include <sys/timeb.h>	/* alex: for struct timeb definition */
-#endif /* SCO_FLAVOR */
-#include <time.h>
-#include <sys/time.h>
 
 #include "utilvfs.h"
 
@@ -59,6 +54,7 @@
 #include "../src/dialog.h"
 #endif
 
+#include "xdirentry.h"
 #include "vfs.h"
 #include "extfs.h"		/* FIXME: we should not know anything about our modules */
 #include "names.h"
@@ -66,6 +62,10 @@
 #   include "tcputil.h"
 #endif
 
+#ifdef	VFS_STANDALONE
+#undef	WITH_SMBFS
+#endif
+
 extern int get_other_type (void);
 
 int vfs_timeout = 60; /* VFS timeout in seconds */
@@ -113,7 +113,7 @@ get_bucket (void)
 /* vfs_local_ops needs to be the first one */
 static vfs *vfs_list = &vfs_local_ops;
 
-int
+static int
 vfs_register (vfs *vfs)
 {
     if (!vfs)
@@ -129,7 +129,7 @@ vfs_register (vfs *vfs)
     return 1;
 }
 
-vfs *
+static vfs *
 vfs_type_from_op (char *path)
 {
     vfs *vfs;
@@ -153,7 +153,7 @@ vfs_type_from_op (char *path)
    suffix from last path component). 
    Returns a malloced string which has to be freed. */
 char *
-vfs_strip_suffix_from_filename (char *filename)
+vfs_strip_suffix_from_filename (const char *filename)
 {
     vfs *vfs;
     char *semi;
@@ -182,7 +182,7 @@ vfs_strip_suffix_from_filename (char *filename)
 }
 
 static int
-path_magic (char *path)
+path_magic (const char *path)
 {
     struct stat buf;
 
@@ -242,7 +242,7 @@ vfs_split (char *path, char **inpath, char **op)
     return ret;
 }
 
-vfs *
+static vfs *
 vfs_rosplit (char *path)
 {
     char *semi;
@@ -303,13 +303,16 @@ void
 vfs_addstamp (vfs *v, vfsid id, struct vfs_stamping *parent)
 {
     if (v != &vfs_local_ops && id != (vfsid)-1){
-        struct vfs_stamping *stamp, *st1;
+        struct vfs_stamping *stamp;
+	struct vfs_stamping *last_stamp = NULL;
         
-        for (stamp = stamps; stamp != NULL; st1 = stamp, stamp = stamp->next)
+        for (stamp = stamps; stamp != NULL; stamp = stamp->next) {
             if (stamp->v == v && stamp->id == id){
 		gettimeofday(&(stamp->time), NULL);
                 return;
 	    }
+	    last_stamp = stamp;
+	}
         stamp = g_new (struct vfs_stamping, 1);
         stamp->v = v;
         stamp->id = id;
@@ -329,10 +332,13 @@ vfs_addstamp (vfs *v, vfsid id, struct vfs_stamping *parent)
         gettimeofday (&(stamp->time), NULL);
         stamp->next = 0;
 
-	if (stamps)
-	    st1->next = stamp;
-	else
+	if (stamps) {
+	    /* Add to the end */
+	    last_stamp->next = stamp;
+	} else {
+	    /* Add first element */
     	    stamps = stamp;
+	}
     }
 }
 
@@ -589,16 +595,14 @@ MC_HANDLEOP (fstat, (int handle, struct stat *buf), (vfs_info (handle), buf))
  * You must g_strdup whatever this function returns, static buffers are in use
  */
 
-char *
+static char *
 mc_return_cwd (void)
 {
     char *p;
     struct stat my_stat, my_stat2;
 
     if (!vfs_rosplit (current_dir)){
-	static char buffer[MC_MAXPATHLEN];
-
-	p = get_current_wd (buffer, MC_MAXPATHLEN);
+	p = g_get_current_dir ();
 	if (!p)  /* One of the directories in the path is not readable */
 	    return current_dir;
 
@@ -609,7 +613,7 @@ mc_return_cwd (void)
 	    my_stat.st_dev != my_stat2.st_dev ||
 	    !cd_symlinks){
 	    g_free (current_dir);
-	    current_dir = g_strdup (p);
+	    current_dir = p;
 	    return p;
 	} /* Otherwise we return current_dir below */
     } 
@@ -686,7 +690,7 @@ char *
 vfs_canon (const char *path)
 {
     if (!path)
-	vfs_die("Can not canonize NULL");
+	vfs_die("Cannot canonicalize NULL");
 
     /* Tilde expansion */
     if (*path == '~'){ 
@@ -1060,8 +1064,8 @@ mc_def_getlocalcopy (vfs *vfs, char *filename)
     fdin = mc_open (filename, O_RDONLY);
     if (fdin == -1)
         return NULL;
-    tmp = tempnam (NULL, "mclocalcopy");
-    fdout = open (tmp, O_CREAT|O_WRONLY|O_TRUNC|O_EXCL, 0600);
+
+    fdout = mc_mkstemps (&tmp, "mclocalcopy", NULL);
     if (fdout == -1)
 	goto fail;
     while ((i = mc_read (fdin, buffer, sizeof (buffer))) > 0){
@@ -1124,8 +1128,11 @@ mc_def_ungetlocalcopy (vfs *vfs, char *filename, char *local, int has_changed)
 	if (i == -1)
 	    goto failed;
 
-        if (close (fdin)==-1)
+        if (close (fdin)==-1) {
+	    fdin = -1;
 	    goto failed;
+	}
+	fdin = -1;
         if (mc_close (fdout)==-1) {
 	    fdout = -1;
 	    goto failed;
@@ -1137,8 +1144,8 @@ mc_def_ungetlocalcopy (vfs *vfs, char *filename, char *local, int has_changed)
 
  failed:
     message_1s (1, _("Changes to file lost"), filename);
-    if (fdout) mc_close(fdout);
-    if (fdin) close(fdin);
+    if (fdout!=-1) mc_close(fdout);
+    if (fdin!=-1) close(fdin);
     unlink (local);
     g_free (local);
     return -1;
@@ -1147,20 +1154,21 @@ mc_def_ungetlocalcopy (vfs *vfs, char *filename, char *local, int has_changed)
 int
 mc_ungetlocalcopy (const char *pathname, char *local, int has_changed)
 {
+    int return_value = 0;
     char *path = vfs_canon (pathname);
     vfs *vfs = vfs_type (path);
 
-    vfs->ungetlocalcopy ? (*vfs->ungetlocalcopy)(vfs, vfs_name (path), local, has_changed) :
-                          mc_def_ungetlocalcopy (vfs, vfs_name (path), local, has_changed);
-    /* FIXME: errors are ignored at this point */
+    return_value = vfs->ungetlocalcopy ? 
+            (*vfs->ungetlocalcopy)(vfs, vfs_name (path), local, has_changed) :
+            mc_def_ungetlocalcopy (vfs, vfs_name (path), local, has_changed);
     g_free (path);
-    return 0;
+    return return_value;
 }
 
 /*
  * Hmm, as timeout is minute or so, do we need to care about usecs?
  */
-inline int
+static inline int
 timeoutcmp (struct timeval *t1, struct timeval *t2)
 {
     return ((t1->tv_sec < t2->tv_sec)
@@ -1320,6 +1328,8 @@ vfs_split_text (char *p)
     char *original = p;
     int  numcols;
 
+    memset (columns, 0, sizeof (columns));
+
     for (numcols = 0; *p && numcols < MAXCOLS; numcols++){
 	while (*p == ' ' || *p == '\r' || *p == '\n'){
 	    *p = 0;
@@ -1353,7 +1363,7 @@ is_dos_date(char *str)
 static int
 is_week (char *str, struct tm *tim)
 {
-    static char *week = "SunMonTueWedThuFriSat";
+    char *week = "SunMonTueWedThuFriSat";
     char *pos;
 
     if((pos=strstr(week, str)) != NULL){
@@ -1367,7 +1377,7 @@ is_week (char *str, struct tm *tim)
 static int
 is_month (char *str, struct tm *tim)
 {
-    static char *month = "JanFebMarAprMayJunJulAugSepOctNovDec";
+    char *month = "JanFebMarAprMayJunJulAugSepOctNovDec";
     char *pos;
     
     if((pos=strstr(month, str)) != NULL){
@@ -1445,7 +1455,7 @@ vfs_parse_filetype (char c)
     }
 }
 
-int vfs_parse_filemode (char *p)
+int vfs_parse_filemode (const char *p)
 {	/* converts rw-rw-rw- into 0666 */
     int res = 0;
     switch (*(p++)){
@@ -1583,7 +1593,7 @@ int vfs_parse_filedate(int idx, time_t *t)
 
 	/* This is a special case for ctime() or Mon DD YYYY hh:mm */
 	if(is_num (idx) && (columns[idx+1][0]) &&
-	    ((got_year = is_year(columns[idx], &tim)) || is_time(columns[idx], &tim)))
+	    ((got_year |= is_year(columns[idx], &tim)) || is_time(columns[idx], &tim)))
 		idx++; /* time & year or reverse */
 	} /* only time or date */
     }
@@ -1608,16 +1618,17 @@ int vfs_parse_filedate(int idx, time_t *t)
 }
 
 int
-vfs_parse_ls_lga (char *p, struct stat *s, char **filename, char **linkname)
+vfs_parse_ls_lga (const char *p, struct stat *s, char **filename, char **linkname)
 {
     int idx, idx2, num_cols;
     int i;
-    char *p_copy;
-    
+    char *p_copy = NULL;
+    char *t = NULL;
+    const char *line = p;
+
     if (strncmp (p, "total", 5) == 0)
         return 0;
 
-    p_copy = g_strdup(p);
     if ((i = vfs_parse_filetype(*(p++))) == -1)
         goto error;
 
@@ -1644,12 +1655,11 @@ vfs_parse_ls_lga (char *p, struct stat *s, char **filename, char **linkname)
             p++;
     }
 
-    g_free(p_copy);
     p_copy = g_strdup(p);
-    num_cols = vfs_split_text (p);
+    num_cols = vfs_split_text (p_copy);
 
     s->st_nlink = atol (columns [0]);
-    if (s->st_nlink < 0)
+    if (s->st_nlink <= 0)
         goto error;
 
     if (!is_num (1))
@@ -1729,22 +1739,13 @@ vfs_parse_ls_lga (char *p, struct stat *s, char **filename, char **linkname)
     if (((S_ISLNK (s->st_mode) || 
         (num_cols == idx + 3 && s->st_nlink > 1))) /* Maybe a hardlink? (in extfs) */
         && idx2){
-	int p;
-	char *s;
 	    
 	if (filename){
-	    s = g_strndup (p_copy + column_ptr [idx], column_ptr [idx2] - column_ptr [idx] - 1);
-	    *filename = s;
+	    *filename = g_strndup (p + column_ptr [idx], column_ptr [idx2] - column_ptr [idx] - 1);
 	}
 	if (linkname){
-	    s = g_strdup (p_copy + column_ptr [idx2+1]);
-	    p = strlen (s) - 1;
-	    if (s [p] == '\r' || s [p] == '\n')
-		s [p] = 0;
-	    if (s [p-1] == '\r' || s [p-1] == '\n')
-		s [p-1] = 0;
-		
-	    *linkname = s;
+	    t = g_strdup (p + column_ptr [idx2+1]);
+	    *linkname = t;
 	}
     } else {
 	/* Extract the filename from the string copy, not from the columns
@@ -1754,22 +1755,22 @@ vfs_parse_ls_lga (char *p, struct stat *s, char **filename, char **linkname)
 	    /* 
 	    *filename = g_strdup (columns [idx++]);
 	    */
-	    int p;
-	    char *s;
-	    
-	    s = g_strdup (p_copy + column_ptr [idx++]);
-	    p = strlen (s) - 1;
-	    /* g_strchomp(); */
-	    if (s [p] == '\r' || s [p] == '\n')
-	        s [p] = 0;
-	    if (s [p-1] == '\r' || s [p-1] == '\n')
-		s [p-1] = 0;
-	    
-	    *filename = s;
+
+	    t = g_strdup (p + column_ptr [idx]);
+	    *filename = t;
 	}
 	if (linkname)
 	    *linkname = NULL;
     }
+
+    if (t) {
+	int p = strlen (t);
+	if ((--p > 0) && (t [p] == '\r' || t [p] == '\n'))
+	    t [p] = 0;
+	if ((--p > 0) && (t [p] == '\r' || t [p] == '\n'))
+	    t [p] = 0;
+    }
+
     g_free (p_copy);
     return 1;
 
@@ -1778,12 +1779,12 @@ error:
       static int errorcount = 0;
 
       if (++errorcount < 5) {
-	message_1s (1, _("Could not parse:"), p_copy);
+	message_1s (1, _("Could not parse:"), p_copy ? p_copy : line);
       } else if (errorcount == 5)
 	message_1s (1, _("More parsing errors will be ignored."), _("(sorry)"));
     }
 
-    if (p_copy != p)		/* Carefull! */
+    if (p_copy)
 	g_free (p_copy);
     return 0;
 }
@@ -1830,6 +1831,8 @@ vfs_translate_url (char *url)
 {
     if (strncmp (url, "ftp://", 6) == 0)
         return  g_strconcat ("/#ftp:", url + 6, NULL);
+    else if (strncmp (url, "a:", 2) == 0)
+        return  g_strdup ("/#a");
     else
         return g_strdup (url);
 }
