@@ -1,17 +1,23 @@
 #ifndef __VFS_H
 #define __VFS_H
 
-#include <config.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <dirent.h>
 
-#if !defined(SCO_FLAVOR) || !defined(_SYS_SELECT_H) || defined(IS_AIX)
-#	include <sys/time.h>	/* alex: this redefines struct timeval */
-#  ifdef IS_AIX
-#       include <time.h>
+#ifdef HAVE_SYS_TIMEB_H
+#  include <sys/timeb.h>
+#endif
+#ifdef TIME_WITH_SYS_TIME
+#  include <sys/time.h>
+#  include <time.h>
+#else
+#  ifdef HAVE_SYS_TIME_H
+#    include <sys/time.h>
+#  else
+#    include <time.h>
 #  endif
-#endif /* SCO_FLAVOR */
+#endif
 
 #ifdef HAVE_UTIME_H
 #    include <utime.h>
@@ -157,7 +163,7 @@ struct utimbuf {
     vfsid vfs_ncs_getid (vfs *nvfs, char *dir, struct vfs_stamping **par);
     void vfs_rm_parents (struct vfs_stamping *stamp);
     char *vfs_path (char *path);
-    char *vfs_strip_suffix_from_filename (char *filename);
+    char *vfs_strip_suffix_from_filename (const char *filename);
     char *vfs_canon (const char *path);
     char *mc_get_current_wd (char *buffer, int bufsize);
     int vfs_current_is_local (void);
@@ -177,9 +183,9 @@ struct utimbuf {
     void vfs_add_noncurrent_stamps (vfs *, vfsid, struct vfs_stamping *);
     void vfs_add_current_stamps (void);
     void vfs_free_resources(char *path);
-    void vfs_timeout_handler ();
+    void vfs_timeout_handler (void);
     void vfs_expire (int);
-    int vfs_timeouts ();
+    int vfs_timeouts (void);
 
     void vfs_fill_names (void (*)(char *));
     char *vfs_translate_url (char *);
@@ -333,16 +339,32 @@ struct utimbuf {
 
 /* These functions are meant for use by vfs modules */
 
-extern int vfs_parse_ls_lga (char *p, struct stat *s, char **filename, char **linkname);
+extern int vfs_parse_ls_lga (const char *p, struct stat *s, char **filename, char **linkname);
 extern int vfs_split_text (char *p);
 extern int vfs_parse_filetype (char c);
-extern int vfs_parse_filemode (char *p);
+extern int vfs_parse_filemode (const char *p);
 extern int vfs_parse_filedate(int idx, time_t *t);
 
 extern void vfs_die (char *msg);
 extern char *vfs_get_password (char *msg);
-extern char *vfs_split_url (char *path, char **host, char **user, int *port, char **pass,
-					int default_port, int flags);
+extern char *vfs_split_url (const char *path, char **host, char **user, 
+			    int *port, char **pass, int default_port, int flags);
+
+#ifdef WITH_SMBFS
+/* Interface for requesting SMB credentials.  */
+struct smb_authinfo {
+    char *host;
+    char *share;
+    char *domain;
+    char *user;
+    char *password;
+};
+
+struct smb_authinfo *
+vfs_smb_get_authinfo (const char *host, const char *share, const char *domain,
+		      const char *user);
+#endif /* WITH_SMBFS */
+
 #define URL_DEFAULTANON 1
 #define URL_NOSLASH 2
 extern void vfs_print_stats (char *fs_name, char *action, char *file_name, int have, int need);
@@ -384,9 +406,7 @@ extern void mc_vfs_done( void );
    listed above and O_APPEND */
 
 #if (O_ALL & O_APPEND)
-#ifdef __GNUC__
-#warning Unexpected problem with flags, O_LINEAR disabled, contact pavel@ucw.cz
-#endif
+ #warning "Unexpected problem with flags, O_LINEAR disabled, contact pavel@ucw.cz"
 #define O_LINEAR 0
 #define IS_LINEAR(a) 0
 #define NO_LINEAR(a) a
