@@ -1,9 +1,8 @@
 #ifndef DIRENTRY_H
 #define DIRENTRY_H
 
-/* $Id: xdirentry.h,v 1.12 2000/10/31 15:43:49 pavel Exp $ */
+/* $Id: xdirentry.h,v 1.15 2001/08/03 10:15:17 andrew Exp $ */
 
-#include <config.h>
 #include <stdio.h>
 #include <ctype.h>
 #include <string.h>
@@ -105,7 +104,6 @@ typedef struct vfs_s_super {
 	    char *proxy;
 	    int failed_on_login;	/* used to pass the failure reason to upper levels */
 	    int use_proxy;		/* use a proxy server */
-	    int result_pending;
 	    int use_source_route;
 	    int use_passive_connection;
 	    int remote_is_amiga;       /* No leading slash allowed for AmiTCP (Amiga) */
@@ -254,8 +252,6 @@ int vfs_s_get_line_interruptible (vfs *me, char *buffer, int size, int fd);
 
 /* misc */
 int vfs_s_retrieve_file (vfs *me, struct vfs_s_inode *ino);
-/* alloc temp name which can be safely free'd with g_free() */
-char *g_tempnam( const char *dir, const char *prefix );
 
 #if 0
 /* If non-null, FREE */
